import { NgModule } from '@angular/core';
import { BrowserModule } from '@angular/platform-browser';
import { FormsModule } from '@angular/forms';
// Blaise imports
import { AriaDirective, BlaiseCoreModule, ModelService, StringFieldConverterService } from '@blaise/core';
// Custom imports
import { AppComponent } from './app.component';
import { CustomModelService } from './services/custom-model/custom-model.service';
import { APP_BASE_HREF } from '@angular/common';
import { HTTP_INTERCEPTORS } from '@angular/common/http';

// DEMO 01: Clock component
import { ClockComponent } from './components/clock/clock.component';

// DEMO 01: TimeConverter component
import { TimeConverterComponent } from './components/time-converter/time-converter.component';

// DEMO 02: Custom Field converter service
import { CustomConverterService } from './services/custom-converter/custom-converter.service';

// DEMO 03: Add a custom non Blaise directive
import { FancyHoverDirective } from './directives/fancy-hover.directive';

// DEMO 04: Add a custom Blaise directive
import { CustomAriaDirective } from './directives/custom-aria.directive';

// DEMO 05: Add a custom non Blaise interceptor
import { TokenInterceptor } from './interceptors/token.interceptor';

@NgModule({
    imports: [BrowserModule, FormsModule, BlaiseCoreModule],
    declarations: [AppComponent, ClockComponent, TimeConverterComponent, FancyHoverDirective, CustomAriaDirective],
    providers: [
        { provide: ModelService, useClass: CustomModelService },
        { provide: StringFieldConverterService, useClass: CustomConverterService },
        { provide: AriaDirective, useClass: CustomAriaDirective },
        { provide: HTTP_INTERCEPTORS, useClass: TokenInterceptor, multi: true },
        { provide: APP_BASE_HREF, useValue: '/clock/debug' }
    ],
    bootstrap: [AppComponent]
})
export class AppModule {}
