import { ChangeDetectionStrategy, ChangeDetectorRef, Component, EventEmitter, Input, Output } from '@angular/core';
import { DateTime } from 'luxon';
import { TimeService } from 'src/app/services/time/time.service';

@Component({
    selector: 'app-time-converter',
    templateUrl: './time-converter.component.html',
    styleUrls: ['./time-converter.component.scss'],
    changeDetection: ChangeDetectionStrategy.OnPush
})
export class TimeConverterComponent {
    /**
     * input decorator to receive the selectedTime
     */
    @Input() selectedTime: string;
    /**
     * output decorator for emitting converted time event
     */
    @Output() convertedTimeEvent = new EventEmitter<DateTime>();

    /**
     * Propertues
     */
    public timezones: string[];
    public selectedTimezone: string;

    /**
     * constructor of the component injects the used dependencies
     * @param cd
     * @param timeService
     */
    constructor(
        private cd: ChangeDetectorRef,
        private timeService: TimeService
    ) {
        // fetch data once
        this.timeService.get().subscribe((response) => {
            this.timezones = response;
            this.cd.detectChanges();
        });
    }

    /**
     * set the selected timezone and convert the date/time string
     * @param args
     */
    setSelectedTimezone = (args: string) => {
        const date = DateTime.fromISO(this.selectedTime);
        const rezoned = date.setZone(args);
        this.convertedTimeEvent.emit(rezoned);
    };
}
