import { AriaOptions } from '@blaise/core';

import { Component, DebugElement } from '@angular/core';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { By } from '@angular/platform-browser';
import { CustomAriaDirective } from './custom-aria.directive';

@Component({
    template: ` <input
            type="text"
            [bl5Aria] />
        <input type="text" />`
})
class TestComponent {}

// empty test to check whether Karma works
describe('HighlightDirective', () => {
    let fixture: ComponentFixture<TestComponent>;
    let inputEls: DebugElement[];

    beforeEach(() => {
        fixture = TestBed.configureTestingModule({
            declarations: [CustomAriaDirective, TestComponent]
        }).createComponent(TestComponent);

        fixture.detectChanges(); // initial binding

        // all elements with an attached HighlightDirective
        inputEls = fixture.debugElement.queryAll(By.directive(CustomAriaDirective));
    });

    it('should return exactly 1 element', () => {
        expect(inputEls.length).toBe(1);
    });

    // DebugElement.providerTokens
    // attached CustomAriaDirective should be listed in the providerTokens
    it('should have `CustomAriaDirective` in 1st <h2> providerTokens', () => {
        expect(inputEls[0].providerTokens).toContain(CustomAriaDirective);
    });

    it('should append prefix when value doesnt start with IBUC', () => {
        const label = 'My test message';
        // get the directive
        const dir = inputEls[0].injector.get(CustomAriaDirective) as CustomAriaDirective;

        dir.ariaOptions = new AriaOptions();
        dir.ariaOptions.label = label;

        fixture.detectChanges();

        expect(inputEls[0].attributes['aria-label']).toBe(`IBUC 2023 - ${label}`);
    });

    it('should do nothing when value already start with IBUC', () => {
        const label = 'IBUC - My test message';
        // get the directive
        const dir = inputEls[0].injector.get(CustomAriaDirective) as CustomAriaDirective;

        dir.ariaOptions = new AriaOptions();
        dir.ariaOptions.label = label;

        fixture.detectChanges();

        expect(inputEls[0].attributes['aria-label']).toBe(label);
    });
});
