import { Injectable } from '@angular/core';
import { ModelService, CustomPropertyService, IBaseControl, IBaseComponentViewModel2 } from '@blaise/core';

// DEMO 01
import { CustomConstants } from './../../constants';
import { ClockComponent } from 'src/app/components/clock/clock.component';
/**
 * Custom model service class
 */
@Injectable({
    providedIn: 'root'
})
export class CustomModelService extends ModelService {
    /**
     * Custom model service class constructor
     * @param {CustomPropertyService} customPropertyService
     */
    public constructor(private customPropertyService: CustomPropertyService) {
        super();
    }

    /**
     * Provides an extension to the Blaise default model service's create child function.
     * @param {IBaseControl} control
     * @param {string} parent
     * @returns {IBaseComponentViewModel}
     */
    public override createChild(control: IBaseControl, parent: string): IBaseComponentViewModel2 {
        const child: IBaseComponentViewModel2 = super.createChild(control, parent);
        // DEMO 01
        if (control && this.customPropertyService.hasCustomProperties(control)) {
            // if applicable, set custom type here
            if (this.customPropertyService.hasCustomProperty(control, CustomConstants.CustomPropertyName)) {
                const showClock = this.customPropertyService.getValueForCustomProperty(control, CustomConstants.CustomPropertyName);

                if (showClock) {
                    child.type = ClockComponent;
                }
            }
        }

        return child;
    }
}
