declare global {
    /**
     * Object constructor extension
     */
    interface ObjectConstructor {
        /**
         * This isWithOwnProperty() method perform a type check cast using the given object's hasOwnProperty method and a given property
         * @param {Object} obj the object to test and convert
         * @param {PropertyKey} prop the property to validate the object on
         * @param {any} valueForType (optional) the type of the property on the object
         * @returns {boolean} true if the given object contains the given property key AND performs a type cast
         * ```
         * // instead of
         * if (Object.prototype.hasOwnProperty.call(foo, 'bar')) {
         *     const fooWithBar = obj as IFooWithBar;
         *     const bar = fooWithBar.bar || foo['bar'];
         * }
         * // you can now do
         * if (Object.isWithOwnProperty(foo, 'bar')) {
         *     const bar = foo.bar;
         * }
         * ```
         */
        isWithOwnProperty<X extends {}, Y extends PropertyKey, T>(obj: X, prop: Y, valueForType?: T): obj is X & Record<Y, T>;
    }
}
export {};
