declare global {
    /**
     * String constructor extension
     */
    interface StringConstructor {
        /**
         * String.isNullOrEmpty performs a value undefined, null and length check
         * @param {Unknown<string>} str the string value to check
         * @returns {boolean} true if the given value is not null or undefined and has a length of at least 1
         */
        isNullOrEmpty(str: Unknown<string>): boolean;
        /**
         * String.hasValue performs a value length check and type check cast
         * @param {Unknown<string>} str the string value to check
         * @returns {boolean} true if the given value is not null or undefined and has a length of at least 1
         */
        hasValue(str: Unknown<string>): str is string;
        /**
         * returns an empty string
         */
        readonly EMPTY: '';
    }
    /**
     * String type extension
     */
    interface String {
        /**
         * String.isEmpty performs a value length check
         * @returns {boolean} true if the given value has a length of at least 1
         */
        isEmpty(this: string): boolean;
    }
}
export {};
