import './array';
import './object';
import './string';
declare global {
    /**
     * allows type T or null
     */
    type Nullable<T> = T | null;
    /**
     * allows type T or undefined
     */
    type Optional<T> = T | undefined;
    /**
     * allows type T, null or undefined
     */
    type Unknown<T> = Optional<Nullable<T>>;
    /**
     * Array type extension
     */
    interface Array<T> {
        /**
         * Array.isEmpty performs an array length check
         * @returns {boolean} true if the array on which the action is performed has a length of at least 1
         */
        isEmpty(arr: Array<T>): boolean;
    }
    /**
     * Object type extension
     */
    interface Object {
        /**
         * This isWithOwnProperty() method perform a type check cast using the given object's hasOwnProperty method and a given property
         * @param {Object} obj the object to test and convert
         * @param {PropertyKey} prop the property to validate the object on
         * @param {any} valueForType (optional) the type of the property on the object
         * @returns {boolean} true if the given object contains the given property key AND performs a type cast
         */
        isWithOwnProperty<X, Y extends PropertyKey, T>(obj: X, prop: Y, valueForType?: T): obj is X & Record<Y, T>;
    }
    /**
     * String type extension
     */
    interface String {
        /**
         * String.isEmpty performs a value length check
         * @returns {boolean} true if the given value has a length of at least 1
         */
        isEmpty(str: string): boolean;
    }
}
export {};
