import { IAction, ICloseDialogAction, ICurrentPageAction, IDialNumberAction, IFinishAction, IFirstPageAction, IGoToParallelEndAction, ILastPageAction, INextPageAction, IPreviousPageAction, IPrintAction, IQuitAction, ISaveAction, IStopAllAudioAction, IStopAllVideoAction, IUndoAllEditsAction } from '../../../typedefinitions/models/actions/IAction';
import { IAssignFieldAction } from '../../../typedefinitions/models/actions/IAssignFieldAction';
import { IAssignFieldPropertyAction } from '../../../typedefinitions/models/actions/IAssignFieldPropertyAction';
import { IConditionalAction } from '../../../typedefinitions/models/actions/IConditionalAction';
import { IConditionFieldAction, IFirstFieldAction, ILastFieldAction, INextFieldAction, IPreviousFieldAction } from '../../../typedefinitions/models/actions/IConditionFieldAction';
import { IControlAction, ICopyToClipboardAction, ICutToClipboardAction, IPasteFromClipboardAction, IPauseAudioAction, IPauseVideoAction, IPlayAudioAction, IPlayPauseAudioAction, IPlayPauseVideoAction, IPlayStopAudioAction, IPlayStopVideoAction, IPlayVideoAction, ISetFocusAction, IStartTimerAction, IStopAudioAction, IStopTimerAction, IStopVideoAction } from '../../../typedefinitions/models/actions/IControlAction';
import { ICustomAction } from '../../../typedefinitions/models/actions/ICustomAction';
import { IForEachAction } from '../../../typedefinitions/models/actions/IForEachAction';
import { IGoToBlockFieldAction, IGoToFieldAction, IGoToFieldPropertyAction } from '../../../typedefinitions/models/actions/IGoToFieldAction';
import { IGoToGroupAction } from '../../../typedefinitions/models/actions/IGoToGroupAction';
import { IGoToUriAction } from '../../../typedefinitions/models/actions/IGoToUriAction';
import { IProcedureCallAction } from '../../../typedefinitions/models/actions/IProcedureCallAction';
import { ISendKeysAction } from '../../../typedefinitions/models/actions/ISendKeysAction';
import { ISetControlPropertyAction } from '../../../typedefinitions/models/actions/ISetControlPropertyAction';
import { ISetDataEntrySettingsAction } from '../../../typedefinitions/models/actions/ISetDataEntrySettingsAction';
import { ISetDeviceFeaturesAction } from '../../../typedefinitions/models/actions/ISetDeviceFeaturesAction';
import { ISetLanguageAction } from '../../../typedefinitions/models/actions/ISetLanguageAction';
import { ISetLayoutSetAction } from '../../../typedefinitions/models/actions/ISetLayoutSetAction';
import { ISetLayoutSetGroupAction } from '../../../typedefinitions/models/actions/ISetLayoutSetGroupAction';
import { ISetParallelAction } from '../../../typedefinitions/models/actions/ISetParallelAction';
import { ISetStyleAction } from '../../../typedefinitions/models/actions/ISetStyleAction';
import { IShowCustomPageAction } from '../../../typedefinitions/models/actions/IShowCustomPageAction';
import { IShowDialogAction } from '../../../typedefinitions/models/actions/IShowDialogAction';
import { IStartSurveyAction } from '../../../typedefinitions/models/actions/IStartSurveyAction';
import { ISuppressSignalAction } from '../../../typedefinitions/models/actions/ISuppressSignalAction';
import { IToggleVisibilityAction } from '../../../typedefinitions/models/actions/IToggleVisibilityAction';
import { IAuditTrailAction, IServerEventAction, IValuesAction } from '../../../typedefinitions/models/actions/IValuesAction';
import { ActionKind } from '../../../typedefinitions/enums/ActionKind';
/**
 * Abstract action class
 */
export declare abstract class Action implements IAction {
    /**
     * Action kind readonly property
     */
    readonly Kind: ActionKind;
    /**
     * Action class constructor
     * @param Kind action kind
     */
    protected constructor(
    /**
     * Action kind readonly property
     */
    Kind: ActionKind);
    /**
     * Next page action type cast check
     * @param action
     */
    static isNextPageAction(action: IAction): action is INextPageAction;
    /**
     * Previous page action type cast check
     * @param action
     */
    static isPreviousPageAction(action: IAction): action is IPreviousPageAction;
    /**
     * First page action type cast check
     * @param action
     */
    static isFirstPageAction(action: IAction): action is IFirstPageAction;
    /**
     * Last page action type cast check
     * @param action
     */
    static isLastPageAction(action: IAction): action is ILastPageAction;
    /**
     * Current page action type cast check
     * @param action
     */
    static isCurrentPageAction(action: IAction): action is ICurrentPageAction;
    /**
     * Next field action type cast check
     * @param action
     */
    static isNextFieldAction(action: IAction | IConditionFieldAction): action is INextFieldAction;
    /**
     * Save action type cast check
     * @param action
     */
    static isSaveAction(action: IAction): action is ISaveAction;
    /**
     * Quit action type cast check
     * @param action
     */
    static isQuitAction(action: IAction): action is IQuitAction;
    /**
     * Set language action type cast check
     * @param action
     */
    static isSetLanguageAction(action: IAction): action is ISetLanguageAction;
    /**
     * Set layout-set group action type cast check
     * @param action
     */
    static isSetLayoutSetGroupAction(action: IAction): action is ISetLayoutSetGroupAction;
    /**
     * Set layout-set action type cast check
     * @param action
     */
    static isSetLayoutSetAction(action: IAction): action is ISetLayoutSetAction;
    /**
     * Set data-entry settings action type cast check
     * @param action
     */
    static isSetDataEntrySettingsAction(action: IAction): action is ISetDataEntrySettingsAction;
    /**
     * Set parallel action type cast check
     * @param action
     */
    static isSetParallelAction(action: IAction): action is ISetParallelAction;
    /**
     * Go to field action type cast check
     * @param action
     */
    static isGoToFieldAction(action: IAction): action is IGoToFieldAction;
    /**
     * Suppress signal action type cast check
     * @param action
     */
    static isSuppressSignalAction(action: IAction): action is ISuppressSignalAction;
    /**
     * Assign field action type cast check
     * @param action
     */
    static isAssignFieldAction(action: IAction): action is IAssignFieldAction;
    /**
     * Set style action type cast check
     * @param action
     */
    static isSetStyleAction(action: IAction): action is ISetStyleAction;
    /**
     * Set device features action type cast check
     * @param action
     */
    static isSetDeviceFeaturesAction(action: IAction): action is ISetDeviceFeaturesAction;
    /**
     * Show custom page action type cast check
     * @param action
     */
    static isShowCustomPageAction(action: IAction): action is IShowCustomPageAction;
    /**
     * Toggle visibility action type cast check
     * @param action
     */
    static isToggleVisibilityAction(action: IAction): action is IToggleVisibilityAction;
    /**
     * Go to block field action type cast check
     * @param action
     */
    static isGoToBlockFieldAction(action: IAction): action is IGoToBlockFieldAction;
    /**
     * Go to group action type cast check
     * @param action
     */
    static isGoToGroupAction(action: IAction): action is IGoToGroupAction;
    /**
     * Go to uri action type cast check
     * @param action
     */
    static isGoToUriAction(action: IAction): action is IGoToUriAction;
    /**
     * Start survey action type cast check
     * @param action
     */
    static isStartSurveyAction(action: IAction): action is IStartSurveyAction;
    /**
     * Procedure call action type cast check
     * @param action
     */
    static isProcedureCallAction(action: IAction): action is IProcedureCallAction;
    /**
     * Conditional action type cast check
     * @param action
     */
    static isConditionalAction(action: IAction): action is IConditionalAction;
    /**
     * Set control property action type cast check
     * @param action
     */
    static isSetControlPropertyAction(action: IAction): action is ISetControlPropertyAction;
    /**
     * Custom action type cast check
     * @param action
     */
    static isCustomAction(action: IAction): action is ICustomAction;
    /**
     * Previous field action type cast check
     * @param action
     */
    static isPreviousFieldAction(action: IAction): action is IPreviousFieldAction;
    /**
     * Print action type cast check
     * @param action
     */
    static isPrintAction(action: IAction): action is IPrintAction;
    /**
     * Finish action type cast check
     * @param action
     */
    static isFinishAction(action: IAction): action is IFinishAction;
    /**
     * Assign field property action type cast check
     * @param action
     */
    static isAssignFieldPropertyAction(action: IAction): action is IAssignFieldPropertyAction;
    /**
     * Go to parallel end action type cast check
     * @param action
     */
    static isGoToParallelEndAction(action: IAction): action is IGoToParallelEndAction;
    /**
     * Dial number action type cast check
     * @param action
     */
    static isDialNumberAction(action: IAction): action is IDialNumberAction;
    /**
     * Start timer action type cast check
     * @param action
     */
    static isStartTimerAction(action: IAction | IControlAction): action is IStartTimerAction;
    /**
     * Stop timer action type cast check
     * @param action
     */
    static isStopTimerAction(action: IAction | IControlAction): action is IStopTimerAction;
    /**
     * Set focus action type cast check
     * @param action
     */
    static isSetFocusAction(action: IAction | IControlAction): action is ISetFocusAction;
    /**
     * Close dialog action type cast check
     * @param action
     */
    static isCloseDialogAction(action: IAction): action is ICloseDialogAction;
    /**
     * Play audio action type cast check
     * @param action
     */
    static isPlayAudioAction(action: IAction | IControlAction): action is IPlayAudioAction;
    /**
     * Pause audio action type cast check
     * @param action
     */
    static isPauseAudioAction(action: IAction | IControlAction): action is IPauseAudioAction;
    /**
     * Play/pause audio action type cast check
     * @param action
     */
    static isPlayPauseAudioAction(action: IAction | IControlAction): action is IPlayPauseAudioAction;
    /**
     * Play/stop audio action type cast check
     * @param action
     */
    static isPlayStopAudioAction(action: IAction | IControlAction): action is IPlayStopAudioAction;
    /**
     * Stop audio action type cast check
     * @param action
     */
    static isStopAudioAction(action: IAction | IControlAction): action is IStopAudioAction;
    /**
     * Stop all audio action type cast check
     * @param action
     */
    static isStopAllAudioAction(action: IAction): action is IStopAllAudioAction;
    /**
     * Play video action type cast check
     * @param action
     */
    static isPlayVideoAction(action: IAction | IControlAction): action is IPlayVideoAction;
    /**
     * Pause video action type cast check
     * @param action
     */
    static isPauseVideoAction(action: IAction | IControlAction): action is IPauseVideoAction;
    /**
     * Play/pause video action type cast check
     * @param action
     */
    static isPlayPauseVideoAction(action: IAction | IControlAction): action is IPlayPauseVideoAction;
    /**
     * Play/stop video action type cast check
     * @param action
     */
    static isPlayStopVideoAction(action: IAction | IControlAction): action is IPlayStopVideoAction;
    /**
     * Stop video action type cast check
     * @param action
     */
    static isStopVideoAction(action: IAction | IControlAction): action is IStopVideoAction;
    /**
     * Stop all video action type cast check
     * @param action
     */
    static isStopAllVideoAction(action: IAction): action is IStopAllVideoAction;
    /**
     * Send keys action type cast check
     * @param action
     */
    static isSendKeysAction(action: IAction): action is ISendKeysAction;
    /**
     * Show dialog action type cast check
     * @param action
     */
    static isShowDialogAction(action: IAction): action is IShowDialogAction;
    /**
     * First field action type cast check
     * @param action
     */
    static isFirstFieldAction(action: IAction | IConditionFieldAction): action is IFirstFieldAction;
    /**
     * Audit-trail action type cast check
     * @param action
     */
    static isAuditTrailAction(action: IAction | IValuesAction): action is IAuditTrailAction;
    /**
     * Last field action type cast check
     * @param action
     */
    static isLastFieldAction(action: IAction | IConditionFieldAction): action is ILastFieldAction;
    /**
     * Cut to clipboard action type cast check
     * @param action
     */
    static isCutToClipboardAction(action: IAction | IControlAction): action is ICutToClipboardAction;
    /**
     * Copy to clipboard action type cast check
     * @param action
     */
    static isCopyToClipboardAction(action: IAction | IControlAction): action is ICopyToClipboardAction;
    /**
     * Paste from clipboard action type cast check
     * @param action
     */
    static isPasteFromClipboardAction(action: IAction | IControlAction): action is IPasteFromClipboardAction;
    /**
     * Go to field property action type cast check
     * @param action
     */
    static isGoToFieldPropertyAction(action: IAction): action is IGoToFieldPropertyAction;
    /**
     * Server event action type cast check
     * @param action
     */
    static isServerEventAction(action: IAction | IValuesAction): action is IServerEventAction;
    /**
     * Undo all edits action type cast check
     * @param action
     */
    static isUndoAllEditsAction(action: IAction): action is IUndoAllEditsAction;
    /**
     * For each action type cast check
     * @param action
     */
    static isForEachAction(action: IAction): action is IForEachAction;
    /**
     * Condition field action type cast check
     * @param action
     */
    static isConditionFieldAction(action: IAction): action is IConditionFieldAction;
    /**
     * Control action type cast check
     * @param action
     */
    static isControlAction(action: IAction): action is IControlAction;
    /**
     * Assign field (property) action type cast check
     * @param action
     */
    static isAssignAction(action: IAction): action is IAssignFieldAction | IAssignFieldPropertyAction;
    /**
     * Assign field (property) action type cast check
     * @param action
     */
    static isValuesAction(action: IAction): action is IAuditTrailAction | IServerEventAction;
}
