import { Action } from './action';
import { EventService } from '../../services/event.service';
import { IActionsEventHandler } from '../../../typedefinitions/models/IActionsEventHandler';
/**
 * Action event handler class allows the execution of multiple class defined actions
 */
export declare class ActionsEventHandler implements IActionsEventHandler {
    private eventService;
    /**
     * Name of the actions event handler
     */
    Name: string;
    /**
     * List of actions
     */
    Actions?: Action[] | undefined;
    /**
     * Optional property containing the id of the control for which the actions event handler is defined
     */
    controlId?: string | undefined;
    /**
     * Flag indication if any actions are defined
     */
    get hasActions(): boolean;
    /**
     * Action event handler class constructor
     * @param eventService
     * @param Name Name of the actions event handler
     * @param Actions (optional) List of actions
     * @param controlId (optional) property containing the id of the control for which the actions event handler is defined
     */
    constructor(eventService: EventService, 
    /**
     * Name of the actions event handler
     */
    Name: string, 
    /**
     * List of actions
     */
    Actions?: Action[] | undefined, 
    /**
     * Optional property containing the id of the control for which the actions event handler is defined
     */
    controlId?: string | undefined);
    /**
     * Executes all class defined actions
     */
    handleActions(): void;
}
