import { Action } from './action';
import { IConditionalAction } from '../../../typedefinitions/models/actions/IConditionalAction';
import { IExpression } from '../../../typedefinitions/models/expressions/IExpression';
import { IAction } from '../../../typedefinitions/models/actions/IAction';
/**
 * Conditional action class
 */
export declare class ConditionalAction extends Action implements IConditionalAction {
    /**
     * Condition boolean property
     */
    Condition: boolean;
    /**
     * Condition expression property
     */
    ConditionAsExpression: IExpression;
    /**
     * ThenBranch condition confirmed result actions property
     */
    ThenBranch: IAction[];
    /**
     * ElseBranch condition declined result actions property
     */
    ElseBranch: IAction[];
    /**
     * Conditional action class constructor
     * @param Condition true/false value as calculated and set by the server (has to be recalculated on execution)
     * @param ConditionAsExpression Expression by which to determine which action branch to use
     * @param ThenBranch Actions to execute when the condition or condition expression result is true
     * @param ElseBranch Actions to execute when the condition or condition expression result is false
     */
    constructor(
    /**
     * Condition boolean property
     */
    Condition: boolean, 
    /**
     * Condition expression property
     */
    ConditionAsExpression: IExpression, 
    /**
     * ThenBranch condition confirmed result actions property
     */
    ThenBranch: IAction[], 
    /**
     * ElseBranch condition declined result actions property
     */
    ElseBranch: IAction[]);
}
