import { Action } from './action';
import { IControlAction } from '../../../typedefinitions/models/actions/IControlAction';
import { ActionKind } from '../../../typedefinitions/enums/ActionKind';
type ControlActionKind = ActionKind.ToggleVisibility | ActionKind.StartTimer | ActionKind.StopTimer | ActionKind.SetFocus | ActionKind.PlayAudio | ActionKind.PauseAudio | ActionKind.PlayPauseAudio | ActionKind.PlayStopAudio | ActionKind.StopAudio | ActionKind.PlayVideo | ActionKind.PauseVideo | ActionKind.PlayPauseVideo | ActionKind.PlayStopVideo | ActionKind.StopVideo | ActionKind.CutToClipboard | ActionKind.CopyToClipboard | ActionKind.PasteFromClipboard;
/**
 * Abstract control action class
 */
export declare abstract class ControlAction extends Action implements IControlAction {
    /**
     * RootID Control root id property
     */
    RootID: string;
    /**
     * ControlID Control id property
     */
    ControlID: string;
    /**
     * Control action class constructor
     * @param kind Control action action kind. Any of the following action kinds: `ToggleVisibility`, `StartTimer`, `StopTimer`, `SetFocus`, `PlayAudio`, `PauseAudio`, `PlayPauseAudio`, `StopAudio`, `PlayVideo`, `PauseVideo`, `PlayPauseVideo`, `StopVideo`, `CutToClipboard`, `CopyToClipboard` or `PasteFromClipboard`
     * @param RootID Control's root id
     * @param ControlID Control id
     */
    protected constructor(kind: ControlActionKind, 
    /**
     * RootID Control root id property
     */
    RootID: string, 
    /**
     * ControlID Control id property
     */
    ControlID: string);
}
export {};
