import { Action } from './action';
import { IStartLocalProcessAction } from '../../../typedefinitions/models/actions/IStartLocalProcessAction';
import { WindowStyle as WindowStyleKind } from '../../../typedefinitions/enums/WindowStyle';
/**
 * Start local process action class
 */ export declare class StartLocalProcessAction extends Action implements IStartLocalProcessAction {
    /**
     * FileName specifies the fully qualified file name of the local process to start
     */
    FileName: Optional<string>;
    /**
     * Arguments specifies the arguments to pass to the local process
     */
    Arguments: Optional<string>;
    /**
     * WorkingDirectory specifies the working directory for the local process
     */
    WorkingDirectory: Optional<string>;
    /**
     * WaitForExit flag, when true, the application waits for the local process to end before continuing
     */
    WaitForExit: boolean;
    /**
     * WindowStyle If the process has a GUI, this property sets the process' window style
     */
    WindowStyle: WindowStyleKind;
    /**
     * Start local process action class constructor
     */
    constructor(
    /**
     * FileName specifies the fully qualified file name of the local process to start
     */
    FileName: Optional<string>, 
    /**
     * Arguments specifies the arguments to pass to the local process
     */
    Arguments: Optional<string>, 
    /**
     * WorkingDirectory specifies the working directory for the local process
     */
    WorkingDirectory: Optional<string>, 
    /**
     * WaitForExit flag, when true, the application waits for the local process to end before continuing
     */
    WaitForExit?: boolean, 
    /**
     * WindowStyle If the process has a GUI, this property sets the process' window style
     */
    WindowStyle?: WindowStyleKind);
}
