import { Type } from '@angular/core';
import { BaseComponent } from '../components/base/base.component';
import { IBaseControl } from '../../typedefinitions/models/controls/IBaseControl';
import { IColor } from '../../typedefinitions/models/IColor';
import { IGridUnit } from '../../typedefinitions/models/IGridUnit';
import { GridType } from '../../typedefinitions/enums/GridType';
/**
 * The base view component class
 */
export declare class BaseViewComponent {
    /**
     * Component type derived from the base component
     */
    type: Type<BaseComponent<IBaseControl>>;
    /**
     *
     */
    dataObject: IBaseControl;
    /**
     * identification string of the parent container control
     */
    parentId: Nullable<string>;
    /**
     * parent container type
     */
    parentType?: string | undefined;
    /**
     * columns info (optional, for table row control only)
     */
    columns?: IGridUnit[] | undefined;
    /**
     * row color (optional, for table row control only)
     */
    rowColor?: IColor | undefined;
    /**
     * row index value (optional, for table row control only)
     */
    rowIndex?: number | undefined;
    /**
     * Flag indicating if the row is an even (true) or odd (false) row (optional, for table row control only)
     */
    isEvenRow?: boolean | undefined;
    /**
     * Grid line visibility
     */
    gridLines?: GridType | undefined;
    /**
     * grid line width
     */
    gridLineWidth?: number | undefined;
    /**
     * grid line color
     */
    gridLineColor?: IColor | undefined;
    /***
     * The base view component class constructor
     * @param type Component type derived from the base component
     * @param dataObject derived from the IBaseControl
     * @param parentId identification string of the container control
     * @param parentType parent container type
     * @param columns (optional, for table row control only)
     * @param rowColor (optional, for table row control only)
     * @param rowIndex (optional, for table row control only)
     * @param isEvenRow (optional, for table row control only)
     * @param gridLines (optional, for table row control only)
     * @param gridLineWidth (optional, for table row control only)
     * @param gridLineColor (optional, for table row control only)
     */
    constructor(
    /**
     * Component type derived from the base component
     */
    type: Type<BaseComponent<IBaseControl>>, 
    /**
     *
     */
    dataObject: IBaseControl, 
    /**
     * identification string of the parent container control
     */
    parentId: Nullable<string>, 
    /**
     * parent container type
     */
    parentType?: string | undefined, 
    /**
     * columns info (optional, for table row control only)
     */
    columns?: IGridUnit[] | undefined, 
    /**
     * row color (optional, for table row control only)
     */
    rowColor?: IColor | undefined, 
    /**
     * row index value (optional, for table row control only)
     */
    rowIndex?: number | undefined, 
    /**
     * Flag indicating if the row is an even (true) or odd (false) row (optional, for table row control only)
     */
    isEvenRow?: boolean | undefined, 
    /**
     * Grid line visibility
     */
    gridLines?: GridType | undefined, 
    /**
     * grid line width
     */
    gridLineWidth?: number | undefined, 
    /**
     * grid line color
     */
    gridLineColor?: IColor | undefined);
}
