import { IBaseControl } from '../../../../typedefinitions/models/controls/IBaseControl';
import { IMenuItem } from '../../../../typedefinitions/models/IMenuItem';
/**
 * Data-structure that holds the values of the execution result of a client side property
 */
export declare class ClientSidePropertyResult {
    /**
     * old value
     */
    oldValue: any;
    /**
     * new value
     */
    newValue: any;
    /**
     * property name
     */
    propertyName: string;
    /**
     * base control
     */
    control: IBaseControl | IMenuItem;
    /**
     * The client side property result class constructor
     * @param {any} oldValue the previous value
     * @param {any} newValue the new value
     * @param {string} propertyName the control's property for which the value has changed
     * @param {IBaseControl|IMenuItem} control the control for which a property value has changed
     */
    constructor(
    /**
     * old value
     */
    oldValue: any, 
    /**
     * new value
     */
    newValue: any, 
    /**
     * property name
     */
    propertyName: string, 
    /**
     * base control
     */
    control: IBaseControl | IMenuItem);
    /**
     * Flag indicating if the client side property has changed the value.
     * @returns {boolean} true when the old value does not equal the new value, otherwise false.
     */
    hasChanged(): boolean;
}
