import { PropertyValue } from './property-value';
import { IConditionalPropertyValue } from '../../../../typedefinitions/models/server/client-side/property-values/IConditionalPropertyValue';
import { IExpression } from '../../../../typedefinitions/models/expressions/IExpression';
import { IPropertyValue } from '../../../../typedefinitions/models/server/client-side/property-values/IPropertyValue';
/**
 * Conditional property-value class
 */
export declare class ConditionalPropertyValue extends PropertyValue implements IConditionalPropertyValue {
    /**
     * Condition Expression to evaluate to determine which actions to execute
     */
    readonly Condition: IExpression;
    /**
     * ThenValue Property value to use on a truthy condition expression evaluation result
     */
    readonly ThenValue: IPropertyValue;
    /**
     * ElseValue Property value to use on a truthy condition expression evaluation result
     */
    readonly ElseValue: IPropertyValue;
    /**
     * Conditional property-value class constructor
     * @param Condition Expression to evaluate to determine which actions to execute
     * @param ThenValue Property value to use on a truthy condition expression evaluation result
     * @param ElseValue Property value to use on a truthy condition expression evaluation result
     */
    constructor(
    /**
     * Condition Expression to evaluate to determine which actions to execute
     */
    Condition: IExpression, 
    /**
     * ThenValue Property value to use on a truthy condition expression evaluation result
     */
    ThenValue: IPropertyValue, 
    /**
     * ElseValue Property value to use on a truthy condition expression evaluation result
     */
    ElseValue: IPropertyValue);
}
