import { PropertyValue } from '../property-value';
import { IBooleanPropertyValue } from '../../../../../typedefinitions/models/server/client-side/property-values/IBooleanPropertyValue';
import { IConstantPropertyValue } from '../../../../../typedefinitions/models/server/client-side/property-values/IConstantPropertyValue';
import { IDoublePropertyValue } from '../../../../../typedefinitions/models/server/client-side/property-values/IDoublePropertyValue';
import { IErrorKindFilterPropertyValue } from '../../../../../typedefinitions/models/server/client-side/property-values/IErrorKindFilterPropertyValue';
import { IFontPropertyValue } from '../../../../../typedefinitions/models/server/client-side/property-values/IFontPropertyValue';
import { IRichTextPropertyValue } from '../../../../../typedefinitions/models/server/client-side/property-values/IRichTextPropertyValue';
import { IStringPropertyValue } from '../../../../../typedefinitions/models/server/client-side/property-values/IStringPropertyValue';
import { ConstantPropertyType } from '../../../../../typedefinitions/enums/ConstantPropertyType';
/**
 * Abstract constant property-value class
 */
export declare abstract class ConstantPropertyValue<T = any> extends PropertyValue implements IConstantPropertyValue<T> {
    /**
     * Value Constant property-value value property
     */
    readonly Value: T;
    /**
     * ConstantType Readonly constant property-value constant property type property
     */
    readonly ConstantType: ConstantPropertyType;
    /**
     * Constant property-value class constructor
     * @param Value Constant property-value value
     * @param ConstantType Constant property-value constant property type `BooleanPropertyValue, DoublePropertyValue, FontPropertyValue, IntegerPropertyValue, RichTextPropertyValue, StringPropertyValue, any ConstantPropertyValue
     */
    protected constructor(
    /**
     * Value Constant property-value value property
     */
    Value: T, 
    /**
     * ConstantType Readonly constant property-value constant property type property
     */
    ConstantType: ConstantPropertyType);
    /**
     * Boolean property value type cast check
     * @param propertyValue
     * @returns propertyValue as a IBooleanPropertyValue when the property value's value type is Boolean.
     */
    static isBooleanPropertyValue(propertyValue: IConstantPropertyValue): propertyValue is IBooleanPropertyValue;
    /**
     * Double property value type cast check
     * @param propertyValue
     * @returns propertyValue as a IDoublePropertyValue when the property value's value type is Double.
     */
    static isDoublePropertyValue(propertyValue: IConstantPropertyValue): propertyValue is IDoublePropertyValue;
    /**
     * Error kind filter property value type cast check
     * @param propertyValue
     * @returns propertyValue as a IErrorKindFilterPropertyValue when the property value's constant type is ErrorKindFilter.
     */
    static isErrorKindFilterPropertyValue(propertyValue: IConstantPropertyValue): propertyValue is IErrorKindFilterPropertyValue;
    /**
     * Font property value type cast check
     * @param propertyValue
     * @returns propertyValue as a IFontPropertyValue when the property value's constant type is Font.
     */
    static isFontPropertyValue(propertyValue: IConstantPropertyValue): propertyValue is IFontPropertyValue;
    /**
     * Rich-text property value type cast check
     * @param propertyValue
     * @returns propertyValue as a IRichTextPropertyValue when the property value's constant type is RichText.
     */
    static isRichTextPropertyValue(propertyValue: IConstantPropertyValue): propertyValue is IRichTextPropertyValue;
    /**
     * String property value type cast check
     * @param propertyValue
     * @returns propertyValue as a IStringPropertyValue when the property value's constant type is String.
     */
    static isStringPropertyValue(propertyValue: IConstantPropertyValue): propertyValue is IStringPropertyValue;
}
