import { ConstantPropertyValue } from '../constant-property-value';
import { IStylableConstantPropertyValue } from '../../../../../../typedefinitions/models/server/client-side/property-values/IStylableConstantPropertyValue';
import { IBrushPropertyValue } from '../../../../../../typedefinitions/models/server/client-side/property-values/IBrushPropertyValue';
import { IColorPropertyValue } from '../../../../../../typedefinitions/models/server/client-side/property-values/IColorPropertyValue';
import { ICornerRadiusPropertyValue } from '../../../../../../typedefinitions/models/server/client-side/property-values/ICornerRadiusPropertyValue';
import { IGridTypePropertyValue } from '../../../../../../typedefinitions/models/server/client-side/property-values/IGridTypePropertyValue';
import { IHorizontalAlignmentPropertyValue } from '../../../../../../typedefinitions/models/server/client-side/property-values/IHorizontalAlignmentPropertyValue';
import { IIntegerPropertyValue } from '../../../../../../typedefinitions/models/server/client-side/property-values/IIntegerPropertyValue';
import { ILineStylePropertyValue } from '../../../../../../typedefinitions/models/server/client-side/property-values/ILineStylePropertyValue';
import { IScrollBarsPropertyValue } from '../../../../../../typedefinitions/models/server/client-side/property-values/IScrollBarsPropertyValue';
import { IScrollBarVisibilityPropertyValue } from '../../../../../../typedefinitions/models/server/client-side/property-values/IScrollBarVisibilityPropertyValue';
import { IThicknessPropertyValue } from '../../../../../../typedefinitions/models/server/client-side/property-values/IThicknessPropertyValue';
import { IUnitPropertyValue } from '../../../../../../typedefinitions/models/server/client-side/property-values/IUnitPropertyValue';
import { IVerticalAlignmentPropertyValue } from '../../../../../../typedefinitions/models/server/client-side/property-values/IVerticalAlignmentPropertyValue';
import { IVisibilityPropertyValue } from '../../../../../../typedefinitions/models/server/client-side/property-values/IVisibilityPropertyValue';
import { ConstantPropertyType } from '../../../../../../typedefinitions/enums/ConstantPropertyType';
/**
 * Abstract stylable constant property-value class
 */
export declare abstract class StylableConstantPropertyValue<T = any> extends ConstantPropertyValue<T> implements IStylableConstantPropertyValue<T> {
    /**
     * Stylable constant property-value class constructor
     * @param value stylable constant property-value value
     * @param constantType stylable constant property-value constant property type `BrushPropertyValue, ColorPropertyValue, CornerRadiusPropertyValue, GridTypePropertyValue, HorizontalAlignmentPropertyValue, LineStylePropertyValue, ScrollBarsPropertyValue, ScrollBarVisibilityPropertyValue, ThicknessPropertyValue, UnitPropertyValue, VerticalAlignmentPropertyValue, VisibilityPropertyValue`
     */
    protected constructor(value: T, constantType: ConstantPropertyType);
    /**
     * Brush property value type cast check
     * @param propertyValue
     */
    static isBrushPropertyValue(propertyValue: IStylableConstantPropertyValue): propertyValue is IBrushPropertyValue;
    /**
     * Color property value type cast check
     * @param propertyValue
     */
    static isColorPropertyValue(propertyValue: IStylableConstantPropertyValue): propertyValue is IColorPropertyValue;
    /**
     * Corner radius property value type cast check
     * @param propertyValue
     */
    static isCornerRadiusPropertyValue(propertyValue: IStylableConstantPropertyValue): propertyValue is ICornerRadiusPropertyValue;
    /**
     * Grid-type property value type cast check
     * @param propertyValue
     */
    static isGridTypePropertyValue(propertyValue: IStylableConstantPropertyValue): propertyValue is IGridTypePropertyValue;
    /**
     * Horizontal alignment property value type cast check
     * @param propertyValue
     */
    static isHorizontalAlignmentPropertyValue(propertyValue: IStylableConstantPropertyValue): propertyValue is IHorizontalAlignmentPropertyValue;
    /**
     * Integer property value type cast check
     * @param propertyValue
     */
    static isIntegerPropertyValue(propertyValue: IStylableConstantPropertyValue): propertyValue is IIntegerPropertyValue;
    /**
     * Line style property value type cast check
     * @param propertyValue
     */
    static isLineStylePropertyValue(propertyValue: IStylableConstantPropertyValue): propertyValue is ILineStylePropertyValue;
    /**
     * Scrollbars property value type cast check
     * @param propertyValue
     */
    static isScrollBarsPropertyValue(propertyValue: IStylableConstantPropertyValue): propertyValue is IScrollBarsPropertyValue;
    /**
     * Scrollbar visibility property value type cast check
     * @param propertyValue
     */
    static isScrollBarVisibilityPropertyValue(propertyValue: IStylableConstantPropertyValue): propertyValue is IScrollBarVisibilityPropertyValue;
    /**
     * Thickness property value type cast check
     * @param propertyValue
     */
    static isThicknessPropertyValue(propertyValue: IStylableConstantPropertyValue): propertyValue is IThicknessPropertyValue;
    /**
     * Unit property value type cast check
     * @param propertyValue
     */
    static isUnitPropertyValue(propertyValue: IStylableConstantPropertyValue): propertyValue is IUnitPropertyValue;
    /**
     * Vertical alignment property value type cast check
     * @param propertyValue
     */
    static isVerticalAlignmentPropertyValue(propertyValue: IStylableConstantPropertyValue): propertyValue is IVerticalAlignmentPropertyValue;
    /**
     * Visibility property value type cast check
     * @param propertyValue
     */
    static isVisibilityPropertyValue(propertyValue: IStylableConstantPropertyValue): propertyValue is IVisibilityPropertyValue;
}
