import { IPropertyValue } from '../../../../typedefinitions/models/server/client-side/property-values/IPropertyValue';
import { IConditionalPropertyValue } from '../../../../typedefinitions/models/server/client-side/property-values/IConditionalPropertyValue';
import { IExpressionPropertyValue } from '../../../../typedefinitions/models/server/client-side/property-values/IExpressionPropertyValue';
import { IConstantPropertyValue } from '../../../../typedefinitions/models/server/client-side/property-values/IConstantPropertyValue';
import { PropertyValueKind } from '../../../../typedefinitions/enums/PropertyValueKind';
/**
 * Abstract property-value class
 */
export declare abstract class PropertyValue implements IPropertyValue {
    /**
     * Kind readonly property-value kind property
     */
    readonly Kind: PropertyValueKind;
    /**
     * Property-value class constructor
     * @param Kind property-value kind `ConditionalPropertyValue, ExpressionPropertyValue, ConstantPropertyValue`
     */
    protected constructor(
    /**
     * Kind readonly property-value kind property
     */
    Kind: PropertyValueKind);
    /**
     * Conditional property value type cast check
     * @param propertyValue property value
     * @returns propertyValue as a IConditionalPropertyValue when the property value's value type is Condition.
     */
    static isConditionalPropertyValue(propertyValue: IPropertyValue): propertyValue is IConditionalPropertyValue;
    /**
     * Expression property value type cast check
     * @param propertyValue property value
     * @returns propertyValue as a IExpressionPropertyValue when the property value's value type is Expression.
     */
    static isExpressionPropertyValue(propertyValue: IPropertyValue): propertyValue is IExpressionPropertyValue;
    /**
     * Constant property value type cast check
     * @param propertyValue property value
     * @returns propertyValue as a IConstantPropertyValue when the property value's value type is Constant.
     */
    static isConstantPropertyValue(propertyValue: IPropertyValue): propertyValue is IConstantPropertyValue;
}
