import { IClientSideRule } from '../../../../typedefinitions/models/server/client-side/rules/IClientSideRule';
import { IFieldAssignmentRule } from '../../../../typedefinitions/models/server/client-side/rules/IFieldAssignmentRule';
import { IConditionalRule } from '../../../../typedefinitions/models/server/client-side/rules/IConditionalRule';
import { RuleKind } from '../../../../typedefinitions/enums/RuleKind';
/**
 * Abstract client side rule class
 */ export declare abstract class ClientSideRule implements IClientSideRule {
    /**
     * Rule kind readonly property
     */
    readonly Kind: RuleKind;
    /**
     * Client side rule class constructor
     * @param Kind client side rule kind
     */
    protected constructor(
    /**
     * Rule kind readonly property
     */
    Kind: RuleKind);
    /**
     * Field assignment rule type cast check
     * @param {IClientSideRule} rule client side rule
     * @returns {boolean} true if the rule is a field assignment rule, otherwise false
     */
    static isFieldAssignmentRule(rule: IClientSideRule): rule is IFieldAssignmentRule;
    /**
     * Conditional rule type cast check
     * @param {IClientSideRule} rule client side rule
     * @returns {boolean} true if the rule is a conditional rule, otherwise false
     */
    static isConditionalRule(rule: IClientSideRule): rule is IConditionalRule;
}
