import { ClientSideRule } from './client-side-rule';
import { IConditionalRule } from '../../../../typedefinitions/models/server/client-side/rules/IConditionalRule';
import { IClientSideRule } from '../../../../typedefinitions/models/server/client-side/rules/IClientSideRule';
import { IExpression } from '../../../../typedefinitions/models/expressions/IExpression';
/**
 * Conditional client side rule class
 */ export declare class ConditionalRule extends ClientSideRule implements IConditionalRule {
    /**
     * Condition expression to evaluate to determine which client side rules to execute
     */
    Condition: IExpression;
    /**
     * ThenBranch Client side rules to execute on a truthy condition expression evaluation result
     */
    ThenBranch: IClientSideRule[];
    /**
     * ThenBranch Client side rules to execute on a falsy condition expression evaluation result
     */
    ElseBranch: IClientSideRule[];
    /**
     * Conditional client side rule class constructor
     * @param Condition expression to evaluate to determine which actions to execute
     * @param ThenBranch Client side rules to execute on a truthy condition expression evaluation result
     * @param ElseBranch  Client side rules to execute on a falsy condition expression evaluation result
     */
    constructor(
    /**
     * Condition expression to evaluate to determine which client side rules to execute
     */
    Condition: IExpression, 
    /**
     * ThenBranch Client side rules to execute on a truthy condition expression evaluation result
     */
    ThenBranch: IClientSideRule[], 
    /**
     * ThenBranch Client side rules to execute on a falsy condition expression evaluation result
     */
    ElseBranch: IClientSideRule[]);
}
