import { IWatermark } from '../../../../typedefinitions/models/controls/properties/watermark/IWatermark';
import { IFontInfo } from '../../../../typedefinitions/models/IFontInfo';
/**
 * Watermark control property object class
 */
export declare class Watermark implements IWatermark {
    /**
     * Watermark text
     */
    Text?: string | undefined;
    /**
     * Watermark font definition
     */
    Font?: IFontInfo | undefined;
    /**
     * Watermark font reference
     */
    FontName?: string | undefined;
    /**
     * Flag indicating if the watermark's text property is populated
     * @private
     */
    private get hasText();
    /**
     * Flag indicating if the watermark's font definition property is populated
     * @private
     */
    private get hasFontInfo();
    /**
     * Flag indicating if the watermark has a font name reference
     */
    get hasFontName(): boolean;
    /**
     * Flag indicating if the watermark has text and a font definition or name and can therefor be used.
     */
    get isEnabled(): boolean;
    /**
     * Watermark control property object class constructor
     */
    constructor(
    /**
     * Watermark text
     */
    Text?: string | undefined, 
    /**
     * Watermark font definition
     */
    Font?: IFontInfo | undefined, 
    /**
     * Watermark font reference
     */
    FontName?: string | undefined);
    /**
     * Creates a watermark object for given information
     * @param watermark
     */
    static deserialize(watermark?: IWatermark): Watermark;
}
