/**
 * Lookup textbox result container class
 */
export declare class ResultContainer {
    private readonly inputEl;
    private readonly resultContainerEl;
    private readonly resultTableEl;
    private readonly isIOS;
    /**
     * The textbox result container class reference array
     */
    cssClass: string[];
    private readonly rootControlEl;
    private _rootControlRect;
    private _inputRect;
    private _tableContainerRect;
    private _tableRect;
    private _drawPreferenceBeneath;
    /**
     * The textbox result container's style definition object
     */
    style: any;
    /**
     * Lookup textbox result container class constructor
     * @param inputEl
     * @param resultContainerEl
     * @param resultTableEl
     * @param isIOS
     * @param cssClass The textbox result container class reference array
     */
    constructor(inputEl: HTMLInputElement, resultContainerEl: HTMLDivElement, resultTableEl: HTMLTableElement, isIOS: boolean, 
    /**
     * The textbox result container class reference array
     */
    cssClass?: string[]);
    /**
     * Sets the textbox result container style to default
     * @param resetDrawPreference flag indicating if the draw preference should reset to default (beneath) as well
     */
    resetStyle(resetDrawPreference: boolean): void;
    /**
     * Calculates and populates the textbox result container style object
     */
    setStyle(): void;
    private get rootControlRect();
    private get inputRect();
    private get tableContainerRect();
    private get tableRect();
    /**
     * table container is set to top pos -9999,
     * on iOS this results in a relative value,
     * we use this value to determine the page top for iOS with soft keyboard on
     * @private
     */
    private get pageTopPos();
    private get pageLeftPos();
    /**
     * Determine the available space above the input
     * @private
     */
    private get spaceAbove();
    /**
     * Determine the available space beneath the input
     * @private
     */
    private get spaceBeneath();
    private get spaceBeneathRoot();
    private get useSpaceBeneathRoot();
    /**
     * Check if the table fits above the input
     * @private
     */
    private get fitsAbove();
    /**
     * Check if the table fits beneath the input
     * @private
     */
    private get fitsBeneath();
    /**
     * Determine the scrollbar height
     * @private
     */
    private get scrollbarHeight();
    /**
     * Check if the table fits above the input when it has a scrollbar
     * @private
     */
    private get fitsAboveWithScroll();
    /**
     * Check if the table fits beneath the input when it has a scrollbar
     * @private
     */
    private get fitsBeneathWithScroll();
    /**
     * Determine the available space from the left side of the input
     * @private
     */
    private get spaceFromLeft();
    /**
     * Checks if the table fits horizontally from its position near the input
     * @private
     */
    private get fitsFromLeft();
    /**
     * Checks if the table fits horizontally on the screen
     * @private
     */
    private get fitsOnScreen();
    /**
     * Determines the scrollbar width
     * @private
     */
    private get scrollbarWidth();
    /**
     * Check if the table fits horizontally from its position near the input with scrollbar
     * @private
     */
    private get fitsFromInputLeftWithScroll();
    /**
     * Check if the table fits horizontally on the screen with scrollbar
     * @private
     */
    private get fitsFromScreenLeftWithScroll();
    /**
     * Determines if a vertical scrollbar is required
     * @private
     */
    private get reqVertScroll();
    /**
     * Determines if a vertical scrollbar is required when a horizontal scrollbar is visible
     * @private
     */
    private get reqVertScrollWithHorScroll();
    /**
     * Determines if a horizontal scrollbar is required
     * @private
     */
    private get reqHorScroll();
    /**
     * Determines if a horizontal scrollbar is required if a vertical scrollbar is visible
     * @private
     */
    private get reqHorScrollWithVertScroll();
    private calcStyle;
}
