import { RunElement } from './run-element';
import { ActionsEventHandler } from '../../../actions/actions-event-handler';
import { IAudioElement } from '../../../../../typedefinitions/models/richText/elements/IAudioElement';
import { IBrush } from '../../../../../typedefinitions/models/IBrush';
import { IColor } from '../../../../../typedefinitions/models/IColor';
import { BorderStyle } from '../../../../../typedefinitions/enums/BorderStyle';
import { Visibility } from '../../../../../typedefinitions/enums/Visibility';
/**
 * Audio run element class
 */
export declare class AudioElement extends RunElement implements IAudioElement {
    /**
     * Height value for the audio element
     */
    Height: string;
    /**
     * Width value for the audio element
     */
    Width: string;
    /**
     * Flag indicating if the audio fragment should start playing automatically on page load
     */
    AutoPlay: boolean;
    /**
     * Flag indicating if the audio controls should be shown
     */
    ShowControls: boolean;
    /**
     * Audio fragment source
     */
    Source: string;
    /**
     * Audio fragment source url
     */
    SourceUrl: string;
    private get mediaUrl();
    /**
     * Audio run element class constructor
     * @param name Element name
     * @param labelledBy Element's label element reference
     * @param accessibilityRole Accessibility role
     * @param id Identifier string
     * @param background Optional element background settings
     * @param screenReaderText Text for the screen reader to read aloud
     * @param showKeyboardFocus Flag indicating whether keyboard focus should be shown or not
     * @param enabled Enabled/Disabled flag indicating whether the element can be interacted with
     * @param tabIndex Value used to determine the elements place in the page's tabbing order
     * @param tooltipText Text displayed near the element when hovering over the element
     * @param visibility Visibility setting
     * @param outlineStyle The outline-style property specifies the style of the outline
     * @param outlineWidth The outline-width property specifies the width of the outline
     * @param outlineColor The outline-color property is used to set the color of the outline
     * @param outlineOffset The outline-offset property adds space between an outline and the edge/border of an element
     * @param onGotFocus Optional, on focus received event handler
     * @param onLostFocus Optional, on focus lost event handler
     * @param onMouseDown Optional, On mouse down action event handler
     * @param onMouseUp Optional, On mouse up action event handler
     * @param onMouseEnter Optional, On mouse enter action event handler
     * @param onMouseLeave Optional, On mouse leave action event handler
     * @param Height Height value for the audio element
     * @param Width Width value for the audio element
     * @param AutoPlay Flag indicating if the audio fragment should start playing automatically on page load
     * @param ShowControls Flag indicating if the audio controls should be shown
     * @param Source Audio fragment source
     * @param SourceUrl Audio fragment source url
     */
    constructor(name: string, labelledBy: string, accessibilityRole: string, id: string, background: Optional<IBrush>, enabled: boolean, screenReaderText: Optional<string>, showKeyboardFocus: boolean, tabIndex: number, tooltipText: Optional<string>, visibility: Visibility, outlineStyle: BorderStyle, outlineWidth: number, outlineColor: IColor, outlineOffset: number, onGotFocus: Optional<ActionsEventHandler>, onLostFocus: Optional<ActionsEventHandler>, onMouseDown: Optional<ActionsEventHandler>, onMouseUp: Optional<ActionsEventHandler>, onMouseEnter: Optional<ActionsEventHandler>, onMouseLeave: Optional<ActionsEventHandler>, 
    /**
     * Height value for the audio element
     */
    Height: string, 
    /**
     * Width value for the audio element
     */
    Width: string, 
    /**
     * Flag indicating if the audio fragment should start playing automatically on page load
     */
    AutoPlay: boolean, 
    /**
     * Flag indicating if the audio controls should be shown
     */
    ShowControls: boolean, 
    /**
     * Audio fragment source
     */
    Source: string, 
    /**
     * Audio fragment source url
     */
    SourceUrl: string);
    /**
     * Converts the audio run element to a html audio element with the source element if enabled
     * @returns string element outer html string
     */
    toHTML(): string;
    /**
     * An audio run element cannot be converted to plain text
     * @returns string empty
     */
    toPlainText(): string;
}
