import { ShapeElement } from './shape-element';
import { ActionsEventHandler } from '../../../actions/actions-event-handler';
import { IBrush } from '../../../../../typedefinitions/models/IBrush';
import { IColor } from '../../../../../typedefinitions/models/IColor';
import { IEllipseElement } from '../../../../../typedefinitions/models/richText/elements/IEllipseElement';
import { IUnit } from '../../../../../typedefinitions/models/IUnit';
import { BorderStyle } from '../../../../../typedefinitions/enums/BorderStyle';
import { LineStyle } from '../../../../../typedefinitions/enums/LineStyle';
import { Visibility } from '../../../../../typedefinitions/enums/Visibility';
/**
 * Ellipse shape element class
 */
export declare class EllipseElement extends ShapeElement implements IEllipseElement {
    /**
     * Ellipse shape element class constructor
     * @param name Element name
     * @param labelledBy Element's label element reference
     * @param accessibilityRole Accessibility role
     * @param id Identifier string
     * @param background Optional element background settings
     * @param screenReaderText Text for the screen reader to read aloud
     * @param showKeyboardFocus Flag indicating whether keyboard focus should be shown or not
     * @param enabled Enabled/Disabled flag indicating whether the element can be interacted with
     * @param tabIndex Value used to determine the elements place in the page's tabbing order
     * @param tooltipText Text displayed near the element when hovering over the element
     * @param visibility Visibility setting
     * @param outlineStyle The outline-style property specifies the style of the outline
     * @param outlineWidth The outline-width property specifies the width of the outline
     * @param outlineColor The outline-color property is used to set the color of the outline
     * @param outlineOffset The outline-offset property adds space between an outline and the edge/border of an element
     * @param onGotFocus Optional, on focus received event handler
     * @param onLostFocus Optional, on focus lost event handler
     * @param onMouseDown On mouse down action event handler
     * @param onMouseUp On mouse up action event handler
     * @param onMouseEnter On mouse enter action event handler
     * @param onMouseLeave On mouse leave action event handler
     * @param height Height value for the shape element
     * @param width Width value for the shape element
     * @param strokeColor Shape's stroke/border color
     * @param strokeStyle Shape's stroke/border style (`solid`, `dash` or `dot`)
     * @param strokeWidth Pixel width of the shape's stroke/border
     */
    constructor(name: string, labelledBy: string, accessibilityRole: string, id: string, background: Optional<IBrush>, enabled: boolean, screenReaderText: Optional<string>, showKeyboardFocus: boolean, tabIndex: number, tooltipText: Optional<string>, visibility: Visibility, outlineStyle: BorderStyle, outlineWidth: number, outlineColor: IColor, outlineOffset: number, onGotFocus: Optional<ActionsEventHandler>, onLostFocus: Optional<ActionsEventHandler>, onMouseDown: Optional<ActionsEventHandler>, onMouseUp: Optional<ActionsEventHandler>, onMouseEnter: Optional<ActionsEventHandler>, onMouseLeave: Optional<ActionsEventHandler>, height: IUnit, width: IUnit, strokeColor: IColor, strokeStyle: LineStyle, strokeWidth: number);
    /**
     * Converts the ellipse element class to a html svg element string
     * @returns string element outer html string
     */
    toHTML(): string;
    /**
     * Returns the tooltip text
     * @returns string textual representation of the ellipse shape
     */
    toPlainText(): string;
}
