import { RunElement } from './run-element';
import { ActionsEventHandler } from '../../../actions/actions-event-handler';
import { IBrush } from '../../../../../typedefinitions/models/IBrush';
import { IColor } from '../../../../../typedefinitions/models/IColor';
import { IHyperlinkElement } from '../../../../../typedefinitions/models/richText/elements/IHyperlinkElement';
import { IUnit } from '../../../../../typedefinitions/models/IUnit';
import { BorderStyle } from '../../../../../typedefinitions/enums/BorderStyle';
import { Visibility } from '../../../../../typedefinitions/enums/Visibility';
import { HorizontalAlignment } from '../../../../../typedefinitions/enums/HorizontalAlignment';
import { VerticalAlignment } from '../../../../../typedefinitions/enums/VerticalAlignment';
/**
 * Hyperlink run element class
 */
export declare class HyperlinkElement extends RunElement implements IHyperlinkElement {
    /**
     * element height value and unit
     */
    Height: IUnit;
    /**
     * element width value and unit
     */
    Width: IUnit;
    /**
     * Text displayed on the element
     */
    Text: string;
    /**
     * References the run element for which this label element provides a label text
     */
    LabelFor: string;
    /**
     * Horizontal alignment of the displayed text within the outline of the element defined by the width property
     */
    HorizontalTextAlignment: HorizontalAlignment;
    /**
     * Vertical alignment of the displayed text within the outline of the element defined by the height property
     */
    VerticalTextAlignment: VerticalAlignment;
    /**
     * Linked page/document
     */
    Uri: string;
    /**
     * Target attribute value specifies where to open the linked page/document
     */
    Target: string;
    /**
     * On mouse click action event handler
     */
    OnClick: ActionsEventHandler;
    /**
     * Hyperlink run element class constructor.
     * @param name Element name
     * @param labelledBy Element's label element reference
     * @param accessibilityRole Accessibility role
     * @param id Identifier string
     * @param background Optional element background settings
     * @param screenReaderText Text for the screen reader to read aloud
     * @param showKeyboardFocus Flag indicating whether keyboard focus should be shown or not
     * @param enabled Enabled/Disabled flag indicating whether the element can be interacted with
     * @param tabIndex Value used to determine the elements place in the page's tabbing order
     * @param tooltipText Text displayed near the element when hovering over the element
     * @param visibility Visibility setting
     * @param outlineStyle The outline-style property specifies the style of the outline
     * @param outlineWidth The outline-width property specifies the width of the outline
     * @param outlineColor The outline-color property is used to set the color of the outline
     * @param outlineOffset The outline-offset property adds space between an outline and the edge/border of an element
     * @param onGotFocus Optional, on focus received event handler
     * @param onLostFocus Optional, on focus lost event handler
     * @param onMouseDown On mouse down action event handler
     * @param onMouseUp On mouse up action event handler
     * @param onMouseEnter On mouse enter action event handler
     * @param onMouseLeave On mouse leave action event handler
     * @param Height element height value and unit
     * @param Width element width value and unit
     * @param Text Text displayed on the element
     * @param LabelFor References the run element for which this label element provides a label text
     * @param HorizontalTextAlignment Horizontal alignment of the displayed text within the outline of the element defined by the width property
     * @param VerticalTextAlignment Vertical alignment of the displayed text within the outline of the element defined by the height property
     * @param Uri Hyperlink the linked page/document
     * @param Target HTML target attribute value specifies where to open the linked page/document
     * @param OnClick On mouse click action event handler
     */
    constructor(name: string, labelledBy: string, accessibilityRole: string, id: string, background: Optional<IBrush>, enabled: boolean, screenReaderText: Optional<string>, showKeyboardFocus: boolean, tabIndex: number, tooltipText: Optional<string>, visibility: Visibility, outlineStyle: BorderStyle, outlineWidth: number, outlineColor: IColor, outlineOffset: number, onGotFocus: Optional<ActionsEventHandler>, onLostFocus: Optional<ActionsEventHandler>, onMouseDown: Optional<ActionsEventHandler>, onMouseUp: Optional<ActionsEventHandler>, onMouseEnter: Optional<ActionsEventHandler>, onMouseLeave: Optional<ActionsEventHandler>, 
    /**
     * element height value and unit
     */
    Height: IUnit, 
    /**
     * element width value and unit
     */
    Width: IUnit, 
    /**
     * Text displayed on the element
     */
    Text: string, 
    /**
     * References the run element for which this label element provides a label text
     */
    LabelFor: string, 
    /**
     * Horizontal alignment of the displayed text within the outline of the element defined by the width property
     */
    HorizontalTextAlignment: HorizontalAlignment, 
    /**
     * Vertical alignment of the displayed text within the outline of the element defined by the height property
     */
    VerticalTextAlignment: VerticalAlignment, 
    /**
     * Linked page/document
     */
    Uri: string, 
    /**
     * Target attribute value specifies where to open the linked page/document
     */
    Target: string, 
    /**
     * On mouse click action event handler
     */
    OnClick: ActionsEventHandler);
    /**
     * Converts the hyperlink element class to a html anchor element string
     * @returns string element outer html string
     */
    toHTML(): string;
    /**
     * Returns the hyperlink's displayed text without markup
     * @returns string element text
     */
    toPlainText(): string;
}
