import { RunElement } from './run-element';
import { ActionsEventHandler } from '../../../actions/actions-event-handler';
import { IBrush } from '../../../../../typedefinitions/models/IBrush';
import { IColor } from '../../../../../typedefinitions/models/IColor';
import { IImageElement } from '../../../../../typedefinitions/models/richText/elements/IImageElement';
import { BorderStyle } from '../../../../../typedefinitions/enums/BorderStyle';
import { ImageStretch } from '../../../../../typedefinitions/enums/ImageStretch';
import { Visibility } from '../../../../../typedefinitions/enums/Visibility';
/**
 * Image run element class
 */
export declare class ImageElement extends RunElement implements IImageElement {
    /**
     * Element height value and unit
     */
    Height: string;
    /**
     * Element width value and unit
     */
    Width: string;
    /**
     * Image source
     */
    Source: string;
    /**
     * Image source url
     */
    SourceUrl: string;
    /**
     * Specifies the transparency of the image element
     */
    Opacity: number;
    /**
     * Specifies the in-element stretch behaviour of the image
     */
    Stretch: ImageStretch;
    /**
     * The linked page/document
     */
    Uri: string;
    /**
     * Specifies where to open the linked page/document
     */
    Target: string;
    /**
     * On mouse click action event handler
     */
    OnClick: ActionsEventHandler;
    /**
     * Image pixel height value
     */
    PixelHeight?: number | undefined;
    /**
     * Image pixel width value
     */
    PixelWidth?: number | undefined;
    /**
     * Image run element class constructor
     * @param name Element name
     * @param labelledBy Element's label element reference
     * @param accessibilityRole Accessibility role
     * @param id Identifier string
     * @param background Optional element background settings
     * @param screenReaderText Text for the screen reader to read aloud
     * @param showKeyboardFocus Flag indicating whether keyboard focus should be shown or not
     * @param enabled Enabled/Disabled flag indicating whether the element can be interacted with
     * @param tabIndex Value used to determine the elements place in the page's tabbing order
     * @param tooltipText Text displayed near the element when hovering over the element
     * @param visibility Visibility setting
     * @param outlineStyle The outline-style property specifies the style of the outline
     * @param outlineWidth The outline-width property specifies the width of the outline
     * @param outlineColor The outline-color property is used to set the color of the outline
     * @param outlineOffset The outline-offset property adds space between an outline and the edge/border of an element
     * @param onGotFocus Optional, on focus received event handler
     * @param onLostFocus Optional, on focus lost event handler
     * @param onMouseDown On mouse down action event handler
     * @param onMouseUp On mouse up action event handler
     * @param onMouseEnter On mouse enter action event handler
     * @param onMouseLeave On mouse leave action event handler
     * @param Height element height value and unit
     * @param Width element width value and unit
     * @param Source image source
     * @param SourceUrl image source url
     * @param Opacity Specifies the transparency of the image element
     * @param Stretch Specifies the in-element stretch behaviour of the image
     * @param Uri The linked page/document when the image serves as a hyperlink
     * @param Target HTML target attribute value specifies where to open the linked page/document
     * @param OnClick On mouse click action event handler
     * @param PixelHeight image pixel height value
     * @param PixelWidth image pixel width value
     */
    constructor(name: string, labelledBy: string, accessibilityRole: string, id: string, background: Optional<IBrush>, enabled: boolean, screenReaderText: Optional<string>, showKeyboardFocus: boolean, tabIndex: number, tooltipText: Optional<string>, visibility: Visibility, outlineStyle: BorderStyle, outlineWidth: number, outlineColor: IColor, outlineOffset: number, onGotFocus: Optional<ActionsEventHandler>, onLostFocus: Optional<ActionsEventHandler>, onMouseDown: Optional<ActionsEventHandler>, onMouseUp: Optional<ActionsEventHandler>, onMouseEnter: Optional<ActionsEventHandler>, onMouseLeave: Optional<ActionsEventHandler>, 
    /**
     * Element height value and unit
     */
    Height: string, 
    /**
     * Element width value and unit
     */
    Width: string, 
    /**
     * Image source
     */
    Source: string, 
    /**
     * Image source url
     */
    SourceUrl: string, 
    /**
     * Specifies the transparency of the image element
     */
    Opacity: number, 
    /**
     * Specifies the in-element stretch behaviour of the image
     */
    Stretch: ImageStretch, 
    /**
     * The linked page/document
     */
    Uri: string, 
    /**
     * Specifies where to open the linked page/document
     */
    Target: string, 
    /**
     * On mouse click action event handler
     */
    OnClick: ActionsEventHandler, 
    /**
     * Image pixel height value
     */
    PixelHeight?: number | undefined, 
    /**
     * Image pixel width value
     */
    PixelWidth?: number | undefined);
    /**
     * Converts the image element class to a html image element string
     * @returns string element outer html string
     */
    toHTML(): string;
    /**
     * Returns the image's alt text
     * @returns string element text
     */
    toPlainText(): string;
}
