import { TextElement } from './text-element';
import { ActionsEventHandler } from '../../../actions/actions-event-handler';
import { IBrush } from '../../../../../typedefinitions/models/IBrush';
import { IColor } from '../../../../../typedefinitions/models/IColor';
import { ILabelElement } from '../../../../../typedefinitions/models/richText/elements/ILabelElement';
import { IUnit } from '../../../../../typedefinitions/models/IUnit';
import { BorderStyle } from '../../../../../typedefinitions/enums/BorderStyle';
import { Visibility } from '../../../../../typedefinitions/enums/Visibility';
import { HorizontalAlignment } from '../../../../../typedefinitions/enums/HorizontalAlignment';
import { VerticalAlignment } from '../../../../../typedefinitions/enums/VerticalAlignment';
/**
 * Label text element class
 */
export declare class LabelElement extends TextElement implements ILabelElement {
    /**
     * Height value for the label element
     */
    Height: IUnit;
    /**
     * Width value for the label element
     */
    Width: IUnit;
    /**
     * References the run element for which this label element provides a label text
     */
    LabelFor: string;
    /**
     * Horizontal alignment of the displayed text within the outline of the element defined by the width property
     */
    HorizontalTextAlignment: HorizontalAlignment;
    /**
     * Vertical alignment of the displayed text within the outline of the element defined by the height property
     */
    VerticalTextAlignment: VerticalAlignment;
    /**
     * Label element class constructor
     * @param name Element name
     * @param labelledBy Element's label element reference
     * @param accessibilityRole Accessibility role
     * @param id Identifier string
     * @param background Optional element background settings
     * @param screenReaderText Text for the screen reader to read aloud
     * @param showKeyboardFocus Flag indicating whether keyboard focus should be shown or not
     * @param enabled Enabled/Disabled flag indicating whether the element can be interacted with
     * @param tabIndex Value used to determine the elements place in the page's tabbing order
     * @param tooltipText Text displayed near the element when hovering over the element
     * @param visibility Visibility setting
     * @param outlineStyle The outline-style property specifies the style of the outline
     * @param outlineWidth The outline-width property specifies the width of the outline
     * @param outlineColor The outline-color property is used to set the color of the outline
     * @param outlineOffset The outline-offset property adds space between an outline and the edge/border of an element
     * @param onGotFocus Optional, on focus received event handler
     * @param onLostFocus Optional, on focus lost event handler
     * @param onMouseDown Optional, On mouse down action event handler
     * @param onMouseUp Optional, On mouse up action event handler
     * @param onMouseEnter Optional, On mouse enter action event handler
     * @param onMouseLeave Optional, On mouse leave action event handler
     * @param Height Height value for the label element
     * @param Width Width value for the label element
     * @param text Text displayed on the element
     * @param LabelFor References the run element for which this label element provides a label text
     * @param HorizontalTextAlignment Horizontal alignment of the displayed text within the outline of the element defined by the width property
     * @param VerticalTextAlignment Vertical alignment of the displayed text within the outline of the element defined by the height property
     */
    constructor(name: string, labelledBy: string, accessibilityRole: string, id: string, background: Optional<IBrush>, enabled: boolean, screenReaderText: Optional<string>, showKeyboardFocus: boolean, tabIndex: number, tooltipText: Optional<string>, visibility: Visibility, outlineStyle: BorderStyle, outlineWidth: number, outlineColor: IColor, outlineOffset: number, onGotFocus: Optional<ActionsEventHandler>, onLostFocus: Optional<ActionsEventHandler>, onMouseDown: Optional<ActionsEventHandler>, onMouseUp: Optional<ActionsEventHandler>, onMouseEnter: Optional<ActionsEventHandler>, onMouseLeave: Optional<ActionsEventHandler>, text: string, 
    /**
     * Height value for the label element
     */
    Height: IUnit, 
    /**
     * Width value for the label element
     */
    Width: IUnit, 
    /**
     * References the run element for which this label element provides a label text
     */
    LabelFor: string, 
    /**
     * Horizontal alignment of the displayed text within the outline of the element defined by the width property
     */
    HorizontalTextAlignment: HorizontalAlignment, 
    /**
     * Vertical alignment of the displayed text within the outline of the element defined by the height property
     */
    VerticalTextAlignment: VerticalAlignment);
    /**
     * Converts the label element class to a html label element string
     * @returns string element outer html string
     */
    toHTML(): string;
    /**
     * Returns the label's displayed text without markup
     * @returns string element text
     */
    toPlainText(): string;
}
