import { RunElement } from './run-element';
import { ActionsEventHandler } from '../../../actions/actions-event-handler';
import { IBrush } from '../../../../../typedefinitions/models/IBrush';
import { IColor } from '../../../../../typedefinitions/models/IColor';
import { IShapeElement } from '../../../../../typedefinitions/models/richText/elements/IShapeElement';
import { IUnit } from '../../../../../typedefinitions/models/IUnit';
import { BorderStyle } from '../../../../../typedefinitions/enums/BorderStyle';
import { ElementKind } from '../../../../../typedefinitions/enums/ElementKind';
import { LineStyle } from '../../../../../typedefinitions/enums/LineStyle';
import { Visibility } from '../../../../../typedefinitions/enums/Visibility';
type ShapeElementKind = ElementKind.Ellipse | ElementKind.Line | ElementKind.Rectangle;
/**
 * Abstract shape element base class
 */
export declare abstract class ShapeElement extends RunElement implements IShapeElement {
    /**
     * Height unit value for the label element
     */
    Height: IUnit;
    /**
     * Width unit value for the label element
     */
    Width: IUnit;
    /**
     * Shape's stroke/border color
     */
    StrokeColor: IColor;
    /**
     * Shape's stroke/border style (`solid`, `dash` or `dot`)
     */
    StrokeStyle: LineStyle;
    /**
     * Pixel width of the shape's stroke/border
     */
    StrokeWidth: number;
    /**
     * Shape element class constructor
     * @param kind Shape element kind
     * @param name Element name
     * @param labelledBy Element's label element reference
     * @param accessibilityRole Accessibility role
     * @param id Identifier string
     * @param background Optional element background settings
     * @param screenReaderText Text for the screen reader to read aloud
     * @param showKeyboardFocus Flag indicating whether keyboard focus should be shown or not
     * @param enabled Enabled/Disabled flag indicating whether the element can be interacted with
     * @param tabIndex Value used to determine the elements place in the page's tabbing order
     * @param tooltipText Text displayed near the element when hovering over the element
     * @param visibility Visibility setting
     * @param outlineStyle The outline-style property specifies the style of the outline
     * @param outlineWidth The outline-width property specifies the width of the outline
     * @param outlineColor The outline-color property is used to set the color of the outline
     * @param outlineOffset The outline-offset property adds space between an outline and the edge/border of an element
     * @param onGotFocus Optional, on focus received event handler
     * @param onLostFocus Optional, on focus lost event handler
     * @param onMouseDown Optional, On mouse down action event handler
     * @param onMouseUp Optional, On mouse up action event handler
     * @param onMouseEnter Optional, On mouse enter action event handler
     * @param onMouseLeave Optional, On mouse leave action event handler
     * @param Height Height unit value for the label element
     * @param Width Width unit value for the label element
     * @param StrokeColor Shape's stroke/border color
     * @param StrokeStyle Shape's stroke/border style (`solid`, `dash` or `dot`)
     * @param StrokeWidth Pixel width of the shape's stroke/border
     * @protected
     */
    protected constructor(kind: ShapeElementKind, name: string, labelledBy: string, accessibilityRole: string, id: string, background: Optional<IBrush>, enabled: boolean, screenReaderText: Optional<string>, showKeyboardFocus: boolean, tabIndex: number, tooltipText: Optional<string>, visibility: Visibility, outlineStyle: BorderStyle, outlineWidth: number, outlineColor: IColor, outlineOffset: number, onGotFocus: Optional<ActionsEventHandler>, onLostFocus: Optional<ActionsEventHandler>, onMouseDown: Optional<ActionsEventHandler>, onMouseUp: Optional<ActionsEventHandler>, onMouseEnter: Optional<ActionsEventHandler>, onMouseLeave: Optional<ActionsEventHandler>, 
    /**
     * Height unit value for the label element
     */
    Height: IUnit, 
    /**
     * Width unit value for the label element
     */
    Width: IUnit, 
    /**
     * Shape's stroke/border color
     */
    StrokeColor: IColor, 
    /**
     * Shape's stroke/border style (`solid`, `dash` or `dot`)
     */
    StrokeStyle: LineStyle, 
    /**
     * Pixel width of the shape's stroke/border
     */
    StrokeWidth: number);
}
export {};
