import { RunElement } from './run-element';
import { ActionsEventHandler } from '../../../actions/actions-event-handler';
import { IBrush } from '../../../../../typedefinitions/models/IBrush';
import { IColor } from '../../../../../typedefinitions/models/IColor';
import { ICornerRadius } from '../../../../../typedefinitions/models/ICornerRadius';
import { ITextBoxElement } from '../../../../../typedefinitions/models/richText/elements/ITextBoxElement';
import { IThickness } from '../../../../../typedefinitions/models/IThickness';
import { IUnit } from '../../../../../typedefinitions/models/IUnit';
import { BorderStyle } from '../../../../../typedefinitions/enums/BorderStyle';
import { Visibility } from '../../../../../typedefinitions/enums/Visibility';
/**
 * TextBox run element class
 */
export declare class TextBoxElement extends RunElement implements ITextBoxElement {
    /**
     * input element height value and unit
     */
    Height: IUnit;
    /**
     * input element width value and unit
     */
    Width: IUnit;
    /**
     * input element border color
     */
    BorderColor: IColor;
    /**
     * input element border width value and unit
     */
    BorderWidth: number;
    /**
     * input element border radius
     */
    CornerRadius: ICornerRadius;
    /**
     * input element padding
     */
    TextMargin: IThickness;
    /**
     * input element text changed actions event handler information
     */
    OnTextChanged: ActionsEventHandler;
    /**
     * TextBox run element class constructor
     * @param name Element name
     * @param labelledBy Element's label element reference
     * @param accessibilityRole Accessibility role
     * @param id Identifier string
     * @param background Optional element background settings
     * @param screenReaderText Text for the screen reader to read aloud
     * @param showKeyboardFocus Flag indicating whether keyboard focus should be shown or not
     * @param enabled Enabled/Disabled flag indicating whether the element can be interacted with
     * @param tabIndex Value used to determine the elements place in the page's tabbing order
     * @param tooltipText Text displayed near the element when hovering over the element
     * @param visibility Visibility setting
     * @param outlineStyle The outline-style property specifies the style of the outline
     * @param outlineWidth The outline-width property specifies the width of the outline
     * @param outlineColor The outline-color property is used to set the color of the outline
     * @param outlineOffset The outline-offset property adds space between an outline and the edge/border of an element
     * @param onGotFocus Optional, on focus received event handler
     * @param onLostFocus Optional, on focus lost event handler
     * @param onMouseDown Optional, On mouse down action event handler
     * @param onMouseUp Optional, On mouse up action event handler
     * @param onMouseEnter Optional, On mouse enter action event handler
     * @param onMouseLeave Optional, On mouse leave action event handler
     * @param Height Input element height value and unit
     * @param Width Input element width value and unit
     * @param BorderColor Input element border color
     * @param BorderWidth Input element border width
     * @param CornerRadius Input element border radius
     * @param TextMargin Input element padding
     * @param OnTextChanged Actions event handler information for when the text is changed by the user
     */
    constructor(name: string, labelledBy: string, accessibilityRole: string, id: string, background: Optional<IBrush>, enabled: boolean, screenReaderText: Optional<string>, showKeyboardFocus: boolean, tabIndex: number, tooltipText: Optional<string>, visibility: Visibility, outlineStyle: BorderStyle, outlineWidth: number, outlineColor: IColor, outlineOffset: number, onGotFocus: Optional<ActionsEventHandler>, onLostFocus: Optional<ActionsEventHandler>, onMouseDown: Optional<ActionsEventHandler>, onMouseUp: Optional<ActionsEventHandler>, onMouseEnter: Optional<ActionsEventHandler>, onMouseLeave: Optional<ActionsEventHandler>, 
    /**
     * input element height value and unit
     */
    Height: IUnit, 
    /**
     * input element width value and unit
     */
    Width: IUnit, 
    /**
     * input element border color
     */
    BorderColor: IColor, 
    /**
     * input element border width value and unit
     */
    BorderWidth: number, 
    /**
     * input element border radius
     */
    CornerRadius: ICornerRadius, 
    /**
     * input element padding
     */
    TextMargin: IThickness, 
    /**
     * input element text changed actions event handler information
     */
    OnTextChanged: ActionsEventHandler);
    /**
     * Converts the text element to a html input element string
     * @returns string element outer html string
     */
    toHTML(): string;
    /**
     * Returns the displayed text without markup
     * @returns string element text
     */
    toPlainText(): string;
}
