import { RunElement } from './run-element';
import { ActionsEventHandler } from '../../../actions/actions-event-handler';
import { IBrush } from '../../../../../typedefinitions/models/IBrush';
import { IColor } from '../../../../../typedefinitions/models/IColor';
import { ITimerElement } from '../../../../../typedefinitions/models/richText/elements/ITimerElement';
import { BorderStyle } from '../../../../../typedefinitions/enums/BorderStyle';
import { Visibility } from '../../../../../typedefinitions/enums/Visibility';
/**
 * Timer run element class
 */
export declare class TimerElement extends RunElement implements ITimerElement {
    /**
     * Flag indicating if the timer should start immediately, without user action
     */
    AutoStart: boolean;
    /**
     * Timer tick interval
     */
    Interval: number;
    OnTick: ActionsEventHandler;
    /**
     * Flag indicating if the timer should restart after a tick
     */
    Repeat: boolean;
    /**
     * Timer run element class constructor
     * @param name Element name
     * @param labelledBy Element's label element reference
     * @param accessibilityRole Accessibility role
     * @param id Identifier string
     * @param background Optional element background settings
     * @param screenReaderText Text for the screen reader to read aloud
     * @param showKeyboardFocus Flag indicating whether keyboard focus should be shown or not
     * @param enabled Enabled/Disabled flag indicating whether the element can be interacted with
     * @param tabIndex Value used to determine the elements place in the page's tabbing order
     * @param tooltipText Text displayed near the element when hovering over the element
     * @param visibility Visibility setting
     * @param outlineStyle The outline-style property specifies the style of the outline
     * @param outlineWidth The outline-width property specifies the width of the outline
     * @param outlineColor The outline-color property is used to set the color of the outline
     * @param outlineOffset The outline-offset property adds space between an outline and the edge/border of an element
     * @param onGotFocus Optional, on focus received event handler
     * @param onLostFocus Optional, on focus lost event handler
     * @param onMouseDown Optional, On mouse down action event handler
     * @param onMouseUp Optional, On mouse up action event handler
     * @param onMouseEnter Optional, On mouse enter action event handler
     * @param onMouseLeave Optional, On mouse leave action event handler
     * @param AutoStart Flag indicating if the timer should start immediately, without user action
     * @param Interval Timer tick interval
     * @param OnTick On tick actions event handler
     * @param Repeat Flag indicating if the timer should restart after a tick
     */
    constructor(name: string, labelledBy: string, accessibilityRole: string, id: string, background: Optional<IBrush>, enabled: boolean, screenReaderText: Optional<string>, showKeyboardFocus: boolean, tabIndex: number, tooltipText: Optional<string>, visibility: Visibility, outlineStyle: BorderStyle, outlineWidth: number, outlineColor: IColor, outlineOffset: number, onGotFocus: Optional<ActionsEventHandler>, onLostFocus: Optional<ActionsEventHandler>, onMouseDown: Optional<ActionsEventHandler>, onMouseUp: Optional<ActionsEventHandler>, onMouseEnter: Optional<ActionsEventHandler>, onMouseLeave: Optional<ActionsEventHandler>, 
    /**
     * Flag indicating if the timer should start immediately, without user action
     */
    AutoStart: boolean, 
    /**
     * Timer tick interval
     */
    Interval: number, OnTick: ActionsEventHandler, 
    /**
     * Flag indicating if the timer should restart after a tick
     */
    Repeat: boolean);
    /**
     * Converts the timer element class to a html div element string and creates a timer in the timer service
     * @returns string element outer html string
     */
    toHTML(): string;
    /**
     * Returns the tooltip text
     * @returns string textual representation of the timer run element
     */
    toPlainText(): string;
}
