import { RunElement } from './run-element';
import { ActionsEventHandler } from '../../../actions/actions-event-handler';
import { IBrush } from '../../../../../typedefinitions/models/IBrush';
import { IColor } from '../../../../../typedefinitions/models/IColor';
import { IVideoElement } from '../../../../../typedefinitions/models/richText/elements/IVideoElement';
import { BorderStyle } from '../../../../../typedefinitions/enums/BorderStyle';
import { Visibility } from '../../../../../typedefinitions/enums/Visibility';
/**
 * Video run element class
 */
export declare class VideoElement extends RunElement implements IVideoElement {
    /**
     * Height value for the element
     */
    Height: string;
    /**
     * Width value for the element
     */
    Width: string;
    /**
     * Flag indicating if the video should start playing immediately
     */
    AutoPlay: boolean;
    /**
     * Flag indicating if the video controls (play/pause, stop, ...) should be shown
     */
    ShowControls: boolean;
    /**
     * Video file source location
     */
    Source: string;
    /**
     * Video source url
     */
    SourceUrl: string;
    private get mediaUrl();
    private get displayExternalVideo();
    /**
     * Video run element class constructor
     * @param name Element name
     * @param labelledBy Element's label element reference
     * @param accessibilityRole Accessibility role
     * @param id Identifier string
     * @param background Optional element background settings
     * @param screenReaderText Text for the screen reader to read aloud
     * @param showKeyboardFocus Flag indicating whether keyboard focus should be shown or not
     * @param enabled Enabled/Disabled flag indicating whether the element can be interacted with
     * @param tabIndex Value used to determine the elements place in the page's tabbing order
     * @param tooltipText Text displayed near the element when hovering over the element
     * @param visibility Visibility setting
     * @param outlineStyle The outline-style property specifies the style of the outline
     * @param outlineWidth The outline-width property specifies the width of the outline
     * @param outlineColor The outline-color property is used to set the color of the outline
     * @param outlineOffset The outline-offset property adds space between an outline and the edge/border of an element
     * @param onGotFocus Optional, on focus received event handler
     * @param onLostFocus Optional, on focus lost event handler
     * @param onMouseDown Optional, On mouse down action event handler
     * @param onMouseUp Optional, On mouse up action event handler
     * @param onMouseEnter Optional, On mouse enter action event handler
     * @param onMouseLeave Optional, On mouse leave action event handler
     * @param Height Height value for the video element
     * @param Width Width value for the video element
     * @param AutoPlay Flag indicating if the video should start playing immediately
     * @param ShowControls Flag indicating if the video controls (play/pause, stop, ...) should be shown
     * @param Source Video file source location
     * @param SourceUrl Video source url
     */
    constructor(name: string, labelledBy: string, accessibilityRole: string, id: string, background: Optional<IBrush>, enabled: boolean, screenReaderText: Optional<string>, showKeyboardFocus: boolean, tabIndex: number, tooltipText: Optional<string>, visibility: Visibility, outlineStyle: BorderStyle, outlineWidth: number, outlineColor: IColor, outlineOffset: number, onGotFocus: Optional<ActionsEventHandler>, onLostFocus: Optional<ActionsEventHandler>, onMouseDown: Optional<ActionsEventHandler>, onMouseUp: Optional<ActionsEventHandler>, onMouseEnter: Optional<ActionsEventHandler>, onMouseLeave: Optional<ActionsEventHandler>, 
    /**
     * Height value for the element
     */
    Height: string, 
    /**
     * Width value for the element
     */
    Width: string, 
    /**
     * Flag indicating if the video should start playing immediately
     */
    AutoPlay: boolean, 
    /**
     * Flag indicating if the video controls (play/pause, stop, ...) should be shown
     */
    ShowControls: boolean, 
    /**
     * Video file source location
     */
    Source: string, 
    /**
     * Video source url
     */
    SourceUrl: string);
    /**
     * Converts the video element class to a html video or iframe element string depending on the video source
     * @returns string element outer html string
     */
    toHTML(): string;
    /**
     * Returns the tooltip text
     * @returns string textual representation of the video
     */
    toPlainText(): string;
}
