import { IBlobType } from '../../../typedefinitions/models/value-types/IBlobType';
import { IClassificationPseudoType } from '../../../typedefinitions/models/value-types/IClassificationPseudoType';
import { IEnumerationType } from '../../../typedefinitions/models/value-types/IEnumerationType';
import { IIntegerType } from '../../../typedefinitions/models/value-types/IIntegerType';
import { IRealType } from '../../../typedefinitions/models/value-types/IRealType';
import { ISetType } from '../../../typedefinitions/models/value-types/ISetType';
import { IStringType } from '../../../typedefinitions/models/value-types/IStringType';
import { IValueType } from '../../../typedefinitions/models/value-types/IValueType';
import { DataType as DataTypeKind } from '../../../typedefinitions/enums/DataType';
/**
 * Abstract value type class
 */
export declare abstract class ValueType implements IValueType {
    /**
     * DataType readonly value type data type property
     */
    readonly DataType: DataTypeKind;
    /**
     * Property-value class constructor
     * @param DataType value type data type property `String, Real, Date, Time, Enumeration, Classification, Set, Integer, Blob`
     */
    protected constructor(
    /**
     * DataType readonly value type data type property
     */
    DataType: DataTypeKind);
    /**
     * String value type data type cast check
     * @param valueType value type
     * @returns IStringType valueType as a IStringType when the value type's data type is String.
     */
    static isStringType(valueType: IValueType): valueType is IStringType;
    /**
     * Number value type data type cast check
     * @param valueType value type
     * @returns IIntegerType valueType as a isIntegerType when the value type's data type is Integer or Real.
     */
    static isIntegerType(valueType: IValueType): valueType is IIntegerType;
    /**
     * Real value type data type cast check
     * @param valueType value type
     * @returns IRealType valueType as a IRealType when the value type's data type is Real.
     */
    static isRealType(valueType: IValueType): valueType is IRealType;
    /**
     * Enumeration value type data type cast check
     * @param valueType value type
     * @returns IEnumerationType valueType as a IEnumerationType when the value type's data type is Enumeration or Set.
     */
    static isEnumerationType(valueType: IValueType): valueType is IEnumerationType;
    /**
     * Set value type data type cast check
     * @param valueType value type
     * @returns ISetType valueType as a ISetType when the value type's data type is Set.
     */
    static isSetType(valueType: IValueType): valueType is ISetType;
    /**
     * Classification pseudo value type data type cast check
     * @param valueType value type
     * @returns IClassificationPseudoType valueType as a IClassificationPseudoType when the value type's data type is Classification.
     */
    static isClassificationPseudoType(valueType: IValueType): valueType is IClassificationPseudoType;
    /**
     * Blob value type data type cast check
     * @param valueType value type
     * @returns IBlobType valueType as a IBlobType when the value type's data type is Blob.
     */
    static isBlobType(valueType: IValueType): valueType is IBlobType;
}
