import { AfterViewInit, ChangeDetectorRef, ElementRef, OnInit } from '@angular/core';
import { BaseComponent } from '../base/base.component';
import { ServiceProviderService } from '../../services/serviceprovider.service';
import { IAudioControl } from '../../../typedefinitions/models/controls/IAudioControl';
import { IBaseControl } from '../../../typedefinitions/models/controls/IBaseControl';
import * as i0 from "@angular/core";
/**
 * Audio component class
 */
export declare class AudioComponent extends BaseComponent<IAudioControl> implements OnInit, AfterViewInit {
    /**
     * sp Service provider service
     */
    protected sp: ServiceProviderService;
    /**
     * el Audio component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    /**
     * The urls of the audio files to load.
     */
    private mediaUrls;
    /**
     * The index of the currently loaded audio file.
     */
    private index;
    /**
     * audio element reference
     * static : true since it is not wrapped in an ngIf or an ngFor, accessible in ngOnInit
     */
    private audioRef;
    /**
     * audio source element reference
     * static : false since it is wrapped in an ngIf or an ngFor, accessible in ngAfterViewInit
     */
    private audioSourceRef;
    private get audioElement();
    private get sourceElement();
    /**
     * The url of the current audio file.
     */
    mediaUrl: string;
    /**
     * ID of the audio element
     */
    get audioId(): string;
    /**
     * controls attribute value
     */
    get controls(): Optional<string>;
    /**
     * autoplay attribute value
     */
    get autoplay(): Optional<string>;
    /**
     * Audio component class constructor
     * @param sp Service provider service
     * @param el Element reference
     * @param cd Change detector reference
     */
    constructor(
    /**
     * sp Service provider service
     */
    sp: ServiceProviderService, 
    /**
     * el Audio component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef);
    /**
     * Creates the audio ended listener for playing multiple audio files sequentially.
     */
    ngOnInit(): void;
    /**
     * Processes control changes and updates the media urls.
     * @param newDataObject Base control
     */
    handleControlUpdate(newDataObject: IBaseControl): void;
    private setMediaUrls;
    /**
     * After playing has ended play the next url
     * When at the end of the playlist, set index to 0
     */
    private nextMediaUrl;
    static ɵfac: i0.ɵɵFactoryDeclaration<AudioComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<AudioComponent, "bl5-audio", never, {}, {}, never, never, false, never>;
}
