import { ChangeDetectorRef, ElementRef, OnInit } from '@angular/core';
import { BaseComponent } from '../base.component';
import { ServiceProviderService } from '../../../services/serviceprovider.service';
import { CSSStyleObject } from '../../../../typedefinitions/models/style/CSSStyleObject';
import { IBaseInvolvedFieldsControl } from '../../../../typedefinitions/models/controls/IBaseInvolvedFieldsControl';
import { IInvolvedField } from '../../../../typedefinitions/models/IInvolvedField';
import * as i0 from "@angular/core";
/**
 * Base involved fields component class
 */
export declare abstract class BaseInvolvedFieldsComponent<T extends IBaseInvolvedFieldsControl> extends BaseComponent<T> implements OnInit {
    /**
     * sp Service provider service
     */
    protected sp: ServiceProviderService;
    /**
     * el Involved fields component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    /**
     * Flag indicating if there are any involved fields
     */
    get hasInvolvedFields(): boolean;
    /**
     * List of involved fields
     */
    involvedFields: Optional<IInvolvedField[]>;
    /**
     * Base involved fields component class constructor
     * @param sp Service provider service
     * @param el Element reference
     * @param cd Change detector reference
     */
    protected constructor(
    /**
     * sp Service provider service
     */
    sp: ServiceProviderService, 
    /**
     * el Involved fields component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef);
    /**
     * Sets the initial visibility of the component after component initialization
     */
    ngOnInit(): void;
    /**
     * Applies the styles to a style object
     * Extends the base class' get style object function and overrides the line height property
     * @return CSS Style Declaration
     */
    getStyleObject(): CSSStyleObject;
    /**
     * Handles a mouse click event and executes a goto field action if the component is enabled
     * @param event Mouse event
     * @param fieldName Name of the field for which the event was triggered
     */
    handleClick(event: MouseEvent, fieldName: string): void;
    /**
     * Retrieves the name or local name from the involved field based on the component's display name setting
     * @param involvedField
     */
    getInvolvedFieldName(involvedField: IInvolvedField): string;
    /**
     * Abstract function used to retrieve involved fields in child components
     * @returns list of involved fields
     */
    protected abstract getInvolvedFields(): Optional<IInvolvedField[]>;
    /**
     * Sets any retrieved involved fields on the class property
     * @returns true, if any involved fields were found and added to the list, otherwise false, to indicate the list was emptied
     */
    private setInvolvedFields;
    /**
     * Sets the control visibility based on the control settings and the availability of any errors
     * @param hasError
     */
    private setControlVisibility;
    static ɵfac: i0.ɵɵFactoryDeclaration<BaseInvolvedFieldsComponent<any>, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<BaseInvolvedFieldsComponent<any>, "ng-component", never, {}, {}, never, never, false, never>;
}
