import { ChangeDetectorRef, ElementRef } from '@angular/core';
import { BaseComponent } from '../base/base.component';
import { ServiceProviderService } from '../../services/serviceprovider.service';
import { IButtonControl } from '../../../typedefinitions/models/controls/IButtonControl';
import * as i0 from "@angular/core";
/**
 * Button component class
 */
export declare class ButtonComponent extends BaseComponent<IButtonControl> {
    /**
     * sp Service provider service
     */
    protected sp: ServiceProviderService;
    /**
     * el Button component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Change detector reference
     */
    protected cd: ChangeDetectorRef;
    /**
     * The button's displayed text.
     */
    text: string;
    /**
     * Button component class constructor injects services and sets the base component's `containsRichText` flag to true.
     * @param sp Service provider service
     * @param el Element reference
     * @param cd Change detector reference
     */
    constructor(
    /**
     * sp Service provider service
     */
    sp: ServiceProviderService, 
    /**
     * el Button component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Change detector reference
     */
    cd: ChangeDetectorRef);
    /**
     * Handles any control updates and (re)sets the button text
     * @param newDataObject base control
     */
    handleControlUpdate(newDataObject: IButtonControl): void;
    /**
     * Handles the mouse click event
     * @param event mouse event
     */
    handleClick(event: MouseEvent): void;
    /**
     * Handles the keyboard's key down event
     * @param event keyboard event
     */
    handleKeyDown(event: KeyboardEvent): void;
    /**
     * Retrieves the component's text for a copy or cut command
     * @returns plain component text
     */
    getText(): string;
    /**
     * Executes any actions defined in the `OnClick` property of the button's data object
     */
    private executeButton;
    static ɵfac: i0.ɵɵFactoryDeclaration<ButtonComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ButtonComponent, "bl5-button", never, {}, {}, never, never, false, never>;
}
