import { ChangeDetectorRef, ElementRef } from '@angular/core';
import { ReferenceComponent } from '../../reference/reference.component';
import { ServiceProviderService } from '../../../services/serviceprovider.service';
import { SetFieldConverterService } from '../../../services/converters/set-field-converter.service';
import { EnumerationFieldConverterService } from '../../../services/converters/enumeration-field-converter.service';
import { ICategoryButtonControl } from '../../../../typedefinitions/models/controls/ICategoryButtonControl';
import { IFieldInfo } from '../../../../typedefinitions/models/observables/IFieldInfo';
import { INavigationModeStrategy } from '../../../../typedefinitions/models/INavigationModeStrategy';
import * as i0 from "@angular/core";
/**
 * Category button component class
 */
export declare class CategoryButtonComponent extends ReferenceComponent<ICategoryButtonControl> {
    /**
     * sp Service provider service
     */
    protected sp: ServiceProviderService;
    /**
     * el Category button component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Change detector reference
     */
    protected cd: ChangeDetectorRef;
    /**
     * Set field converter service
     */
    protected setConverter: SetFieldConverterService;
    /**
     * Enumeration converter service
     */
    protected enumerationConverter: EnumerationFieldConverterService;
    /**
     * Represents the selected state of the category.
     */
    protected isSelected: boolean;
    /**
     * The button's displayed text.
     */
    text: string;
    /**
     * Category button component class constructor.
     * the constructor injects services and sets the base component's `containsRichText` flag to true.
     * @param sp Service provider service
     * @param el Element reference
     * @param cd Change detector reference
     * @param setConverter Set field converter service
     * @param enumerationConverter Enumeration converter service
     */
    constructor(
    /**
     * sp Service provider service
     */
    sp: ServiceProviderService, 
    /**
     * el Category button component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Change detector reference
     */
    cd: ChangeDetectorRef, 
    /**
     * Set field converter service
     */
    setConverter: SetFieldConverterService, 
    /**
     * Enumeration converter service
     */
    enumerationConverter: EnumerationFieldConverterService);
    /**
     * Handles any control updates and (re)sets the button text
     * @param control
     */
    handleControlUpdate(control: ICategoryButtonControl): void;
    /**
     * Handles the mouse click event
     * @param event mouse event
     */
    handleClick(event: MouseEvent): void;
    /**
     * Handles the keyboard's key down event
     * @param event keyboard event
     */
    handleKeyDown(event: KeyboardEvent): void;
    /**
     * Set specific logic for insert strategy
     * @returns New category button insert navigation mode strategy
     */
    getKeyboardInsertStrategy(): INavigationModeStrategy;
    /**
     * Retrieves the empty strategy for keyboard
     */
    getKeyboardEmptyStrategy(): INavigationModeStrategy;
    /**
     * Set specific logic for speed key pressed event
     */
    handleSpeedKeyPressed(): void;
    /**
     * Retrieves the component's text for a copy or cut command
     * @returns plain component text
     */
    getText(): string;
    /**
     * Handles field value updates.
     * @param fieldInfo updated field info
     */
    protected handleFieldUpdate(fieldInfo: IFieldInfo): void;
    /**
     * Selects or deselects a category or enumeration button, triggers a field info update and if needed, also an auto-enter event
     */
    protected executeButton(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<CategoryButtonComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<CategoryButtonComponent, "bl5-category-button", never, {}, {}, never, never, false, never>;
}
