import { ElementRef, ChangeDetectorRef } from '@angular/core';
import { ReferenceComponent } from '../../reference/reference.component';
import { ServiceProviderService } from '../../../services/serviceprovider.service';
import { SetFieldConverterService } from '../../../services/converters/set-field-converter.service';
import { ICategoryCheckboxControl } from '../../../../typedefinitions/models/controls/ICategoryCheckboxControl';
import { IFieldInfo } from '../../../../typedefinitions/models/observables/IFieldInfo';
import { INavigationModeStrategy } from '../../../../typedefinitions/models/INavigationModeStrategy';
import * as i0 from "@angular/core";
/**
 * Category checkbox component class
 */
export declare class CategoryCheckboxComponent extends ReferenceComponent<ICategoryCheckboxControl> {
    /**
     * sp Service provider service designed to provide easy access to several common services via one injectable service
     */
    protected sp: ServiceProviderService;
    /**
     * el Category radio button component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    /**
     * converter Set field converter service
     */
    protected converter: SetFieldConverterService;
    /**
     * Represents the checked state of the category checkbox.
     */
    isChecked: boolean;
    /**
     * Category checkbox component class constructor
     * @param sp Service provider service
     * @param el Element reference
     * @param cd Change detector reference
     * @param converter Enumeration field converter service
     */
    constructor(
    /**
     * sp Service provider service designed to provide easy access to several common services via one injectable service
     */
    sp: ServiceProviderService, 
    /**
     * el Category radio button component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef, 
    /**
     * converter Set field converter service
     */
    converter: SetFieldConverterService);
    /**
     * Extends the reference component's `handleFieldUpdate` function.
     * Updates the `isChecked` property's value.
     * @param fieldInfo updated field info
     */
    handleFieldUpdate(fieldInfo: IFieldInfo): void;
    /**
     * Extends the base component's `getStyleObject` function.
     * Removes the background style object properties if no background color is set.
     * @returns CSS style declaration object
     */
    getStyleObject(): CSSStyleDeclaration;
    /**
     * Handle clicking on the checkbox.
     * The field will be set to the new state.
     * In `handleFieldUpdate` the checkbox checked state will be determined again.
     * @param event Mouse event
     */
    handleClick(event: MouseEvent | CustomEvent): void;
    /**
     * Set specific logic for insert strategy
     * @returns Checkbox insert navigation mode strategy
     */
    getKeyboardInsertStrategy(): INavigationModeStrategy;
    /**
     * Set specific logic for empty / accessible strategy
     * @returns Radio button empty / accessible navigation mode strategy
     */
    getKeyboardEmptyStrategy(): INavigationModeStrategy;
    /**
     * Set specific logic for speed key pressed event
     */
    handleSpeedKeyPressed(): void;
    private executeCheckBox;
    static ɵfac: i0.ɵɵFactoryDeclaration<CategoryCheckboxComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<CategoryCheckboxComponent, "bl5-category-checkbox", never, {}, {}, never, never, false, never>;
}
