import { ChangeDetectorRef, ElementRef, OnInit, OnDestroy } from '@angular/core';
import { ReferenceComponent } from '../reference/reference.component';
import { ClassificationObject } from './ClassificationObject';
import { ClassificationFieldConverterService } from '../../services/converters/classification-field-converter.service';
import { ServiceProviderService } from '../../services/serviceprovider.service';
import { IClassificationControl } from '../../../typedefinitions/models/controls/IClassificationControl';
import { IClassificationItem } from '../../../typedefinitions/models/IClassificationItem';
import { IFieldInfo } from '../../../typedefinitions/models/observables/IFieldInfo';
import { INavigationModeStrategy } from '../../../typedefinitions/models/INavigationModeStrategy';
import * as i0 from "@angular/core";
/**
 * Classification component class
 */
export declare class ClassificationComponent extends ReferenceComponent<IClassificationControl> implements OnInit, OnDestroy {
    /**
     * sp Service provider service
     */
    protected sp: ServiceProviderService;
    /**
     * el Classification component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    /**
     * Classification field converter service
     */
    protected converter: ClassificationFieldConverterService;
    /**
     * A string subject observable that allows for text change values to be multicasted to many observables
     */
    private textChange;
    /**
     * Text change subscription
     */
    private textChangeSubscription?;
    private controlVisibilityChangeSubscription;
    /**
     * Input element's css classes
     */
    inputClasses: string[];
    /**
     * the string value on the input element
     */
    textValue: string;
    /**
     * The classification object
     */
    classificationObject: ClassificationObject;
    get txtSearch(): string;
    get txtOK(): string;
    get txtStart(): string;
    get txtBack(): string;
    get txtSelectedValue(): string;
    get selectedValueText(): string;
    /**
     * Classification component class constructor
     * @param sp Service provider service
     * @param el Element reference
     * @param cd Change detector reference
     * @param converter Classification field converter service
     */
    constructor(
    /**
     * sp Service provider service
     */
    sp: ServiceProviderService, 
    /**
     * el Classification component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef, 
    /**
     * Classification field converter service
     */
    converter: ClassificationFieldConverterService);
    /**
     * Lifecycle hook, called after the component has initialized, that subscribes to the text change subscription
     */
    ngOnInit(): void;
    /**
     * Callback method that performs subscription clean-up immediately after the component instance is destroyed.
     */
    ngOnDestroy(): void;
    /**
     * Fires on every keystroke
     * @param event
     */
    onChange(event: string): void;
    /**
     * Handles change of the value after editing (doesn't fire on every keystroke).
     */
    handleChange(): void;
    /**
     * Checks if the classification object has the selected code
     */
    hasSelectedValue(): string;
    /**
     * Searches for a given classification code when the search button is clicked
     */
    handleSearch(): void;
    /**
     * Selects for a classification code when the ok button is clicked
     */
    handleOk(): void;
    /**
     * Selects a previous classification code when the back button is clicked
     */
    goBack(): void;
    /**
     * Classification item click handler selects a clicked classification object and if it has children, expands the list
     */
    handleClick(item: IClassificationItem): void;
    /**
     * Handles focus of various classification control components
     * @param value
     */
    handleFocus(value: string): void;
    /**
     * Selects a previous classification code when a classification item in the history tree is clicked
     */
    setHistoryFrom(item: string): void;
    /**
     * Returns the keyboard insert strategy
     */
    getKeyboardInsertStrategy(): INavigationModeStrategy;
    /**
     * Retrieves the empty strategy for keyboard
     */
    getKeyboardEmptyStrategy(): INavigationModeStrategy;
    /**
     * Checks if the given item is focused.
     * @param COFC Classification Object Focused Code
     * @param itemCode item code
     * @param index item index
     */
    hasFocus(COFC: string, itemCode: string, index: number): boolean;
    /**
     * Checks if the given item is selected.
     * @param COFC Classification Object Focused Code
     * @param itemCode item code
     */
    isSelected(COFC: string, itemCode: string): boolean;
    /**
     * If the component is subscribed to a field and it's data is changed then this method will be called.
     * Process the updated field in this method.
     * @param fieldInfo Field info
     */
    protected handleFieldUpdate(fieldInfo: IFieldInfo): void;
    private pushChange;
    static ɵfac: i0.ɵɵFactoryDeclaration<ClassificationComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ClassificationComponent, "bl5-classification", never, {}, {}, never, never, false, never>;
}
