import { ElementRef, ChangeDetectorRef } from '@angular/core';
import { ReferenceComponent } from '../reference/reference.component';
import { ServiceProviderService } from '../../services/serviceprovider.service';
import { FieldConverterService } from '../../services/converters/field-converter.service';
import { IFieldInfo } from '../../../typedefinitions/models/observables/IFieldInfo';
import { IInputControl } from '../../../typedefinitions/models/controls/IInputControl';
/**
 * The custom component class. A simple base component for custom referenced components.
 */
export declare abstract class CustomComponent<T extends IInputControl> extends ReferenceComponent<T> {
    protected sp: ServiceProviderService;
    protected el: ElementRef;
    protected cd: ChangeDetectorRef;
    /**
     * Custom component class constructor
     * @param sp Service provider service
     * @param el Element reference
     * @param cd Change detector reference
     */
    protected constructor(sp: ServiceProviderService, el: ElementRef, cd: ChangeDetectorRef);
    /**
     * Handles change of the value after editing (doesn't fire on every keystroke).
     */
    handleChange(converter: FieldConverterService): void;
    /**
     * Abstract change handler function.
     */
    abstract handleCustomChange(fieldInfo: IFieldInfo): void;
}
