import { ChangeDetectorRef, ElementRef } from '@angular/core';
import { ColumnModel, GridComponent, GridLine, RowSelectEventArgs } from '@syncfusion/ej2-angular-grids';
import { LookupComponent } from '../lookup/lookup.component';
import { ServiceProviderService } from '../../services/serviceprovider.service';
import { ClassificationFieldConverterService } from '../../services/converters/classification-field-converter.service';
import { IDataGridControl } from '../../../typedefinitions/models/controls/IDataGridControl';
import { ILookupState } from '../../../typedefinitions/models/server/ILookupState';
import * as i0 from "@angular/core";
/**
 * Data-grid component class
 */
export declare class DataGridComponent extends LookupComponent<IDataGridControl> {
    /**
     * sp Service provider service
     */
    protected sp: ServiceProviderService;
    /**
     * el Data-grid component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    /**
     * Classification field converter service
     */
    protected converter: ClassificationFieldConverterService;
    private returnField;
    private returnFieldIndex;
    /**
     * Lookup state search result data rows
     */
    data: object[];
    /**
     * Column info (containing field names and styles)
     */
    columns: ColumnModel[];
    /**
     * Reference to the slider element
     */
    protected dataGridElement: GridComponent;
    /**
     * Returns the CSS class name for the flag indicating whether the grid headers should be shown if true or omitted otherwise
     */
    get showHeadersClass(): string;
    /**
     * Defines the display mode of grid lines
     */
    lines: GridLine;
    /**
     * The selected row index property is used to select a row at initial rendering. it can also be used to retrieve the currently selected row index.
     */
    selectedRowIndex: number;
    /**
     * Host-bound odd-color data-grid css style property
     */
    oddColor: Optional<string>;
    /**
     * Host-bound even-color data-grid css style property
     */
    evenColor: Optional<string>;
    /**
     * Host-bound hover-color data-grid css style property
     */
    hoverColor: Optional<string>;
    /**
     * Host-bound selected-color data-grid css style property
     */
    selectedColor: Optional<string>;
    /**
     * Host-bound width property for the data-grid grid-lines css style
     */
    cellBorderWidth: Optional<number>;
    /**
     * Host-bound color property for the data-grid grid-lines css style
     */
    cellBorderColor: Optional<string>;
    /**
     * Host-bound data-grid header background-color css style property
     */
    headerBackgroundColor: Optional<string>;
    /**
     * Host-bound width property for the data-grid header grid-lines css style
     */
    headerCellBorderWidth: Optional<number>;
    /**
     * Host-bound color property for the data-grid header grid-lines css style
     */
    headerCellBorderColor: Optional<string>;
    /**
     * Host-bound font-family property for the data-grid header css style
     */
    headerFontFamily: Optional<string>;
    /**
     * Host-bound font-size property for the data-grid header css style
     */
    headerFontSize: Optional<number>;
    /**
     * Host-bound font-color property for the data-grid header css style
     */
    headerFontColor: Optional<string>;
    /**
     * Host-bound font-weight property for the data-grid header css style
     */
    headerFontWeight: Optional<string>;
    /**
     * Host-bound font-style property for the data-grid header css style
     */
    headerFontStyle: Optional<string>;
    /**
     * Host-bound font-decoration property for the data-grid header css style
     */
    headerFontDecoration: Optional<string>;
    /**
     * Data grid component class constructor
     * @param sp Service provider service
     * @param el Element reference
     * @param cd Change detector reference
     * @param converter Classification field converter service
     */
    constructor(
    /**
     * sp Service provider service
     */
    sp: ServiceProviderService, 
    /**
     * el Data-grid component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef, 
    /**
     * Classification field converter service
     */
    converter: ClassificationFieldConverterService);
    /**
     * Processes control changes, updates component css style variables and if enabled performs a search.
     * @param newDataObject Updated data object
     */
    handleControlUpdate(newDataObject: IDataGridControl): void;
    /**
     * Processes field changes, updates the control based on the result
     * @param lookupState
     */
    handleLookupStateUpdate(lookupState: ILookupState): void;
    /**
     * Adds (header-)grid-line css classes to the control
     * @returns
     */
    getCssClasses(): string[];
    /**
     * Handles the row selected event
     * @param args
     */
    rowSelected(args: RowSelectEventArgs): void;
    private searchOnControlUpdate;
    private processLookupInformation;
    /**
     * Processes the provided datasource
     * @param dataSource
     * @param hasSearchResult
     * @param hasFieldNames
     * @param fieldNames
     */
    private processDataSource;
    /**
     * Set the select row index of the datagrid
     * @param rowIndex
     */
    private setSelectedRecord;
    /**
     * Pushes the given value to the field
     * @param value
     */
    private pushChange;
    static ɵfac: i0.ɵɵFactoryDeclaration<DataGridComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DataGridComponent, "bl5-datagrid", never, {}, {}, never, never, false, never>;
}
