import { ElementRef, ChangeDetectorRef, OnInit, OnDestroy } from '@angular/core';
import { LookupComponent } from '../../lookup/lookup.component';
import { ServiceProviderService } from '../../../services/serviceprovider.service';
import { IDataGridKeySelectorControl } from '../../../../typedefinitions/models/controls/IDataGridKeySelectorControl';
import { ILookupState } from '../../../../typedefinitions/models/server/ILookupState';
import { ISelectListItem } from '../../../../typedefinitions/models/ISelectListItem';
import * as i0 from "@angular/core";
/**
 * Data-grid key selector component
 */
export declare class DataGridKeySelectorComponent extends LookupComponent<IDataGridKeySelectorControl> implements OnInit, OnDestroy {
    /**
     * sp Service provider service designed to provide easy access to several common services via one injectable service
     */
    protected sp: ServiceProviderService;
    /**
     * el Data-grid key selector component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    private activeKey;
    /**
     * Flag indicator for the initialisation of the option list styles
     */
    private optionListInitialized;
    /**
     * Subscription to the application wide scroll event
     */
    private scrollSubscription?;
    /**
     * Button html element
     */
    private button;
    /**
     * Option list html element
     */
    private ulist;
    /**
     * Key names as from data source
     */
    keyNames: string[];
    /**
     * Option list id formed with the data object id
     */
    optionListId: string;
    /**
     * Select option item list
     */
    optionList: ISelectListItem[];
    /**
     * Flag indicating if the option item list is populated
     */
    get hasOptions(): boolean;
    /**
     * Option list CSS class list
     */
    optionListClass: string[];
    /**
     * Option list CSS style declaration object
     */
    optionListStyle: any;
    /**
     * Option item css styles object
     */
    optionItemStyle: any;
    /**
     * Flag indication whether the options are visible (`true`) or not (`false`)
     */
    optionsVisible: boolean;
    /**
     * Index of the focused option item
     */
    targetIndex: number;
    /**
     * Display text for the selected language as shown in the button
     */
    displayText: string;
    /**
     * Element visibility flag
     */
    get isExploded(): boolean;
    /**
     * Data grid key selector component class constructor
     * @param sp Service provider service
     * @param el Element reference
     * @param cd Change detector reference
     */
    constructor(
    /**
     * sp Service provider service designed to provide easy access to several common services via one injectable service
     */
    sp: ServiceProviderService, 
    /**
     * el Data-grid key selector component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef);
    /**
     * Subscribes to the window scroll event to hide the option list when needed.
     * Initializes the control visibility.
     * Hides the option list.
     */
    ngOnInit(): void;
    /**
     * Unsubscribes from subscriptions
     */
    ngOnDestroy(): void;
    /**
     * Process control changes and update the media url.
     * @param newDataObject
     */
    handleControlUpdate(newDataObject: IDataGridKeySelectorControl): void;
    /**
     * Toggles options visibility
     */ toggleOptionsVisible(): void;
    /**
     * Hide options
     */
    handleBlur(): void;
    /**
     * Handles the selection of a value in the dropdownlist
     */
    setValue(optionItem: ISelectListItem): void;
    /**
     * Handles the mouse down event
     */
    handleMouseDown: () => void;
    /**
     * Handles the mouse up event
     * @description For WCAG 2.1 changed the mousedown event to mouseup
     */
    handleMouseUp: () => void;
    /**
     * Sets an option item as target when hovered
     * @param index
     */
    handleMouseOver(index: number): void;
    /**
     * Handles option list navigation via keyboard input
     * @param event
     */
    handleKey(event: KeyboardEvent): void;
    /**
     * The on change event handler function set the new active key for the current field
     */
    onChange: (event: Event) => void;
    /**
     * Checks if a key is selected by comparing its key name against a given key name
     * @param keyName name of the key against which to compare
     * @returns true, if the active key name equals the given key name, otherwise false
     */
    isSelected: (keyName: string) => boolean;
    /**
     * Retrieves the component's text for a copy or cut command
     * @returns plain component text
     */
    getText(): string;
    /**
     * If the component is subscribed to a lookup-state and it's data is changed then this method will be called.
     * Process the updated lookup-state in this method.
     * @param newLookupState
     */
    protected handleLookupStateUpdate(newLookupState: ILookupState): void;
    /**
     * Extends base functionality of the apply-styles-and-dimensions function and applies option list styles
     */
    protected applyStylesAndDimensions(): void;
    private setOptionsListClass;
    private setOptions;
    private setSelectedOption;
    private onWindowScroll;
    private hideList;
    /**
     * Resets list style properties
     */
    private resetList;
    private initializeList;
    private handleEnterKey;
    private handleKeyUp;
    private handleKeyDown;
    private handleKeyEvent;
    /**
     * Determines in which direction the list should show and brings the list into the viewport
     */
    private showList;
    /**
     * Scroll to the list item with the current target index
     */
    private scrollToTargetIndex;
    static ɵfac: i0.ɵɵFactoryDeclaration<DataGridKeySelectorComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DataGridKeySelectorComponent, "bl5-datagrid-key-selector", never, {}, {}, never, never, false, never>;
}
