import { ChangeDetectorRef, ElementRef } from '@angular/core';
import { SliderChangeEventArgs, SliderOrientation } from '@syncfusion/ej2-angular-inputs';
import { LookupComponent } from '../../lookup/lookup.component';
import { ServiceProviderService } from '../../../services/serviceprovider.service';
import { IDataGridNavigatorControl } from '../../../../typedefinitions/models/controls/IDataGridNavigatorControl';
import { ILookupState } from '../../../../typedefinitions/models/server/ILookupState';
import * as i0 from "@angular/core";
interface IThumb {
    step: number;
    start: number;
    value: number;
    range: IThumbRange;
    enabled: boolean;
    direction: string;
    orientation: SliderOrientation;
}
interface IThumbRange {
    min: number;
    max: number;
}
/**
 * Data-grid navigator component class
 */
export declare class DataGridNavigatorComponent extends LookupComponent<IDataGridNavigatorControl> {
    /**
     * sp Service provider service designed to provide easy access to several common services via one injectable service
     */
    protected sp: ServiceProviderService;
    /**
     * el Data-grid navigator component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    private DEFAULT_THUMB;
    /**
     * Flag indicating if the first and last page buttons should be shown (true), or not (false, default)
     */
    private showFirstAndLastPageButtons;
    /**
     * Flag indicating if previous and next page buttons should be shown (true), or not (false, default)
     */
    private showPreviousAndNextPageButtons;
    /**
     * Flag indicating if the previous and next record buttons should be shown (true), or not (false, default)
     */
    private showPreviousAndNextRecordButtons;
    /**
     * Flag indicating if the buttons can be enabled (true), or not (false, default)
     */
    private buttonsEnabled;
    /**
     * Flag indicating if the previous record button should be enabled (true), or not (false, default)
     */
    private enablePreviousRecordButton;
    /**
     * Flag indicating if the next record button should be enabled (true), or not (false, default)
     */
    private enableNextRecordButton;
    /**
     * Flag indicating if the previous page button should be enabled (true), or not (false, default)
     */
    private enablePreviousPageButton;
    /**
     * Flag indicating if the next page button should be enabled (true), or not (false, default)
     */
    private enableNextPageButton;
    /**
     * Flag indicating if the first page button should be enabled (true), or not (false, default)
     */
    private enableFirstPageButton;
    /**
     * Flag indicating if the last page button should be enabled (true), or not (false, default)
     */
    private enableLastPageButton;
    /**
     * String representation of the component orientation (horizontal (default)/vertical)
     */
    private orientation;
    /**
     * String representation of the component orientation (horizontal (default)/vertical)
     */
    private orientationStr;
    /**
     * Determines the slider text direction (rtl or ltr)
     */
    private direction;
    /**
     * Flag indicating if the navigator should show a scrollbar thumb
     */
    showThumb: boolean;
    /**
     * The thumb configuration object
     */
    thumb: IThumb;
    /**
     * The maximum amount of visible result rows
     */
    pageSize: number;
    /**
     * The amount of pages
     */
    pages: number;
    /**
     * Button property definition list
     */
    buttons: any[];
    /**
     * Readonly button property definition list
     */
    get prevButtons(): any[];
    /**
     * Readonly button property definition list
     */
    get nextButtons(): any[];
    /**
     * Data grid navigator component class constructor
     * @param sp Service provider service
     * @param el Element reference
     * @param cd change detector reference
     */
    constructor(
    /**
     * sp Service provider service designed to provide easy access to several common services via one injectable service
     */
    sp: ServiceProviderService, 
    /**
     * el Data-grid navigator component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef);
    /**
     * Process control changes and update the media url.
     * @param newDataObject Updated data grid navigator data object
     */
    handleControlUpdate(newDataObject: IDataGridNavigatorControl): void;
    /**
     * Extends the base method to include the orientation class to the list
     * @return list of css class names
     */
    getCssClasses(): string[];
    /**
     * Overrides the base's content width setter function when the width's unit type is set to auto
     */
    setContentWidth(): void;
    /**
     * Overrides the base's content height setter function when the height's unit type is set to auto
     */
    setContentHeight(): void;
    /**
     * Updates the current lookup state's start index
     * @param event Mouse event
     * @param cmd update command (first, last, page, record)
     * @param modifier (optional) Used to specify the record or page in the respective commands
     */
    handleClick(event: MouseEvent, cmd: string, modifier?: number): void;
    /**
     * Fires whenever the Slider value is changed. In other term, this event will be triggered, while drag the slider thumb completed.
     * @param args
     */
    handleThumbChanged(args: SliderChangeEventArgs): void;
    /**
     * If the component is subscribed to a lookup state and it's data is changed then this method will be called.
     * Process the updated lookup state in this method.
     * @param newLookupState Updated lookup state to process
     */
    protected handleLookupStateUpdate(newLookupState: ILookupState): void;
    private createButtons;
    static ɵfac: i0.ɵɵFactoryDeclaration<DataGridNavigatorComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DataGridNavigatorComponent, "bl5-datagrid-navigator", never, {}, {}, never, never, false, never>;
}
export {};
