import { ElementRef, ChangeDetectorRef } from '@angular/core';
import { LookupComponent } from '../../lookup/lookup.component';
import { ServiceProviderService } from '../../../services/serviceprovider.service';
import { IDataGridSearchButtonControl } from '../../../../typedefinitions/models/controls/IDataGridSearchButtonControl';
import * as i0 from "@angular/core";
/**
 * Data-grid search button component class
 */
export declare class DataGridSearchButtonComponent extends LookupComponent<IDataGridSearchButtonControl> {
    /**
     * sp Service provider service designed to provide easy access to several common services via one injectable service
     */
    protected sp: ServiceProviderService;
    /**
     * el Data-grid search button component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    /**
     * Data-grid search button text
     */
    text: string;
    /**
     * Data-grid search button component class constructor
     * @param sp Service provider service
     * @param el Element reference
     * @param cd Change detector reference
     */
    constructor(
    /**
     * sp Service provider service designed to provide easy access to several common services via one injectable service
     */
    sp: ServiceProviderService, 
    /**
     * el Data-grid search button component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef);
    /**
     * Process control changes and update the media url.
     * @param newDataObject Data-grid search button control
     */
    handleControlUpdate(newDataObject: IDataGridSearchButtonControl): void;
    /**
     * Handles the mouse click event
     * @param event Mouse event
     */
    handleClick(event: MouseEvent): void;
    /**
     * Handles the keyboard's key down event
     * @param event keyboard event
     */
    handleKeyDown(event: KeyboardEvent): void;
    /**
     * Retrieves the component's text for a copy or cut command
     * @returns plain component text
     */
    getText(): string;
    private requestSearch;
    static ɵfac: i0.ɵɵFactoryDeclaration<DataGridSearchButtonComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DataGridSearchButtonComponent, "bl5-datagrid-search-button", never, {}, {}, never, never, false, never>;
}
