import { ElementRef, ChangeDetectorRef, OnInit, OnDestroy } from '@angular/core';
import { LookupComponent } from '../../lookup/lookup.component';
import { ServiceProviderService } from '../../../services/serviceprovider.service';
import { IDataGridSearchBoxControl } from '../../../../typedefinitions/models/controls/IDataGridSearchBoxControl';
import * as i0 from "@angular/core";
/**
 * Data-grid search box component class
 */
export declare class DataGridSearchBoxComponent extends LookupComponent<IDataGridSearchBoxControl> implements OnInit, OnDestroy {
    /**
     * sp Service provider service designed to provide easy access to several common services via one injectable service
     */
    protected sp: ServiceProviderService;
    /**
     * el Data-grid search box component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    private textChange;
    private textChangeSubscription?;
    /**
     * Data-grid search box input text value
     */
    textValue: string;
    /**
     * Data grid search box component class constructor
     * @param sp Service provider service
     * @param el Element reference
     * @param cd Change detector reference
     */
    constructor(
    /**
     * sp Service provider service designed to provide easy access to several common services via one injectable service
     */
    sp: ServiceProviderService, 
    /**
     * el Data-grid search box component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef);
    /**
     * Lifecycle hook, called after the component has initialized, that subscribes to the text change subscription
     */
    ngOnInit(): void;
    /**
     * Callback method that performs subscription clean-up immediately after the component instance is destroyed.
     */
    ngOnDestroy(): void;
    /**
     * Fires on every keystroke
     * @param event
     */
    onChange(event: string): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<DataGridSearchBoxComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DataGridSearchBoxComponent, "bl5-datagrid-searchbox", never, {}, {}, never, never, false, never>;
}
