import { ChangeDetectorRef, ElementRef, NgZone, OnInit } from '@angular/core';
import { DateTime, DurationLike } from 'luxon';
import { CalendarBaseViewComponent } from './calendar-base-view.component';
import { ColorService } from '../../../services/color.service';
import { StyleGeneratorService } from '../../../services/style-generator.service';
import { ICalendarItem } from '../../../../typedefinitions/models/ICalendarItem';
import * as i0 from "@angular/core";
/**
 * The calendar's decade view component class
 */
export declare class CalendarDecadeViewComponent extends CalendarBaseViewComponent implements OnInit {
    /**
     * Decade calendar view name
     * @protected
     */
    protected readonly viewName = "decade";
    /**
     * Decade date format
     * @protected
     */
    protected readonly dateFormat = "yyyy";
    /**
     * Calendar year view component class constructor
     * @param el View element reference
     * @param cd Change detector reference
     * @param ngZone executes work outside the Angular zone
     * @param colorService Provides functionality for converting a color object into a css style string
     * @param styleGeneratorService Style generator service
     */
    constructor(el: ElementRef, cd: ChangeDetectorRef, ngZone: NgZone, colorService: ColorService, styleGeneratorService: StyleGeneratorService);
    /**
     * Sets padding styles and regenerates the decade view with the view date as reference.
     */
    ngOnInit(): void;
    /**
     * Regenerates the view with the next month as reference date
     * @param date
     */
    nextDecade(date?: DateTime): void;
    /**
     * Regenerates the view with the previous month as reference date
     * @param date
     */
    previousDecade(date?: DateTime): void;
    /**
     * Notifies the date control of a view date changes and switches to the calendar year view
     * @param date the date to set as selected
     */
    selectYear(date: DateTime): void;
    /**
     * Checks if any date in the next decade is selectable and prevents further navigation if not
     */
    canNavigateToNextDecade(): boolean;
    /**
     * Checks if any date of the previous decade is selectable and prevents further navigation if not
     */
    canNavigateToPreviousDecade(): boolean;
    /**
     * @inheritDoc
     * Regenerates the calendar view using a given date as reference point
     * @param date Date used to regenerate the view
     */
    regenerate(date: DateTime): void;
    /**
     * @inheritDoc
     * Determines the background color using the calendar cell item information
     * @param calendarItem year cell information used to determine the result
     */
    determineBackgroundColor(calendarItem: ICalendarItem): string;
    /**
     * @inheritDoc
     * Handles the previous item group keyboard command
     * @param event Keyboard event information
     * @protected
     */
    protected previousItemGroup(event: KeyboardEvent): boolean;
    /**
     * @inheritDoc
     * Handles the next item group keyboard command
     * @param event Keyboard event information
     * @protected
     */
    protected nextItemGroup(event: KeyboardEvent): boolean;
    /**
     * @inheritDoc
     * Handles the previous item row keyboard command
     * @param event Keyboard event information
     * @param duration The mutation amount
     * @protected
     */
    protected previousItemRow(event: KeyboardEvent, duration?: DurationLike): boolean;
    /**
     * @inheritDoc
     * Handles the next item row keyboard command
     * @param event Keyboard event information
     * @param duration The mutation amount
     * @protected
     */
    protected nextItemRow(event: KeyboardEvent, duration?: DurationLike): boolean;
    /**
     * @inheritDoc
     * Handles the previous item keyboard command
     * @param event Keyboard event information
     * @param duration The mutation amount
     * @protected
     */
    protected previousItem(event: KeyboardEvent, duration?: DurationLike): boolean;
    /**
     * @inheritDoc
     * Handles the next item keyboard command
     * @param event Keyboard event information
     * @param duration The mutation amount
     * @protected
     */
    protected nextItem(event: KeyboardEvent, duration?: DurationLike): boolean;
    /**
     * @inheritDoc
     * Handles the select item keyboard command
     * @param event Keyboard event information
     * @protected
     */
    protected selectItem(event: KeyboardEvent): boolean;
    /**
     * @inheritDoc
     * Generates a display label for a cell based on its value
     * @param date The date-time value on which to base the label
     * @protected
     */
    protected generateLabel(date: DateTime): void;
    private yearInDecade;
    private generateYearsForDecade;
    private yearIsDisabled;
    static ɵfac: i0.ɵɵFactoryDeclaration<CalendarDecadeViewComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<CalendarDecadeViewComponent, "bl5-calendar-decade-view", never, {}, {}, never, never, false, never>;
}
