import { OnInit, ElementRef, ChangeDetectorRef, NgZone } from '@angular/core';
import { DateTime, DurationLike } from 'luxon';
import { CalendarBaseViewComponent } from './calendar-base-view.component';
import { CultureInfoService } from '../../../services/culture-info.service';
import { StyleGeneratorService } from '../../../services/style-generator.service';
import { ColorService } from '../../../services/color.service';
import { ICalendarItem } from '../../../../typedefinitions/models/ICalendarItem';
import * as i0 from "@angular/core";
/**
 * The calendar's year view component class
 */
export declare class CalendarYearViewComponent extends CalendarBaseViewComponent implements OnInit {
    private cultureInfoService;
    /**
     * Decade calendar view name
     * @protected
     */
    protected readonly viewName = "year";
    /**
     * Year date format
     * @protected
     */
    protected readonly dateFormat = "yyyyMM";
    /**
     * Calendar year view component class constructor
     * @param el View element reference
     * @param cd Change detector reference
     * @param ngZone executes work outside the Angular zone
     * @param colorService Provides functionality for converting a color object into a css style string
     * @param cultureInfoService Used for storing and consulting culture settings
     * @param styleGeneratorService Style generator service
     */
    constructor(el: ElementRef, cd: ChangeDetectorRef, ngZone: NgZone, colorService: ColorService, cultureInfoService: CultureInfoService, styleGeneratorService: StyleGeneratorService);
    /**
     * Assigns header and body styles as defined in the date picker settings
     */
    ngOnInit(): void;
    /**
     * Converts a calendar month date to a formatted string
     * @param month
     */
    formatMonth(month: ICalendarItem): string;
    /**
     * Notifies the date control of a month change and triggers a calendar view change
     * @param date
     */
    selectMonth(date: any): void;
    /**
     * Notifies the date control of a date change and triggers a calendar view change
     */
    switchToDecadeView(): void;
    /**
     * Updates the calendar view date's year to a given year, or if no year is provided, adds a year to the calendar view date
     * @param date
     */
    nextYear(date?: DateTime): void;
    /**
     * Updates the calendar view date's year to a given year, or if no year is provided, reduces the calendar view date's years by 1
     * @param date
     */
    previousYear(date?: DateTime): void;
    /**
     * Checks if dates of the next year are in bounds according to the date constraints
     */
    canNavigateToNextYear(): boolean;
    /**
     * Checks if dates of the previous year are in bounds according to the date constraints
     */
    canNavigateToPreviousYear(): boolean;
    /**
     * @inheritDoc
     * Regenerates the calendar view using a given date as reference point
     * @param date Date used to regenerate the view
     */
    regenerate(date: any): void;
    /**
     * @inheritDoc
     * Determines the background color using the calendar cell item information
     * @param calendarItem month cell information used to determine the result
     */
    determineBackgroundColor(calendarItem: ICalendarItem): string;
    /**
     * @inheritDoc
     * Handles the previous item group keyboard command
     * @param event Keyboard event information
     * @protected
     */
    protected previousItemGroup(event: KeyboardEvent): boolean;
    /**
     * @inheritDoc
     * Handles the next item group keyboard command
     * @param event Keyboard event information
     * @protected
     */
    protected nextItemGroup(event: KeyboardEvent): boolean;
    /**
     * @inheritDoc
     * Handles the previous item row keyboard command
     * @param event Keyboard event information
     * @param duration The mutation amount
     * @protected
     */
    protected previousItemRow(event: KeyboardEvent, duration?: DurationLike): boolean;
    /**
     * @inheritDoc
     * Handles the next item row keyboard command
     * @param event Keyboard event information
     * @param duration The mutation amount
     * @protected
     */
    protected nextItemRow(event: KeyboardEvent, duration?: DurationLike): boolean;
    /**
     * @inheritDoc
     * Handles the previous item keyboard command
     * @param event Keyboard event information
     * @param duration The mutation amount
     * @protected
     */
    protected previousItem(event: KeyboardEvent, duration?: DurationLike): boolean;
    /**
     * @inheritDoc
     * Handles the next item keyboard command
     * @param event Keyboard event information
     * @param duration The mutation amount
     * @protected
     */
    protected nextItem(event: KeyboardEvent, duration?: DurationLike): boolean;
    /**
     * @inheritDoc
     * Handles the select item keyboard command
     * @param event Keyboard event information
     * @protected
     */
    protected selectItem(event: KeyboardEvent): boolean;
    /**
     * @inheritDoc
     * Set a given HTML table cell element as the active cell and focus that cell
     * @param cell The cell to select
     * @protected
     */
    protected selectCell(cell: Nullable<HTMLTableCellElement>): void;
    /**
     * @inheritDoc
     * Generates a display label for a cell based on its value
     * @param date The date-time value on which to base the label
     * @protected
     */
    protected generateLabel(date: any): void;
    private monthIsDisabled;
    private generateMonths;
    static ɵfac: i0.ɵɵFactoryDeclaration<CalendarYearViewComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<CalendarYearViewComponent, "bl5-calendar-year-view", never, {}, {}, never, never, false, never>;
}
