import { ElementRef, ChangeDetectorRef } from '@angular/core';
import { BaseComponent } from '../base/base.component';
import { ServiceProviderService } from '../../services/serviceprovider.service';
import { CSSStyleObject } from '../../../typedefinitions/models/style/CSSStyleObject';
import { IBaseControl } from '../../../typedefinitions/models/controls/IBaseControl';
import { IEllipseControl } from '../../../typedefinitions/models/controls/IEllipseControl';
import * as i0 from "@angular/core";
/**
 * Ellipse shape component class
 */
export declare class EllipseComponent extends BaseComponent<IEllipseControl> {
    /**
     * sp Service provider service
     */
    protected sp: ServiceProviderService;
    /**
     * el Ellipse component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    /**
     * Ellipse component class constructor
     * @param sp Service provider service
     * @param el Element reference
     * @param cd Change detector reference
     */
    constructor(
    /**
     * sp Service provider service
     */
    sp: ServiceProviderService, 
    /**
     * el Ellipse component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef);
    /**
     * Processes control changes.
     * @param newDataObject
     */
    handleControlUpdate(newDataObject: IBaseControl): void;
    /**
     * Extends the base class' get style object function and applies the stroke style
     * @return CSS Style Declaration
     */
    getStyleObject(): CSSStyleObject;
    static ɵfac: i0.ɵɵFactoryDeclaration<EllipseComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<EllipseComponent, "bl5-ellipse", never, {}, {}, never, never, false, never>;
}
