import { ElementRef, ChangeDetectorRef, OnInit, OnDestroy } from '@angular/core';
import { ReferenceComponent } from '../reference/reference.component';
import { ServiceProviderService } from '../../services/serviceprovider.service';
import { EnumerationFieldConverterService } from '../../services/converters/enumeration-field-converter.service';
import { CSSStyleObject } from '../../../typedefinitions/models/style/CSSStyleObject';
import { IFieldInfo } from '../../../typedefinitions/models/observables/IFieldInfo';
import { IEnumerationTextBoxControl } from '../../../typedefinitions/models/controls/IEnumerationTextBoxControl';
import { INavigationModeStrategy } from '../../../typedefinitions/models/INavigationModeStrategy';
import * as i0 from "@angular/core";
/**
 * Enumeration textbox component class
 */
export declare class EnumerationTextboxComponent extends ReferenceComponent<IEnumerationTextBoxControl> implements OnInit, OnDestroy {
    /**
     * sp Service provider service designed to provide easy access to several common services via one injectable service
     */
    protected sp: ServiceProviderService;
    /**
     * el Category radio button component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    /**
     * converter Enumeration field converter service
     */
    protected converter: EnumerationFieldConverterService;
    private textChange;
    private textChangeSubscription?;
    /**
     * object used for font style copying
     */
    private fontStyle;
    /**
     * Input value
     */
    textValue: string;
    /**
     * Maximum length of the inputted value
     */
    size: number;
    /**
     * Enumeration textbox component class constructor
     * @param sp Service provider service
     * @param el Element reference
     * @param cd Change detector reference
     * @param converter Enumeration field converter service
     */
    constructor(
    /**
     * sp Service provider service designed to provide easy access to several common services via one injectable service
     */
    sp: ServiceProviderService, 
    /**
     * el Category radio button component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef, 
    /**
     * converter Enumeration field converter service
     */
    converter: EnumerationFieldConverterService);
    /**
     *  On component initialisation subscribes to reference through its base class and as extension to the text change subscription
     */
    ngOnInit(): void;
    /**
     * Terminates subscriptions
     */
    ngOnDestroy(): void;
    /**
     * Overrides the base components set content width function if the control size is set to auto and there are font sizes available by which to determine the width.
     */
    setContentWidth(): void;
    /**
     * Fires on every keystroke
     * @param event
     */
    onInput(event: Event): void;
    /**
     * Handles the blur event of the component.
     */
    onBlur(): void;
    /**
     * Set specific logic for keyboard insert strategy
     */
    getKeyboardInsertStrategy(): INavigationModeStrategy;
    /**
     * Extends the base class' get style object function and copies the font style for width calculation
     * @return CSS Style Declaration
     */
    getStyleObject(): CSSStyleObject;
    /**
     * Notify base to include the watermark class
     * @return font css classes
     */
    getFontCssClasses(): string[];
    /**
     * Retrieves the component's text for a copy or cut command
     * @returns plain component text
     */
    getText(): string;
    /**
     * Sets text from a paste command on the component
     * @param text Text to set on the control
     */
    setText(text: string): void;
    /**
     * Clears the text from the component after a cut command
     */
    clearText(): void;
    /**
     * If the component is subscribed to a field and it's data is changed then this method will be called.
     * Process the updated field in this method.
     * @param fieldInfo updated field info
     */
    protected handleFieldUpdate(fieldInfo: IFieldInfo): void;
    private pushChange;
    static ɵfac: i0.ɵɵFactoryDeclaration<EnumerationTextboxComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<EnumerationTextboxComponent, "bl5-enumeration-textbox", never, {}, {}, never, never, false, never>;
}
