import { ElementRef, ChangeDetectorRef } from '@angular/core';
import { ReferenceComponent } from '../reference/reference.component';
import { ServiceProviderService } from '../../services/serviceprovider.service';
import { IFieldInfo } from '../../../typedefinitions/models/observables/IFieldInfo';
import { IErrorTextControl } from '../../../typedefinitions/models/controls/IErrorTextControl';
import * as i0 from "@angular/core";
/**
 * Error text component class
 */
export declare class ErrorComponent extends ReferenceComponent<IErrorTextControl> {
    /**
     * sp Service provider service designed to provide easy access to several common services via one injectable service
     */
    protected sp: ServiceProviderService;
    /**
     * el Error text component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    /**
     * Indicates whether the text contains markup and/or rich text components
     */
    isSimpleText: boolean;
    /**
     * Error text shown in template
     */
    errorText: string;
    /**
     * Error text component class constructor
     * @param sp Service provider service
     * @param el Element reference
     * @param cd Change detector reference
     */
    constructor(
    /**
     * sp Service provider service designed to provide easy access to several common services via one injectable service
     */
    sp: ServiceProviderService, 
    /**
     * el Error text component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef);
    /**
     * Retrieves the component's text for a copy or cut command
     * @returns plain component text
     */
    getText(): string;
    /**
     * The field update handler sets the error text and adds/removes skip-links
     * @description when a field changes trigger an update
     * @param fieldInfo Field info
     */
    protected handleFieldUpdate(fieldInfo: IFieldInfo): void;
    private setErrorText;
    static ɵfac: i0.ɵɵFactoryDeclaration<ErrorComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ErrorComponent, "bl5-error-text", never, {}, {}, never, never, false, never>;
}
