import { ElementRef, ChangeDetectorRef } from '@angular/core';
import { BaseComponent } from '../base/base.component';
import { GridControlSize } from '../../services/sizetree/GridControlSize';
import { ModelService } from '../../services/model.service';
import { ServiceProviderService } from '../../services/serviceprovider.service';
import { IControlSize } from '../../services/sizetree/IControlSize';
import { IBaseControl } from '../../../typedefinitions/models/controls/IBaseControl';
import { IBaseComponentViewModel } from '../../../typedefinitions/models/view/IBaseViewModel';
import { ITableLayout } from '../../../typedefinitions/models/ITableLayout';
import { IGridComponentViewModel } from '../../../typedefinitions/models/view/IGridComponentViewModel';
import { IGridControl } from '../../../typedefinitions/models/controls/IGridControl';
import { IGridUnit } from '../../../typedefinitions/models/IGridUnit';
import * as i0 from "@angular/core";
/**
 * Grid component class
 */
export declare class GridComponent extends BaseComponent<IGridControl> implements IGridComponentViewModel {
    protected modelService: ModelService;
    protected sp: ServiceProviderService;
    protected el: ElementRef;
    protected cd: ChangeDetectorRef;
    /**
     * Grid component's layout information
     */
    tableLayout?: ITableLayout;
    /**
     * Nullable grid control size object getter
     */
    get controlSize(): Nullable<GridControlSize>;
    /**
     * Nullable grid control size object setter
     */
    set controlSize(value: Nullable<GridControlSize>);
    get viewModels(): Nullable<IBaseComponentViewModel>[];
    /**
     * Grid component class constructor
     * @param modelService
     * @param sp
     * @param el
     * @param cd
     */
    constructor(modelService: ModelService, sp: ServiceProviderService, el: ElementRef, cd: ChangeDetectorRef);
    /**
     * Returns an extended array of css classes to apply on the grid component
     */
    getCssClasses(): string[];
    /**
     * Processes control changes.
     * @param newDataObject Updated data object
     */
    handleControlUpdate(newDataObject: IBaseControl): void;
    /**
     * Handles the focus event of the grid component with table layout
     */
    handleFocus: () => void;
    /**
     * Retrieves style classes for a specified column based on the  column unit type
     * @param column Table Column for which to retrieve style classes
     * @returns array of css classes for the given column
     */
    columnClass: (column: IGridUnit) => string[];
    /**
     * Returns a css style object with a width set to the predefined size
     * @param i index at which to retrieve a column width from the table layout definition object
     * @returns css style object containing only the width property
     */
    columnWidth(i: number): {
        width: string;
    };
    /**
     * Returns a css style object with a height set to the predefined size
     * @param i index at which to retrieve a row height from the table layout definition
     * @returns css style object containing only the height property
     */
    rowHeight(i: number): {
        height: string;
    };
    /**
     * Handles grid styles and dimensions
     */
    protected applyStylesAndDimensions(): void;
    /**
     * Calculates the child control sizes
     * @returns Array of control sizes
     */
    protected createChildControlSizes(): IControlSize[];
    /**
     * Retrieves values to assign to the controlSize object
     */
    protected updateControlSize(): void;
    /**
     * Initializes the table layout on the first control update
     */
    private initTableLayout;
    /**
     * Updates the table layout on a control update
     */
    private updateTableLayout;
    private applyTableLayout;
    private findWidth;
    private hasChildWithScrollbar;
    private findChild;
    static ɵfac: i0.ɵɵFactoryDeclaration<GridComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<GridComponent, "bl5-grid", never, {}, {}, never, never, false, never>;
}
