import { ElementRef, ChangeDetectorRef, OnInit, OnDestroy } from '@angular/core';
import { BaseInvolvedFieldsComponent } from '../../base/involved-fields/base-involved-fields.component';
import { ServiceProviderService } from '../../../services/serviceprovider.service';
import { IGroupInvolvedFieldsControl } from '../../../../typedefinitions/models/controls/IGroupInvolvedFieldsControl';
import { IInvolvedField } from '../../../../typedefinitions/models/IInvolvedField';
import * as i0 from "@angular/core";
/**
 * Group involved fields component class
 */
export declare class GroupInvolvedFieldsComponent extends BaseInvolvedFieldsComponent<IGroupInvolvedFieldsControl> implements OnInit, OnDestroy {
    /**
     * sp Service provider service
     */
    protected sp: ServiceProviderService;
    /**
     * el Group involved fields component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    private allFieldsSubscription?;
    /**
     * Readonly group name property
     */
    get groupName(): string;
    /**
     * Group involved fields component class constructor
     * @param sp Service provider service
     * @param el Element reference
     * @param cd Change detector reference
     */
    constructor(
    /**
     * sp Service provider service
     */
    sp: ServiceProviderService, 
    /**
     * el Group involved fields component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef);
    /**
     * Subscribe to all fields observable to be able to set an error when needed
     */
    ngOnInit(): void;
    /**
     * Unsubscribe from subscriptions on component destruction
     */
    ngOnDestroy(): void;
    /**
     * Retrieves involved fields from the render state service using the reference group name and the set error kind filter. If needed, the group errors are included in the search.
     * @returns list of involved fields
     */
    protected getInvolvedFields(): Optional<IInvolvedField[]>;
    static ɵfac: i0.ɵɵFactoryDeclaration<GroupInvolvedFieldsComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<GroupInvolvedFieldsComponent, "bl5-group-involved-fields", never, {}, {}, never, never, false, never>;
}
