import { ElementRef, ChangeDetectorRef, OnInit } from '@angular/core';
import { GroupComponent } from '../group.component';
import { ServiceProviderService } from '../../../services/serviceprovider.service';
import { IGroupSuppressButtonControl } from '../../../../typedefinitions/models/controls/IGroupSuppressButtonControl';
import * as i0 from "@angular/core";
/**
 * Group suppress button component class
 */
export declare class GroupSuppressButtonComponent extends GroupComponent<IGroupSuppressButtonControl> implements OnInit {
    /**
     * sp Service provider service
     */
    protected sp: ServiceProviderService;
    /**
     * el Group suppress button component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    /**
     * Suppress button text
     */
    text: string;
    /**
     * Group suppress button component class constructor
     * @param sp Service provider service
     * @param el Element reference
     * @param cd Change detector reference
     */
    constructor(
    /**
     * sp Service provider service
     */
    sp: ServiceProviderService, 
    /**
     * el Group suppress button component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef);
    /**
     * Initializes the suppress-button component and sets the value of the button text property.
     */
    ngOnInit(): void;
    /**
     * Creates and executes a suppress-signal action when the button is enabled and clicked
     * @param event Mouse event
     */
    handleClick(event: MouseEvent): void;
    /**
     * Creates and executes a suppress-signal action on enter or space press, when is enabled
     * @param event Keyboard event
     */
    handleKeyDown(event: KeyboardEvent): void;
    /**
     * Retrieves the component's text for a copy or cut command
     * @returns plain component text
     */
    getText(): string;
    /**
     * Creates and executes the button's suppress signal action
     */
    private executeButton;
    static ɵfac: i0.ɵɵFactoryDeclaration<GroupSuppressButtonComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<GroupSuppressButtonComponent, "bl5-group-suppress-button", never, {}, {}, never, never, false, never>;
}
