import { ElementRef, ChangeDetectorRef } from '@angular/core';
import { BaseComponent } from '../base/base.component';
import { ServiceProviderService } from '../../services/serviceprovider.service';
import { IHyperlinkControl } from '../../../typedefinitions/models/controls/IHyperlinkControl';
import * as i0 from "@angular/core";
/**
 * Hyperlink component class
 */
export declare class HyperlinkComponent extends BaseComponent<IHyperlinkControl> {
    /**
     * sp Service provider service
     */
    protected sp: ServiceProviderService;
    /**
     * el Hyperlink component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    /**
     * Hyperlink hidden anchor element reference
     * static : true since it is not wrapped in an ngIf or an ngFor, accessible in ngOnInit
     */
    private hidAnchor;
    /**
     * Hyperlink link-element id
     */
    get linkId(): string;
    /**
     * Hyperlink browser target
     */
    get target(): Optional<string>;
    get href(): Optional<string>;
    get title(): string;
    /**
     * ShowKeyboardFocus
     */
    get showKeyboardFocus(): boolean;
    /**
     * TabIndex
     */
    get tabIndex(): Optional<number>;
    /**
     * Hyperlink component class constructor
     * @param sp Service provider service
     * @param el element wrapper reference object
     * @param cd change detector reference object
     */
    constructor(
    /**
     * sp Service provider service
     */
    sp: ServiceProviderService, 
    /**
     * el Hyperlink component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef);
    /**
     * Navigates hyperlink on mouse click and executes the on click actions if any are set, when the component is enabled
     * @param event Mouse event
     */
    handleClick(event: MouseEvent): void;
    /**
     * Navigates hyperlink on keydown click and executes the on click actions if any are set, when the component is enabled
     * @param event KeyBoard event
     * @returns
     */
    handleKeyDown: (event: KeyboardEvent) => void;
    /**
     * Execute the action of the Hyperlink
     */
    execute: () => void;
    /**
     * Retrieves the component's text for a copy or cut command
     * @returns plain component text
     */
    getText(): string;
    static ɵfac: i0.ɵɵFactoryDeclaration<HyperlinkComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<HyperlinkComponent, "bl5-hyperlink", never, {}, {}, never, never, false, never>;
}
