import { ElementRef, ChangeDetectorRef, OnInit } from '@angular/core';
import { BaseComponent } from '../base/base.component';
import { ServiceProviderService } from '../../services/serviceprovider.service';
import { CSSStyleObject } from '../../../typedefinitions/models/style/CSSStyleObject';
import { IBaseControl } from '../../../typedefinitions/models/controls/IBaseControl';
import { IImageControl } from '../../../typedefinitions/models/controls/IImageControl';
import * as i0 from "@angular/core";
/**
 * Image component class
 */
export declare class ImageComponent extends BaseComponent<IImageControl> implements OnInit {
    /**
     * sp Service provider service
     */
    protected sp: ServiceProviderService;
    /**
     * el Image component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    private pixelWidth;
    private pixelHeight;
    private get imageUrl();
    /**
     * Hidden anchor element reference
     * static : false since it is wrapped in an ngIf or an ngFor, accesible in ngAfterViewInit
     */
    private hidAnchor;
    /**
     * Image source
     */
    src: string;
    /**
     * Flag indicating whether the user can click on the image (true, it's enabled, has a URI or click actions) or not (false)
     */
    get isClickable(): boolean;
    /**
     * Readonly id of the image element
     */
    get imageId(): string;
    /**
     * Readonly id of the image anchor
     */
    get imageAnchorId(): string;
    /**
     * Readonly URI target
     */
    get target(): string;
    /**
     * Image alt parameter value, set via the aria-object's aria-label
     */
    get ariaLabel(): string;
    /**
     * Readonly tab index for keyboard navigation
     */
    get tabIndex(): number;
    /**
     * Readonly image URI
     */
    get uri(): string;
    /**
     * Image component class constructor
     * @param sp Service provider service
     * @param el Element reference
     * @param cd Change detector reference
     */
    constructor(
    /**
     * sp Service provider service
     */
    sp: ServiceProviderService, 
    /**
     * el Image component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef);
    /**
     * Set the image source after initialization
     */
    ngOnInit(): void;
    /**
     * Recalculate image width/height the component is updated
     * @param newDataObject base control data object
     */
    handleControlUpdate(newDataObject: IBaseControl): void;
    /**
     * Extends the base-component's method to handle auto-width
     */
    setContentWidth(): void;
    /**
     * Extends the base-component's method to handle auto-height
     */
    setContentHeight(): void;
    /**
     * Extends the base-component's method to add extra css classes when needed
     */
    getCssClasses(): string[];
    /**
     * Extends the base-component's method to create and add the image as a css style background image to the component
     */
    getStyleObject(): CSSStyleObject;
    /**
     * If the component is enabled, navigates the uri and executes the click actions if provided on click
     * @param event Mouse event
     */
    handleClick(event: MouseEvent): void;
    /**
     * If the component is enabled, navigates the uri and executes the click actions if provided on enter or space press
     * @param event Keyboard event
     */
    handleKeyDown(event: KeyboardEvent): void;
    /**
     * If the component is enabled, navigates the uri and executes the click actions if provided
     */
    private executeAction;
    static ɵfac: i0.ɵɵFactoryDeclaration<ImageComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ImageComponent, "bl5-image", never, {}, {}, never, never, false, never>;
}
