import { ElementRef, ChangeDetectorRef } from '@angular/core';
import { BaseComponent } from '../base/base.component';
import { ServiceProviderService } from '../../services/serviceprovider.service';
import { IBaseControl } from '../../../typedefinitions/models/controls/IBaseControl';
import { IIndexItemButtonControl } from '../../../typedefinitions/models/controls/IIndexItemButtonControl';
import * as i0 from "@angular/core";
/**
 * Index item button component class
 */
export declare class IndexItemButtonComponent extends BaseComponent<IIndexItemButtonControl> {
    /**
     * sp Service provider service
     */
    protected sp: ServiceProviderService;
    /**
     * el Index item button component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    private sectionName;
    private action;
    /**
     * Text to display on the button
     */
    text: string;
    /**
     * Index item button component class constructor
     * @param sp Service provider service
     * @param el Element reference
     * @param cd Change detector reference
     */
    constructor(
    /**
     * sp Service provider service
     */
    sp: ServiceProviderService, 
    /**
     * el Index item button component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef);
    /**
     * Sets the button text, retrieves the section name and creates the button-click action based on the updated data object
     * @param newDataObject Updated data object
     */
    handleControlUpdate(newDataObject: IBaseControl): void;
    /**
     * Executes the button on mouse click if the component is enabled
     * @param event Mouse event
     */
    handleClick(event: MouseEvent): void;
    /**
     * Executes the button on enter or space press if the component is enabled
     * @param event Keyboard event
     */
    handleKeyDown(event: KeyboardEvent): void;
    /**
     * Retrieves the component's text for a copy or cut command
     * @returns plain component text
     */
    getText(): string;
    /**
     * Sets the button text, retrieves the section name and creates the button-click action
     */
    private init;
    /**
     * Executes the button action
     */
    private executeButton;
    static ɵfac: i0.ɵɵFactoryDeclaration<IndexItemButtonComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IndexItemButtonComponent, "bl5-index-item-button", never, {}, {}, never, never, false, never>;
}
