import { ElementRef, ChangeDetectorRef, OnInit } from '@angular/core';
import { BaseComponent } from '../../base/base.component';
import { ServiceProviderService } from '../../../services/serviceprovider.service';
import { ILanguageButtonControl } from '../../../../typedefinitions/models/controls/ILanguageButtonControl';
import * as i0 from "@angular/core";
/**
 * Language button component class
 */
export declare class LanguageButtonComponent extends BaseComponent<ILanguageButtonControl> implements OnInit {
    /**
     * sp Service provider service
     */
    protected sp: ServiceProviderService;
    /**
     * el Language button component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    private languageName;
    /**
     * Language button text
     */
    text: string;
    /**
     * Language button component class constructor
     * @param sp Service provider service
     * @param el Element reference
     * @param cd Change detector reference
     */
    constructor(
    /**
     * sp Service provider service
     */
    sp: ServiceProviderService, 
    /**
     * el Language button component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef);
    /**
     * Sets the button text after component initialization
     */
    ngOnInit(): void;
    /**
     * Creates and executes the set language action on mouse click, when the component is enabled
     * @param event Mouse event
     */
    handleClick(event: MouseEvent): void;
    /**
     * Creates and executes the set language action on enter or space press, when the component is enabled
     * @param event Keyboard event
     */
    handleKeyDown(event: KeyboardEvent): void;
    /**
     * Retrieves the component's text for a copy or cut command
     * @returns plain component text
     */
    getText(): string;
    /**
     * Creates and executes the set language action
     */
    private executeButton;
    static ɵfac: i0.ɵɵFactoryDeclaration<LanguageButtonComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<LanguageButtonComponent, "bl5-language-button", never, {}, {}, never, never, false, never>;
}
