import { ChangeDetectorRef, ElementRef, OnInit, OnDestroy } from '@angular/core';
import { BaseComponent } from '../../base/base.component';
import { ServiceProviderService } from '../../../services/serviceprovider.service';
import { IBaseControl } from '../../../../typedefinitions/models/controls/IBaseControl';
import { ILanguageSelectorControl } from '../../../../typedefinitions/models/controls/ILanguageSelectorControl';
import { ISelectListItem } from '../../../../typedefinitions/models/ISelectListItem';
import * as i0 from "@angular/core";
/**
 * Language selector component class
 */
export declare class LanguageSelectorComponent extends BaseComponent<ILanguageSelectorControl> implements OnInit, OnDestroy {
    /**
     * sp Service provider service
     */
    protected sp: ServiceProviderService;
    /**
     * el Language selector component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    /**
     * The language info from the render state's layout model state
     * Array with all available languages. Objects are similar to:
     * { CultureID : 'en', Description : 'English', IsLeftToRight : true, Kind : 10, MappedLanguage : 'Default', Name: 'Eng' }
     */
    private languageOptions;
    /**
     * Flag indicator for the initialisation of the option list styles
     */
    private optionListInitialized;
    /**
     * Subscription to the application wide scroll event
     */
    private scrollSubscription?;
    /**
     * Button html element
     */
    private button;
    /**
     * Option list html element
     */
    private ulist;
    /**
     * Option list id formed with the data object id
     */
    optionListId: string;
    /**
     * Select option item list
     */
    optionList: ISelectListItem[];
    /**
     * Flag indicating if the option item list is populated
     */
    get hasOptions(): boolean;
    /**
     * Option list CSS class list
     */
    optionListClass: string[];
    /**
     * Option list CSS style declaration object
     */
    optionListStyle: any;
    /**
     * Option item css styles object
     */
    optionItemStyle: any;
    /**
     * Flag indication whether the options are visible (`true`) or not (`false`)
     */
    optionsVisible: boolean;
    /**
     * Index of the focused option item
     */
    targetIndex: number;
    /**
     * Display text for the selected language as shown in the button
     */
    displayText: string;
    /**
     * Element visibility flag
     */
    get isExploded(): boolean;
    /**
     * Readonly property returning the value of the first selected value
     */
    get selectedValue(): string;
    /**
     * Host-bound width css style property of the option list element
     */
    optionListWidth: string;
    /**
     * Host-bound absolute horizontal position of the option list element relatively to the left side of the page
     */
    optionListLeft: string;
    /**
     * Host-bound absolute vertical position of the option list element relatively to the top of the page
     */
    optionListTop: string;
    /**
     * Host-bound visibility style property of the time picker element
     */
    optionListVisibility: string;
    /**
     * Language selector component class constructor
     * @param sp Service provider service
     * @param el Element reference
     * @param cd Change detector reference
     */
    constructor(
    /**
     * sp Service provider service
     */
    sp: ServiceProviderService, 
    /**
     * el Language selector component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef);
    /**
     * Subscribes to the window scroll event to hide the option list when needed.
     * Initializes the control visibility.
     * Hides the option list.
     */
    ngOnInit(): void;
    /**
     * Unsubscribes from subscriptions
     */
    ngOnDestroy(): void;
    /**
     * Processes control changes.
     * @param newDataObject
     */
    handleControlUpdate(newDataObject: IBaseControl): void;
    /**
     * Toggles options visibility
     */ toggleOptionsVisible(): void;
    /**
     * Hide options
     */ blurField(): void;
    /**
     * Handles the selection of a value in the dropdownlist
     */
    setValue(optionItem: Optional<ISelectListItem>): void;
    /**
     * Retrieves an option item by its value
     * @param value Option value
     */
    getOptionItemByValue(value: string): Optional<ISelectListItem>;
    /**
     * Sets an option item as target when hovered
     * @param index
     */
    handleMouseOver(index: number): void;
    /**
     * Handles option list navigation via keyboard input
     * @param event
     */
    handleKey(event: KeyboardEvent): void;
    /**
     * Hide the list when the window is resized
     */
    onWindowResize(): void;
    /**
     * Click outside handler
     * @param event
     */
    onWindowMousedown(event: MouseEvent): void;
    /**
     * Hide the list on touch outside
     * @param event
     */
    onWindowTouchMove(event: TouchEvent): void;
    /**
     * Hide the list on touch outside
     * @param event
     */
    onWindowTouchEnd(event: TouchEvent): void;
    /**
     * Retrieves the component's text for a copy or cut command
     * @returns plain component text
     */
    getText(): string;
    /**
     * Extends base functionality for applying styles and dimensions by processing option list styles
     */
    protected applyStylesAndDimensions(): void;
    private setOptionsListClass;
    private setOptions;
    private setSelectedOption;
    private onWindowScroll;
    private hideList;
    /**
     * Resets list style properties
     */
    private resetList;
    private initializeList;
    private getBackgroundStyle;
    /**
     * Determines in which direction the list should show and brings the list into the viewport
     */
    private showList;
    /**
     * Scroll to the list item with the current target index
     */
    private scrollToTargetIndex;
    private handleEnterKey;
    private handleKeyUp;
    private handleKeyDown;
    private handleKeyEvent;
    static ɵfac: i0.ɵɵFactoryDeclaration<LanguageSelectorComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<LanguageSelectorComponent, "bl5-language-selector", never, {}, {}, never, never, false, never>;
}
