import { ElementRef, ChangeDetectorRef } from '@angular/core';
import { BaseComponent } from '../base/base.component';
import { ServiceProviderService } from '../../services/serviceprovider.service';
import { CSSStyleObject } from '../../../typedefinitions/models/style/CSSStyleObject';
import { IBaseControl } from '../../../typedefinitions/models/controls/IBaseControl';
import { ILineControl } from '../../../typedefinitions/models/controls/ILineControl';
import * as i0 from "@angular/core";
/**
 * Line shape component class
 */
export declare class LineComponent extends BaseComponent<ILineControl> {
    /**
     * sp Service provider service
     */
    protected sp: ServiceProviderService;
    /**
     * el Line component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    /**
     * Line shape component class constructor
     * @param sp Service provider service
     * @param el Element reference
     * @param cd Change detector reference
     */
    constructor(
    /**
     * sp Service provider service
     */
    sp: ServiceProviderService, 
    /**
     * el Line component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef);
    /**
     * Processes control changes.
     * @param newDataObject
     */
    handleControlUpdate(newDataObject: IBaseControl): void;
    /**
     * Extends the base class' get style object function and applies the stroke style
     * @return CSS Style Declaration
     */
    getStyleObject(): CSSStyleObject;
    private applyStrokeStyles;
    private calculateSize;
    private getBorder;
    private getBorderWidth;
    private getBorderStyle;
    private getBorderColor;
    static ɵfac: i0.ɵɵFactoryDeclaration<LineComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<LineComponent, "bl5-line", never, {}, {}, never, never, false, never>;
}
