import { ElementRef, ChangeDetectorRef, OnInit, OnDestroy, EventEmitter } from '@angular/core';
import { Subscription } from 'rxjs';
import { ReferenceComponent } from '../reference/reference.component';
import { ServiceProviderService } from '../../services/serviceprovider.service';
import { IDataValueControl } from '../../../typedefinitions/models/controls/IDataValueControl';
import { ILookupState } from '../../../typedefinitions/models/server/ILookupState';
import * as i0 from "@angular/core";
/**
 * The `LookupComponent` class implements all basic functionality of components with lookup state fields.
 */
export declare abstract class LookupComponent<T extends IDataValueControl> extends ReferenceComponent<T> implements OnInit, OnDestroy {
    /**
     * sp Service provider service designed to provide easy access to several common services via one injectable service
     */
    protected sp: ServiceProviderService;
    /**
     * el Lookup component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    /**
     * The lookup state subscription
     */
    protected lookupStateSubscription?: Subscription;
    /**
     * The current lookup state
     */
    currentLookupState: ILookupState;
    /**
     * When a start value is set on the primary, triggers a lookup post
     */
    startValueFieldsEvent: EventEmitter<string>;
    /**
     * Lookup component class constructor
     * @param sp Service provider service designed to provide easy access to several common services via one injectable service
     * @param el Lookup component element wrapper
     * @param cd Provides change detection functionality
     */
    protected constructor(
    /**
     * sp Service provider service designed to provide easy access to several common services via one injectable service
     */
    sp: ServiceProviderService, 
    /**
     * el Lookup component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef);
    /**
     * Subscribes to the lookup state reference on component initialisation
     */
    ngOnInit(): void;
    /**
     * Unsubscribes from the lookup state reference on component destruction
     */
    ngOnDestroy(): void;
    /**
     * Override this method in subclasses to process field changes.
     * @param lookupState updated lookup state
     */
    protected handleLookupStateUpdate(lookupState: ILookupState): void;
    /**
     * Set up the lookup state subscription for this component.
     */
    private subscribeToLookupStateReference;
    private initialize;
    static ɵfac: i0.ɵɵFactoryDeclaration<LookupComponent<any>, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<LookupComponent<any>, "ng-component", never, {}, { "startValueFieldsEvent": "startValueFieldsEvent"; }, never, never, false, never>;
}
