import { OnInit, AfterViewChecked, OnDestroy } from '@angular/core';
import { Title, DomSanitizer } from '@angular/platform-browser';
import { ActivatedRoute } from '@angular/router';
import { HttpClient } from '@angular/common/http';
import { ToastrService } from 'ngx-toastr';
import { AuditTrailService } from '../../services/audit-trail/audit-trail.service';
import { CultureInfoService } from '../../services/culture-info.service';
import { DataService } from '../../services/data.service';
import { EventService } from '../../services/event.service';
import { FontService } from '../../services/font.service';
import { HelperService } from '../../services/helper.service';
import { ModelService } from '../../services/model.service';
import { PerformanceService } from '../../services/performance/performance.service';
import { RenderStateService } from '../../services/renderstate.service';
import { RuntimeParametersService } from '../../services/runtime-parameters.service';
import { ShortcutService } from '../../services/shortcut.service';
import { SizeTreeService } from '../../services/sizetree/sizetree.service';
import { SubscriptionService } from '../../services/subscription.service';
import { UserAgentService } from '../../services/user-agent.service';
import { IBaseComponentViewModel2 } from '../../../typedefinitions/models/view/IBaseViewModel';
import * as i0 from "@angular/core";
/**
 * The main component lives through the entire application lifecycle.
 */
export declare class MainComponent implements AfterViewChecked, OnInit, OnDestroy {
    private activatedRoute;
    private document;
    private domSanitizer;
    private http;
    private title;
    private auditTrailService;
    private cultureInfoService;
    private dataService;
    private eventService;
    private fontService;
    private helperService;
    private modelService;
    private performanceService;
    private renderStateService;
    private runtimeParametersService;
    private shortcutService;
    private sizeTreeService;
    private subscriptionService;
    private toastrService;
    private userAgentService;
    private cssLinkHref;
    private cssLink;
    private fontStyles;
    private pageInitialized;
    private newPage;
    private queryParamsSubscription?;
    private rootControlSubscription?;
    private renderStateSubscription?;
    private runtimeParametersSubscription?;
    /**
     * The view/component children displayed in the grid
     */
    child: Nullable<IBaseComponentViewModel2>;
    /**
     * Main component class constructor.
     * @param activatedRoute Contains the information about the route associated with the main component, which is loaded in the router outlet.
     * @param document A reference class for the global document object
     * @param domSanitizer helps preventing Cross Site Scripting Security bugs (XSS) by sanitizing
     * @param http Provides methods to perform HTTP requests
     * @param title Title A service that can be used to get and set the title of a current HTML document
     * @param auditTrailService Provides functionality for tracking user behaviour
     * @param cultureInfoService Used for storing and consulting culture settings
     * @param dataService A central hub for most server communications
     * @param fontService used to calculate text sizes for specified font styles
     * @param eventService A central hub containing global application events
     * @param helperService Provides general functions that are commonly user throughout the application
     * @param modelService A helper service for determining the right child component by its control type
     * @param performanceService handles performance measuring
     * @param renderStateService Provides functionality for managing the render state information
     * @param runtimeParametersService Runtime parameters factory class
     * @param shortcutService Shortcut subscription handler service
     * @param sizeTreeService Size tree manager service
     * @param subscriptionService A central hub for managing subscriptions
     * @param toastrService Shows a toast (pop-up message)
     * @param userAgentService Provides device/browser information
     */
    constructor(activatedRoute: ActivatedRoute, document: Document, domSanitizer: DomSanitizer, http: HttpClient, title: Title, auditTrailService: AuditTrailService, cultureInfoService: CultureInfoService, dataService: DataService, eventService: EventService, fontService: FontService, helperService: HelperService, modelService: ModelService, performanceService: PerformanceService, renderStateService: RenderStateService, runtimeParametersService: RuntimeParametersService, shortcutService: ShortcutService, sizeTreeService: SizeTreeService, subscriptionService: SubscriptionService, toastrService: ToastrService, userAgentService: UserAgentService);
    /**
     * Initializes the page and the subscriptions
     */
    ngOnInit(): void;
    /**
     * Updates the after-view-checked subject
     */
    ngAfterViewChecked(): void;
    /**
     * Unsubscribe from all active subscription
     */
    ngOnDestroy(): void;
    /**
     * Notifies the audit trail service of any pressed keys
     */
    handleKeyboardEvent(event: KeyboardEvent): void;
    private setRootControlSubscription;
    /**
     * Creates a render state subscription and defines a render state change handler that updates document elements based on the new render state
     * @private
     */
    private setRenderStateSubscription;
    private initializePage;
    /**
     * Determine the depth of the RootControl
     * @param object
     */
    private determineDepthOfObject;
    static ɵfac: i0.ɵɵFactoryDeclaration<MainComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<MainComponent, "bl5-main", never, { "child": { "alias": "child"; "required": false; }; }, {}, never, never, false, never>;
}
