import { AfterViewInit, ChangeDetectorRef, ElementRef } from '@angular/core';
import { Maps, CenterPositionModel, LayerSettingsModel, ZoomSettingsModel, IMouseEventArgs } from '@syncfusion/ej2-angular-maps';
import { ToastrService } from 'ngx-toastr';
import { MapsComponent } from '../maps.component';
import { ServiceProviderService } from '../../../services/serviceprovider.service';
import { MapsFieldConverterService } from '../../../services/converters/maps-field-converter.service';
import * as i0 from "@angular/core";
/**
 * Bing Maps component class
 */
export declare class BingMapsComponent extends MapsComponent implements AfterViewInit {
    /**
     * sp Service provider service
     */
    protected sp: ServiceProviderService;
    /**
     * el Component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    /**
     * Toastr service for showing pop up messages
     */
    protected toastr: ToastrService;
    /**
     * Maps field converter service
     */
    protected converter: MapsFieldConverterService;
    /**
     * The template's maps component class
     */
    maps: Maps;
    /**
     * Flag indicating map settings are ready to be used
     */
    ready: boolean;
    /**
     * Provides a settings list for all the map layers
     */
    layers: LayerSettingsModel[];
    /**
     * The maps component's zoom settings
     */
    zoomSettings: ZoomSettingsModel;
    /**
     * The maps component's initial center position
     */
    centerPosition: CenterPositionModel;
    /**
     * Bing Maps component class constructor
     * @param sp Service provider service
     * @param el Element reference
     * @param cd Change detector reference
     * @param toastr Service for showing pop up messages
     * @param converter Maps field converter service
     */
    constructor(
    /**
     * sp Service provider service
     */
    sp: ServiceProviderService, 
    /**
     * el Component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef, 
    /**
     * Toastr service for showing pop up messages
     */
    toastr: ToastrService, 
    /**
     * Maps field converter service
     */
    converter: MapsFieldConverterService);
    /**
     * Extends the base after view init callback function and applies all maps settings
     */
    ngAfterViewInit(): void;
    /**
     * Activates the field and if allowed, adds the selected geolocation to the selected locations in the response value.
     * @param ev IMouseEventArgs Mouse click event arguments.
     */
    onBingMapsClick(ev: IMouseEventArgs): void;
    /**
     * Activates the field and handles the marker click event.
     * User locations are removed when clicked, while for static markers the value of the selected flag is toggled.
     * @param ev IMouseEventArgs Mouse click event arguments.
     */
    onBingMarkerClick(ev: IMouseEventArgs): void;
    private refreshMap;
    private toCenterPositionModel;
    private toCoords;
    private getMarkerSettings;
    static ɵfac: i0.ɵɵFactoryDeclaration<BingMapsComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<BingMapsComponent, "bl5-bing-maps", never, {}, {}, never, never, false, never>;
}
