/// <reference types="google.maps" />
import { ChangeDetectorRef, ElementRef, OnInit } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { Observable } from 'rxjs';
import { ToastrService } from 'ngx-toastr';
import { MapsComponent } from '../maps.component';
import { ServiceProviderService } from '../../../services/serviceprovider.service';
import { MapsFieldConverterService } from '../../../services/converters/maps-field-converter.service';
import { IMarker } from '../../../../typedefinitions/models/IMarker';
import * as i0 from "@angular/core";
/**
 * Google Maps component class
 */
export declare class GoogleMapsComponent extends MapsComponent implements OnInit {
    private httpClient;
    /**
     * sp Service provider service
     */
    protected sp: ServiceProviderService;
    /**
     * el Component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    /**
     * Toastr service for showing pop up messages
     */
    protected toastr: ToastrService;
    /**
     * Maps field converter service
     */
    protected converter: MapsFieldConverterService;
    /**
     * MarkerOptions object used to define the properties that can be set on a Marker.
     */ private get markerOptions();
    /**
     * Flag indicating if the api is loaded and ready to be use
     */
    apiLoaded: Observable<boolean>;
    /**
     * MapOptions object used to define the properties that can be set on a Map.
     */ get mapOptions(): google.maps.MapOptions;
    /**
     * Google Maps component class constructor
     * @param httpClient Http Client
     * @param sp Service provider service
     * @param el Element reference
     * @param cd Change detector reference
     * @param toastr Service for showing pop up messages
     * @param converter Maps field converter service
     */
    constructor(httpClient: HttpClient, 
    /**
     * sp Service provider service
     */
    sp: ServiceProviderService, 
    /**
     * el Component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef, 
    /**
     * Toastr service for showing pop up messages
     */
    toastr: ToastrService, 
    /**
     * Maps field converter service
     */
    converter: MapsFieldConverterService);
    /**
     * Extends the base control's ngOnInit function and loads the maps through the Google Maps api, using the provided api key
     */
    ngOnInit(): void;
    /**
     * Activates the field and if allowed, adds the selected geolocation to the selected locations in the response value.
     * @param ev Google Maps map mouse event, containing
     */
    onGoogleMapsClick(ev: google.maps.MapMouseEvent): void;
    /**
     * Activates the field and handles the marker click event.
     * User locations are removed when clicked, while for static markers the value of the selected flag is toggled.
     * @param marker The marker for which to handle the click event.
     */
    onGoogleMarkerClick(marker: IMarker): void;
    /**
     * Remove a given user location from the selected locations
     * @param location the user location to remove.
     */
    onGoogleUserLocationClick(location: string): void;
    /**
     * Retrieves a base set of marker options
     * @param location
     */
    getBaseMarkerOptions(location: string): google.maps.MarkerOptions & {
        position: Optional<google.maps.LatLngLiteral>;
        visible: boolean;
    };
    /**
     * Retrieves the map's marker options for a specific marker
     * @param Location location of the marker
     * @param Description marker description
     * @param Selected flag indicating whether the marker is selected
     */
    getMarkerOptions({ Location, Description, Selected }: IMarker): google.maps.MarkerOptions;
    /**
     * Returns the (un)selected marker icon url
     * @param selected Flag by which to determine the returned url.
     */
    getMarkerIcon(selected?: boolean): string;
    /**
     * Converts a comma seperated coordinates string into a Google Maps LatLngLiteral object
     * @param coords coordinate string
     */
    toLatLngLiteral(coords: string): Optional<google.maps.LatLngLiteral>;
    /**
     * Converts a Google Maps LatLngLiteral object into a comma seperated coordinates string
     * @param latLng
     */
    private toCoords;
    static ɵfac: i0.ɵɵFactoryDeclaration<GoogleMapsComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<GoogleMapsComponent, "bl5-google-maps", never, {}, {}, never, never, false, never>;
}
