import { EventEmitter, OnDestroy, OnInit } from '@angular/core';
import { BehaviorSubject } from 'rxjs';
import { SubscriptionService } from '../../../services/subscription.service';
import { IMenuItem } from '../../../../typedefinitions/models/IMenuItem';
import { IBackgroundStyle } from '../../../../typedefinitions/models/style/IBackgroundStyle';
import * as i0 from "@angular/core";
/**
 * Menu-item component class
 */
export declare class MenuItemComponent implements OnInit, OnDestroy {
    private subscriptionService;
    /**
     * menu-item field subscription
     */
    private menuItemSubscription?;
    /**
     * menu-item object
     */
    private menuItem;
    /**
     * active element tree subject
     */
    aetSubject: BehaviorSubject<string[]>;
    /**
     * ID of the current menu item
     */
    menuItemId: string;
    /**
     * current menu item list level
     */
    level: number;
    /**
     * background brush for menu item sub lists determined by the main menu component
     */
    submenuBackground: IBackgroundStyle;
    /**
     * Menu item changed notifier
     */
    itemChanged: EventEmitter<IMenuItem>;
    /**
     * Menu item click event emitter used to notify the menu control of the click event on one of it's children
     */
    itemClicked: EventEmitter<IMenuItem>;
    /**
     * Read-only flag indicating if the menu-item is enabled or not
     */
    get isEnabled(): boolean;
    /**
     * Read-only flag indicating if the menu-item is disabled or not
     */
    get isDisabled(): boolean;
    /**
     * Read-only flag indicating if the menu-item is visible or not
     */
    get isVisible(): boolean;
    /**
     * Read-only flag indicating if the menu-item is hidden or not
     */
    get isHidden(): boolean;
    /**
     * Read-only flag indicating if the menu-item is collapsed or not
     */
    get isCollapsed(): boolean;
    /**
     * Read-only flag indicating if the menu-item has a sub menu or not
     */
    get hasChildren(): boolean;
    /**
     * Read-only property containing sub-menu menu-items
     */
    get children(): IMenuItem[];
    /**
     * Read-only property for the displayed menu item text
     */
    get text(): string;
    /**
     * Read-only menu item shortcut
     */
    get shortcut(): string;
    /**
     * Tab index property for WCAG
     */
    get tabindex(): number;
    /**
     * Menu-item component class constructor
     * @param subscriptionService
     */
    constructor(subscriptionService: SubscriptionService);
    /**
     * A callback method that is invoked immediately after the default change detector has checked the directive's data-bound properties for the first time,
     * and before any of the view or content children have been checked.
     * It is invoked only once when the directive is instantiated.
     */
    ngOnInit(): void;
    /**
     * A callback method that performs custom clean-up, invoked immediately after the directive is destroyed.
     */
    ngOnDestroy(): void;
    /**
     * Notify the parent control to execute the related action
     */
    handleItemClick(item: IMenuItem): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<MenuItemComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<MenuItemComponent, "li[bl5-menu-item]", never, { "aetSubject": { "alias": "aetSubject"; "required": false; }; "menuItemId": { "alias": "menuItemId"; "required": false; }; "level": { "alias": "level"; "required": false; }; "submenuBackground": { "alias": "submenuBackground"; "required": false; }; }, { "itemChanged": "itemChanged"; "itemClicked": "itemClicked"; }, never, never, false, never>;
}
