import { OnDestroy, EventEmitter, OnInit, ChangeDetectorRef } from '@angular/core';
import { BehaviorSubject } from 'rxjs';
import { SubscriptionService } from '../../../services/subscription.service';
import { ColorService } from '../../../services/color.service';
import { IBackgroundStyle } from '../../../../typedefinitions/models/style/IBackgroundStyle';
import { IColor } from '../../../../typedefinitions/models/IColor';
import { IMenuItem } from '../../../../typedefinitions/models/IMenuItem';
import * as i0 from "@angular/core";
/**
 * Menu-list component class
 */
export declare class MenuListComponent implements OnInit, OnDestroy {
    private subscriptionService;
    private colorService;
    cd: ChangeDetectorRef;
    /**
     * menu-item field subscription
     */
    private parentSubscription?;
    private get isRoot();
    /**
     * active element tree subscription
     */
    private aetSubscription?;
    /**
     * active element tree array
     */
    aet: string[];
    /**
     * active element tree subject
     */
    aetSubject: BehaviorSubject<string[]>;
    /**
     * current menu list level
     */
    level: number;
    /**
     * flag indicating whether the list is enabled
     */
    enabled: boolean;
    /**
     * list of menu items in this menu list
     */
    menuItems: IMenuItem[];
    /**
     * background brush for menu item sub lists determined by the main menu component
     */
    submenuBackground: IBackgroundStyle;
    /**
     * ID of the menu item containing this list
     */
    parentId: string;
    /**
     * Menu item click event emitter used to notify the menu control of the click event on one of it's children
     */
    itemClicked: EventEmitter<IMenuItem>;
    /**
     * Menu-list component class constructor
     * @param subscriptionService
     * @param colorService
     * @param cd Change detector reference
     */
    constructor(subscriptionService: SubscriptionService, colorService: ColorService, cd: ChangeDetectorRef);
    /**
     * A callback method that is invoked immediately after the default change detector has checked the directive's data-bound properties for the first time,
     * and before any of the view or content children have been checked.
     * It is invoked only once when the directive is instantiated.
     */
    ngOnInit(): void;
    /**
     * A callback method that performs custom clean-up, invoked immediately after the directive is destroyed.
     */
    ngOnDestroy(): void;
    /**
     * Prevent the parent list-item from being triggered when the user click between buttons
     * @param event Click event
     */
    onListClick: (event: Event) => void;
    /**
     * Toggle display item's submenu on click
     * @param event Click event
     * @param menuItem Targeted menu item child object
     */
    onItemClick: (event: Event, menuItem: IMenuItem) => boolean;
    /**
     * Display child submenu on mouse-enter of a submenu-item (not for root-items)
     * @param event Mouse-over event
     * @param menuItem Targeted menu item child object
     */
    onItemMouseEnter: (event: Event, menuItem: IMenuItem) => void;
    /**
     * Bubble up the event
     * @param menuItem
     */
    handleItemClick(menuItem: IMenuItem): void;
    /**
     * Retrieves the background for each menu item
     * @param color
     */
    getColor(color: IColor): string;
    static ɵfac: i0.ɵɵFactoryDeclaration<MenuListComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<MenuListComponent, "ul[bl5-menu-list]", never, { "aetSubject": { "alias": "aetSubject"; "required": false; }; "level": { "alias": "level"; "required": false; }; "enabled": { "alias": "enabled"; "required": false; }; "menuItems": { "alias": "menuItems"; "required": false; }; "submenuBackground": { "alias": "submenuBackground"; "required": false; }; "parentId": { "alias": "parentId"; "required": false; }; }, { "itemClicked": "itemClicked"; }, never, never, false, never>;
}
