import { ElementRef, ChangeDetectorRef } from '@angular/core';
import { BehaviorSubject } from 'rxjs';
import { BaseComponent } from '../base/base.component';
import { ServiceProviderService } from '../../services/serviceprovider.service';
import { IBackgroundStyle } from '../../../typedefinitions/models/style/IBackgroundStyle';
import { IBaseControl } from '../../../typedefinitions/models/controls/IBaseControl';
import { IMenuControl } from '../../../typedefinitions/models/controls/IMenuControl';
import { IMenuItem } from '../../../typedefinitions/models/IMenuItem';
import * as i0 from "@angular/core";
/**
 * Menu component class
 */
export declare class MenuComponent extends BaseComponent<IMenuControl> {
    /**
     * sp Service provider service
     */
    protected sp: ServiceProviderService;
    /**
     * el Menu component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    /**
     * static : false since it is wrapped in an ngIf or an ngFor, accessible in ngAfterViewInit
     */
    private menuList;
    /**
     * Active element tree behaviour subject is used to show/hide active menu item elements
     */
    aetSubject: BehaviorSubject<string[]>;
    /**
     * Readonly flag indicating if the menu has menu-items
     */
    get hasChildren(): boolean;
    /**
     * Readonly flag indicating if the component is enabled
     */
    get isEnabled(): boolean;
    /**
     * Read-only menu-items property
     */
    get children(): IMenuItem[];
    /**
     * Read-only submenu background info property
     */
    get submenuBackground(): IBackgroundStyle;
    /**
     * Menu component class constructor
     * @param sp Service provider service
     * @param el Element reference
     * @param cd Change detector reference
     */
    constructor(
    /**
     * sp Service provider service
     */
    sp: ServiceProviderService, 
    /**
     * el Menu component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef);
    /**
     * The menu item key event triggers the click event
     * @param event
     */
    onKeyup(event: KeyboardEvent): void;
    /**
     * Processes control changes.
     * @param newDataObject
     */
    handleControlUpdate(newDataObject: IBaseControl): void;
    /**
     * The menu item click handler executes menu-item defined action
     * @param item
     */
    handleItemClick(item: IMenuItem): void;
    /**
     * Overrides the implementation to determine the auto-width. The auto-width of the menu component depends on the size of the menu items.
     */
    setContentWidth(): void;
    /**
     * Deactivates/closes all menu items
     */
    onClickOutside(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<MenuComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<MenuComponent, "bl5-menu", never, {}, {}, never, never, false, never>;
}
