import { ChangeDetectorRef, ElementRef, AfterViewInit } from '@angular/core';
import { SliderChangeEventArgs, SliderComponent, SliderTickEventArgs, TicksDataModel } from '@syncfusion/ej2-angular-inputs';
import { ReferenceComponent } from '../../reference/reference.component';
import { FieldConverterService } from '../../../services/converters/field-converter.service';
import { NumberFieldConverterService } from '../../../services/converters/number-field-converter.service';
import { RealFieldConverterService } from '../../../services/converters/real-field-converter.service';
import { ServiceProviderService } from '../../../services/serviceprovider.service';
import { TicksService } from '../../../services/ticks.service';
import { IFieldInfo } from '../../../../typedefinitions/models/observables/IFieldInfo';
import { INavigationModeStrategy } from '../../../../typedefinitions/models/INavigationModeStrategy';
import { INumberSliderControl } from '../../../../typedefinitions/models/controls/INumberSliderControl';
import * as i0 from "@angular/core";
/**
 * Number slider component class
 */
export declare class NumberSliderComponent extends ReferenceComponent<INumberSliderControl> implements AfterViewInit {
    /**
     * sp Service provider service
     */
    protected sp: ServiceProviderService;
    /**
     * el Number slider component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    /**
     * Number field converter service
     */
    protected numberConverter: NumberFieldConverterService;
    /**
     * Real field converter service
     */
    protected realConverter: RealFieldConverterService;
    /**
     * ticksService Calculates the number of ticks and their individual placement
     */
    protected ticksService: TicksService;
    /**
     * Determines where the labels are drawn
     */
    private labelInterval;
    /**
     * Determines whether the slider will be drawn in horizontal or vertical direction
     */
    orientation: number;
    /**
     * Text representation of the property determining whether the slider will be drawn in horizontal or vertical direction
     */
    orientationStr: string;
    /**
     * Determines the slider text direction
     */
    rtl: boolean;
    /**
     * Depending on the orientation, this property determines the height or width of the slider handle (for a respectively horizontal and vertical oriented slider)
     */
    private thumbSize;
    /**
     * Color of the slider thumb element
     */
    private thumbColor;
    /**
     * Determines the position of tick marks with respect to the track of the slider: None, TopLeft, BottomRight or Both
     */
    private tickPlacement;
    /**
     * Determines where the tick marks are drawn
     */
    private ticksPerInterval;
    /**
     * Flag indicating if the number slider should display options in an ascending (false) or descending (true) order
     */
    private reverseOrder;
    /**
     * Precision represents the number of decimal digits
     */
    private precision;
    /**
     * Initiator flag
     */
    private isDefaultValue;
    /**
     * Floor value
     */
    private _minValue;
    /**
     * Ceil value
     */
    private _maxValue;
    /**
     * Current selected value
     */
    private _selectedValue;
    /**
     * Reference to the slider element
     */
    protected sliderElement: SliderComponent;
    /**
     * Depending on the orientation, determines the height or width of the slider bar (for a respectively horizontal and vertical oriented slider)
     */
    trackSize: string;
    /**
     * Color of the slider track
     */
    trackColor: string;
    /**
     * Thumb pixel size css variable
     */
    get sfThumbSize(): string;
    /**
     * Thumb background color css variable
     */
    get sfThumbBackgroundColor(): string;
    /**
     * Slider step size
     */
    step: number;
    /**
     * Determines whether the ticks are visible
     */
    showTicks: boolean;
    /**
     * Tick configuration collection
     */
    ticks: TicksDataModel;
    /**
     * Floor value
     */
    get minValue(): number;
    /**
     * Ceil value
     */
    get maxValue(): number;
    /**
     * Current selected value
     */
    get selectedValue(): number;
    /**
     * Flag indicating whether the control is enabled
     */
    get enabled(): boolean;
    /**
     * Number slider component class constructor
     * @param sp Service provider service
     * @param el Element reference
     * @param cd Change detector reference
     * @param numberConverter Number field converter service
     * @param realConverter Real field converter service
     * @param ticksService Calculates the number of ticks and their individual placement
     */
    constructor(
    /**
     * sp Service provider service
     */
    sp: ServiceProviderService, 
    /**
     * el Number slider component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef, 
    /**
     * Number field converter service
     */
    numberConverter: NumberFieldConverterService, 
    /**
     * Real field converter service
     */
    realConverter: RealFieldConverterService, 
    /**
     * ticksService Calculates the number of ticks and their individual placement
     */
    ticksService: TicksService);
    /**
     * Triggers the size-tree once after the view is initialized
     */
    ngAfterViewInit(): void;
    /**
     * Processes control changes, extends the base-class and reevaluates settings
     * @param dataObject Updated number slider control data object
     */
    handleControlUpdate(dataObject: INumberSliderControl): void;
    /**
     * Handles the change of values of the corresponding field
     * @param fieldInfo updated field info
     */
    handleFieldUpdate(fieldInfo: IFieldInfo): void;
    /**
     * Extends the base method and returns an extended array of css classes to apply
     * @returns list of css class names
     */
    getCssClasses(): string[];
    /**
     * Method used to determine if a tick is selected
     * @param {number} value tick value
     * @returns {boolean} indication whether the given flag value equals the currently selected value
     */
    isSelected(value: number): boolean;
    /**
     * Overrides the base component's set content width function to set the leaf's content width
     */
    setContentWidth(): void;
    /**
     * Overrides the base component's set content height function to set the leaf's content height
     */
    setContentHeight(): void;
    /**
     * Initializes the number slider control and all its components
     */
    init(): void;
    /**
     * Fires whenever the Slider value is changed. In other term, this event will be triggered, while drag the slider thumb completed.
     */
    handleChanged(args: SliderChangeEventArgs): void;
    /**
     * Fires while dragging the thumb
     */
    handleChange(args?: SliderChangeEventArgs): void;
    /**
     * Triggers on rendering the ticks element in the Slider, which is used to customize the ticks labels dynamically.
     * @param args
     */
    handleRenderingTicks(args: SliderTickEventArgs): void;
    /**
     * Select the previous step value.
     */
    previousValue(): void;
    /**
     *  Set the next step value.
     */
    nextValue(): void;
    /**
     * Selects the first value of the number slider
     */
    firstValue(): void;
    /**
     * Selects the last value of the number slider
     */
    lastValue(): void;
    /**
     * Set specific logic for keyboard navigation in insert mode
     * @returns Keyboard insert navigation mode strategy
     */
    getKeyboardInsertStrategy(): INavigationModeStrategy;
    /**
     * Retrieves the empty strategy for keyboard
     */
    getKeyboardEmptyStrategy(): INavigationModeStrategy;
    /**
     * Overrides the reference component's default check auto enter method
     * @param autoEnterEnabled true if auto enter is enabled, otherwise false
     * @param converter Field converter service
     * @param fieldInfo Field info
     * @returns flag indicating whether auto-enter should be executed or not
     */
    protected checkAutoEnter(autoEnterEnabled: boolean, converter: FieldConverterService, fieldInfo: IFieldInfo): boolean;
    private getConverter;
    private setSelectedValue;
    private setTicks;
    static ɵfac: i0.ɵɵFactoryDeclaration<NumberSliderComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<NumberSliderComponent, "bl5-number-slider", never, {}, {}, never, never, false, never>;
}
