import { ElementRef, ChangeDetectorRef, OnInit } from '@angular/core';
import { BaseComponent } from '../../base/base.component';
import { ServiceProviderService } from '../../../services/serviceprovider.service';
import { IPageSuppressButtonControl } from '../../../../typedefinitions/models/controls/IPageSuppressButtonControl';
import * as i0 from "@angular/core";
/**
 * Page suppress button component class
 */
export declare class PageSuppressButtonComponent extends BaseComponent<IPageSuppressButtonControl> implements OnInit {
    /**
     * sp Service provider service
     */
    protected sp: ServiceProviderService;
    /**
     * el Page suppress button component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    /**
     * Page suppress button text
     */
    text: string;
    /**
     * Page suppress button component class constructor
     * @param sp Service provider service
     * @param el Element reference
     * @param cd Change detector reference
     */
    constructor(
    /**
     * sp Service provider service
     */
    sp: ServiceProviderService, 
    /**
     * el Page suppress button component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef);
    /**
     * Sets the button text after component initialization
     */
    ngOnInit(): void;
    /**
     * Creates and executes the suppress-signal action on mouse click, when the component is enabled
     * @param event Mouse event
     */
    handleClick(event: MouseEvent): void;
    /**
     * Creates and executes the suppress-signal action on enter or space press, when the component is enabled
     * @param event Keyboard event
     */
    handleKeyDown(event: KeyboardEvent): void;
    /**
     * Retrieves the component's text for a copy or cut command
     * @returns plain component text
     */
    getText(): string;
    /**
     * Creates and executes the suppress-signal action
     */
    private executeButton;
    static ɵfac: i0.ɵɵFactoryDeclaration<PageSuppressButtonComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<PageSuppressButtonComponent, "bl5-page-suppress-button", never, {}, {}, never, never, false, never>;
}
