import { AfterViewInit, ChangeDetectorRef, ElementRef, OnDestroy, OnInit } from '@angular/core';
import { BaseComponent } from '../base/base.component';
import { PanelControlSize } from '../../services/sizetree/PanelControlSize';
import { ServiceProviderService } from '../../services/serviceprovider.service';
import { ModelService } from '../../services/model.service';
import { IBaseComponentViewModel } from '../../../typedefinitions/models/view/IBaseViewModel';
import { IControlSize } from '../../services/sizetree/IControlSize';
import { IPanelComponentViewModel } from '../../../typedefinitions/models/view/IPanelComponentViewModel';
import { IPanelControl } from '../../../typedefinitions/models/controls/IPanelControl';
import * as i0 from "@angular/core";
/**
 * Panel/Group-box component class
 */
export declare class PanelComponent extends BaseComponent<IPanelControl> implements OnInit, OnDestroy, AfterViewInit, IPanelComponentViewModel {
    protected modelService: ModelService;
    protected sp: ServiceProviderService;
    protected el: ElementRef;
    protected cd: ChangeDetectorRef;
    /**
     * Default auto-height value for when this control contains a container control
     */
    private readonly DEFAULT_AUTO_HEIGHT;
    /**
     * legend element reference
     */
    private fieldSetElementRef;
    /**
     * legend element reference
     */
    private legendElementRef;
    /**
     * HTML element used for determining the controls auto width size
     */
    protected get fieldSetElement(): Nullable<HTMLElement>;
    /**
     * HTML element used for determining the controls auto height size
     */
    protected get legendElement(): Nullable<HTMLElement>;
    /**
     * Component's child
     */
    child: IBaseComponentViewModel;
    /**
     * Nullable panel control size object getter
     */
    get controlSize(): Nullable<PanelControlSize>;
    /**
     * Nullable panel control size object setter
     */
    set controlSize(value: Nullable<PanelControlSize>);
    /**
     * Control's horizontal scrollbar property
     */
    horizontalScrollbar: any;
    /**
     * Control's vertical scrollbar property
     */
    verticalScrollbar: any;
    /**
     * Legend text
     */
    legendText: Optional<string>;
    /**
     * Legend specific styling object
     */
    legendStyle: any;
    /**
     * Flag indicating if the component is visualised as group box control
     */
    get isGroupBox(): boolean;
    /**
     * Flag indicating if there is a legend text
     */
    get hasLegendText(): boolean;
    /**
     * The host-bound legend padding property sets the space between element legend's content and its border.
     */
    elementLegendPadding: string;
    /**
     * Panel control class constructor
     * @param modelService The model service is a helper service for determining the right child component by its control type.
     * @param sp The service provider service is designed to provide easy access to several common services via one injectable service.
     * @param el Component element wrapper
     * @param cd Provides change detection functionality
     */
    constructor(modelService: ModelService, sp: ServiceProviderService, el: ElementRef, cd: ChangeDetectorRef);
    /**
     * A callback method that is invoked immediately after the default change detector has checked the directive's data-bound properties for the first time,
     * and before any of the view or content children have been checked.
     * It is invoked only once when the directive is instantiated.
     * Extends the base control function, instigates the panel's child control.
     */
    ngOnInit(): void;
    /**
     * A callback method that is invoked immediately after Angular has completed initialization of a component's view.
     * It is invoked only once when the view is instantiated.
     * Extends the base control function, adds a scroll event listener.
     */
    ngAfterViewInit(): void;
    /**
     * A callback method that performs custom clean-up, invoked immediately after the directive is destroyed, extends the base control function.
     */
    ngOnDestroy(): void;
    /**
     * Returns the array of css classes to apply, extends the base control function.
     */
    getCssClasses(): string[];
    /**
     * Process control changes, extends the base control function.
     * @param newDataObject Updated panel control data object
     */
    handleControlUpdate(newDataObject: IPanelControl): void;
    /**
     * Retrieves the height that the browser assigned to the element, if this is an auto-sized leaf control, overrides the base control function.
     */
    setContentWidth(): void;
    /**
     * Retrieves the height that the browser assigned to the element, if this is an auto-sized leaf control, overrides the base control function.
     */
    setContentHeight(): void;
    /**
     * Applying of the styles, not affecting the subscriptions
     * Overrides the base component function to add specific style values
     */
    getStyleObject(): Partial<CSSStyleDeclaration>;
    /**
     * Retrieves the component's text for a copy or cut command
     * @returns plain component text
     */
    getText(): string;
    /**
     * Creates the child's size tree control size
     */
    protected createChildControlSizes(): IControlSize[];
    /**
     * Updates the child's size tree control size
     */
    protected updateControlSize(): void;
    private addScrollEventListener;
    private removeScrollEventListener;
    private handleScroll;
    static ɵfac: i0.ɵɵFactoryDeclaration<PanelComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<PanelComponent, "bl5-panel", never, {}, {}, never, never, false, never>;
}
