import { ElementRef, ChangeDetectorRef, OnInit } from '@angular/core';
import { BaseComponent } from '../../base/base.component';
import { ServiceProviderService } from '../../../services/serviceprovider.service';
import { IParallelButtonControl } from '../../../../typedefinitions/models/controls/IParallelButtonControl';
import * as i0 from "@angular/core";
/**
 * Parallel button component class
 */
export declare class ParallelButtonComponent extends BaseComponent<IParallelButtonControl> implements OnInit {
    /**
     * sp Service provider service
     */
    protected sp: ServiceProviderService;
    /**
     * el Parallel button component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    /**
     * Button text
     */
    text: string;
    /**
     * Parallel button component class constructor
     * @param sp Service provider service
     * @param el Element reference
     * @param cd Change detector reference
     */
    constructor(
    /**
     * sp Service provider service
     */
    sp: ServiceProviderService, 
    /**
     * el Parallel button component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef);
    /**
     * Sets the button text on component initialization
     */
    ngOnInit(): void;
    /**
     * Creates and executes the set parallel button action on mouse click, when the component is enabled
     * @param event Mouse event
     */
    handleClick(event: MouseEvent): void;
    /**
     * Creates and executes the set parallel button action on enter or space press, when the component is enabled
     * @param event Keyboard event
     */
    handleKeyDown(event: KeyboardEvent): void;
    /**
     * Retrieves the component's text for a copy or cut command
     * @returns plain component text
     */
    getText(): string;
    /**
     * Creates and executes the set parallel button action
     */
    private executeButton;
    static ɵfac: i0.ɵɵFactoryDeclaration<ParallelButtonComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ParallelButtonComponent, "bl5-parallel-button", never, {}, {}, never, never, false, never>;
}
