import { ElementRef, ChangeDetectorRef, OnInit, OnDestroy } from '@angular/core';
import { BaseComponent } from '../../base/base.component';
import { ServiceProviderService } from '../../../services/serviceprovider.service';
import { IRecordErrorsInvolvedFieldsControl } from '../../../../typedefinitions/models/controls/IRecordErrorsInvolvedFieldsControl';
import * as i0 from "@angular/core";
/**
 * Record errors involved fields component class
 */
export declare class RecordErrorsInvolvedFieldsComponent extends BaseComponent<IRecordErrorsInvolvedFieldsControl> implements OnInit, OnDestroy {
    /**
     * sp Service provider service Provides easy access to several commonly used services
     */
    protected sp: ServiceProviderService;
    /**
     * el Record errors involved fields component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides view-change detection functionality
     */
    protected cd: ChangeDetectorRef;
    /**
     * Involved field names subscription
     */
    private involvedFieldNamesSubscription?;
    /**
     * List item view children
     */
    private listItems;
    /**
     * Involved field names observable property
     */
    involvedFieldNames: string[];
    /**
     * Record errors involved fields component class constructor
     * @param sp Service provider service provides easy access to several commonly used services
     * @param el Element reference component element wrapper
     * @param cd Change detector reference provides view-change detection functionality
     */
    constructor(
    /**
     * sp Service provider service Provides easy access to several commonly used services
     */
    sp: ServiceProviderService, 
    /**
     * el Record errors involved fields component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides view-change detection functionality
     */
    cd: ChangeDetectorRef);
    /**
     * Sets the involved field names observable after component initialization
     */
    ngOnInit(): void;
    /**
     * Unsubscribe from involved field names subscription on component destruction
     */
    ngOnDestroy(): void;
    /**
     * Involved field name click handler
     * @param fieldName Name of the field to navigate to
     */
    handleClick(fieldName: string): void;
    /**
     * Sets the hover color on the currently hovered list item
     * @param index hovered list item index
     */
    onMouseOver: (index: number) => void;
    /**
     * Removes the hover color when a list item is no longer hovered
     * @param index hovered list item index
     */
    onMouseOut: (index: number) => void;
    /**
     * Sets the involved field names observable.
     */
    private getInvolvedFieldNames;
    /**
     * Retrieves the name or local name from the involved field based on the component's display name setting
     * @param involvedField
     */
    private getInvolvedFieldName;
    private setSetHoverColors;
    private removeColors;
    private isEqual;
    static ɵfac: i0.ɵɵFactoryDeclaration<RecordErrorsInvolvedFieldsComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<RecordErrorsInvolvedFieldsComponent, "bl5-record-errors-involved-fields", never, {}, {}, never, never, false, never>;
}
