import { AfterViewInit, ChangeDetectorRef, ElementRef, OnDestroy, OnInit } from '@angular/core';
import { BaseComponent } from '../../base/base.component';
import { ServiceProviderService } from '../../../services/serviceprovider.service';
import { IError } from '../../../../typedefinitions/models/IError';
import { IRecordErrorsListboxControl } from '../../../../typedefinitions/models/controls/IRecordErrorsListboxControl';
import * as i0 from "@angular/core";
/**
 * Record error listbox component class
 */ export declare class RecordErrorsListboxComponent extends BaseComponent<IRecordErrorsListboxControl> implements OnInit, AfterViewInit, OnDestroy {
    /**
     * sp Service provider service Provides easy access to several commonly used services
     */
    protected sp: ServiceProviderService;
    /**
     * el Record errors listbox component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides view-change detection functionality
     */
    protected cd: ChangeDetectorRef;
    /**
     * The record errors subscription disposable resource
     */
    private recordErrorsSubscription?;
    /**
     * List item view children
     */
    private listItems;
    /**
     * Records error list property
     */
    recordErrors: IError[];
    /**
     * Record errors listbox component class constructor
     * @param sp Service provider service provides easy access to several commonly used services
     * @param el Element reference component element wrapper
     * @param cd Change detector reference provides view-change detection functionality
     */
    constructor(
    /**
     * sp Service provider service Provides easy access to several commonly used services
     */
    sp: ServiceProviderService, 
    /**
     * el Record errors listbox component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides view-change detection functionality
     */
    cd: ChangeDetectorRef);
    /**
     * Subscribes to the record errors subscription and sets the publicly accessible the record errors on change.
     */
    ngOnInit(): void;
    /**
     * Sets the selection color on the selected item after view init
     */
    ngAfterViewInit(): void;
    /**
     * Sets the selection color on the selected item after a control update
     */
    handleControlUpdate(newDataObject: IRecordErrorsListboxControl): void;
    /**
     * Unsubscribe from the record-errors subscription.
     */
    ngOnDestroy(): void;
    /**
     * Click handler that sets the error related fields as selected and removes selection from all other fields
     * @param recordError The click record error
     * @param index index of the clicked records error in the list
     */
    handleClick(recordError: IError, index: number): void;
    /**
     * Creates error text for a given record error based on the error type and name
     * @param recordError The error for which to retrieve the error text
     */
    getErrorText: (recordError: IError) => string;
    /**
     * Sets the hover color on the currently hovered list item
     * @param index hovered list item index
     */
    onMouseOver: (index: number) => void;
    /**
     * Removes the hover color on mouse out
     * @param index hovered list item index
     */
    onMouseOut: (index: number) => void;
    private getInvolvedFieldName;
    /**
     * Subscribes to the record errors subscription and sets the publicly accessible the record errors on change.
     */
    private getRecordErrorsSubscription;
    private updateRecordErrors;
    private setSelectedRecord;
    private setSelectedRecordColor;
    private setColors;
    private removeAllColors;
    private recordErrorSelected;
    private setSelectedColors;
    private setSetHoverColors;
    private removeColors;
    private isEqual;
    static ɵfac: i0.ɵɵFactoryDeclaration<RecordErrorsListboxComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<RecordErrorsListboxComponent, "bl5-record-errors-listbox", never, {}, {}, never, never, false, never>;
}
