import { ElementRef, ChangeDetectorRef } from '@angular/core';
import { ReferenceComponent } from '../reference/reference.component';
import { ServiceProviderService } from '../../services/serviceprovider.service';
import { IResponseControl } from '../../../typedefinitions/models/controls/IResponseControl';
import { INavigationModeStrategy } from '../../../typedefinitions/models/INavigationModeStrategy';
import { IFieldInfo } from '../../../typedefinitions/models/observables/IFieldInfo';
import * as i0 from "@angular/core";
/**
 * Response component class
 */
export declare class ResponseComponent extends ReferenceComponent<IResponseControl> {
    /**
     * sp Service provider service designed to provide easy access to several common services via one injectable service
     */
    protected sp: ServiceProviderService;
    /**
     * el Category radio button component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    private converterService;
    /**
     * Represents the checked state of the response radio button.
     */
    isChecked: boolean;
    /**
     * Response component class constructor
     * @param sp Service provider service
     * @param el Element reference
     * @param cd Change detector reference
     */
    constructor(
    /**
     * sp Service provider service designed to provide easy access to several common services via one injectable service
     */
    sp: ServiceProviderService, 
    /**
     * el Category radio button component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef);
    /**
     * Extends the reference component's `handleFieldUpdate` function.
     * @param fieldInfo Updated field info
     */
    handleFieldUpdate(fieldInfo: IFieldInfo): void;
    /**
     * Extends the base control's get style object function and removes the background styling if needed
     * @return CSS style declaration object
     */
    getStyleObject(): CSSStyleDeclaration;
    /**
     * Response control's click event handler
     * @param event
     */
    handleClick(event: MouseEvent): void;
    /**
     * Set specific logic for insert strategy
     * @returns Radio button navigation mode insert strategy object
     */
    getKeyboardInsertStrategy(): INavigationModeStrategy;
    /**
     * Sets and returns a field converter service based on a given data value subscription's data type
     * @param fieldInfo Field info
     * @returns Field converter service
     */
    private getConverter;
    static ɵfac: i0.ɵɵFactoryDeclaration<ResponseComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ResponseComponent, "bl5-response", never, {}, {}, never, never, false, never>;
}
