import { ChangeDetectorRef, ElementRef, OnInit, OnDestroy } from '@angular/core';
import { ServiceProviderService } from '../../../services/serviceprovider.service';
import { ModelService } from '../../../services/model.service';
import { BaseComponent } from '../../base/base.component';
import { IBaseComponentViewModel } from '../../../../typedefinitions/models/view/IBaseViewModel';
import { ISkiplinksContainerControl } from '../../../../typedefinitions/models/controls/ISkiplinksContainerControl';
import * as i0 from "@angular/core";
/**
 * Skip links component class
 */
export declare class SkiplinksContainerComponent extends BaseComponent<ISkiplinksContainerControl> implements OnInit, OnDestroy {
    protected modelService: ModelService;
    /**
     * sp Service provider service
     */
    protected sp: ServiceProviderService;
    /**
     * el Button component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Change detector reference
     */
    protected cd: ChangeDetectorRef;
    /**
     * Component's child
     */
    children: IBaseComponentViewModel[];
    /**
     * SkiplinkContainer component class constructor.
     * Injects the required services
     * @param modelService The model service is a helper service for determining the right child component by its control type.
     * @param sp Service provider service
     * @param el Element reference
     * @param cd Change detector reference
     */
    constructor(modelService: ModelService, 
    /**
     * sp Service provider service
     */
    sp: ServiceProviderService, 
    /**
     * el Button component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Change detector reference
     */
    cd: ChangeDetectorRef);
    /**
     * A callback method that is invoked immediately after the default change detector has checked the directive's data-bound properties for the first time,
     * and before any of the view or content children have been checked.
     * It is invoked only once when the directive is instantiated.
     * Extends the base control function, instigates the panel's child control.
     */
    ngOnInit(): void;
    /**
     * A callback method that performs custom clean-up, invoked immediately after the directive is destroyed, extends the base control function.
     */
    ngOnDestroy(): void;
    /**
     * Handles the focus event of the skip links container component
     */
    onFocus: () => void;
    /**
     * The container should always be hidden/height = 0
     */
    setContentHeight(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<SkiplinksContainerComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SkiplinksContainerComponent, "bl5-skiplinks-container", never, {}, {}, never, never, false, never>;
}
