import { ElementRef, ChangeDetectorRef } from '@angular/core';
import { ReferenceComponent } from '../../reference/reference.component';
import { ServiceProviderService } from '../../../services/serviceprovider.service';
import { SetFieldConverterService } from '../../../services/converters/set-field-converter.service';
import { EnumerationFieldConverterService } from '../../../services/converters/enumeration-field-converter.service';
import { IFieldInfo } from '../../../../typedefinitions/models/observables/IFieldInfo';
import { INavigationModeStrategy } from '../../../../typedefinitions/models/INavigationModeStrategy';
import { ISpecialAnswerButtonControl } from '../../../../typedefinitions/models/controls/ISpecialAnswerButtonControl';
import * as i0 from "@angular/core";
/**
 * Special answer button component
 */
export declare class SpecialAnswerButtonComponent extends ReferenceComponent<ISpecialAnswerButtonControl> {
    /**
     * sp Service provider service designed to provide easy access to several common services via one injectable service
     */
    protected sp: ServiceProviderService;
    /**
     * el Special answer button component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    /**
     * setConverter The converter service for fields of data type set
     */
    protected setConverter: SetFieldConverterService;
    /**
     * enumerationConverter The converter service for fields of data type enumeration
     */
    protected enumerationConverter: EnumerationFieldConverterService;
    /**
     * Represents the selected state of the category.
     */
    private isSelected;
    /**
     * The displayed text for the button.
     */
    text: string;
    /**
     * Special answer button component class constructor
     * @param sp
     * @param el
     * @param cd
     * @param setConverter
     * @param enumerationConverter
     */
    constructor(
    /**
     * sp Service provider service designed to provide easy access to several common services via one injectable service
     */
    sp: ServiceProviderService, 
    /**
     * el Special answer button component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef, 
    /**
     * setConverter The converter service for fields of data type set
     */
    setConverter: SetFieldConverterService, 
    /**
     * enumerationConverter The converter service for fields of data type enumeration
     */
    enumerationConverter: EnumerationFieldConverterService);
    /**
     * Handles the mouse down event
     */
    handleMouseDown(): void;
    /**
     * Handles the mouse up event
     */
    handleMouseUp(): void;
    /**
     * Handles the mouse click event
     * @param event mouse event
     */
    handleClick(event: MouseEvent): void;
    /**
     * Handles the key down event
     * @param event keyboard event
     */
    handleKeyDown(event: KeyboardEvent): void;
    /**
     * Set specific logic for insert strategy
     * @returns Navigation mode strategy
     */
    getKeyboardInsertStrategy(): INavigationModeStrategy;
    /**
     * Retrieves the empty strategy for keyboard
     */
    getKeyboardEmptyStrategy(): INavigationModeStrategy;
    /**
     * Set specific logic for speed key pressed event
     */
    handleSpeedKeyPressed(): void;
    /**
     * Retrieves the component's text for a copy or cut command
     * @returns plain component text
     */
    getText(): string;
    /**
     * Handles field value updates.
     * @param fieldInfo Field info
     */
    protected handleFieldUpdate(fieldInfo: IFieldInfo): void;
    private executeButton;
    static ɵfac: i0.ɵɵFactoryDeclaration<SpecialAnswerButtonComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SpecialAnswerButtonComponent, "bl5-special-answer-button", never, {}, {}, never, never, false, never>;
}
