import { ElementRef, ChangeDetectorRef } from '@angular/core';
import { ReferenceComponent } from '../../reference/reference.component';
import { ServiceProviderService } from '../../../services/serviceprovider.service';
import { SetFieldConverterService } from '../../../services/converters/set-field-converter.service';
import { IFieldInfo } from '../../../../typedefinitions/models/observables/IFieldInfo';
import { INavigationModeStrategy } from '../../../../typedefinitions/models/INavigationModeStrategy';
import { ISpecialAnswerCheckboxControl } from '../../../../typedefinitions/models/controls/ISpecialAnswerCheckboxControl';
import * as i0 from "@angular/core";
/**
 * Special answer checkbox component
 */
export declare class SpecialAnswerCheckboxComponent extends ReferenceComponent<ISpecialAnswerCheckboxControl> {
    /**
     * sp Service provider service designed to provide easy access to several common services via one injectable service
     */
    protected sp: ServiceProviderService;
    /**
     * el Special answer checkbox component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    /**
     * converter The converter service for fields of data type set
     */
    protected converter: SetFieldConverterService;
    /**
     * Flag that indicates if the special answer checkbox is checked
     */
    isChecked: boolean;
    /**
     * Special answer checkbox component class constructor
     * @param sp Service provider service designed to provide easy access to several common services via one injectable service
     * @param el Special answer checkbox component element wrapper
     * @param cd Provides change detection functionality
     * @param converter The converter service for fields of data type set
     */
    constructor(
    /**
     * sp Service provider service designed to provide easy access to several common services via one injectable service
     */
    sp: ServiceProviderService, 
    /**
     * el Special answer checkbox component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef, 
    /**
     * converter The converter service for fields of data type set
     */
    converter: SetFieldConverterService);
    /**
     * Handles field value updates.
     * @param fieldInfo updated field info
     */
    handleFieldUpdate(fieldInfo: IFieldInfo): void;
    /**
     * Applies styles
     * @returns style object
     */
    getStyleObject(): CSSStyleDeclaration;
    /**
     * Handle clicking on the checkbox.
     * The field will be set to the new state. In handleFieldUpdate the checkbox checked state will be determined again.
     */
    handleClick(): void;
    /**
     * Set specific logic for insert strategy
     * @returns navigation mode strategy
     */
    getKeyboardInsertStrategy(): INavigationModeStrategy;
    /**
     * Set specific logic for empty / accessible strategy
     * @returns navigation mode strategy
     */
    getKeyboardEmptyStrategy(): INavigationModeStrategy;
    /**
     * Set specific logic for speed key pressed event
     */
    handleSpeedKeyPressed(): void;
    private executeCheckBox;
    static ɵfac: i0.ɵɵFactoryDeclaration<SpecialAnswerCheckboxComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SpecialAnswerCheckboxComponent, "bl5-special-answer-checkbox", never, {}, {}, never, never, false, never>;
}
