import { ElementRef, ChangeDetectorRef } from '@angular/core';
import { ReferenceComponent } from '../../reference/reference.component';
import { ServiceProviderService } from '../../../services/serviceprovider.service';
import { EnumerationFieldConverterService } from '../../../services/converters/enumeration-field-converter.service';
import { IFieldInfo } from '../../../../typedefinitions/models/observables/IFieldInfo';
import { INavigationModeStrategy } from '../../../../typedefinitions/models/INavigationModeStrategy';
import { ISpecialAnswerRadioButtonControl } from '../../../../typedefinitions/models/controls/ISpecialAnswerRadioButtonControl';
import * as i0 from "@angular/core";
/**
 * Special answer radio button component class
 */
export declare class SpecialAnswerRadioButtonComponent extends ReferenceComponent<ISpecialAnswerRadioButtonControl> {
    /**
     * sp Service provider service designed to provide easy access to several common services via one injectable service
     */
    protected sp: ServiceProviderService;
    /**
     * el Special answer radio button component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    /**
     * converter Enumeration field converter service
     */
    protected converter: EnumerationFieldConverterService;
    /**
     * Represents the checked state of the category's special answer.
     */
    isChecked: boolean;
    /**
     * Special answer radio button component class constructor
     * @param sp Service provider service
     * @param el Element reference
     * @param cd Change detector reference
     * @param converter Enumeration field converter service
     */
    constructor(
    /**
     * sp Service provider service designed to provide easy access to several common services via one injectable service
     */
    sp: ServiceProviderService, 
    /**
     * el Special answer radio button component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef, 
    /**
     * converter Enumeration field converter service
     */
    converter: EnumerationFieldConverterService);
    /**
     * Extends the reference component's `handleFieldUpdate` function.
     * Updates the `isChecked` property's value.
     * @param fieldInfo updated field info
     */
    handleFieldUpdate(fieldInfo: IFieldInfo): void;
    /**
     * Extends the base component's `getStyleObject` function.
     * Removes the background style object properties if no background color is set.
     * @returns CSS style declaration object
     */
    getStyleObject(): CSSStyleDeclaration;
    /**
     * Handles data value subscription value changes
     */
    handleChange(): void;
    /**
     * Set specific logic for insert strategy
     * @returns Radio button insert navigation mode strategy
     */
    getKeyboardInsertStrategy(): INavigationModeStrategy;
    /**
     * Set specific logic for empty / accessible strategy
     * @returns navigation mode strategy
     */
    getKeyboardEmptyStrategy(): INavigationModeStrategy;
    /**
     * Set specific logic for speed key pressed event
     */
    handleSpeedKeyPressed(): void;
    private executeRadioButton;
    static ɵfac: i0.ɵɵFactoryDeclaration<SpecialAnswerRadioButtonComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SpecialAnswerRadioButtonComponent, "bl5-special-answer-radio-button", never, {}, {}, never, never, false, never>;
}
