import { OnInit, OnDestroy } from '@angular/core';
import { EventService } from '../../services/event.service';
import { RenderStateService } from '../../services/renderstate.service';
import { SubscriptionService } from '../../services/subscription.service';
import * as i0 from "@angular/core";
/**
 * The `SplashComponent` is responsible for showing and hiding the loading animation.
 * Toggle these states by triggering the `showSplash` and `hideSplash` events from the
 * `EventService` respectively.
 *
 * <h6 class='code'>Example usage</h6>
 * ```typescript
 * // show splash screen
 * this.eventService.showSplash.emit();
 *
 * // hide splash screen
 * this.eventService.hideSplash.emit();
 * ```
 */
export declare class SplashComponent implements OnInit, OnDestroy {
    private eventService;
    private renderStateService;
    private subscriptionService;
    private showSplashSubscription?;
    private hideSplashSubscription?;
    private renderStateSubscription?;
    /**
     * Flag indicating if the splash screen overlay should be shown
     */
    showSplash: boolean;
    /**
     * The flash image source
     */
    readonly src: string;
    /**
     * The flash overlay is disabled when the optimize-no-stylesheet flag is enabled
     */
    optimizeNoStylesheets: boolean;
    /**
     * The splash component class constructor sets the splash source property.
     * @param eventService the central hub in Blaise containing global application events
     * @param renderStateService provides functionality for easy access to the render state information
     * @param subscriptionService provides a central hub for managing subjects and subscriptions
     */
    constructor(eventService: EventService, renderStateService: RenderStateService, subscriptionService: SubscriptionService);
    /**
     * Subscribes to events that trigger a visibility change on the splash overlay
     */
    ngOnInit(): void;
    /**
     * Unsubscribes from all running subscriptions
     */
    ngOnDestroy(): void;
    /**
     * Start a timer observable to show the splash screen, but terminate the stream as soon as a cancelObservable emits.
     * This way the splash screen won't show at all if the cancel event occurs sooner than the timer event.
     */
    private setDelayedSplash;
    private show;
    private hide;
    static ɵfac: i0.ɵɵFactoryDeclaration<SplashComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SplashComponent, "bl5-splash", never, {}, {}, never, never, false, never>;
}
