import { ChangeDetectorRef, ElementRef } from '@angular/core';
import { BaseComponent } from '../base/base.component';
import { ModelService } from '../../services/model.service';
import { ServiceProviderService } from '../../services/serviceprovider.service';
import { IBaseControl } from '../../../typedefinitions/models/controls/IBaseControl';
import { ITableControl } from '../../../typedefinitions/models/controls/ITableControl';
import { ITableCellViewModel, ITableLayoutCss } from '../../../typedefinitions/models/ITableLayoutCss';
import { ITableComponentViewModel } from '../../../typedefinitions/models/view/ITableComponentViewModel';
import { GridType } from '../../../typedefinitions/enums/GridType';
import * as i0 from "@angular/core";
/**
 * CSS Table component class forms an CSS grid friendly alternative to the Table Component Class
 */
export declare class CssTableComponent extends BaseComponent<ITableControl> implements ITableComponentViewModel {
    /**
     * modelService Model service
     */
    protected modelService: ModelService;
    /**
     * sp Service provider service
     */
    protected sp: ServiceProviderService;
    /**
     * el Table component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    /**
     * The table layout definition object contains layout info for the table columns, rows and cells
     */
    tableLayout: ITableLayoutCss;
    /**
     * The host-bound odd-row-color property sets the background color of an odd row element.
     */
    oddRowColor: string;
    /**
     * The host-bound even-row-color property sets the background color of an even row element.
     */
    evenRowColor: string;
    /**
     * The grid-line-color property defines the border color of a cell border.
     */
    gridLineColor: string;
    /**
     * The grid-line-width property sets the border width of a cell.
     */
    gridLineWidth: string;
    /**
     * The grid-lines property defines which cell border should be drawn (`None`, `Horizontal` only, `Vertical` only or `Both` horizontal and vertical).
     */
    gridLines: GridType;
    /**
     * Table component class constructor
     * @param modelService Model service
     * @param sp Service provider service
     * @param el Element reference
     * @param cd Change detector reference
     */
    constructor(
    /**
     * modelService Model service
     */
    modelService: ModelService, 
    /**
     * sp Service provider service
     */
    sp: ServiceProviderService, 
    /**
     * el Table component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef);
    /**
     * Processes control changes
     * @param newDataObject The updated data object
     */
    handleControlUpdate(newDataObject: IBaseControl): void;
    /**
     * handles the mouse over event to show the tooltip defined on the tablerow
     * @param event
     * @param cell
     * @returns
     */
    handleMouseOver(event: MouseEvent, cell: ITableCellViewModel): void;
    /**
     * handles the mouse out event to hide the tooltip defined on the tablerow
     */
    handleMouseOut(): void;
    private isTooltipDisabled;
    private initialize;
    /**
     * Initialize columns, rows and cells
     * @private
     */
    private initializeTableLayout;
    /**
     * Initialize columns
     * @private
     */
    private initializeColumns;
    /**
     * Creates a table cell css background object for a table row
     * @private
     */
    private determineBackground;
    private initializeRow;
    private initializeCells;
    /**
     * Create empty cells in tablelayout
     * @param rowIndex
     * @param background
     * @param isVisible
     */
    private initializeEmptyCells;
    /**
     * Added GridLine to tableLayout
     */
    private addGridLines;
    static ɵfac: i0.ɵɵFactoryDeclaration<CssTableComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<CssTableComponent, "bl5-css-table", never, {}, {}, never, never, false, never>;
}
