import { ElementRef, ChangeDetectorRef } from '@angular/core';
import { BaseComponent } from '../base/base.component';
import { GridControlSize } from '../../services/sizetree/GridControlSize';
import { ServiceProviderService } from '../../services/serviceprovider.service';
import { ModelService } from '../../services/model.service';
import { IBaseControl } from '../../../typedefinitions/models/controls/IBaseControl';
import { IBaseComponentViewModel } from '../../../typedefinitions/models/view/IBaseViewModel';
import { IControlSize } from '../../services/sizetree/IControlSize';
import { ITableLayout } from '../../../typedefinitions/models/ITableLayout';
import { ITableControl } from '../../../typedefinitions/models/controls/ITableControl';
import { ITableComponentViewModel } from '../../../typedefinitions/models/view/ITableComponentViewModel';
import * as i0 from "@angular/core";
/**
 * Table component class
 */
export declare class TableComponent extends BaseComponent<ITableControl> implements ITableComponentViewModel {
    /**
     * modelService Model service
     */
    protected modelService: ModelService;
    /**
     * sp Service provider service
     */
    protected sp: ServiceProviderService;
    /**
     * el Table component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    private oddRowColor;
    private evenRowColor;
    /**
     * Table component layout information
     */
    tableLayout: Nullable<ITableLayout>;
    /**
     * List of children : ITableRow[]
     */
    children: IBaseComponentViewModel[];
    /**
     * Nullable grid control size object getter
     */
    get controlSize(): Nullable<GridControlSize>;
    /**
     * Nullable grid control size object setter
     */
    set controlSize(value: Nullable<GridControlSize>);
    /**
     * Table component class constructor
     * @param modelService Model service
     * @param sp Service provider service
     * @param el Element reference
     * @param cd Change detector reference
     */
    constructor(
    /**
     * modelService Model service
     */
    modelService: ModelService, 
    /**
     * sp Service provider service
     */
    sp: ServiceProviderService, 
    /**
     * el Table component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef);
    /**
     * (Re)initialize on control update
     * @param newDataObject
     */
    handleControlUpdate(newDataObject: IBaseControl): void;
    /**
     * Set control properties based on available information
     */
    initialize: () => void;
    /**
     * Initialize control layout
     */
    initiateTableLayout: () => ITableLayout;
    /**
     * Extends the base control's get CSS classes function and adds additional css classes when applicable
     */
    getCssClasses(): string[];
    /**
     * Extends the base control's apply styles and dimensions function to account for column sizes
     */
    protected applyStylesAndDimensions(): void;
    /**
     * Calculates the child control sizes
     */
    protected createChildControlSizes(): IControlSize[];
    /**
     * Extends the base control's update control size function
     */
    protected updateControlSize(): void;
    private findChild;
    static ɵfac: i0.ɵɵFactoryDeclaration<TableComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TableComponent, "bl5-table", never, {}, {}, never, never, false, never>;
}
