import { ElementRef, ChangeDetectorRef, OnInit, OnDestroy } from '@angular/core';
import { BaseComponent } from '../base/base.component';
import { ServiceProviderService } from '../../services/serviceprovider.service';
import { ITextControl } from '../../../typedefinitions/models/controls/ITextControl';
import * as i0 from "@angular/core";
/**
 * Text component class
 */
export declare class TextComponent extends BaseComponent<ITextControl> implements OnInit, OnDestroy {
    /**
     * sp Service provider service
     */
    protected sp: ServiceProviderService;
    /**
     * el Text component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    private subscription?;
    /**
     * Component text
     */
    text: string;
    /**
     * Readonly label-for property
     */
    get labelFor(): Optional<string>;
    /**
     * Text component class constructor
     * @param sp Service provider service
     * @param el element wrapper reference object
     * @param cd change detector reference object
     */
    constructor(
    /**
     * sp Service provider service
     */
    sp: ServiceProviderService, 
    /**
     * el Text component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef);
    /**
     * Subscribes to the size tree ready event on component initialization
     */
    ngOnInit(): void;
    /**
     * Unsubscribe from active subscriptions
     */
    ngOnDestroy(): void;
    /**
     * Updates the displayed text on new information given by a control update
     * @param newDataObject
     */
    handleControlUpdate(newDataObject: ITextControl): void;
    /**
     * Retrieves the component's text for a copy or cut command
     * @returns plain component text
     */
    getText(): string;
    private onSizeTreeReady;
    static ɵfac: i0.ɵɵFactoryDeclaration<TextComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TextComponent, "bl5-text", never, {}, {}, never, never, false, never>;
}
