import { ElementRef, ChangeDetectorRef } from '@angular/core';
import { BaseComponent } from '../base/base.component';
import { ServiceProviderService } from '../../services/serviceprovider.service';
import { ITextBoxControl } from '../../../typedefinitions/models/controls/ITextBoxControl';
import * as i0 from "@angular/core";
/**
 * Text component class
 */
export declare class TextboxComponent extends BaseComponent<ITextBoxControl> {
    /**
     * sp Service provider service
     */
    protected sp: ServiceProviderService;
    /**
     * el Text component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    /**
     * Text value
     */
    text: string;
    /**
     * max-length property of the textbox: maximum number of characters allowed
     */
    maxLength: number;
    /**
     * Value for the size attribute which specifies the visible width, in characters, of the input element
     */
    size: number;
    /**
     * Text component class constructor
     * @param sp Service provider service
     * @param el element wrapper reference object
     * @param cd change detector reference object
     */
    constructor(
    /**
     * sp Service provider service
     */
    sp: ServiceProviderService, 
    /**
     * el Text component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef);
    /**
     * Sets the input value and triggers on text changed actions for the control
     * @param event
     */
    onInput(event: Event): void;
    /**
     * Extends the base component's update handler by setting the component's text
     * Retrieves the data object text from the render state on initialisation
     * The text can be updated from the action service through and
     * @param newDataObject
     */
    handleControlUpdate(newDataObject: ITextBoxControl): void;
    /**
     * Retrieves the component's text for a copy or cut command
     * @returns plain component text
     */
    getText(): string;
    /**
     * Sets text from a paste command on the component
     * @param text Text to set on the control
     */
    setText(text: string): void;
    /**
     * Clears the text from the component after a cut command
     */
    clearText(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<TextboxComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TextboxComponent, "bl5-textbox", never, {}, {}, never, never, false, never>;
}
