import { OnInit, OnDestroy, ElementRef, ChangeDetectorRef } from '@angular/core';
import { BaseComponent } from '../base/base.component';
import { ServiceProviderService } from '../../services/serviceprovider.service';
import { TimerService } from '../../services/timer.service';
import { ITimerControl } from '../../../typedefinitions/models/controls/ITimerControl';
import * as i0 from "@angular/core";
/**
 * Timer component class
 */
export declare class TimerComponent extends BaseComponent<ITimerControl> implements OnInit, OnDestroy {
    /**
     * sp Service provider service
     */
    protected sp: ServiceProviderService;
    /**
     * el Timer component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    /**
     * timerService The timer service allows for a set of actions to be periodically executed.
     */
    private timerService;
    /**
     * Timer component class constructor
     * @param sp Service provider service
     * @param el Element reference
     * @param cd Change detector reference
     * @param timerService The timer service allows for a set of actions to be periodically executed.
     */
    constructor(
    /**
     * sp Service provider service
     */
    sp: ServiceProviderService, 
    /**
     * el Timer component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef, 
    /**
     * timerService The timer service allows for a set of actions to be periodically executed.
     */
    timerService: TimerService);
    /**
     * Creates a timer in the timer service on component initialization
     */
    ngOnInit(): void;
    /**
     * Removes the timer from the timer service on component destruction
     */
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<TimerComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TimerComponent, "bl5-timer", never, {}, {}, never, never, false, never>;
}
