import { ColorService } from '../../services/color.service';
import { TooltipService } from '../../services/tooltip.service';
import { RenderStateService } from '../../services/renderstate.service';
import { RichTextConverterService } from '../../services/rich-text-converter.service';
import { StyleGeneratorService } from '../../services/style-generator.service';
import { CSSStyleObject } from '../../../typedefinitions/models/style/CSSStyleObject';
import { ITooltipEvent } from '../../../typedefinitions/events/ITooltipEvent';
import * as i0 from "@angular/core";
/**
 * The tooltip component is shown near a Blaise control by the tooltip directive when it is defined on the control's data object and the control is being hoovered by the mouse
 */
export declare class TooltipComponent {
    private colorService;
    private tooltipService;
    private renderStateService;
    private richTextConverterService;
    private styleGeneratorService;
    private placement;
    private tooltipRef;
    private get tooltipElement();
    /**
     * The absolute top-position of the control on the page. Default is off-page.
     */
    top: number;
    /**
     * The absolute left-position of the control on the page. Default is off-page.
     */
    left: number;
    /**
     * The html content or simple text to show on the tooltip
     */
    text: string;
    /**
     * Tooltip css class list
     */
    cssClass: string[];
    /**
     * Tooltip style object
     */
    style: CSSStyleObject;
    /**
     * The tooltip class constructor subscribes to the handle tooltip event thrown by the tooltip directive on the tooltip service.
     * @param colorService provides functionality for converting a color object into a css style string
     * @param tooltipService provides throws tooltip events on which we can subscribe
     * @param renderStateService provides easy access to render state information as provided by the server
     * @param richTextConverterService converts a rich text object to rich and dynamic html string
     * @param styleGeneratorService generates css style objects
     */
    constructor(colorService: ColorService, tooltipService: TooltipService, renderStateService: RenderStateService, richTextConverterService: RichTextConverterService, styleGeneratorService: StyleGeneratorService);
    /**
     * The tooltip event handler function shows/hides the tooltip
     * @param event Contains information on how to handle the event such as the desired visible, info about the host element and information about the tooltip
     */
    handleEvent(event: ITooltipEvent): void;
    private show;
    private hide;
    private positionElements;
    private position;
    private offset;
    private getStyle;
    private parentOffsetEl;
    private isStaticPositioned;
    static ɵfac: i0.ɵɵFactoryDeclaration<TooltipComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TooltipComponent, "bl5-tooltip", never, {}, {}, never, never, false, never>;
}
