import { OnDestroy, ViewContainerRef } from '@angular/core';
import { TooltipService } from '../../services/tooltip.service';
import { UserAgentService } from '../../services/user-agent.service';
import { ITooltip } from '../../../typedefinitions/models/controls/properties/tooltip/ITooltip';
import * as i0 from "@angular/core";
/**
 * The tooltip directive is responsible for retrieving all tooltip information from
 * the control object and displaying the tooltip when the user hovers over the element
 * with the mouse.
 */
export declare class TooltipDirective implements OnDestroy {
    private viewRef;
    private tooltipService;
    private userAgentService;
    /**
     * Flag indicating whether showing the tooltip should be disabled or not.
     * It gets disabled when a mobile device is detected or when no tooltip text is set.
     * Returns true when the tooltip should be disabled, otherwise false.
     */
    private get isDisabled();
    /**
     * Component data object containing tooltip information
     */
    tooltip?: ITooltip;
    /**
     * Tooltip directive class constructor
     * @param viewRef View container reference represents a container where one or more views can be attached to a component.
     * @param tooltipService
     * @param userAgentService
     */
    constructor(viewRef: ViewContainerRef, tooltipService: TooltipService, userAgentService: UserAgentService);
    /**
     * Always hide on component/directive destruction
     */
    ngOnDestroy(): void;
    /**
     * The mouse over event handler triggers showing the tooltip
     * @param event
     */ onMouseOver(event: MouseEvent): void;
    /**
     * The mouse out event handler triggers hiding the tooltip
     */ onMouseLeave(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<TooltipDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<TooltipDirective, "[bl5Tooltip]", never, { "tooltip": { "alias": "bl5Tooltip"; "required": false; }; }, {}, never, never, false, never>;
}
