import { ElementRef, ChangeDetectorRef } from '@angular/core';
import { ReferenceComponent } from '../reference/reference.component';
import { BlobFieldConverterService } from '../../services/converters/blob-field-converter.service';
import { ServiceProviderService } from '../../services/serviceprovider.service';
import { UploadService } from '../../services/upload.service';
import { IFieldInfo } from '../../../typedefinitions/models/observables/IFieldInfo';
import { IUploadControl } from '../../../typedefinitions/models/controls/IUploadControl';
import * as i0 from "@angular/core";
/**
 * Upload component class allows uploading blob data objects
 */
export declare class UploadComponent extends ReferenceComponent<IUploadControl> {
    /**
     * sp Service provider service Provides easy access to several commonly used services
     */
    protected sp: ServiceProviderService;
    /**
     * el Upload component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides view-change detection functionality
     */
    protected cd: ChangeDetectorRef;
    /**
     * uploadService File upload service
     */
    protected uploadService: UploadService;
    /**
     * Blob field converter service
     */
    private converter;
    /**
     * input control element reference
     * static : false since it is wrapped in an ngIf, not accessible in ngOnInit
     */
    private fileRef;
    private get file();
    private get files();
    /**
     * The button's displayed text.
     */
    get text(): string;
    /**
     * Property containing allowed file extensions and mime types
     */
    fileFilter: string;
    /**
     * Upload component class constructor
     * @param sp Service provider service
     * @param el Element reference
     * @param cd Change detector reference
     * @param uploadService File upload service
     * @param converter Blob field converter service
     */
    constructor(
    /**
     * sp Service provider service Provides easy access to several commonly used services
     */
    sp: ServiceProviderService, 
    /**
     * el Upload component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides view-change detection functionality
     */
    cd: ChangeDetectorRef, 
    /**
     * uploadService File upload service
     */
    uploadService: UploadService, 
    /**
     * Blob field converter service
     */
    converter: BlobFieldConverterService);
    /**
     * Processes control changes, extends the base-class method by updating edit-mask settings
     * @param newDataObject updated data object
     */
    handleControlUpdate(newDataObject: IUploadControl): void;
    /**
     * Handles the change of values of the corresponding field
     * @param fieldInfo updated field info
     */
    handleFieldUpdate(fieldInfo: IFieldInfo): void;
    /**
     * Handles the mouse click event
     * @param event mouse event
     */
    handleClick(event: MouseEvent): void;
    /**
     * Handles the keyboard's key down event
     * @param event keyboard event
     */
    handleKeyDown(event: KeyboardEvent): void;
    /**
     * Handles change of the value after editing (doesn't fire on every keystroke).
     */
    handleChange: () => void;
    /**
     * Retrieves the component's text for a copy or cut command
     * @returns plain component text
     */
    getText(): string;
    private selectFile;
    private uploadFile;
    static ɵfac: i0.ɵɵFactoryDeclaration<UploadComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UploadComponent, "bl5-upload", never, {}, {}, never, never, false, never>;
}
