import { ElementRef, ChangeDetectorRef } from '@angular/core';
import { BaseComponent } from '../base/base.component';
import { ServiceProviderService } from '../../services/serviceprovider.service';
import { IBaseControl } from '../../../typedefinitions/models/controls/IBaseControl';
import { IDimension } from '../../../typedefinitions/models/IDimension';
import { IVideoControl } from '../../../typedefinitions/models/controls/IVideoControl';
import * as i0 from "@angular/core";
/**
 * Video component class
 */
export declare class VideoComponent extends BaseComponent<IVideoControl> {
    /**
     * ServiceProviderService Service provider service
     */
    protected sp: ServiceProviderService;
    /**
     * el Video component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    /**
     * audio element reference
     */
    private videoRef;
    /**
     * audio source element reference
     */
    private videoSource;
    /**
     * video element from reference
     */
    private get videoElement();
    /**
     * The media source url of the video file to play.
     */
    mediaUrl: string;
    /**
     * Flag indicating external sources, use alternative control view
     */
    displayExternalVideo: boolean;
    /**
     * Style object for setting the video element sizes
     */
    videoStyle: {
        width: string;
        height: string;
    };
    get videoId(): string;
    get autoPlay(): Optional<string>;
    get showControls(): Optional<string>;
    /**
     * Video component class constructor
     * @param sp Service provider service
     * @param el Element reference
     * @param cd Change detector reference
     */
    constructor(
    /**
     * ServiceProviderService Service provider service
     */
    sp: ServiceProviderService, 
    /**
     * el Video component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef);
    /**
     * Processes control changes and updates the media url.
     * @param newDataObject
     */
    handleControlUpdate(newDataObject: IBaseControl): void;
    /**
     * Extends the base component's `getDimensions` function.
     * Set the width and height dimensions in the video element's style object.
     * @returns CSS style declaration object
     */
    getDimensions(): IDimension;
    static ɵfac: i0.ɵɵFactoryDeclaration<VideoComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<VideoComponent, "bl5-video", never, {}, {}, never, never, false, never>;
}
