import { IColor } from '../../typedefinitions/models/IColor';
/**
 * Class containing defaults for culture specific formats
 */
export declare class CULTURE_FORMATS {
    /**
     * Default date and time format
     * e.g. 19-4-2021 16:01:24.076+01:00
     */
    static readonly DATETIME: string;
    /**
     * Default date format
     * e.g. 19-4-2021
     */
    static readonly DATE: string;
    /**
     * Default time format
     * e.g. 7:01:24
     */
    static readonly TIME: string;
}
/**
 * Class containing default values for the web application
 */
export declare class APPCONSTANTS {
    /**
     * Default rgba color
     */
    static readonly DEFAULT_COLOR: IColor;
    /**
     * Default flag for determining if the splash screen should be used or not
     */
    static readonly SHOW_SPLASH: boolean;
    /**
     * The number of milliseconds to delay before the splash (load) screen will be displayed
     */
    static readonly SHOW_SPLASH_DELAY: number;
    /**
     * The default base path for the web api
     */
    static readonly API_BASEPATH: string;
    /**
     * The default value list string separator
     */
    static readonly VALUE_SEPARATOR: string;
    /**
     * The default decimal separator
     */
    static readonly DECIMAL_SEPARATOR: string;
    /**
     * The number of significant digits in floating point math
     */
    static readonly FLOATING_POINT_PRECISION: number;
    /**
     * Class containing defaults for culture specific formats
     */
    static readonly FORMAT: typeof CULTURE_FORMATS;
    /**
     * the maximum length of a number input value, the value cannot exceed this length
     */
    static readonly NUMBER_MAX_LENGTH: number;
    /**
     * The maximum size of a textbox.
     */
    static readonly STRING_MAX_SIZE: number;
    /**
     * The maximum length of a text area value.
     */
    static readonly OPEN_MAX_LENGTH: number;
    /**
     * The maximum width (in columns) of a text area. Based on character W -> 80 cols = 48;
     */
    static readonly OPEN_MAX_COLS: number;
    /**
     * The default columns value of a text area
     */
    static readonly OPEN_DEFAULT_COLS: number;
    /**
     * The maximum height (in rows) of a text area
     */
    static readonly OPEN_MAX_ROWS: number;
    /**
     * The keystroke debounce frequency
     */
    static readonly KEYSTROKE_DEBOUNCE: number;
    /**
     * The maximum result count of a lookup-textbox / data-grid controls
     */
    static readonly MAX_RESULT_COUNT: number;
    /**
     * A one-pixel transparent fall-back image
     */
    static readonly PIXEL_TRANSPARENT: string;
    /**
     * Default return field for CATI
     */
    static readonly SURVEY_LIST_RETURNFIELD: string;
    /**
     * Default return field for an appointment
     */
    static readonly APPOINTMENT_LIST_RETURNFIELD: string;
}
