import { EventEmitter, ElementRef, OnInit, OnDestroy } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * Tracks clicks and touches outside the element it is placed on. Listen to the `clickOutside`
 * event do execute code whenever such an event is emitted.
 */
export declare class ClickOutsideDirective implements OnInit, OnDestroy {
    private elementRef;
    /**
     * click, touch start and touch move subscription
     */
    private subscription?;
    /**
     * Can hold a reference to another HTM element. If so, a click inside that element will not
     * trigger the `clickOutside` event.
     */ context: Nullable<HTMLElement>;
    /**
     * Emits an event every time a click or touch is performed outside the element context.
     */
    clickOutside: EventEmitter<any>;
    /**
     * Click outside directive class constructor
     * @param elementRef Reference to the element on which the directive is placed
     */
    constructor(elementRef: ElementRef);
    /**
     * Subscribes to the click, touch-start and touch-move events
     */
    ngOnInit(): void;
    /**
     * Unsubscribe from all active subscriptions
     */
    ngOnDestroy(): void;
    /**
     * @param event
     */
    private handleSubscription;
    /**
     * @param event
     * @param targetElement
     * @param isMouse
     */
    private handleEvent;
    /**
     * @param targetElement
     * @param event
     * @param isMouse
     */
    private hasClickedInside;
    /**
     * Checks if the target element is branched from a given element
     * @param element
     * @param targetElement
     * @param event
     * @param isMouse
     * @returns true, if the target element is a child of or situated within a given element, otherwise false
     */
    private elementOrChildContainsTargetElement;
    /**
     * Checks if the event occurred within the child boundaries
     * @param event
     * @param childBoundaries
     * @param isMouse
     * @returns true, if the event occurred within the child boundaries, otherwise false.
     */
    private isInsideBoundaries;
    static ɵfac: i0.ɵɵFactoryDeclaration<ClickOutsideDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<ClickOutsideDirective, "[bl5ClickOutside]", never, { "context": { "alias": "bl5ClickOutsideContext"; "required": false; }; }, { "clickOutside": "bl5ClickOutside"; }, never, never, false, never>;
}
