import { OnChanges, OnDestroy, ViewContainerRef } from '@angular/core';
import { ComponentService } from '../services/component.service';
import { MouseEventService } from '../services/mouse-event.service';
import { IColor } from '../../typedefinitions/models/IColor';
import { IGridUnit } from '../../typedefinitions/models/IGridUnit';
import { GridType } from '../../typedefinitions/enums/GridType';
import * as i0 from "@angular/core";
/**
 * The component directive class allows dynamically adding components derived from the Blaise Base Component as a child component on a container component such as a Panel, Table(-Row) or Grid
 */
export declare class ComponentDirective implements OnChanges, OnDestroy {
    private viewContainerRef;
    private componentService;
    private mouseEventService;
    private compRef;
    /**
     * The type of the child component, derived from the Blaise Base Component with a data object that extends the `IBaseControl`
     */
    childType: any;
    /**
     * The child component's data object, based on `IBaseControl`
     */
    dataObject: any;
    /**
     * The id of the parent/container component
     */
    parentId: Nullable<string>;
    /**
     * The component name of the parent/container component
     */
    parentType: string;
    /**
     * Array of width values and units for the columns of this table-row
     */
    columns?: IGridUnit[];
    /**
     * Flag indicating if the table-row should be handled as a row with an even index
     */
    isEvenRow?: boolean;
    /**
     * The table-row's row index
     */
    rowIndex?: number;
    /**
     * The table-row's background color
     */
    rowColor?: IColor;
    /**
     * The table-row's grid line type, can be `None`, `Horizontal`, `Vertical` or `Both`
     */
    gridLines?: GridType;
    /**
     * The table-row's grid line pixel width
     */
    gridLineWidth?: number;
    /**
     * The table-row's grid line color
     */
    gridLineColor?: IColor;
    /**
     * Component directive class constructor
     * @param viewContainerRef
     * @param componentService
     * @param mouseEventService
     */
    constructor(viewContainerRef: ViewContainerRef, componentService: ComponentService, mouseEventService: MouseEventService);
    /**
     * Instantiates references and creates an instance of a component as specified on the directive's input bindings
     */
    ngOnChanges(): void;
    /**
     * Clears/destroys references and remove the component from service ledgers
     */
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<ComponentDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<ComponentDirective, "[bl5Component]", never, { "childType": { "alias": "childType"; "required": false; }; "dataObject": { "alias": "dataObject"; "required": false; }; "parentId": { "alias": "parentId"; "required": false; }; "parentType": { "alias": "parentType"; "required": false; }; "columns": { "alias": "columns"; "required": false; }; "isEvenRow": { "alias": "isEvenRow"; "required": false; }; "rowIndex": { "alias": "rowIndex"; "required": false; }; "rowColor": { "alias": "rowColor"; "required": false; }; "gridLines": { "alias": "gridLines"; "required": false; }; "gridLineWidth": { "alias": "gridLineWidth"; "required": false; }; "gridLineColor": { "alias": "gridLineColor"; "required": false; }; }, {}, never, never, false, never>;
}
