import { ElementRef, OnDestroy, OnInit } from '@angular/core';
import { EventService } from '../services/event.service';
import { IBaseControl } from '../../typedefinitions/models/controls/IBaseControl';
import * as i0 from "@angular/core";
/**
 * The focus event directive is attached to a blaise component and handles the focus and blur events
 */
export declare class FocusEventDirective implements OnInit, OnDestroy {
    private eventService;
    private elementRef;
    private suppressFocusOnce;
    /**
     * Subscription to the referenced control that is being observed for focusing.
     */
    private focusSubscription?;
    /**
     * Subscription to the referenced control that is being observed for blurring.
     */
    private blurSubscription?;
    private get element();
    /**
     * The control object which contains the control ID and field name of the control.
     */
    dataObject: IBaseControl;
    /**
     * Focus event directive class constructor
     * @param eventService The action service provides functionality for executing one or more client or server actions at a time.
     * @param elementRef
     */
    constructor(eventService: EventService, elementRef: ElementRef);
    /**
     * Subscribes to an observable mirrored from the focus and touch-start event observables on directive initialisation.
     */
    ngOnInit(): void;
    /**
     * Terminates subscriptions on directive destruction.
     */
    ngOnDestroy(): void;
    /**
     * Focus subscription notification handler
     * @param event
     */
    private handleFocusSubscription;
    /**
     * Blur subscription notification handler
     * @param event
     */
    private handleBlurSubscription;
    private elementContainsTarget;
    private hasFocusEventActions;
    private findSkiplinkElement;
    static ɵfac: i0.ɵɵFactoryDeclaration<FocusEventDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<FocusEventDirective, "[bl5FocusEvent]", never, { "dataObject": { "alias": "bl5FocusEvent"; "required": false; }; }, {}, never, never, false, never>;
}
