import { ElementRef, AfterViewInit, OnInit, OnDestroy } from '@angular/core';
import { EventService } from '../services/event.service';
import { FocusService } from '../services/focus.service';
import { RenderStateService } from '../services/renderstate.service';
import { UserAgentService } from '../services/user-agent.service';
import { NavigationService } from '../services/navigation/navigation.service';
import { IBaseControl } from '../../typedefinitions/models/controls/IBaseControl';
import * as i0 from "@angular/core";
/**
 * The focus directive is attached to an element and changes the active field to said
 * element when that element receives a focus event.
 */
export declare class FocusDirective implements OnInit, AfterViewInit, OnDestroy {
    private elementRef;
    private eventService;
    private focusService;
    private navigationService;
    private renderStateService;
    private userAgentService;
    /**
     * Subscription to the referenced control that is being observed for focusing.
     */
    private focusSubscription?;
    /**
     * Subscription to the referenced control that is being observed for blurring.
     */
    private blurSubscription?;
    private get element();
    /**
     * Flag indicating if there is no explicit SetFocus event in the active field, only execute focus when true.
     * @private
     */
    private get allowFocus();
    /**
     * Constant for the focus-from attribute name
     */
    private readonly attributeName;
    /**
     * Constant for the focus-from attribute value
     */
    private readonly attributeValue;
    /**
     * The control object which contains the control ID and field name of the control.
     */
    dataObject: IBaseControl;
    /**
     * Focus directive class constructor
     * @param elementRef
     * @param eventService
     * @param focusService
     * @param navigationService
     * @param renderStateService
     * @param userAgentService
     */
    constructor(elementRef: ElementRef, eventService: EventService, focusService: FocusService, navigationService: NavigationService, renderStateService: RenderStateService, userAgentService: UserAgentService);
    /**
     * Subscribes to an observable mirrored from the focus and touch-start event observables on directive initialisation.
     */
    ngOnInit(): void;
    /**
     * Selects the first input control for the active field if autofocus is not disabled.
     */
    ngAfterViewInit(): void;
    /**
     * Terminates subscriptions on directive destruction.
     */
    ngOnDestroy(): void;
    /**
     * Focus subscription notification handler
     * @param event
     */
    private handleFocusSubscription;
    static ɵfac: i0.ɵɵFactoryDeclaration<FocusDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<FocusDirective, "[bl5Focus]", never, { "dataObject": { "alias": "bl5Focus"; "required": false; }; }, {}, never, never, false, never>;
}
