import { ElementRef, OnInit, OnDestroy } from '@angular/core';
import { MouseEventService } from '../services/mouse-event.service';
import { IBaseControl } from '../../typedefinitions/models/controls/IBaseControl';
import * as i0 from "@angular/core";
/**
 * The mouse-event directive is attached to a blaise component and allows for style-change actions on mouse-enter, -leave, -down and -up events
 * When any of these events are already used on the component, this directive's listeners will be trigger according to declaration (which should be first)
 */
export declare class MouseEventDirective implements OnInit, OnDestroy {
    private mouseEventService;
    private elementRef;
    /**
     * Subscription to the referenced control that is being observed for mouse events.
     */
    private subscriptions;
    private get element();
    /**
     * The control object which contains the control ID, field name of the control and mouse event definitions.
     */
    dataObject: IBaseControl;
    /**
     * Mouse event directive class constructor
     * @param mouseEventService Service required for handling drag-out and window-leave behaviour.
     * @param elementRef
     */
    constructor(mouseEventService: MouseEventService, elementRef: ElementRef);
    /**
     * Subscribes to an observable mirrored from the event observables on directive initialisation.
     */
    ngOnInit(): void;
    /**
     * Terminates subscriptions on directive destruction.
     */
    ngOnDestroy(): void;
    /**
     * Has the mouse-event service handle the mouse-enter event actions for the bound control
     */
    onMouseEnter(): void;
    /**
     * Has the mouse-event service handle the mouse-leave event actions for the bound control
     */
    onMouseLeave(): void;
    /**
     * Has the mouse-event service handle the mouse-down event actions for the bound control
     * @param event
     */
    onMouseDown(event: MouseEvent): void;
    /**
     * Has the mouse-event service handle the mouse-up event actions for the bound control
     * @param event
     */
    onMouseUp(event: MouseEvent): void;
    private updateComponent;
    static ɵfac: i0.ɵɵFactoryDeclaration<MouseEventDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<MouseEventDirective, "[bl5MouseEvent]", never, { "dataObject": { "alias": "bl5MouseEvent"; "required": false; }; }, {}, never, never, false, never>;
}
