import { ElementRef } from '@angular/core';
import { AfterViewInit, OnDestroy, OnInit } from '@angular/core';
import { StyleGeneratorService } from '../services/style-generator.service';
import { IBaseControl } from '../../typedefinitions/models/controls/IBaseControl';
import * as i0 from "@angular/core";
/**
 * The outline directive is attached to an element and changes the outline of the
 * element when that element receives the focus.
 */
export declare class OutlineDirective implements OnInit, AfterViewInit, OnDestroy {
    private elementRef;
    private styleGeneratorService;
    /**
     * Subscription to the referenced control that is being observed for focusing.
     */
    private focusSubscription?;
    /**
     * Subscription to the referenced control that is being observed for blurring.
     */
    private blurSubscription?;
    /**
     * The default outline-style property
     */
    private _originalStyle;
    /**
     * The default outline-width property
     */
    private _originalWidth;
    /**
     * The default outline-color property
     */
    private _originalColor;
    /**
     * The default outline-offset property
     */
    private _originalOffset;
    /**
     * The outline-style property specifies the style of the outline as defined on the control's data object.
     * Possible values are `dotted`, `dashed`, `solid`, `double`, `groove`, `ridge`, `inset`, `outset`, `none`, `hidden`
     */
    private outlineStyle;
    /**
     * The outline-width property specifies the width of the outline in pixels as defined on the control's data object.
     */
    private outlineWidth;
    /**
     * The outline-color property is used to set the color of the outline as defined on the control's data object.
     */
    private outlineColor;
    /**
     * The outline-offset property adds a transparent space between the outline and the edge/border of the element.
     * The field's value is defined on the control's data object.
     */
    private outlineOffset;
    private get element();
    private get elementStyle();
    /**
     * The control object which contains the control ID and field name of the control.
     */
    dataObject: IBaseControl;
    /**
     * Outline directive class constructor
     * @param elementRef Element reference
     * @param styleGeneratorService Style generator service generates css style objects and strings for stylable properties
     */
    constructor(elementRef: ElementRef, styleGeneratorService: StyleGeneratorService);
    /**
     * Subscribes to the focus and blur events of this directive's referenced element.
     */
    ngOnInit(): void;
    /**
     * Retrieves and stores the original outline style property values from the data object in order to reset them after blur
     */
    ngAfterViewInit(): void;
    /**
     * Terminates subscriptions on directive destruction.
     */
    ngOnDestroy(): void;
    private handleFocusSubscription;
    /**
     *
     */
    private handleBlurSubscription;
    private isRelevant;
    static ɵfac: i0.ɵɵFactoryDeclaration<OutlineDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<OutlineDirective, "[bl5Outline]", never, { "dataObject": { "alias": "bl5Outline"; "required": false; }; }, {}, never, never, false, never>;
}
