import { ViewContainerRef, OnInit, OnDestroy } from '@angular/core';
import { DataService } from '../services/data.service';
import { EventService } from '../services/event.service';
import { ExpressionService } from '../services/client-side/expression.service';
import { RenderStateService } from '../services/renderstate.service';
import { UserAgentService } from '../services/user-agent.service';
import * as i0 from "@angular/core";
/**
 * A directive responsible for checking if the browser window gets resized.
 * Whenever a resize of orientation change happens, a `windowResize` event
 * is emitted followed by a `windowResized` event when the resizing has
 * finished.
 *
 * Note that this directive should only be used on the root control. Using
 * it multiple times on the same page will result in multiple resize events
 * which can lead to increased load and strange results due to (intermediate)
 * calculations overriding each other.
 */
export declare class WindowResizeDirective implements OnInit, OnDestroy {
    private dataService;
    private eventService;
    private expressionService;
    private renderStateService;
    private userAgentService;
    private viewContainerRef;
    private windowResizingSubscription?;
    private get useCssVars();
    private get event();
    /**
     * Window resize directive class constructor
     * @param dataService The data service is a central hub for most server communications.
     * @param eventService The event service is the central hub in Blaise containing global application events to which other classes can subscribe. When subscribing to an event, classes can be decoupled from one another.
     * @param expressionService The expression service provides functionality for evaluating client side expressions.
     * @param renderStateService The render state service provides functionality for managing the render state information as provided by the server.
     * @param userAgentService The user agent service provides device/browser information.
     * @param viewContainerRef Represents a container where one or more views can be attached to a component.
     */
    constructor(dataService: DataService, eventService: EventService, expressionService: ExpressionService, renderStateService: RenderStateService, userAgentService: UserAgentService, viewContainerRef: ViewContainerRef);
    /**
     * Listens to and handles the window resize event and applies a debounced handler when resizing has finished
     */
    ngOnInit(): void;
    /**
     * Unsubscribes from all window resize(d) listeners and subscriptions
     */
    ngOnDestroy(): void;
    /**
     * Triggered when the resizing of the browser window starts.
     * Emits a show splash event. Can be called manually.
     * @fires EventService#showSplashEvent
     */
    windowResize(): void;
    /**
     * Triggered when the resizing of the browser has finished.
     * Emits a window resized event with the new width and height values of the page.
     * @fires EventService#windowResizeEvent
     */
    private windowResized;
    static ɵfac: i0.ɵɵFactoryDeclaration<WindowResizeDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<WindowResizeDirective, "[bl5WindowResize]", never, {}, {}, never, never, false, never>;
}
