import { AuditTrailService } from './audit-trail/audit-trail.service';
import { ClientSidePropertiesService } from './client-side/properties/client-side-properties.service';
import { ClipboardService } from './clipboard.service';
import { EventService } from './event.service';
import { ExpressionService } from './client-side/expression.service';
import { HelperService } from './helper.service';
import { HotkeyService } from './hotkeys/hotkey.service';
import { RenderStateService } from './renderstate.service';
import { StylablePropertyService } from './stylable-property.service';
import { SubscriptionService } from './subscription.service';
import { TimerService } from './timer.service';
import { IAction, IDialNumberAction, IPrintAction } from '../../typedefinitions/models/actions/IAction';
import { IAssignFieldAction } from '../../typedefinitions/models/actions/IAssignFieldAction';
import { IAssignFieldPropertyAction } from '../../typedefinitions/models/actions/IAssignFieldPropertyAction';
import { IAuditTrailAction } from '../../typedefinitions/models/actions/IValuesAction';
import { IClipboardAction, IControlAction } from '../../typedefinitions/models/actions/IControlAction';
import { IConditionFieldAction, INextFieldAction } from '../../typedefinitions/models/actions/IConditionFieldAction';
import { IConditionalAction } from '../../typedefinitions/models/actions/IConditionalAction';
import { IForEachAction } from '../../typedefinitions/models/actions/IForEachAction';
import { IGoToBlockFieldAction, IGoToFieldAction, IGoToFieldPropertyAction } from '../../typedefinitions/models/actions/IGoToFieldAction';
import { IGoToGroupAction } from '../../typedefinitions/models/actions/IGoToGroupAction';
import { IGoToUriAction } from '../../typedefinitions/models/actions/IGoToUriAction';
import { IProcedureCallAction } from '../../typedefinitions/models/actions/IProcedureCallAction';
import { ISendKeysAction } from '../../typedefinitions/models/actions/ISendKeysAction';
import { ISetControlPropertyAction } from '../../typedefinitions/models/actions/ISetControlPropertyAction';
import { ISetDataEntrySettingsAction } from '../../typedefinitions/models/actions/ISetDataEntrySettingsAction';
import { ISetDeviceFeaturesAction } from '../../typedefinitions/models/actions/ISetDeviceFeaturesAction';
import { ISetLayoutSetAction } from '../../typedefinitions/models/actions/ISetLayoutSetAction';
import { ISetLayoutSetGroupAction } from '../../typedefinitions/models/actions/ISetLayoutSetGroupAction';
import { ISetStyleAction } from '../../typedefinitions/models/actions/ISetStyleAction';
import { IShowDialogAction } from '../../typedefinitions/models/actions/IShowDialogAction';
import { IShowCustomPageAction } from '../../typedefinitions/models/actions/IShowCustomPageAction';
import { IStartLocalProcessAction } from '../../typedefinitions/models/actions/IStartLocalProcessAction';
import { IStartSurveyAction } from '../../typedefinitions/models/actions/IStartSurveyAction';
import { ISuppressSignalAction } from '../../typedefinitions/models/actions/ISuppressSignalAction';
import { IToggleVisibilityAction } from '../../typedefinitions/models/actions/IToggleVisibilityAction';
import { IActionKeyValuePair } from '../../typedefinitions/models/IActionKeyValuePair';
import { IActionsEventHandler } from '../../typedefinitions/models/IActionsEventHandler';
import * as i0 from "@angular/core";
/**
 * The action service provides functionality for executing one or more client or server actions at a time.
 * It evaluates an {IAction} object, determines the {ActionKind} and handles the action accordingly.
 */
export declare class ActionService {
    protected auditTrailService: AuditTrailService;
    protected clientSidePropertiesService: ClientSidePropertiesService;
    protected clipboardService: ClipboardService;
    protected document: Document;
    protected eventService: EventService;
    protected expressionService: ExpressionService;
    protected helperService: HelperService;
    protected hotkeyService: HotkeyService;
    protected renderStateService: RenderStateService;
    protected stylablePropertiesService: StylablePropertyService;
    protected subscriptionService: SubscriptionService;
    protected timerService: TimerService;
    private readonly defaultStr;
    /**
     * The action functions object contains all possible determine-, local- and server-action functions
     */
    private readonly afo;
    /**
     * Action service class constructor. Initializes actions and subscriptions for the action service.
     * @param auditTrailService Provides functionality for tracking user behaviour.
     * @param clientSidePropertiesService Allows for creation and execution of client side properties defined by the server.
     * @param clipboardService Provides functionality setting and retrieving a control's text to and from the clipboard.
     * @param document A reference class for the global document object.
     * @param eventService Contains global application events.
     * @param expressionService Provides functionality for evaluating client side expressions.
     * @param helperService Provides general functions that are commonly used throughout the application.
     * @param hotkeyService Hotkey manager service.
     * @param renderStateService For managing the render state information as provided by the server.
     * @param stylablePropertiesService For managing the stylable properties of controls.
     * @param subscriptionService For managing subjects and subscriptions.
     * @param timerService Timer control service.
     */
    constructor(auditTrailService: AuditTrailService, clientSidePropertiesService: ClientSidePropertiesService, clipboardService: ClipboardService, document: Document, eventService: EventService, expressionService: ExpressionService, helperService: HelperService, hotkeyService: HotkeyService, renderStateService: RenderStateService, stylablePropertiesService: StylablePropertyService, subscriptionService: SubscriptionService, timerService: TimerService);
    /**
     * Initializes the action service.
     */
    initialize(): void;
    /**
     * Processes all actions of an action event handler object that corresponds with a control (e.g. OnClick, OnValueChanged, ...).
     * @param actionsEventHandler
     * @param controlId (optional) caller id
     */
    protected handleActions(actionsEventHandler: IActionsEventHandler, controlId?: string): void;
    /**
     * Processes a provided action.
     * @param actionObj
     * @param controlId (optional) caller id
     * @param eventName name of the defined shortcut (e.g. OnCtrlP)
     * @returns a server action if the provided action object was a server action
     */
    protected handleAction(actionObj: IAction, controlId?: string, eventName?: string): void;
    /**
     * Goes to the next page in the survey
     * @returns next page server action { Key: 0, Value: null }
     */
    protected nextPage(): Optional<IActionKeyValuePair>;
    /**
     * Goes to the previous page in the survey
     * @returns previous page server action { Key: 1, Value: null }
     */
    protected previousPage(): Optional<IActionKeyValuePair>;
    /**
     * Goes to the first page in the survey
     * @returns first server action { Key: 2, Value: null }
     */
    protected firstPage(): Optional<IActionKeyValuePair>;
    /**
     * Goes to the last page in the survey
     * @returns last server action { Key: 3, Value: null }
     */
    protected lastPage(): Optional<IActionKeyValuePair>;
    /**
     * Reloads the current page
     * @returns current page server action { Key: 4, Value: null }
     */
    protected currentPage(): IActionKeyValuePair;
    /**
     * Goes to and activates the next field in the survey
     * @param actionObj next field action object
     * @param controlId caller id
     * @param preferServerActions This function can be both a local and a server action. When the action is part of an action list that has server actions, the parameter will be set to true and the action will return a key value pair.
     * @returns next field server action { Key: 5, Value: null } or undefined
     */
    protected nextField(actionObj: INextFieldAction, controlId: string, preferServerActions?: boolean): Optional<IActionKeyValuePair>;
    /**
     * Goes to and activates the previous field in the survey
     * @param actionObj previous field action object
     * @param controlId caller id
     * @param preferServerActions This function can be both a local and a server action. When the action is part of an action list that has server actions, the parameter will be set to true and the action will return a key value pair.
     * @returns previous field server action { Key: 28, Value: null } or undefined
     */
    protected previousField(actionObj: IConditionFieldAction, controlId: string, preferServerActions?: boolean): Optional<IActionKeyValuePair>;
    /**
     * Assigns a value to a field
     * @param actionObj assign field action object
     * @param controlId caller id
     * @param preferServerActions This function can be both a local and a server action. When the action is part of an action list that has server actions, the parameter will be set to true and the action will return a key value pair.
     * @returns assign field server action { Key: 15, Value: { FieldName: `string`, ValueAsString: `string`, FieldNameAsExpression: `object` } } or undefined
     */
    protected assignField(actionObj: IAssignFieldAction, controlId: string, preferServerActions?: boolean): Optional<IActionKeyValuePair>;
    /**
     * Assigns a value to a field's property
     * @param actionObj assign field property action object
     * @param controlId caller id
     * @param preferServerActions This function can be both a local and a server action. When the action is part of an action list that has server actions, the parameter will be set to true and the action will return a key value pair.
     * @returns assign field property server action { Key: 31, Value: { FieldName: `string`, ValueAsString: `string`, FieldPropertyName: `string`, FieldNameAsExpression: `object` } } or undefined
     */
    protected assignFieldProperty(actionObj: IAssignFieldPropertyAction, controlId: string, preferServerActions?: boolean): Optional<IActionKeyValuePair>;
    /**
     * Goes to and activates the first found field in the survey that complies with the condition
     * @param actionObj condition field action object
     * @returns first field server action { Key: 5, Value: { Condition: { Kind: 0 } } } or undefined
     */
    protected firstField(actionObj: IConditionFieldAction): Optional<IActionKeyValuePair>;
    /**
     * Goes to and activates the last found field in the survey that complies with the condition
     * @param actionObj condition field action object
     * @returns last field server action { Key: 5, Value: { Condition: { Kind: 0 } } } or undefined
     */
    protected lastField(actionObj: IConditionFieldAction): Optional<IActionKeyValuePair>;
    /**
     * Either activates a field on the current page or navigates to a page to activate a field there
     * @param actionObj go to field action object
     * @param controlId
     * @param preferServerActions This function can be both a local and a server action. When the action is part of an action list that has server actions, the parameter will be set to true and the action will return a key value pair.
     * @returns go to field server action { Key: 13, Value: { FieldName: `string` } }
     */
    protected goToField(actionObj: IGoToFieldAction, controlId: string, preferServerActions?: boolean): Optional<IActionKeyValuePair>;
    /**
     * Navigate to and activate a block field
     * @param actionObj go to field action object
     * @returns go to field server action { Key: 20, Value: { FieldName: `string` } } or undefined
     */
    protected goToBlockField(actionObj: IGoToBlockFieldAction): IActionKeyValuePair;
    /**
     * Navigate to and activate a group field
     * @param actionObj go to group action object
     * @returns go to group server action { Key: 21, Value: { GroupName: `string` } } or undefined
     */
    protected goToGroup(actionObj: IGoToGroupAction): IActionKeyValuePair;
    /**
     * Executes the go-to-uri action.
     * @param actionObj go to uri action object
     */
    protected goToUri(actionObj: IGoToUriAction): void;
    /**
     * Executes the go-to-parallel-end action
     * @returns go to parallel end server action { Key: 32, Value: null }
     */
    protected goToParallelEnd(): IActionKeyValuePair;
    /**
     * Either activates a field property on the current page or navigates to a page to activate a field property there
     * @param actionObj go to field property action object
     * @param controlId
     * @param preferServerActions This function can be both a local and a server action. When the action is part of an action list that has server actions, the parameter will be set to true and the action will return a key value pair.
     * @returns go to field server action { Key: 13, Value: { FieldName: `string` } }
     */
    protected goToFieldProperty(actionObj: IGoToFieldPropertyAction, controlId: string, preferServerActions?: boolean): Optional<IActionKeyValuePair>;
    /**
     * (Re)starts a specified timer
     * @param actionObj the actionObj containing the timer id
     * @param controlId caller id
     */
    protected startTimer(actionObj: IControlAction, controlId: string): void;
    /**
     * Unsubscribes and removes the observable from the timer
     * @param actionObj the timer id or the actionObj containing the id
     * @param controlId caller id
     */
    protected stopTimer(actionObj: IControlAction, controlId: string): void;
    /**
     * Executes the close dialog action
     * @returns close dialog server action
     */
    protected closeDialog(): IActionKeyValuePair;
    /**
     * Executes the show dialog action
     * @returns show dialog server action
     */
    protected showDialog(actionObj: IShowDialogAction): IActionKeyValuePair;
    /**
     * Executes the play action on an audio element by its control ID
     * @param actionObj
     * @param controlId caller id
     */
    protected playAudio(actionObj: IControlAction, controlId: string): void;
    /**
     * Executes the pause action on an audio element by its control ID
     * @param actionObj
     * @param controlId caller id
     */
    protected pauseAudio(actionObj: IControlAction, controlId: string): void;
    /**
     * Toggles between the play and pause actions on an audio element by its control ID
     * @param actionObj
     * @param controlId caller id
     */
    protected playPauseAudio(actionObj: IControlAction, controlId: string): void;
    /**
     * Toggles between the play and stop actions on an audio element by its control ID
     * @param actionObj
     * @param controlId caller id
     */
    protected playStopAudio(actionObj: IControlAction, controlId: string): void;
    /**
     * Executes the stop action on an audio element by its control ID
     * @param actionObj
     * @param controlId caller id
     */
    protected stopAudio(actionObj: IControlAction, controlId: string): void;
    /**
     * Executes the stop all audio action on a page by
     */
    protected stopAllAudio(actionObj: IAction, controlId: string): void;
    /**
     * Executes the play action on a video element by its control ID
     * @param actionObj
     * @param controlId caller id
     */
    protected playVideo(actionObj: IControlAction, controlId: string): void;
    /**
     * Executes the pause action on a video element by its control ID
     * @param actionObj
     * @param controlId caller id
     */
    protected pauseVideo(actionObj: IControlAction, controlId: string): void;
    /**
     * Toggles between the play and pause actions on a video element by its control ID
     * @param actionObj
     * @param controlId caller id
     */
    protected playPauseVideo(actionObj: IControlAction, controlId: string): void;
    /**
     * Toggles between the play and stop actions on a video element by its control ID
     * @param actionObj
     * @param controlId caller id
     */
    protected playStopVideo(actionObj: IControlAction, controlId: string): void;
    /**
     * Executes the stop action on a video element by its control ID
     * @param actionObj
     * @param controlId caller id
     */
    protected stopVideo(actionObj: IControlAction, controlId: string): void;
    /**
     * Executes the stop all video action on a page by
     * @param actionObj
     * @param controlId caller id
     */
    protected stopAllVideo(actionObj: IAction, controlId: string): void;
    /**
     * Overridable function for custom actions
     * @param actionObj custom action's action object
     * @param controlId (optional) caller id
     */ protected custom(actionObj?: IAction, controlId?: string): void;
    /**
     * Saves the survey data
     * @returns save survey server action { Key: 6, Value: null }
     */
    protected save(): IActionKeyValuePair;
    /**
     * Exits the survey
     * @returns quit survey server action { Key: 7, Value: null }
     */
    protected quit(): IActionKeyValuePair;
    /**
     * Sets the language/culture for the survey
     * @param actionObj set language action object
     * @returns set language server action { Key: 8, Value: { Language: `string` } }
     */
    protected setLanguage(actionObj: IAction): IActionKeyValuePair;
    /**
     * Sets the layout set group for the survey by name
     * @param actionObj set layout set group action object
     * @returns set layout set group server action { Key: 9, Value: { LayoutSetGroupName: `string` } }
     */
    protected setLayoutSetGroup(actionObj: ISetLayoutSetGroupAction): IActionKeyValuePair;
    /**
     * Sets the layout set for the survey by name
     * @param actionObj set layout set action object
     * @returns set layout set server action { Key: 10, Value: { LayoutSetName: `string` } }
     */
    protected setLayoutSet(actionObj: ISetLayoutSetAction): IActionKeyValuePair;
    /**
     * Sets the data entry settings for the survey
     * @param actionObj set data entry setting action object
     * @returns set data entry setting server action { Key: 11, Value: { DataEntrySettings: `string` } }
     */
    protected setDataEntrySettings(actionObj: ISetDataEntrySettingsAction): IActionKeyValuePair;
    /**
     * Sets a parallel for the survey
     * @param actionObj set parallel action object
     * @returns set parallel server action { Key: 12, Value: { Parallel: `string` } }
     */
    protected setParallel(actionObj: IAction): IActionKeyValuePair;
    /**
     * Suppresses an error signal for a specified check
     * @param actionObj suppress signal action object
     * @returns suppress signal server action { Key: 14, Value: { CheckName: `string` } }
     */
    protected suppressSignal(actionObj: ISuppressSignalAction): IActionKeyValuePair;
    /**
     * Sets a specific style on the survey
     * @param actionObj set style action object
     * @returns set style server action { Key: 16, Value: { StyleName: `string` } }
     */
    protected setStyle(actionObj: ISetStyleAction): IActionKeyValuePair;
    /**
     * Set device features for the survey
     * @param actionObj set device features action object
     * @returns  set device features server action { Key: 17, Value: { Features: `object[]` } }
     */
    protected setDeviceFeatures(actionObj: ISetDeviceFeaturesAction): IActionKeyValuePair;
    /**
     * Shows a custom Blaise user page
     * @param actionObj show custom page action object
     * @returns show custom page server action { Key: 18, Value: { PageKindName: `string` } }
     */
    protected showCustomPage(actionObj: IShowCustomPageAction): IActionKeyValuePair;
    /**
     * Sets the visibility of the target control according to the following rules:
     * * If the control is currently hidden/collapsed, show it.
     * * If the control is currently its default and visible, then hide the element using the action's InvisibleValue property to either hidden or collapsed
     * * If the control by default is hidden/collapsed, but currently visible, then revert the visibility to its default value
     * @param actionObj toggle visibility action object
     */
    protected toggleVisibility(actionObj: IToggleVisibilityAction): void;
    /**
     * Executes the start-survey action
     * @param actionObj start survey action object
     * @returns start survey server action { Key: 23, Value: { InstrumentID: `string`, KeyValue: `string[]`, RuntimeParameters: `object[]`, Fields: `object[]` } }
     */
    protected startSurvey(actionObj: IStartSurveyAction): IActionKeyValuePair;
    /**
     * Executes the procedure-call action
     * @param actionObj procedure call action object
     * @returns procedure call server action { Key: 24, Value: { Expression: `object` } }
     */
    protected procedureCall(actionObj: IProcedureCallAction): IActionKeyValuePair;
    /**
     * Executes a condition expression to determine which action(s) to execute.
     * @param actionObj conditional action object
     * @returns conditional server action object
     */
    protected conditional(actionObj: IConditionalAction): IActionKeyValuePair;
    /**
     * Sets a control's property to a specified value
     * @param actionObj set control property action object
     * @returns set control property server action { Key: 26, Value: { ControlID: `string`, PropertyName: `string`, Value: `object` } } or undefined
     */
    protected setControlProperty(actionObj: ISetControlPropertyAction): Optional<IActionKeyValuePair>;
    /**
     * Prints the survey
     * Syntax:
     * PRINT( {
     *    "LayoutSetGroup",
     *    "LayoutSet",
     *    "Language",
     *    "Style",
     *    "DataEntrySettings",
     *    "Orientation",
     *    "PaperSize",
     *    "IncludeKeyParallel",
     *    "IncludeMainParallel",
     *    "IncludeParallels",
     *    "IncludeCurrentParallel",
     *    "PageRange",
     *    "OutputFileName",
     *    "SuccessMessageKey"
     * })
     * @param actionObj print action object
     * @returns print server action { Key: 29, Value: { LayoutSetGroup: `string`, LayoutSet: `string`, Language: `string`, Style: `string`, DataEntrySettings: `string`, Orientation: `number`, PaperSize: `number`, IncludeKeyParallel: `bool`, IncludeMainParallel: `bool`, IncludeParallels: `bool`, IncludeCurrentParallel: `bool`, PageRange: `number`, OutputFileName: `string`, SuccessMessageKey: `string` } }
     */
    protected print(actionObj: IPrintAction): IActionKeyValuePair;
    /**
     * Completes/Finishes the survey
     * @returns finish server action { Key: 30, Value: null }
     */
    protected finish(): IActionKeyValuePair;
    /**
     * Signals the server to dial a phone number
     * @param actionObj dial number action object
     * @returns dial number server action { Key: 33, Value: { Number: `string`, Interviewer: `string`, AdditionalInfo: `string` } }
     */
    protected dialNumber(actionObj: IDialNumberAction): IActionKeyValuePair;
    /**
     * Sets focus to a given control on the page
     * @param actionObj set focus action object
     * @param controlId caller id
     */
    protected setFocus(actionObj: IControlAction, controlId: string): void;
    /**
     * Logs a custom audit trail event
     * @param actionObj audit trail action object
     */
    protected auditTrail(actionObj: IAuditTrailAction): void;
    /**
     * Removes text from a given control and sets it on the clipboard
     * @param actionObj cut to clipboard action object
     */
    protected cutToClipboard(actionObj: IClipboardAction): void;
    /**
     * Copies text from a given control and sets it on the clipboard
     * @param actionObj copy to clipboard action object
     */
    protected copyToClipboard(actionObj: IClipboardAction): void;
    /**
     * Places text from the clipboard on a given control
     * @param actionObj paste from clipboard action object
     */
    protected pasteFromClipboard(actionObj: IClipboardAction): void;
    /**
     * Triggers a server event
     */
    protected serverEvent(): IActionKeyValuePair;
    /**
     * Request an unmodified version of the page from the server
     */
    protected undoAllEdits(): IActionKeyValuePair;
    /**
     * Executes one or more actions on a collection
     * @param actionObj for each action object containing the collection to loop over, the item to use from each item in the collection and a list of actions to execute on that item
     * @param controlId
     */
    protected forEach(actionObj: IForEachAction, controlId?: string): Optional<IActionKeyValuePair>;
    /**
     * Sends keys an input control
     * @param actionObj send keys action object, containing the keys to send
     */
    protected sendKeys(actionObj: ISendKeysAction): void;
    /**
     * Log but skip the local process action (not supported by browser clients)
     */
    protected startLocalProcess(actionObj: IStartLocalProcessAction): void;
    private createDefaultActionKeyValuePair;
    private static createActionKeyValuePair;
    private createAFO;
    /**
     * Processes local page forward actions
     * @param actions
     * @param eventName
     * @param controlId
     * @param onTryLeavePageForward
     * @returns flag indicating if page events should be applied
     */
    private processActions;
    /**
     * Active field change handler function
     * When there is a fieldChange
     *    and the previous field is critical or refresh mode is set to question
     *    and the previous field is dirty,
     * this function starts a go-to-field server action
     * @param fieldChangedEventArgs
     */
    private handleActiveFieldChanged;
    private confirm;
    private decline;
    private nullValueReturn;
    /**
     * Determines if the action specified in the given action object is a server-action
     * @param actionObj
     * @param executorObj
     * @param onTryLeavePageForward
     */
    private isLeavePageOrServerAction;
    /**
     * Determines if the action specified in the given action object is a server- or a local-action
     * @param actionObj
     * @param executorObj
     */
    private isServerAction;
    private getServerActionFn;
    private getUnboundLocalActionFn;
    private getLocalActionFn;
    private executeLocalAction;
    private splitActions;
    private splitAction;
    /**
     * @param executorObj ActionExecutorObject containing local actions, server actions, optional indexes, controlId and an event name (the name of the defined shortcut (e.g. OnCtrlP))
     */
    private executeActions;
    private executeLocalActions;
    /**
     * Executes a list of server actions through the data service.
     * @param serverActions
     * @param controlId (optional) caller id
     * @param eventName name of the defined shortcut (e.g. OnCtrlP)
     * @param preferServerActions skip optional local actions
     */
    private executeServerActions;
    /**
     * Processes local page forward actions
     * @param controlId
     * @returns flag indicating if page events should be applied
     */
    private handleOnTryLeavePageForwardActions;
    private isNextPageActionAllowed;
    private isPreviousPageActionAllowed;
    private isNextFieldServerAction;
    private isPreviousFieldServerAction;
    private isLeaveActiveFieldServerAction;
    /**
     * Get the field name of the assignment action from the field name expression property of the action object, if available, otherwise from the static field name property.
     * @param actionObj
     * @returns field name
     */
    private getAssignActionFieldName;
    /**
     * Get the static value of the assignment action, or the (evaluated) expression value if available.
     * @param actionObj
     * @returns assignment value
     */
    private getAssignActionValue;
    private fromExpression;
    private isAssignFieldServerAction;
    private isAssignPropertyFieldServerAction;
    private isGoToFieldServerAction;
    private isGoToFieldPropertyServerAction;
    /**
     * Checks if the fields first input-control is visible
     * @returns false if the fields first input-control is not visible, otherwise true.
     */
    private isFieldElementVisible;
    /**
     * Checks if the fields first input-control is/can be visible
     * @returns false if the fields first input-control is not visible, otherwise true.
     */
    private isFieldInputControlReachable;
    /**
     * Checks if the next field action is allowed.
     * @returns false if the current active field has a first relevant signal or check error of which it is the last involved field and none of the involved fields have been modified, otherwise true.
     */
    private isNextFieldActionAllowed;
    private playMedia;
    private pauseMedia;
    private playPauseMedia;
    private stopMedia;
    private stopAllMedia;
    private getMediaElementById;
    private getMediaElementsByTagName;
    private splitConditionalActions;
    private executeLocalConditionalAction;
    /**
     * Determines if the current page is not the last page
     */
    private surveyHasNextPage;
    /**
     * Determines if the current page is not the first page
     */
    private surveyHasPreviousPage;
    private isForEachServerAction;
    static ɵfac: i0.ɵɵFactoryDeclaration<ActionService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ActionService>;
}
