import { BehaviorSubject } from 'rxjs';
import { EventService } from '../event.service';
import { SubscriptionService } from '../subscription.service';
import { IAuditTrailServerInfo } from '../../../typedefinitions/models/server/IAuditTrailServerInfo';
import * as i0 from "@angular/core";
/**
 * The audit trail config service monitors the audit trail configuration and pushes changes when needed
 */
export declare class AuditTrailServerInfoService {
    private eventService;
    private subscriptionService;
    /**
     * Gets the subscribable audit-trail server info subject
     * @returns audit-trail server info subject
     */
    get subject(): BehaviorSubject<Nullable<IAuditTrailServerInfo>>;
    /**
     * Retrieves the audit-trail server info
     */
    get serverInfo(): Nullable<IAuditTrailServerInfo>;
    /**
     * Sets the audit-trail server info
     */
    set serverInfo(auditTrailServerInfo: Nullable<IAuditTrailServerInfo>);
    /**
     * Audit trail config service class constructor
     * @param subscriptionService A central hub for managing subscriptions.
     * @param eventService A central hub for managing events
     */
    constructor(eventService: EventService, subscriptionService: SubscriptionService);
    /**
     * Forms and stores the audit-trail server info from a server payload object
     */
    private setServerInfo;
    static ɵfac: i0.ɵɵFactoryDeclaration<AuditTrailServerInfoService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<AuditTrailServerInfoService>;
}
