import * as i0 from "@angular/core";
/**
 * The function service is used for client side expressions and evaluates a set of arguments through a specified function.
 */
export declare class FunctionService {
    /**
     * Evaluates a set of arguments through a specified function
     * @param functionName
     * @param args
     * @returns function result
     */
    evaluateFunction(functionName: string, args?: any[]): any;
    private evaluateEquality;
    private evaluateInequality;
    private evaluateAND;
    private evaluateOR;
    private evaluateNOT;
    private evaluateGreaterThan;
    private evaluateGreaterThanOrEqual;
    private evaluateLessThan;
    private evaluateLessThanOrEqual;
    /**
     * Evaluate the `+` addition function
     * @param args arguments: args[0]: Number | Set | String, args[1]: Number | String, args[2] (new, optional): DataType
     * @private
     */
    private evaluateAddition;
    /**
     * Evaluate the `-` subtraction function
     * @param args arguments: args[0]: Number | Set, args[1]: Number | String, args[2] (new, optional): DataType
     * @private
     */
    private evaluateSubtraction;
    private evaluateMultiplication;
    private evaluateDivision;
    private evaluateMax;
    private evaluateMin;
    /**
     * Determines if the specified number is a floating point number
     * @param n potential float number
     */
    private isFloat;
    private evaluateIntegerDivision;
    private evaluateModulo;
    /**
     * evaluate the `IN` function
     * @param args arguments: args[0]: Number | String, args[1]: Set | String, args[2] (new, optional): DataType
     * @private
     */
    private evaluateIn;
    /**
     * Retrieves a part of a given text starting at a given position or at the beginning of the text and with a given length
     * @param args args[0]: text, args[1]: start position, args[2]: length of the substring (optional)
     * @returns the substring or an empty string if the arguments are invalid
     */
    private evaluateSubstring;
    /**
     * Retrieves the position index of a given substring from a given text starting at the beginning of the text or from a given position
     * @param args args[0]: substring, args[1]: text, args[2]: start position (optional)
     * @returns the position index of the substring or 0 if not found, empty, `DONTKNOW`, `EMPTY` or `REFUSAL`
     */
    private evaluatePosition;
    private evaluateUpperCase;
    private evaluateLowerCase;
    private evaluateStartsWith;
    private evaluateEndsWith;
    private evaluateLength;
    private evaluateToString;
    private evaluateToInteger;
    private evaluateToReal;
    private evaluateRound;
    private evaluateTrunc;
    private evaluateInRanges;
    private evaluateInRange;
    private evaluateInMinMaxRange;
    private evaluateInSimpleRange;
    /**
     * Converts a string to a rich text object in order to return it as an expression result.
     */
    private evaluateToRichText;
    static ɵfac: i0.ɵɵFactoryDeclaration<FunctionService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<FunctionService>;
}
