import { ClientSidePropertyValuesService } from '../property-values/client-side-property-values.service';
import { EventService } from '../../event.service';
import { ExpressionService } from '../expression.service';
import { PerformanceService } from '../../performance/performance.service';
import { StylablePropertyService } from '../../stylable-property.service';
import { SubscriptionService } from '../../subscription.service';
import { ClientSidePropertyResult } from '../../../classes/client-side/properties/client-side-property-result';
import { IClientSideProperty } from '../../../../typedefinitions/models/server/client-side/properties/IClientSideProperty';
import * as i0 from "@angular/core";
/**
 * The client side properties service allows for creation and execution of client side properties defined by the server
 */
export declare class ClientSidePropertiesService {
    private eventService;
    private expressionService;
    private performanceService;
    private propertyValueService;
    private stylablePropertyService;
    private subscriptionService;
    private clientSideProperties;
    private navigationModeSubscription?;
    private windowResizedSubscription?;
    /**
     * Client side properties service class constructor
     * @param eventService
     * @param expressionService
     * @param performanceService
     * @param propertyValueService
     * @param stylablePropertyService
     * @param subscriptionService
     */
    constructor(eventService: EventService, expressionService: ExpressionService, performanceService: PerformanceService, propertyValueService: ClientSidePropertyValuesService, stylablePropertyService: StylablePropertyService, subscriptionService: SubscriptionService);
    /**
     * Initializes the client side properties and subscribes to the navigation mode changed event
     * @param clientSideProperties
     */
    initialize(clientSideProperties: IClientSideProperty[]): void;
    /**
     * (Re)-evaluate all client side properties.
     */
    executeProperties(): void;
    /**
     * (Re)-evaluate a given client side property and updates the related control
     * @param property Client-side property to (re)-evaluate
     * @returns Client-side property evaluation result
     */
    executeProperty(property: IClientSideProperty): Nullable<ClientSidePropertyResult>;
    private updateControl;
    private getControlOrMenuItemSubject;
    private hasFontProperties;
    static ɵfac: i0.ɵɵFactoryDeclaration<ClientSidePropertiesService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ClientSidePropertiesService>;
}
