import { EventService } from '../../event.service';
import { RenderStateService } from '../../renderstate.service';
import { SubscriptionService } from '../../subscription.service';
import { IClientSideRouteItemEvent } from '../../../../typedefinitions/events/IClientSideRouteItemEvent';
import * as i0 from "@angular/core";
/**
 * Handles the client side route item event subscriptions
 */
export declare class ClientSideRouteItemEventsService {
    private eventService;
    private renderStateService;
    private subscriptionService;
    /**
     * Active field changed subscription
     */
    private activeFieldChangedSubscription?;
    /**
     * page initialized subscription
     */
    private pageInitializedSubscription?;
    /**
     * Route item event list
     */
    private _routeItemEvents;
    get routeItemEvents(): IClientSideRouteItemEvent[];
    get initialized(): boolean;
    /**
     * Last item which had an onEnter event
     */
    private lastOnEnterField;
    /**
     * Client side route item event service class constructor
     * @param eventService
     * @param renderStateService
     * @param subscriptionService
     */
    constructor(eventService: EventService, renderStateService: RenderStateService, subscriptionService: SubscriptionService);
    /**
     * Initializes the route item event array and subscribes to the page initialized event, if this was not already done.
     * @param routeItemEvents
     */
    initialize(routeItemEvents: IClientSideRouteItemEvent[]): void;
    /**
     * Check if the RouteItemEvents contain an event that should debounce the page initialized event
     */
    shouldDebounce(): boolean;
    /**
     * Subscribes to the active field changed subscription on page initialisation.
     */
    private subscribeToChanges;
    /**
     * Handles the initial field change by setting the needed parameters for the called field change handler.
     */
    private handleInitialFieldChange;
    /**
     * Handles the field change event by executing the corresponding route item event actions
     * @param fieldChangedEvent
     */
    private handleFieldChange;
    static ɵfac: i0.ɵɵFactoryDeclaration<ClientSideRouteItemEventsService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ClientSideRouteItemEventsService>;
}
