import { ClientSidePropertiesService as PropertiesService } from '../properties/client-side-properties.service';
import { ConverterFactoryService } from '../../converters/converter-factory.service';
import { EventService } from '../../event.service';
import { ExpressionService } from '../expression.service';
import { PerformanceService } from '../../performance/performance.service';
import { SubscriptionService } from '../../subscription.service';
import { IClientSideRule } from '../../../../typedefinitions/models/server/client-side/rules/IClientSideRule';
import * as i0 from "@angular/core";
/**
 * The `ClientSideRulesService` is responsible for executing the client side rules when any field values change.
 */
export declare class ClientSideRulesService {
    private converterFactoryService;
    private eventService;
    private expressionService;
    private performanceService;
    private propertiesService;
    private subscriptionService;
    private rules;
    private fieldValueChangedSubscription?;
    private pageInitializedSubscription?;
    private renderStateSubscription?;
    /**
     * Client side rules service class constructor
     * @param converterFactoryService
     * @param eventService
     * @param expressionService
     * @param performanceService
     * @param propertiesService
     * @param subscriptionService
     */
    constructor(converterFactoryService: ConverterFactoryService, eventService: EventService, expressionService: ExpressionService, performanceService: PerformanceService, propertiesService: PropertiesService, subscriptionService: SubscriptionService);
    /**
     * Initialize the client side rules service. If first creates the ClientSideRule objects and then subscribes to
     * the events it should listen to in order to execute the rules.
     * @param rules
     */
    initialize(rules: IClientSideRule[]): void;
    /**
     * Unsubscribe from events, to prevent unnecessary calculation of rules and properties
     */
    unsubscribeFromChanges(): void;
    /**
     * Execute the current collection of client side rules
     */
    execute(): void;
    /**
     * Executes multiple rule expressions and handles the responses
     */
    private executeRules;
    /**
     * Execute a rule expression and handles the response
     */
    private executeRule;
    /**
     * Execute a rule expression and assigns the result value to the given field (property)
     */
    private executeFieldAssignmentRule;
    /**
     * Executes the rule's condition expression and all rules of the result branch
     */
    private executeConditionalRule;
    /**
     * Subscribe to events that should trigger a recalculation of rules and properties
     */
    private subscribeToChanges;
    static ɵfac: i0.ɵɵFactoryDeclaration<ClientSideRulesService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ClientSideRulesService>;
}
