import { IColorService } from '../../typedefinitions/services/IColorService';
import { IColor } from '../../typedefinitions/models/IColor';
import * as i0 from "@angular/core";
/**
 * The color service provides functionality for converting a color object into a css style string.
 */
export declare class ColorService implements IColorService {
    /**
     * Helper function that checks whether a color is relevant (not transparent)
     * @param colorObj rgba color object
     * @returns {boolean} true if any of the color object's properties are set to a value higher than 0, otherwise false
     */
    hasColor(colorObj?: IColor): colorObj is IColor;
    /**
     * Generates an RGB color string based on the given color object
     * @param colorObj
     * @param property (optional) When provided this property is prefixed to the color string
     * @returns RGB color string
     */
    generateRGBColorForProperty(colorObj: IColor, property?: string): string;
    /**
     * Generates an RGBA color string based on the given color object
     * @param colorObj
     * @param property (optional) When provided this property is prefixed to the color string
     * @returns RGBA color string
     */
    generateRGBAColorForProperty(colorObj: IColor, property?: string): string;
    /**
     * Generates an RGBA color string based on the given color object
     * @param colorObj
     * @returns RGBA color string
     */
    generateRGBAColor(colorObj: IColor): string;
    /**
     * Generates an RGB color string based on the given color object
     * @param colorObj
     * @returns RGB color string
     */
    private generateRGBColor;
    static ɵfac: i0.ɵɵFactoryDeclaration<ColorService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ColorService>;
}
