import { EventService } from './event.service';
import { IBaseComponentViewModel2 } from '../../typedefinitions/models/view/IBaseViewModel';
import { IDictionary } from '../../typedefinitions/models/IDictionary';
import * as i0 from "@angular/core";
/**
 * The component service manages page components
 */
export declare class ComponentService {
    private eventService;
    /**
     * component object containing id-named properties with a base component view model value
     */
    private _components;
    get components(): IDictionary<IBaseComponentViewModel2>;
    set components(value: IDictionary<IBaseComponentViewModel2>);
    get componentsAsList(): IBaseComponentViewModel2[];
    /**
     * Component service class constructor
     * @param eventService
     */
    constructor(eventService: EventService);
    /**
     * Adds a component reference to the component dictionary using the control ID as key.
     * @param id
     * @param component
     */
    registerComponent(id: string, component: any): void;
    /**
     * Removes a component reference from the component dictionary by its key.
     * @param id
     */
    removeComponent(id: string): void;
    /**
     * Get a component reference by its control ID.
     * @param controlId
     * @returns component reference
     */
    getComponent(controlId: string): Nullable<IBaseComponentViewModel2>;
    /**
     * Get a component reference by its control ID.
     * @param controlId
     * @returns component reference
     */
    getComponentParentId(controlId: string): Nullable<string>;
    /**
     * Get a component parent's reference by its control ID.
     * @param controlId
     * @returns component reference
     */
    getComponentParent(controlId: string): Nullable<IBaseComponentViewModel2>;
    static ɵfac: i0.ɵɵFactoryDeclaration<ComponentService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ComponentService>;
}
