import { FieldConverterService } from './field-converter.service';
import { IFieldInfo } from '../../../typedefinitions/models/observables/IFieldInfo';
import { IBlobType } from '../../../typedefinitions/models/value-types/IBlobType';
import { IValueType } from '../../../typedefinitions/models/value-types/IValueType';
import { RangeCheckResult } from '../../../typedefinitions/enums/RangeCheckResult';
import * as i0 from "@angular/core";
/**
 * Blob field converter service class
 */
export declare class BlobFieldConverterService extends FieldConverterService {
    private readonly kiloByte;
    private readonly megaByte;
    /**
     * Retrieves the blob file name from the data value
     * @param fieldInfo Field info
     */
    convertToString(fieldInfo: IFieldInfo): string;
    /**
     * Sets the blob's filename and mime type on the data value
     * @param fileName
     * @param mimeType
     * @param fieldInfo Field info
     */
    setBlobAnswer(fileName: string, mimeType: string, fieldInfo: IFieldInfo): void;
    /**
     * Validates the selected file
     * @param input
     * @param valueType
     */ isValid(input: string, valueType: IValueType): RangeCheckResult;
    /**
     * Checks if the selected file is allowed
     * @param input
     * @param valueType
     */ isAllowed(input: string, valueType: IValueType): RangeCheckResult;
    /**
     * Return the max file size as a textual representation for error messages.
     * @param valueType
     */
    getMaxFileSizeText(valueType: IBlobType): string;
    /**
     * Validates the selected file
     * @param file
     * @param valueType
     */
    isBlobValid(file: File, valueType: IBlobType): RangeCheckResult;
    /**
     * Blob will auto-enter to the next field if answer is set and a filename is present
     * @param fieldInfo Field info
     */
    autoEnter(fieldInfo: IFieldInfo): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<BlobFieldConverterService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<BlobFieldConverterService>;
}
