import { FieldConverterService } from './field-converter.service';
import { IFieldInfo } from '../../../typedefinitions/models/observables/IFieldInfo';
import { IEnumerationType } from '../../../typedefinitions/models/value-types/IEnumerationType';
import { RangeCheckResult } from '../../../typedefinitions/enums/RangeCheckResult';
import * as i0 from "@angular/core";
/**
 * Enumeration field converter service class
 */
export declare class EnumerationFieldConverterService extends FieldConverterService {
    /**
     * Enumeration field converter service class constructor
     */
    constructor();
    /**
     * Determines if the given category is selected
     * @param fieldInfo Field info
     * @param category
     * @return true if selected, otherwise false
     */
    isSelected(fieldInfo: IFieldInfo, category: number): boolean;
    /**
     * Determines if currently selected option is the given special answer
     * @param {IFieldInfo} fieldInfo Field info
     * @param {string} specialAnswer
     * @returns {boolean} true if selected, otherwise false
     */
    isSelectedSpecial(fieldInfo: IFieldInfo, specialAnswer: string): boolean;
    /**
     * Sets the selected option from a given code
     * @param fieldInfo Field info
     * @param code
     */
    setSelected(fieldInfo: IFieldInfo, code: number): void;
    /**
     * Evaluate auto enter logic for enumeration fields
     * @param fieldInfo Field info
     */
    autoEnter(fieldInfo: IFieldInfo): boolean;
    /**
     * Returns if the specified category exists
     * @param fieldInfo Field info
     * @param category
     */
    categoryExists(fieldInfo: IFieldInfo, category: number): boolean;
    /**
     * Validates if the string value is equal to one of the enumeration values
     * @param input
     * @param valueType Enumeration type
     */
    isValid(input: string, valueType: IEnumerationType): RangeCheckResult;
    /**
     *  Validates if the string value is equal to or starts with one of the enumeration values
     * @param input
     * @param valueType
     */
    isAllowed(input: string, valueType: IEnumerationType): RangeCheckResult;
    static ɵfac: i0.ɵɵFactoryDeclaration<EnumerationFieldConverterService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<EnumerationFieldConverterService>;
}
