import { FieldConverterService } from './field-converter.service';
import { IFieldInfo } from '../../../typedefinitions/models/observables/IFieldInfo';
import { IIntegerType } from '../../../typedefinitions/models/value-types/IIntegerType';
import { RangeCheckResult } from '../../../typedefinitions/enums/RangeCheckResult';
import * as i0 from "@angular/core";
/**
 * Number field converter service class
 */
export declare class NumberFieldConverterService extends FieldConverterService {
    /**
     * Regex that checks for an optional minus sign and any number of digits
     */
    private integerCharValidator;
    /**
     * Returns the value as string from the data value subscription
     * @param fieldInfo Field info
     */
    convertToString(fieldInfo: IFieldInfo): string;
    /**
     * Configure the answer object for a regular answer.
     * @param valueStr string value
     * @param fieldInfo Field info
     */
    convertFromString(valueStr: string, fieldInfo: IFieldInfo): void;
    /**
     * Sanitize the value against the DataValue
     * @param value
     * @param valueType
     */ sanitize: (value: string, valueType: IIntegerType) => string;
    /**
     * Validates if the string is allowed in a number input field and in range
     * @param value
     * @param valueType
     * @returns range check result
     */
    isValid(value: string, valueType: IIntegerType): RangeCheckResult;
    /**
     * Validates if the string value is allowed, of an allowed length and if it can contain a minus sign in a number input field
     * @param value
     * @param valueType
     * @returns range check result
     */
    isAllowed(value: string, valueType: IIntegerType): RangeCheckResult;
    /**
     * Checks if auto-enter may be applied
     * @param fieldInfo Field info
     * @returns true, if auto-enter may be applied, otherwise false
     */
    autoEnter(fieldInfo: IFieldInfo): boolean;
    /**
     * Adds the specified separator inside a number string.
     * @param value
     * @param culture
     * @param decimalSeparator
     * @param significantDigits
     * @returns a thousand separated string representation of a given numeric value
     */
    addThousandSeparators: (value: string, culture: string, decimalSeparator: string, significantDigits?: number) => string;
    /**
     * Removes the specified separator from a number string.
     * @param value
     * @param thousandSeparator
     * @param decimalSeparator
     * @param hasDecimals
     * @returns a value without thousands separator
     */
    removeThousandSeparators: (value: string, thousandSeparator: string, decimalSeparator: string, hasDecimals: boolean) => string;
    /**
     * Adds thousands separators to the non-decimal part of a given value
     * @param value
     * @param thousandSeparator
     * @returns a thousand separated representation of a numeric value
     */
    private addThousandSeparatorsToNonDecimalPartOfValue;
    static ɵfac: i0.ɵɵFactoryDeclaration<NumberFieldConverterService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<NumberFieldConverterService>;
}
