import { NumberFieldConverterService } from './number-field-converter.service';
import { CultureInfoService } from '../culture-info.service';
import { IFieldInfo } from '../../../typedefinitions/models/observables/IFieldInfo';
import { IRealType } from '../../../typedefinitions/models/value-types/IRealType';
import { RangeCheckResult } from '../../../typedefinitions/enums/RangeCheckResult';
import * as i0 from "@angular/core";
/**
 * The real field converter service is responsible for validating input and setting the correct errors as
 * well as converting the input value to a string suitable for the server.
 */
export declare class RealFieldConverterService extends NumberFieldConverterService {
    protected cultureInfoService: CultureInfoService;
    /**
     * Regex that checks for an optional minus sign and any number of digits with an optional decimal separator between the digits
     */
    private realCharValidator;
    /**
     * Provides easy access to the globally defined decimal separator constant
     */
    private decimalSeparator;
    /**
     * Set field converter service class constructor
     * @param cultureInfoService
     */
    constructor(cultureInfoService: CultureInfoService);
    /**
     * Sets the decimal separator on a real value
     * @param decimalSeparator
     */
    setDecimalSeparator(decimalSeparator: string): void;
    /**
     * Convert the field value to a display value
     * @param fieldInfo Field info
     */
    convertToString(fieldInfo: IFieldInfo): string;
    /**
     * Convert the display value to a system value
     * @param value
     * @param fieldInfo Field info
     */
    convertFromString(value: string, fieldInfo: IFieldInfo): void;
    /**
     * Determine if the field is ready to auto-enter the next field
     * @param {IFieldInfo} fieldInfo Field info
     * @returns {boolean} true if the next field should be automatically activated, otherwise false
     */
    autoEnter(fieldInfo: IFieldInfo): boolean;
    /**
     * Validates if the string representation of a real field is allowed in a number input field
     * @param value
     * @param valueType
     */
    isValid(value: string, valueType: IRealType): RangeCheckResult;
    /**
     * Checks if the provided string is a valid real value and if it's allowed in the given range
     * @param value
     * @param valueType
     * @returns range check result
     */
    isAllowed(value: string, valueType: IRealType): RangeCheckResult;
    /**
     * Replaces commas by points.
     */
    replaceSeparators(input: string): string;
    /**
     * Sanitizes a string representation of a real value to one with a maximum length of 18
     * @param value
     * @param valueType
     * @returns sanitized value
     */
    sanitize: (value: string, valueType: IRealType) => string;
    /**
     * Returns the amount of decimals in the ValueType based on the Decimals property or the determined ranges
     * @param valueType
     * @returns amount of decimals
     */
    fixedDecimals(valueType: IRealType): number;
    /**
     * Returns the amount of decimals in the ValueType based on the Decimals property or the determined ranges
     * @param valueType
     * @returns amount of decimals
     */
    private maxDecimals;
    /**
     * Checks if the provided string is numeric and the max amount of decimals has been reached
     * @param {IFieldInfo} fieldInfo Field info
     * @returns {boolean} true if the maximum amount of decimals is reached, otherwise false
     */
    private maxDecimalsReached;
    private rangeHasDecimals;
    private getDecimalsOfRange;
    private getDecimalsOfValue;
    private validationSanitize;
    static ɵfac: i0.ɵɵFactoryDeclaration<RealFieldConverterService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<RealFieldConverterService>;
}
