import { FieldConverterService } from './field-converter.service';
import { IFieldInfo } from '../../../typedefinitions/models/observables/IFieldInfo';
import { IStringType } from '../../../typedefinitions/models/value-types/IStringType';
import { RangeCheckResult } from '../../../typedefinitions/enums/RangeCheckResult';
import * as i0 from "@angular/core";
/**
 * String field converter service class
 */
export declare class StringFieldConverterService extends FieldConverterService {
    /**
     * Configure the answer object for a regular answer.
     * @param valueStr string value
     * @param fieldInfo Field info
     */
    convertFromString(valueStr: string, fieldInfo: IFieldInfo): void;
    /**
     * Checks if auto-enter may be applied
     * @param fieldInfo Field info
     * @param args Optional additional arguments that might be needed to check if the auto-enter should be applied
     * @returns true, if auto-enter may be applied, otherwise false
     */
    autoEnter(fieldInfo: IFieldInfo, args?: any[]): boolean;
    /**
     * Validates the input value against any restrictions defined on the value type
     * @param input
     * @param valueType
     * @returns range check result
     */
    isValid(input: string, valueType: IStringType): RangeCheckResult;
    /**
     * Validates the input value's length
     * @param input
     * @param valueType
     * @returns range check result
     */
    isAllowed(input: string, valueType: IStringType): RangeCheckResult;
    static ɵfac: i0.ɵɵFactoryDeclaration<StringFieldConverterService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<StringFieldConverterService>;
}
