import { DateTime } from 'luxon';
import { FieldConverterService } from './field-converter.service';
import { CultureInfoService } from '../culture-info.service';
import { IFieldInfo } from '../../../typedefinitions/models/observables/IFieldInfo';
import { IValueType } from '../../../typedefinitions/models/value-types/IValueType';
import { RangeCheckResult } from '../../../typedefinitions/enums/RangeCheckResult';
import * as i0 from "@angular/core";
/**
 * Time field converter service class
 */
export declare class TimeFieldConverterService extends FieldConverterService {
    protected cultureInfoService: CultureInfoService;
    /**
     * Time field converter service class constructor
     * @param cultureInfoService
     */
    constructor(cultureInfoService: CultureInfoService);
    /**
     * Retrieves the in short time pattern formatted value as string
     * @param fieldInfo Field info
     */
    convertToString(fieldInfo: IFieldInfo): string;
    /**
     * Sets the value as string for a given time
     * @param value
     * @param fieldInfo Field info
     */
    convertFromString(value: Nullable<string>, fieldInfo: IFieldInfo): void;
    /**
     * Check if the string value is valid according to the selected culture time pattern
     * @param value
     */
    matchesTimePattern(value: Nullable<string>): RangeCheckResult;
    /**
     * Check if the string value is valid according to the Blaise time format
     * @param value should be in the CULTURE_FORMATS.TIME format
     * @param valueType
     */
    isValid(value: Nullable<string>, valueType: IValueType): RangeCheckResult;
    /**
     * Checks if the given time is within the allowed range
     * @param input
     * @param valueType
     * @returns the check result
     */ isAllowed(input: string, valueType: IValueType): RangeCheckResult;
    /**
     * Parse the supplied value to either strictly one pattern or multiple possible patterns
     * @param value value to parse
     * @param strict when false, interpret the value in different ways
     * @returns a luxon DateTime time object
     */
    parseTime(value?: string, strict?: boolean): DateTime;
    /**
     * Retrieves the erroneous part of an input value
     * @param value input value
     * @param fieldInfo Field info
     */ protected getInvalidValue(value: string, fieldInfo: IFieldInfo): string;
    static ɵfac: i0.ɵɵFactoryDeclaration<TimeFieldConverterService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<TimeFieldConverterService>;
}
