import { ICultureInfoService } from '../../typedefinitions/services/ICultureInfoService';
import { ICultureInfo } from '../../typedefinitions/models/ICultureInfo';
import * as i0 from "@angular/core";
/**
 * The culture info service is used for storing and consulting culture settings
 */
export declare class CultureInfoService implements ICultureInfoService {
    /**
     * Culture info field
     */
    private _cultureInfo;
    /**
     * Culture info property getter
     * @returns Culture info
     */
    get cultureInfo(): ICultureInfo;
    /**
     * Culture info property setter
     * @param cultureInfo
     */
    set cultureInfo(cultureInfo: ICultureInfo);
    /**
     * Retrieves the first segment from a long culture id to create the short culture id
     * @param longCultureId the long culture id e.g. nl-NL
     * @returns short culture id e.g. nl
     */
    getShortCultureId(longCultureId: string): string;
    /**
     * Parses the short date format from the server's culture info into a client friendly pattern
     * @param cultureInfo
     */
    private parseShortDateFormat;
    /**
     * Parse the culture info to Luxon format based:
     * https://moment.github.io/luxon/#/parsing?id=table-of-tokens
     * @param cultureInfo
     * @returns
     */
    private parseShortDateFormatLuxon;
    /**
     * Parses the short time format from the server's culture info into a client friendly pattern
     * @param cultureInfo
     */
    private parseShortTimeFormat;
    static ɵfac: i0.ɵɵFactoryDeclaration<CultureInfoService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<CultureInfoService>;
}
