import { NgZone } from '@angular/core';
import { ClientSideRouteItemEventsService } from './client-side/route-item-events/client-side-route-item-events.service';
import { EventService } from './event.service';
import { RenderStateService } from './renderstate.service';
import { SubscriptionService } from './subscription.service';
import * as i0 from "@angular/core";
/**
 * Focus service handles the focussing, blurring and activation of fields
 */
export declare class FocusService {
    private ngZone;
    private clientSideRouteItemEventService;
    private document;
    private eventService;
    private renderStateService;
    private subscriptionService;
    private readonly fieldChangeSubscription?;
    private readonly sizeTreeReadySubscription?;
    /**
     * Focus service class constructor
     * @param ngZone
     * @param clientSideRouteItemEventService
     * @param document A reference class for the global document object
     * @param eventService
     * @param renderStateService
     * @param subscriptionService
     */
    constructor(ngZone: NgZone, clientSideRouteItemEventService: ClientSideRouteItemEventsService, document: Document, eventService: EventService, renderStateService: RenderStateService, subscriptionService: SubscriptionService);
    /**
     * Give focus to the first control in the active field
     * @param activeField
     * @param elementId (optional)
     * @param source (optional)
     * @param triggerFocus (optional)
     */
    focusActiveField(activeField: string, elementId?: string, source?: string, triggerFocus?: boolean): void;
    /**
     * Tries to set focus on an element in the document with the given id.
     * @param elementId
     */
    focusElementId(elementId: string): Optional<HTMLElement>;
    /**
     * Sets focus on a hidden element at the top of the page.
     * @deprecated
     */
    focusHiddenTag(): void;
    /**
     * Check if the first input control is in the active field
     * @param id
     * returns true, if the control by id is the first input control in the active field, otherwise false
     */
    isFirstInputControlInActiveField(id: string): boolean;
    /**
     * Check if active field has SetFocus event in ClientSideRouteItemEvents
     * returns true, if ClientSideRouteItemEvents contains a SetFocus Event for the active field
     */
    hasSetFocusEventInClientSideRouteItem(): boolean;
    /**
     * Checks if a given element is in the viewport
     * @param el HTML element to check
     */
    isInViewport(el: HTMLElement): boolean;
    /**
     * returns an element's scroll parent
     * @param node HTML element
     */
    private getScrollParent;
    static ɵfac: i0.ɵɵFactoryDeclaration<FocusService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<FocusService>;
}
