import { RenderStateService } from './renderstate.service';
import { IBaseControl } from '../../typedefinitions/models/controls/IBaseControl';
import { IDictionary } from '../../typedefinitions/models/IDictionary';
import { IFontInfo } from '../../typedefinitions/models/IFontInfo';
import { IHasFont } from '../../typedefinitions/models/controls/properties/IHasFont';
import { IInputControl } from '../../typedefinitions/models/controls/IInputControl';
import * as i0 from "@angular/core";
/**
 * Font service class is used to calculate text sizes for specified font styles
 */
export declare class FontService {
    private document;
    /**
     * RenderStateService provides functionality for managing the render state information as provided by the server
     */
    protected renderStateService: RenderStateService;
    /**
     * Combined fonts field
     */
    private _combinedFonts;
    /**
     * combined fonts property getter
     * @returns combinedFonts
     */
    get combinedFonts(): IDictionary<IFontInfo>;
    /**
     * combined fonts property setter, also determines the case-insensitive keys
     * @param value
     */
    set combinedFonts(value: IDictionary<IFontInfo>);
    /**
     * Font service class constructor
     * @param document A reference class for the global document object
     * @param renderStateService The render state service provides functionality for managing the render state information as provided by the server.
     */
    constructor(document: Document, 
    /**
     * RenderStateService provides functionality for managing the render state information as provided by the server
     */
    renderStateService: RenderStateService);
    /**
     * Create a span in order to determine the dimensions of a character in the control font.
     */
    createFontSpan: (control: IInputControl) => void;
    /**
     * Create a span in order to determine the dimensions of a character in the control's alternative font.
     */
    createAltFontSpan(fontName?: Nullable<string>, font?: Nullable<IFontInfo>, controlId?: Nullable<string>, char?: Nullable<string>, altName?: Nullable<string>): void;
    /**
     * Calculates the offset width for a given control using a span element created with the control's font style properties
     * @param control
     */
    getOffsetWidthSpanElement(control: IBaseControl & IHasFont): number;
    /**
     * Calculates the offset width for a given control using a span element created with given font information
     * @param fontName
     * @param controlId
     * @param char
     * @param altName
     */
    getAltOffsetWidthSpanElement(fontName?: string, controlId?: string, char?: string, altName?: string): number;
    /**
     * Calculates the offset height for a given control using a span element created with the control's font style properties
     * @param control
     */
    getOffsetHeightSpanElement(control: IBaseControl & IHasFont): number;
    /**
     * Calculates the offset height for a given control using a span element created with given font information
     * @param fontName
     * @param controlId
     * @param char
     * @param altName
     */
    getAltOffsetHeightSpanElement(fontName?: string, controlId?: string, char?: string, altName?: string): number;
    /**
     * Remove the span when it contains a control specific font definition
     */
    removeFontSpan(control: IInputControl): void;
    /**
     * Remove the span when it contains a control specific font definition
     */
    removeAltFontSpan(controlId: string, char?: Nullable<string>, altName?: string): void;
    /**
     * Checks if a given font is declared on the defined fonts
     * @param font The font name to search for in the combined fonts
     * @returns Check result flag
     */
    hasCombinedFont(font: string): boolean;
    private getSpan;
    private getSpanById;
    private getChar;
    /**
     * Generate id based on font-id and control type
     */
    private generateFontId;
    /**
     * Generate id based on font-id and control type
     */
    private generateAltFontId;
    static ɵfac: i0.ɵɵFactoryDeclaration<FontService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<FontService>;
}
