import { PlatformLocation } from '@angular/common';
import { RenderStateService } from './renderstate.service';
import { IInvolvedField } from '../../typedefinitions/models/IInvolvedField';
import { DisplayName } from '../../typedefinitions/enums/DisplayName';
import * as i0 from "@angular/core";
/**
 * The helper service provides general functions that are commonly used throughout the application
 */
export declare class HelperService {
    private platformLocation;
    private renderStateService;
    /**
     * Helper service class constructor
     * @param platformLocation
     * @param renderStateService
     */
    constructor(platformLocation: PlatformLocation, renderStateService: RenderStateService);
    /**
     * Generates a root based path to a css file base on the parameters
     * @param surveyRoot
     * @param styleName part of the file name
     * @param resourceSetName part of the file name
     * @param resourceLanguageName part of the file name
     * @returns root based path to a css file ('/instrumentName/Resources/styleName-resourceSetName-resourceLanguageName.css')
     */
    generateStyleCssLink(surveyRoot: string, styleName: string, resourceSetName: string, resourceLanguageName: string): string;
    /**
     * Generates a string containing an object's own properties
     * @param object object to convert
     * @returns result
     */
    convertStyleObjectToString(object: any): string;
    /**
     * Adds a css class to the provided html element
     * @param el
     * @param className
     */
    addClass(el: HTMLElement, className: string): void;
    /**
     * Removes a css class from the provided html element
     * @param el
     * @param className
     */
    removeClass(el: HTMLElement, className: string): void;
    /**
     * Get the base resource folder as relative url
     * @param surveyRoot (optional)
     * @returns base resource folder
     */
    getBaseResourceFolder: (surveyRoot?: string) => string;
    /**
     * Get the base survey folder as relative url
     * @param excludeDebug
     * @param surveyRoot (optional)
     * @returns base survey folder
     */
    getBaseHref: (excludeDebug: boolean, surveyRoot?: string) => string;
    /**
     * Retrieves the name or local name from the involved field based on the component's display name setting
     * @param involvedField
     * @param selectedName DisplayName
     */
    getInvolvedFieldName(involvedField: IInvolvedField, selectedName: DisplayName): string;
    /**
     * separates categories bundled in a string
     * @param valueAsString string to separate
     * @param minusSign
     * @param char
     */
    separateCategories(valueAsString: string, minusSign?: string[1], char?: string[1]): string[];
    /**
     * Compare helper method for the number text box
     * @param diff1
     * @param diff2
     */
    compare: (diff1: any, diff2: any) => ICompareResult;
    /**
     * Convert a string to kebab case
     * @param value
     * @returns
     */
    private kebabCase;
    static ɵfac: i0.ɵɵFactoryDeclaration<HelperService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<HelperService>;
}
export interface ICompareResult {
    lines: ICompareLine[];
    lineCountDeleted: number;
    lineCountInserted: number;
    lineCountMoved: number;
    aMove?: any[];
    aMoveIndex?: any[];
    bMove?: any[];
    bMoveIndex?: any[];
}
export interface ICompareLine {
    aIndex: number;
    bIndex: number;
    line: string;
}
