export declare const COMMAND = "command";
export declare const SHIFT = "shift";
export declare const LEFT = "left";
export declare const RIGHT = "right";
export declare const UP = "up";
export declare const DOWN = "down";
export declare const RETURN = "return";
export declare const BACKSPACE = "backspace";
export declare const MOD = "mod";
export declare const CTRL = "ctrl";
/**
 * The Extended keyboard event interface extends on the keyboard event object which describes a user interaction with the keyboard;
 * Each event describes a single interaction between the user and a key (or combination of a key with modifier keys) on the keyboard.
 */
export interface IExtendedKeyboardEvent extends KeyboardEvent {
    /**
     * Return value flag for IE
     */
    returnValue: boolean;
}
/**
 * Hotkey model class for Mousetrap-binding a new hotkey
 */
export declare class Hotkey {
    /**
     * combo mousetrap key binding
     */
    combo: string | string[];
    /**
     * callback method to call when key is pressed
     */
    callback: (event: KeyboardEvent, combo: string) => IExtendedKeyboardEvent | boolean;
    /**
     * allowIn an array of tag names to allow this combo in ('INPUT', 'SELECT', and/or 'TEXTAREA')
     */
    allowIn?: string[] | undefined;
    /**
     * action (Optional) the type of event to listen for (for mousetrap)
     */
    action?: string | undefined;
    /**
     * persistent (Optional) if true, the binding is preserved upon route changes
     */
    persistent?: boolean | undefined;
    private _formatted;
    /**
     * Returns a list of symbolized hot keys
     */
    get formatted(): string[];
    /**
     * Creates a new hot key for Mousetrap-binding
     * @param combo       mousetrap key binding
     * @param callback    method to call when key is pressed
     * @param allowIn     (optional) an array of tag names to allow this combo in ('INPUT', 'SELECT', and/or 'TEXTAREA')
     * @param action      the type of event to listen for (for mousetrap)
     * @param persistent  if true, the binding is preserved upon route changes
     */
    constructor(
    /**
     * combo mousetrap key binding
     */
    combo: string | string[], 
    /**
     * callback method to call when key is pressed
     */
    callback: (event: KeyboardEvent, combo: string) => IExtendedKeyboardEvent | boolean, 
    /**
     * allowIn an array of tag names to allow this combo in ('INPUT', 'SELECT', and/or 'TEXTAREA')
     */
    allowIn?: string[] | undefined, 
    /**
     * action (Optional) the type of event to listen for (for mousetrap)
     */
    action?: string | undefined, 
    /**
     * persistent (Optional) if true, the binding is preserved upon route changes
     */
    persistent?: boolean | undefined);
    private static symbolize;
}
