import 'hammerjs';
import { Hotkey } from './hotkey.model';
import { EventService } from '../event.service';
import { NavigationService } from '../navigation/navigation.service';
import { SpeedKeyService } from '../speed-key.service';
import { IClientSideShortcut } from '../../../typedefinitions/models/server/IClientSideShortcut';
import * as i0 from "@angular/core";
/**
 * Hotkey service
 */
export declare class HotkeyService {
    private eventService;
    private navigationService;
    private speedKeyService;
    private registeredHotkeys;
    /**
     * From original angular2-hotkeys
     */
    private hotkeys;
    private pausedHotkeys;
    private mousetrap;
    private _preventIn;
    private eventSubject;
    private eventSubscription?;
    private eventDelay;
    private lastEvent;
    /**
     * Hotkey service class constructor
     * @param eventService
     * @param navigationService
     * @param speedKeyService
     */
    constructor(eventService: EventService, navigationService: NavigationService, speedKeyService: SpeedKeyService);
    /**
     * Initializes and registers all system hotkeys
     */
    initialize(): void;
    /**
     * Unregister system hotkeys
     */
    unregisterSystemHotkeys(): void;
    /**
     * Registers hotkeys
     * @param shortcut
     * @param callback
     * @param allowIn
     */
    registerHotkey(shortcut: any, callback: any, allowIn: string[]): void;
    /**
     * Registers a hotkey based on the object it is given
     * @param shortcutObject
     */
    registerHotkeyFromObject(shortcutObject: IClientSideShortcut): void;
    /**
     * Pauses the hotkeys
     * @param hotkey
     */
    pause(hotkey?: Hotkey | Hotkey[]): Nullable<Hotkey | Hotkey[]>;
    /**
     * Unpauses the hotkeys
     * @param hotkey
     */
    unpause(hotkey?: Hotkey | Hotkey[]): Nullable<Hotkey | Hotkey[]>;
    private handleSubscriptionUpdate;
    /**
     * Registers a keystroke hotkey
     * @param shortcut
     * @param callback
     * @param allowIn
     */
    private registerKeystrokeHotkey;
    /**
     * Generates a hotkey combo string
     * @param shortcut
     */
    private generateHotkeyCombo;
    private add;
    private mousetrapBindCallback;
    private remove;
    private findHotkey;
    static ɵfac: i0.ɵɵFactoryDeclaration<HotkeyService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<HotkeyService>;
}
