import { IKeyCodesService } from '../../typedefinitions/services/IKeyCodesService';
import * as i0 from "@angular/core";
/**
 * Key code service is used to evaluate the kind of key pressed
 */
export declare class KeyCodesService implements IKeyCodesService {
    /**
     * Checks whether the key pressed is alphabetic
     * @param key The key code
     * @param allowed (optional) Array of additional allowed keystrokes
     * @returns true, if the key pressed is a roman alphabet key, otherwise false
     */
    isAlpha(key: number, allowed?: number[]): boolean;
    /**
     * Checks whether the key pressed is alphanumeric
     * @param key The key code
     * @param allowed (optional) Array of additional allowed keystrokes
     * @returns true, if the key pressed is an alphanumeric key, otherwise false
     */
    isAlphaNumeric(key: number, allowed?: number[]): boolean;
    /**
     * Checks whether the key is a valid decimal separator
     * @param key The key code
     * @param allowed (optional) Array of additional allowed keystrokes
     * @returns true, if the key pressed is a valid decimal separator, otherwise false
     */
    isDecimalSeparatorKey(key: number, allowed?: number[]): boolean;
    /**
     * Checks whether the key is an edit key (Backspace or Delete)
     * @param key The key code
     * @param allowed (optional) Array of additional allowed keystrokes
     * @returns true, if the key pressed is an edit key, otherwise false
     */
    isEditKey(key: number, allowed?: number[]): boolean;
    /**
     * Checks whether the pressed keys are CTRL+C, CTRL+X, CTRL+V or CTRL+A
     * @param key The key code
     * @param ctrl (optional)
     * @returns true, if the pressed keys are copy, cut, paste or select all command keys, otherwise false
     */
    isCopyOrPasteKey(key: number, ctrl?: boolean): boolean;
    /**
     * Checks whether the key is a function key (F1 - F12)
     * @param key The key code
     * @param allowed (optional) Array of additional allowed keystrokes
     * @returns true, if the key pressed is a function key, otherwise false
     */
    isFunctionKey(key: number, allowed?: number[]): boolean;
    /**
     * Checks whether the key is a digit key
     * @param key The key code
     * @param allowed (optional) Array of additional allowed keystrokes
     * @returns true, if the key pressed is a digit key, otherwise false
     */
    isDigitKey(key: number, allowed?: number[]): boolean;
    /**
     * Checks whether the key is a num-pad key
     * @param key The key code
     * @param allowed (optional) Array of additional allowed keystrokes
     * @returns true, if the key pressed is a num-pad key, otherwise false
     */
    isNumPadKey(key: number, allowed?: number[]): boolean;
    /**
     * Checks whether the key is a zero key
     * @param key The key code
     * @param allowed (optional) Array of additional allowed keystrokes
     * @returns true, if the key pressed is a zero key, otherwise false
     */
    isZeroKey(key: number, allowed?: number[]): boolean;
    /**
     * Checks whether the key is the minus key
     * @param key The key code
     * @param allowed (optional) Array of additional allowed keystrokes
     * @returns true, if the key pressed is the minus key, otherwise false
     */
    isMinusKey(key: number, allowed?: number[]): boolean;
    /**
     * Checks whether the key pressed is numeric
     * @param key The key code
     * @param allowed (optional) Array of additional allowed keystrokes
     * @returns true, if the key pressed is numeric, otherwise false
     */
    isNumeric(key: number, allowed?: number[]): boolean;
    /**
     * Checks whether the key pressed is a possible date separator
     * @param key The key code
     * @param allowed (optional) Array of additional allowed keystrokes
     * @returns true, if the key pressed is a possible date separator, otherwise false
     */
    isDateSeparatorKey(key: number, allowed?: number[]): boolean;
    /**
     * Checks whether the key pressed is a possible time separator
     * @param key The key code
     * @param allowed (optional) Array of additional allowed keystrokes
     * @returns true, if the key pressed is a possible time separator, otherwise false
     */
    isTimeSeparatorKey(key: number, allowed?: number[]): boolean;
    /**
     * Checks whether the key pressed is a possible am-pm designator key
     * @param character
     * @param amPm
     * @returns true, if the key pressed is a possible am-pm designator key, otherwise false
     */
    isAmPmDesignatorKey(character: string, amPm: string): boolean;
    /**
     * Checks whether the key pressed is a navigation key
     * @param key The key code
     * @param allowed (optional) Array of additional allowed keystrokes
     * @returns true, if the key pressed is a navigation key, otherwise false
     */
    isNavigationKey(key: number, allowed?: number[]): boolean;
    /**
     * Checks whether the key pressed is an arrow key
     * @param key The key code
     * @param allowed (optional) Array of additional allowed keystrokes
     * @returns true, if the key pressed is an arrow key, otherwise false
     */
    isArrowKey(key: number, allowed?: number[]): boolean;
    /**
     * Checks if a given key is present in a list of allowed or additional allowed keys
     * @param key The key code
     * @param allowed Array of allowed keystrokes
     * @param additionalAllowed Array of additional allowed keystrokes
     * @returns true, if the given key is present in the list of allowed or additional allowed keys, otherwise false
     */
    private isKeyAllowed;
    static ɵfac: i0.ɵɵFactoryDeclaration<KeyCodesService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<KeyCodesService>;
}
