import { HttpClient } from '@angular/common/http';
import { LoggerOptions } from '../classes/logger/logger-options';
import { LogLevel } from '../../typedefinitions/enums/LogLevel';
import * as i0 from "@angular/core";
/**
 * Logger service for console interactions
 */
export declare class LoggerService {
    private http;
    private options?;
    private readonly consoleDebugMethod;
    private readonly defaultOptions;
    private _level;
    private readonly _globalAs;
    private _store;
    private readonly _storeAs;
    private _send;
    private readonly _sendUrl;
    private readonly _baseHref;
    /**
     * Public getter for the send field flag
     */
    get send(): boolean;
    /**
     * Public setter for the send field flag
     * @param value
     */
    set send(value: boolean);
    /**
     * Public getter for the send-url field value
     */
    get sendUrl(): string;
    /**
     * Public getter for the base-url field value
     */
    get baseHref(): string;
    /**
     * Public getter for the log level field
     * @returns log level field
     */
    get level(): LogLevel;
    /**
     * Public setter for the log level field
     * @param level
     */
    set level(level: LogLevel);
    /**
     * Flag indicating if error messages are logged.
     * @returns {boolean} true if error messages will be logged,otherwise false
     */
    get isErrorEnabled(): boolean;
    /**
     * Flag indicating if warning messages are logged.
     * @returns {boolean} true if error messages will be logged,otherwise false
     */
    get isWarnEnabled(): boolean;
    /**
     * Flag indicating if information messages are logged.
     * @returns {boolean} true if error messages will be logged,otherwise false
     */
    get isInfoEnabled(): boolean;
    /**
     * Flag indicating if debug messages are logged.
     * @returns {boolean} true if error messages will be logged,otherwise false
     */
    get isDebugEnabled(): boolean;
    /**
     * Flag indicating if log messages are logged.
     * @returns {boolean} true if error messages will be logged,otherwise false
     */
    get isLogEnabled(): boolean;
    /**
     * Logger service constructor. Instantiates new Logger instance.
     * By default, a logger is instantiated with a set of default options.
     * Override these options by passing a modified {@link LoggerOptions} object to the constructor.
     * @param http Http Client
     * @param options (optional) logger options
     */
    constructor(http: HttpClient, options?: LoggerOptions | undefined);
    /**
     * Logs an error message.
     * @param args
     */
    error(...args: any[]): void;
    /**
     * Logs a warning message.
     * @param args
     */
    warn(...args: any[]): void;
    /**
     * Logs an info message.
     * @param args
     */
    info(...args: any[]): void;
    /**
     * Logs a debug message.
     * @param args
     */
    debug(...args: any[]): void;
    /**
     * Logs a default log message.
     * @param args
     */
    log(...args: any[]): void;
    /**
     * Stores the current log level in the local storage.
     * @returns logger service
     */
    store(): LoggerService;
    /**
     * Removes the stored log level from the local storage.
     * @returns logger service
     */
    unstore(): LoggerService;
    private loadLevel;
    private storeLevel;
    private global;
    private sendToUrl;
    static ɵfac: i0.ɵɵFactoryDeclaration<LoggerService, [null, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<LoggerService>;
}
