import { HttpClient } from '@angular/common/http';
import { EventService } from './event.service';
import { PayloadService } from './payload.service';
import { SubscriptionService } from './subscription.service';
import { ILookupState } from '../../typedefinitions/models/server/ILookupState';
import * as i0 from "@angular/core";
/**
 * Look up service performs lookup requests for lookup controls
 */
export declare class LookupService {
    private http;
    private eventService;
    private payloadService;
    private subscriptionService;
    private _fetchLookupResultsPath;
    private _fetchSurveyListResultsPath;
    private _fetchAppointmentListResultsPath;
    private _selectExternalRecordPath;
    /**
     * Write-only public property fetch lookup results path
     * @param path
     */
    set fetchLookupResultsPath(path: string);
    /**
     * Write-only public property fetch survey list results path
     * @param path
     */
    set fetchSurveyListResultsPath(path: string);
    /**
     * Write-only public property fetch appointment list results path
     * @param path
     */
    set fetchAppointmentListResultsPath(path: string);
    /**
     * Write-only public property select external record path
     * @param path
     */
    set selectExternalRecordPath(path: string);
    /**
     * Lookup service class constructor
     * @param http Http Client
     * @param eventService
     * @param payloadService
     * @param subscriptionService
     */
    constructor(http: HttpClient, eventService: EventService, payloadService: PayloadService, subscriptionService: SubscriptionService);
    /**
     * Fetch lookup results by field name and search term
     * @param fieldName
     * @param searchTerm
     * @param maxResultCount Limits the returned results to the provided amount (optional, default is 15)
     * @returns result
     */
    performLookup(fieldName: string, searchTerm: any, maxResultCount?: number): void;
    /**
     * Select an external record
     * @param lookupFieldName Name of the lookup field
     * @param externalFieldNames Names of the external fields
     * @param externalFieldValues Values of the external fields
     * @param autoEnter if true, the focus should shift to the next question, otherwise the current question will keep focus
     */
    selectExternalRecord(lookupFieldName: string, externalFieldNames: string[], externalFieldValues: any[], autoEnter: boolean): void;
    /**
     * Requests either an appointment list, a survey list or a search result from the server by field name and lookup state
     * @param fieldName
     * @param lookupState
     * @param resetStartIndex
     */
    requestSearch(fieldName: string, lookupState: ILookupState, resetStartIndex?: boolean): void;
    /**
     * Updates the lookup state's search text
     * @param fieldName
     * @param searchText
     */
    setSearchTerm(fieldName: string, searchText: string): void;
    /**
     * Updates the lookup state's active key and triggers a new request search
     * @param fieldName
     * @param activeKey
     */
    setActiveKey(fieldName: string, activeKey: string): void;
    /**
     * Sets the lookup state's start index and triggers a request search
     * @param fieldName
     * @param startIndex
     */
    setStartIndex(fieldName: string, startIndex: number): void;
    private handlePerformLookup;
    private handleException;
    private handleRequestSearch;
    private handleFetchAppointmentList;
    private handleFetchSurveyList;
    private resetStartIndex;
    private lowerCaseStringCompare;
    static ɵfac: i0.ɵɵFactoryDeclaration<LookupService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<LookupService>;
}
