import { HelperService } from './helper.service';
import { IMediaUrls } from '../../typedefinitions/models/server/IMediaUrls';
import { IMediaService } from '../../typedefinitions/services/IMediaService';
import * as i0 from "@angular/core";
/**
 * The media service provides functionality for retrieving media urls and making them accessible.
 */
export declare class MediaService implements IMediaService {
    private helperService;
    /**
     * Media urls
     */
    private _mediaUrls;
    /**
     * Lookup object
     */
    private _lookups;
    /**
     * Media service class constructor
     * @param helperService
     */
    constructor(helperService: HelperService);
    /**
     * mediaUrls property getter
     * @returns media urls
     */
    get mediaUrls(): IMediaUrls;
    /**
     * mediaUrls property setter, also determines the case-insensitive keys
     * @param value
     */
    set mediaUrls(value: IMediaUrls);
    /**
     * Retrieves the url for an audio media file
     * @param fileName
     * @returns url for a audio file
     */
    getMediaUrlForAudio(fileName: string): Nullable<string>;
    /**
     * Retrieves the url for an document media file
     * @param fileName
     * @returns url for a document
     */
    getMediaUrlForDocument(fileName: string): Nullable<string>;
    /**
     * Retrieves the url for an image media file
     * @param fileName
     * @returns url for an image file
     */
    getMediaUrlForImage(fileName: string): string;
    /**
     * Retrieves the url for a video media file
     * @param fileName
     * @returns url for a video file
     */
    getMediaUrlForVideo(fileName: string): Nullable<string>;
    /**
     * Retrieves the url for a media file by type and file name
     * @param mediaType
     * @param key
     * @returns url for a media file
     */
    getMediaUrl(mediaType: string, key: string): Nullable<string>;
    /**
     * Add lowercase lookup string in dictionary for every item
     * @param mediaType
     */
    private determineKeys;
    static ɵfac: i0.ɵɵFactoryDeclaration<MediaService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<MediaService>;
}
