import { Type } from '@angular/core';
import { BaseComponent } from '../components/base/base.component';
import { IBaseComponentViewModel2 } from '../../typedefinitions/models/view/IBaseViewModel';
import { IBaseControl } from '../../typedefinitions/models/controls/IBaseControl';
import { ControlKind } from '../../typedefinitions/enums/ControlKind';
import * as i0 from "@angular/core";
type ExtendedControlKind = ControlKind | number | string;
/**
 * The model service is a helper service for determining the right child component by its control type.
 */
export declare class ModelService {
    private readonly defaultStr;
    private readonly componentTypes;
    private readonly mapsComponentTypes;
    /**
     * Model service class constructor. Sets all available component types in the designated property.
     */
    constructor();
    /**
     * Create a component view model based on a control object.
     * @param {IBaseControl} control Control for which to create a component view model
     * @param {Nullable<string>} parent Id of the control's parent, null for the root control
     * @param {ExtendedControlKind} controlKind (optional), extended control kind. default: value of the Kind property of the control
     * @returns {IBaseComponentViewModel2}
     */
    createChild(control: IBaseControl, parent: Nullable<string>, controlKind?: ExtendedControlKind): IBaseComponentViewModel2;
    /**
     * Adds a component type to the default component types list.
     * This removes the need to use custom properties and to override/extend(!) the create child function
     * @param {ExtendedControlKind} kind Control kind enum value or another unique number or string representing a custom control kind
     * @param {Type<BaseComponent<IBaseControl>>} type The component type (must extend the base component or any of its derived classes).
     */
    protected addComponentType(kind: ExtendedControlKind, type: Type<BaseComponent<IBaseControl>>): void;
    /**
     * Initializes the component type object properties
     */
    private setComponentTypes;
    /**
     * Returns the component type for a given control kind or default (null) if not found.
     * @param {ExtendedControlKind} controlKind Control kind enum value or another unique number or string representing a custom control kind
     * @returns {Nullable<ComponentType>}
     */
    private getType;
    /**
     * Returns the maps component type for a given provider or default (null) if not found.
     * @param {ExtendedMapProvider} provider MapProvider
     * @returns {Nullable<MapsComponentType>}
     */
    private getMapType;
    static ɵfac: i0.ɵɵFactoryDeclaration<ModelService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ModelService>;
}
export {};
