import { EventService } from './event.service';
import { IBaseControl } from '../../typedefinitions/models/controls/IBaseControl';
import * as i0 from "@angular/core";
/**
 * Mouse event service class handles mouse events and executes assigned mouse event actions
 */
export declare class MouseEventService {
    private eventService;
    private mouseEventStates;
    private mouseOverTree;
    private mouseUp;
    /**
     * Mouse event service class constructor
     * @param eventService Central hub in Blaise containing global application events.
     */
    constructor(eventService: EventService);
    /**
     * Check if the control has a mouse event defined
     * @param controlId
     * @returns boolean
     */
    hasMouseEvents(controlId: string): boolean;
    /**
     * Adds the control to the control state dictionary
     * @param dataObject
     * @param parentId
     */
    registerComponent(dataObject: IBaseControl, parentId: Nullable<string>): void;
    /**
     * Updates the control in the control state dictionary
     * @param dataObject
     */
    updateComponent(dataObject: IBaseControl): void;
    /**
     * Removes a control from the control state dictionary by its key.
     * @param id
     */
    removeComponent(id: string): void;
    /**
     * Executes the mouse-enter event actions for a control.
     * @param controlId
     */
    handleMouseEnterEvent(controlId: string): void;
    /**
     * Executes the (pending) mouse-leave actions for this control and all its children.
     * @param controlId
     */
    handleMouseLeaveEvent(controlId: string): void;
    /**
     * Handles an elements mouse down event, sets a mouse up event as pending
     * @param controlId
     */
    handleMouseDownEvent(controlId: string): void;
    /**
     * Executes the pending mouse-up event actions
     */
    handleMouseUpEvent(): void;
    private resolvePendingLeaveEvents;
    private populateMouseOverTree;
    private addMouseOverTreeParent;
    /**
     * Checks if an actions event handler has on or more actions
     */
    private hasMouseEventActions;
    static ɵfac: i0.ɵɵFactoryDeclaration<MouseEventService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<MouseEventService>;
}
