import { INavigationModeStrategy } from '../../../typedefinitions/models/INavigationModeStrategy';
import { INavigationCommand } from '../../../typedefinitions/models/INavigationCommand';
import { Injector } from '@angular/core';
import { ClassificationComponent } from '../../components/classification/classification.component';
/**
 *  Concrete implementation of strategy pattern.
 *  This strategy does nothing by default.
 */
export declare class ClassificationEmptyStrategy implements INavigationModeStrategy {
    private injector;
    private component;
    /**
     * Navigation service
     */
    private navigationService;
    /**
     * Empty strategy class constructor.
     * @param injector
     * @param component
     */
    constructor(injector: Injector, component: ClassificationComponent);
    /**
     * Creates corresponding commands for the f2 key pressed event
     * @returns navigation commands
     */
    f2KeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the enter key pressed event
     * Should Select the value, equivalent of pressing the OK button
     * @param event
     * @returns navigation commands
     */
    enterKeyPressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the left key pressed event
     * @param event
     * @returns navigation commands
     */
    leftKeyPressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the right key pressed event
     * @param event
     * @returns navigation commands
     */
    rightKeyPressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the up key pressed event
     * @returns navigation commands
     */
    upKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the down key pressed event
     * @returns navigation commands
     */
    downKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the page up key pressed event
     * @returns navigation commands
     */
    pageUpKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the page down key pressed event
     * @returns navigation commands
     */
    pageDownKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the home key pressed event
     * @returns navigation commands
     */
    homeKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the end key pressed event
     * @returns navigation commands
     */
    endKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the tab key pressed event
     * @returns navigation commands
     */
    tabKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the shift-tab key combination pressed event
     * @returns navigation commands
     */
    shiftTabPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the escape key pressed event
     * @param event
     * @returns navigation commands
     */
    escapePressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the space bar pressed event
     * Used for navigation in de control, equivalent of selecting a value or back
     * @param event
     * @returns navigation commands
     */
    spacePressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Retrieves the empty insert strategy name
     * @returns empty insert strategy name
     */
    getName(): string;
}
