import { Injector } from '@angular/core';
import { INavigationModeStrategy } from '../../../typedefinitions/models/INavigationModeStrategy';
import { INavigationCommand } from '../../../typedefinitions/models/INavigationCommand';
import { DateComponent } from '../../components/date/date.component';
import { BaseEmptyStrategy } from './BaseEmptyStrategy';
/**
 * The date insert strategy class allows creation of key press corresponding commands for te date component's input field
 */
export declare class DateEmptyAccessibleStrategy extends BaseEmptyStrategy implements INavigationModeStrategy {
    private injector;
    protected component: DateComponent;
    /**
     * Navigation service
     */
    private navigationService;
    /**
     * Lookup textbox insert strategy class constructor.
     * @param injector
     * @param component
     */
    constructor(injector: Injector, component: DateComponent);
    /**
     * Creates corresponding commands for the f2 key pressed event
     * @returns navigation commands
     */
    f2KeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the enter key pressed event
     * @returns navigation commands
     */
    enterKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the left key pressed event
     * @param event
     * @returns navigation commands
     */
    leftKeyPressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the right key pressed event
     * @param event
     * @returns navigation commands
     */
    rightKeyPressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the up key pressed event
     * @param event
     * @returns navigation commands
     */
    upKeyPressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the down key pressed event
     * @param event
     * @returns navigation commands
     */
    downKeyPressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the page up key pressed event
     * @returns navigation commands
     */
    pageUpKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the page down key pressed event
     * @returns navigation commands
     */
    pageDownKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the home key pressed event
     * @returns navigation commands
     */
    homeKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the end key pressed event
     * @returns navigation commands
     */
    endKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the tab key pressed event
     * @returns navigation commands
     */
    tabKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the shift-tab key combination pressed event
     * @returns navigation commands
     */
    shiftTabPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the escape key pressed event
     * @returns navigation commands
     */
    escapePressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the space bar pressed event
     * @returns navigation commands
     */
    spacePressed(): INavigationCommand[];
    /**
     * Retrieves the empty insert strategy name
     * @returns empty insert strategy name
     */
    getName(): string;
}
