import { Injector } from '@angular/core';
import { IHasDropdownList } from '../../../typedefinitions/models/IHasDropdownList';
import { INavigationModeStrategy } from '../../../typedefinitions/models/INavigationModeStrategy';
import { INavigationCommand } from '../../../typedefinitions/models/INavigationCommand';
/**
 * The dropdown list insert strategy class allows creation of key press corresponding commands for the dropdown list component
 */
export declare class DropdownlistInsertStrategy implements INavigationModeStrategy {
    protected injector: Injector;
    protected dropdownList: IHasDropdownList;
    /**
     * Navigation service
     */
    private navigationService;
    /**
     * Dropdown list insert strategy class constructor.
     * @param injector
     * @param dropdownList
     */
    constructor(injector: Injector, dropdownList: IHasDropdownList);
    /**
     * Creates corresponding commands for the f2 key pressed event
     * @returns navigation commands
     */
    f2KeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the enter key pressed event
     * @param event
     * @returns navigation commands
     */
    enterKeyPressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the left key pressed event
     * @returns navigation commands
     */
    leftKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the right key pressed event
     * @returns navigation commands
     */
    rightKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the up key pressed event
     * @returns navigation commands
     */
    upKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the down key pressed event
     * @returns navigation commands
     */
    downKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the page up key pressed event
     * @returns navigation commands
     */
    pageUpKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the page down key pressed event
     * @returns navigation commands
     */
    pageDownKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the home key pressed event
     * @param event
     * @returns navigation commands
     */
    homeKeyPressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the end key pressed event
     * @param event
     * @returns navigation commands
     */
    endKeyPressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the tab key pressed event
     * @returns navigation commands
     */
    tabKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the shift-tab key combination pressed event
     * @returns navigation commands
     */
    shiftTabPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the escape key pressed event
     * @param event
     * @returns navigation commands
     */
    escapePressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the space bar pressed event
     * @param event
     * @returns navigation commands
     */
    spacePressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Retrieves the dropdown list insert strategy name
     * @returns dropdown list insert strategy name
     */
    getName(): string;
}
