import { Injector } from '@angular/core';
import { NumberSliderComponent } from '../../components/number/slider/number-slider.component';
import { INavigationModeStrategy } from '../../../typedefinitions/models/INavigationModeStrategy';
import { INavigationCommand } from '../../../typedefinitions/models/INavigationCommand';
/**
 * The number slider insert strategy class allows creation of key press corresponding commands for the number slider component
 */
export declare class NumberSliderEmptyStrategy implements INavigationModeStrategy {
    private injector;
    private numberSlider;
    /**
     * Navigation service
     */
    private navigationService;
    /**
     * Number slider insert strategy class constructor.
     * @param injector
     * @param numberSlider
     */
    constructor(injector: Injector, numberSlider: NumberSliderComponent);
    /**
     * Creates corresponding commands for the f2 key pressed event
     * @returns navigation commands
     */
    f2KeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the enter key pressed event
     * @returns navigation commands
     */
    enterKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the left key pressed event. If the control's orientation in horizontal, decrease the input's value by one step.
     * @param event
     * @returns navigation commands
     */
    leftKeyPressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the left key pressed event. If the control's orientation in horizontal, increase the input's value by one step.
     * @param event
     * @returns navigation commands
     */
    rightKeyPressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the up key pressed event. If the control's orientation in vertical, decrease the input's value by one step.
     * @param event
     * @returns navigation commands
     */
    upKeyPressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the down key pressed event. If the control's orientation in vertical, increase the input's value by one step.
     * @param event
     * @returns navigation commands
     */
    downKeyPressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the page up key pressed event
     * @returns navigation commands
     */
    pageUpKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the page down key pressed event
     * @returns navigation commands
     */
    pageDownKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the home key pressed event
     * @param event
     * @returns navigation commands
     */
    homeKeyPressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the end key pressed event
     * @param event
     * @returns navigation commands
     */
    endKeyPressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the tab key pressed event
     * @returns navigation commands
     */
    tabKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the shift-tab key combination pressed event
     * @returns navigation commands
     */
    shiftTabPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the escape key pressed event
     * @returns navigation commands
     */
    escapePressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the space bar pressed event
     * @returns navigation commands
     */
    spacePressed(): INavigationCommand[];
    /**
     * Retrieves the number slider insert strategy name
     * @returns number slider insert strategy name
     */
    getName(): string;
}
