import { INavigationModeStrategy } from '../../../typedefinitions/models/INavigationModeStrategy';
import { INavigationCommand } from '../../../typedefinitions/models/INavigationCommand';
/**
 * The radio button empty strategy class
 *
 * Keyboard navigation used in WCAG mode = KeyboardNavigation.None
 * As less interference with the default browser behaviour as possible
 *
 * https://www.csun.edu/universal-design-center/web-accessibility-criteria-tab-order
 * ↑/↓ or ←/→ - select an option.
 * Tab - move to the next element.
 */
export declare class RadioButtonEmptyStrategy implements INavigationModeStrategy {
    /**
     * Creates corresponding commands for the f2 key pressed event
     * @returns navigation commands
     */
    f2KeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the enter key pressed event
     * @returns navigation commands
     */
    enterKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the left key pressed event
     * @returns navigation commands
     */
    leftKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the right key pressed event
     * @returns navigation commands
     */
    rightKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the up key pressed event
     * @returns navigation commands
     */
    upKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the down key pressed event
     * @returns navigation commands
     */
    downKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the page up key pressed event
     * @returns navigation commands
     */
    pageUpKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the page down key pressed event
     * @returns navigation commands
     */
    pageDownKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the home key pressed event
     * @returns navigation commands
     */
    homeKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the end key pressed event
     * @returns navigation commands
     */
    endKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the tab key pressed event
     * @returns navigation commands
     */
    tabKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the shift-tab key combination pressed event
     * @returns navigation commands
     */
    shiftTabPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the escape key pressed event
     * @returns navigation commands
     */
    escapePressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the space bar pressed event
     * @returns navigation commands
     */
    spacePressed(): INavigationCommand[];
    /**
     * Retrieves the radio button insert strategy name
     * @returns radio button insert strategy name
     */
    getName(): string;
}
