import { Injector } from '@angular/core';
import { INavigationModeStrategy } from '../../../typedefinitions/models/INavigationModeStrategy';
import { INavigationCommand } from '../../../typedefinitions/models/INavigationCommand';
import { CategoryRadioButtonComponent } from '../../components/category/radio-button/category-radio-button.component';
import { SpecialAnswerRadioButtonComponent } from '../../components/special-answer/radio-button/special-answer-radio-button.component';
import { ResponseComponent } from '../../components/response/response.component';
/**
 * The radio button insert strategy class allows creation of key press corresponding commands
 */
export declare class RadioButtonInsertStrategy implements INavigationModeStrategy {
    private injector;
    protected component: CategoryRadioButtonComponent | ResponseComponent | SpecialAnswerRadioButtonComponent;
    /**
     * Navigation service
     */
    private navigationService;
    /**
     * Radio button insert strategy class constructor
     * @param injector
     * @param component
     */
    constructor(injector: Injector, component: CategoryRadioButtonComponent | ResponseComponent | SpecialAnswerRadioButtonComponent);
    /**
     * Creates corresponding commands for the f2 key pressed event
     * @returns navigation commands
     */
    f2KeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the enter key pressed event
     * @param event
     * @returns navigation commands
     */
    enterKeyPressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the left key pressed event
     * @param event
     * @returns navigation commands
     */
    leftKeyPressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the right key pressed event
     * @param event
     * @returns navigation commands
     */
    rightKeyPressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the up key pressed event
     * @param event
     * @returns navigation commands
     */
    upKeyPressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the down key pressed event
     * @param event
     * @returns navigation commands
     */
    downKeyPressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the page up key pressed event
     * @returns navigation commands
     */
    pageUpKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the page down key pressed event
     * @returns navigation commands
     */
    pageDownKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the home key pressed event
     * @param event
     * @returns navigation commands
     */
    homeKeyPressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the end key pressed event
     * @param event
     * @returns navigation commands
     */
    endKeyPressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the tab key pressed event
     * @param event
     * @returns navigation commands
     */
    tabKeyPressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the shift-tab key combination pressed event
     * @param event
     * @returns navigation commands
     */
    shiftTabPressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the escape key pressed event
     * @param event
     * @returns navigation commands
     */
    escapePressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the space bar pressed event
     * @returns navigation commands
     */
    spacePressed(): INavigationCommand[];
    /**
     * Retrieves the radio button insert strategy name
     * @returns radio button insert strategy name
     */
    getName(): string;
}
