import { Injector } from '@angular/core';
import { INavigationModeStrategy } from '../../../typedefinitions/models/INavigationModeStrategy';
import { INavigationCommand } from '../../../typedefinitions/models/INavigationCommand';
/**
 * The string textbox insert strategy class allows creation of key press corresponding commands
 */
export declare class StringTextboxInsertStrategy implements INavigationModeStrategy {
    private injector;
    private isOpenField;
    private isMultiLine;
    private nextFieldOnEnter;
    /**
     * Navigation service
     */
    private navigationService;
    /**
     * String textbox insert strategy class constructor.
     * @param injector
     * @param isOpenField Flag indicating if the field is an open field. Default is false.
     * @param isMultiLine Flag indicating if the field is a multi-line string field. Default is false.
     * @param nextFieldOnEnter Flag for an open or multi-line string field indicating what the enter key should do in insert mode. When true, the enter key triggers a go-to-next-field action, when false, it generates a line-break.
     */
    constructor(injector: Injector, isOpenField?: boolean, isMultiLine?: boolean, nextFieldOnEnter?: boolean);
    /**
     * Creates corresponding commands for the f2 key pressed event
     * @returns navigation commands
     */
    f2KeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the enter key pressed event
     * @param event
     * @returns navigation commands
     */
    enterKeyPressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the left key pressed event
     * @returns navigation commands
     */
    leftKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the right key pressed event
     * @returns navigation commands
     */
    rightKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the up key pressed event
     * @param event
     * @returns navigation commands
     */
    upKeyPressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the down key pressed event
     * @param event
     * @returns navigation commands
     */
    downKeyPressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the page up key pressed event
     * @returns navigation commands
     */
    pageUpKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the page down key pressed event
     * @returns navigation commands
     */
    pageDownKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the home key pressed event
     * @returns navigation commands
     */
    homeKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the end key pressed event
     * @returns navigation commands
     */
    endKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the tab key pressed event
     * @returns navigation commands
     */
    tabKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the shift-tab key combination pressed event
     * @returns navigation commands
     */
    shiftTabPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the escape key pressed event
     * @param event
     * @returns navigation commands
     */
    escapePressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the space bar pressed event
     * @returns navigation commands
     */
    spacePressed(): INavigationCommand[];
    /**
     * Retrieves the string textbox insert strategy name
     * @returns string textbox insert strategy name
     */
    getName(): string;
}
