import { Injector } from '@angular/core';
import { IHasDropdownList } from '../../../typedefinitions/models/IHasDropdownList';
import { INavigationCommand } from '../../../typedefinitions/models/INavigationCommand';
import { EmptyStrategy } from './EmptyStrategy';
/**
 * Keyboard navigation strategy for the time picker button in insert mode
 */
export declare class TimePickerButtonEmptyAccessibleStrategy extends EmptyStrategy {
    protected injector: Injector;
    protected timeComponent: IHasDropdownList;
    /**
     * Navigation service
     */
    private navigationService;
    /**
     * Time picker button insert strategy class constructor.
     * @param injector
     * @param timeComponent
     */
    constructor(injector: Injector, timeComponent: IHasDropdownList);
    /**
     * Creates corresponding commands for the enter key pressed event.
     * If the time picker list is open, selects the active enum value, otherwise navigates to the next field.
     * @param event
     * @returns navigation commands
     */
    enterKeyPressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the space bar pressed event. Opens/closes the list.
     * @param event
     * @returns navigation commands
     */
    spacePressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the up key pressed event. If the time picker list is open, selects the previous enum value.
     * @param event
     * @returns navigation commands
     */
    upKeyPressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the down key pressed event. If the time picker list is open, selects the next enum value.
     * @param event
     * @returns navigation commands
     */
    downKeyPressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the escape key pressed event and closes the list.
     * @param event
     * @returns navigation commands
     */
    escapePressed(event: KeyboardEvent): INavigationCommand[];
}
