import { Injector } from '@angular/core';
import { IHasDropdownList } from '../../../typedefinitions/models/IHasDropdownList';
import { INavigationModeStrategy } from '../../../typedefinitions/models/INavigationModeStrategy';
import { INavigationCommand } from '../../../typedefinitions/models/INavigationCommand';
/**
 * Keyboard navigation strategy for the time picker button in insert mode
 */
export declare class TimePickerButtonInsertStrategy implements INavigationModeStrategy {
    protected injector: Injector;
    protected timeComponent: IHasDropdownList;
    /**
     * Navigation service
     */
    private navigationService;
    /**
     * Time picker button insert strategy class constructor.
     * @param injector
     * @param timeComponent
     */
    constructor(injector: Injector, timeComponent: IHasDropdownList);
    /**
     * Creates corresponding commands for the f2 key pressed event
     * @returns navigation commands
     */
    f2KeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the enter key pressed event.
     * If the time picker list is open, selects the active enum value, otherwise navigates to the next field.
     * @param event
     * @returns navigation commands
     */
    enterKeyPressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the left key pressed event
     * @returns navigation commands
     */
    leftKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the right key pressed event
     * @returns navigation commands
     */
    rightKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the up key pressed event. If the time picker list is open, selects the previous enum value.
     * @param event
     * @returns navigation commands
     */
    upKeyPressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the down key pressed event. If the time picker list is open, selects the next enum value.
     * @param event
     * @returns navigation commands
     */
    downKeyPressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the page up key pressed event
     * @param event
     * @returns navigation commands
     */
    pageUpKeyPressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the page down key pressed event
     * @param event
     * @returns navigation commands
     */
    pageDownKeyPressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the home key pressed event. If the time picker list is open, selects the first enum value.
     * @param event
     * @returns navigation commands
     */
    homeKeyPressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the end key pressed event. If the time picker list is open, selects the last enum value.
     * @param event
     * @returns navigation commands
     */
    endKeyPressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the tab key pressed event
     * @returns navigation commands
     */
    tabKeyPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the shift-tab key combination pressed event
     * @returns navigation commands
     */
    shiftTabPressed(): INavigationCommand[];
    /**
     * Creates corresponding commands for the escape key pressed event and closes the list.
     * @param event
     * @returns navigation commands
     */
    escapePressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Creates corresponding commands for the space bar pressed event. Opens/closes the list.
     * @param event
     * @returns navigation commands
     */
    spacePressed(event: KeyboardEvent): INavigationCommand[];
    /**
     * Retrieves the time picker button insert strategy name
     * @returns time picker button insert strategy name
     */
    getName(): string;
}
