import { Injector } from '@angular/core';
import { INavigationCommand } from '../../../../typedefinitions/models/INavigationCommand';
import { NavigationCommandKind } from '../../../../typedefinitions/enums/NavigationCommandKind';
/**
 * Factory that allows creation of a concrete strategy for each available navigation mode.
 */
export declare class NavigationCommandFactory {
    /**
     * Creates a command for a specified type.
     * @param kind Navigation command kind to create
     * @param injector Service injector instance
     * @param controlId only required/used for a focus control navigation command
     * @param fieldName only required/used for a goto field navigation command
     * @returns command for a specified type.
     */
    static createCommand(kind: NavigationCommandKind, injector: Injector, controlId?: string, fieldName?: string): INavigationCommand;
    /**
     * Create multiple commands for specified types.
     * @param kinds Navigation command kinds to create
     * @param injector Service injector instance
     * @param controlId only required/used for focus control navigation commands
     * @param fieldName only required/used for goto field navigation commands
     * @returns multiple commands for specified types
     */
    static createCommands(kinds: NavigationCommandKind[], injector: Injector, controlId?: string, fieldName?: string): INavigationCommand[];
}
