import { ComponentService } from './component.service';
import { ConverterFactoryService } from './converters/converter-factory.service';
import { EventService } from './event.service';
import { SubscriptionService } from './subscription.service';
import { IDataEntrySettingsInfo } from '../../typedefinitions/models/server/IDataEntrySettingsInfo';
import { IDataSource } from '../../typedefinitions/models/server/data-source/IDataSource';
import { IError } from '../../typedefinitions/models/IError';
import { IFieldInfo } from '../../typedefinitions/models/observables/IFieldInfo';
import { IFieldProperty } from '../../typedefinitions/models/IFieldProperty';
import { IField } from '../../typedefinitions/models/IField';
import { IGroup } from '../../typedefinitions/models/IGroup';
import { ILookupInformation } from '../../typedefinitions/models/server/ILookupInformation';
import { IPage } from '../../typedefinitions/models/server/IPage';
import { IRouteItemReference } from '../../typedefinitions/models/IRouteItemReference';
import { ISection } from '../../typedefinitions/models/ISection';
import { ITextBox } from '../../typedefinitions/models/ITextBox';
import { IInvolvedField } from '../../typedefinitions/models/IInvolvedField';
import { IRenderState } from '../../typedefinitions/models/server/IRenderState';
import { ILayoutModelState } from '../../typedefinitions/models/server/ILayoutModelState';
import { ILanguageInfo } from '../../typedefinitions/models/server/ILanguageInfo';
import { IRenderStateService } from '../../typedefinitions/services/IRenderStateService';
import { IRuntimeSettings } from '../../typedefinitions/models/server/IRuntimeSettings';
import { KeyboardNavigation } from '../../typedefinitions/enums/KeyboardNavigation';
import { NavigationMode } from '../../typedefinitions/enums/NavigationMode';
import * as i0 from "@angular/core";
/**
 * The render state service provides functionality for managing of and easy access to render state information as provided by the server.
 * This render state information consists of layout model state information, (active) field info, page info, error info, data entry settings and more.
 */
export declare class RenderStateService implements IRenderStateService {
    private componentService;
    private converterFactoryService;
    private eventService;
    private subscriptionService;
    /**
     * Document represents any web page loaded in the browser and serves as an entry point into the web page's content.
     */
    protected document: Document;
    /**
     * Previous ParallelName
     */
    private _previousParallelName;
    /**
     * Previous PageIndex
     */
    private _previousPageIndex;
    /**
     * cached render state
     */
    private _renderState;
    /**
     * subscription for render state changes
     */
    private _renderStateChangedSubscription?;
    /**
     * subscription for ControlVisibilityChanged event
     */
    private _controlVisibilityChangedSubscription?;
    /**
     * Constructor
     * @param componentService
     * @param converterFactoryService
     * @param subscriptionService
     * @param eventService
     * @param document A reference class for the global document object
     */
    constructor(componentService: ComponentService, converterFactoryService: ConverterFactoryService, eventService: EventService, subscriptionService: SubscriptionService, 
    /**
     * Document represents any web page loaded in the browser and serves as an entry point into the web page's content.
     */
    document: Document);
    /**
     * Gets the render state object
     * @returns renderState
     */
    get renderState(): Nullable<IRenderState>;
    /**
     * Sets the render state and converts all date and time values to the right format
     * @param renderState
     */
    set renderState(renderState: Nullable<IRenderState>);
    /**
     * Gets the layout model state from the render state
     * @returns layout model state
     */
    get layoutModelState(): Nullable<ILayoutModelState>;
    /**
     * Gets the active culture id from the render state's layout model state
     * @returns active culture id
     */
    get activeCultureId(): string;
    /**
     * Gets the language name from the render state's layout model state
     * @returns language name
     */
    get languageName(): string;
    /**
     * Gets the language info from the render state's layout model state
     * @returns language info
     */
    get languageInfo(): Nullable<ILanguageInfo[]>;
    /**
     * Gets the current language from the render state's layout model state's language info array using the current language name
     * @returns language info
     */
    get currentLanguage(): Optional<ILanguageInfo>;
    /**
     * Gets the style name from the render state's layout model state
     * @returns style name
     */
    get styleName(): string;
    /**
     * Gets the resource set name from the render state's layout model state
     * @returns resource set name
     */
    get resourceSetName(): string;
    /**
     * Gets the resource language name from the render state's layout model state
     * @returns resource language name
     */
    get resourceLanguageName(): string;
    /**
     * Retrieves the parallel name from the render state's layout model state
     * @returns parallel name string
     */
    get parallelName(): string;
    /**
     * Retrieves the previous parallel name from the render state's layout model state
     * @returns previous parallel name string
     */
    get previousParallelName(): string;
    /**
     * Sets the previous parallel name on the render state's layout model state
     */
    set previousParallelName(value: string);
    /**
     * Flag indicating that the parallel name has changed
     * @returns {boolean} true if the parallel name does not match the previous parallel name
     */
    get parallelNameHasChanged(): boolean;
    /**
     * Retrieves the rule session id string from the render state's layout model state
     * @returns rule session id
     */
    get ruleSessionId(): string;
    /**
     * Gets the valid appointment flag value from the render state's layout model state
     * @returns active culture id
     */
    get hasValidAppointment(): boolean;
    /**
     * Gets the valid appointment flag value from the render state's layout model state
     * @returns active culture id
     */
    set hasValidAppointment(val: boolean);
    /**
     * Gets the active field name from the render state's layout model state
     * @returns if set, returns the active field name, otherwise returns an empty string
     */
    get activeFieldName(): string;
    /**
     * Gets the active field property name from the render state's layout model state
     * @returns if set, returns the active field property name, otherwise undefined
     */
    get activeFieldPropertyName(): Nullable<string>;
    /**
     * Sets a provided field name as the active field name on the render state's layout model state
     * @param fieldName new active field name
     * @param fieldPropertyName optional
     * @param eventSource (optional)
     * @param elementId (optional)
     * @param triggerFocus (optional)
     */
    setActiveFieldName(fieldName: string, fieldPropertyName?: string, eventSource?: string, elementId?: string, triggerFocus?: boolean): void;
    /**
     * Gets the actual layout set name from the render state's layout model state
     * @returns actual layout set name
     */
    get actualLayoutSetName(): string;
    /**
     * Gets the page index from the render state's layout model state
     * @returns page index
     */
    get pageIndex(): number;
    /**
     * Get the previous page index
     */
    get previousPageIndex(): number;
    /**
     * Set the previous page index
     */
    set previousPageIndex(value: number);
    /**
     * Get the boolean flag value if the page index has changed from its previous index
     * @returns boolean
     */
    get pageIndexHasChanged(): boolean;
    /**
     * Gets the highest page index from the render state's layout model state
     * @returns max page index
     */
    get maxPageIndex(): number;
    /**
     * Retrieves the custom page name from the render state's layout model state
     * @returns custom page name
     */
    get customPageName(): string;
    /**
     * Gets the data entry settings name from the render state's layout model state
     * @returns Data entry settings info
     */
    get dataEntrySettingsName(): string;
    /**
     * Gets the data entry settings info from the render state's layout model state
     * @returns Data entry settings info
     */
    get dataEntrySettingsInfo(): Nullable<IDataEntrySettingsInfo[]>;
    /**
     * Gets the current data entry settings from the render state's layout model state's data entry settings info array using the data entry settings name
     * @returns Current data entry settings info
     */
    get currentDataEntrySettings(): Optional<IDataEntrySettingsInfo>;
    /**
     * Retrieves the runtime settings from the render state's layout model state's current data entry settings
     * @returns {Nullable<IRuntimeSettings>} runtime settings
     */
    get runtimeSettings(): Nullable<IRuntimeSettings>;
    /**
     * Function that checks if the render state's current layout model state runtime settings' refresh mode is set to question.
     * @returns {boolean} true if the refresh mode is set to question, otherwise false
     */
    get isRefreshModeQuestion(): boolean;
    /**
     * Gets the optimize-no-style-sheets property value from the render state's current layout model state's runtime settings
     * @returns optimize-no-style-sheets
     */
    get optimizeNoStylesheets(): boolean;
    /**
     * Gets the use skip links property value from the render state's current layout model state's runtime settings
     * @returns use skip links
     */
    get useSkipLinks(): boolean;
    /**
     * Gets the disable-autofocus property value from the render state's current layout model state's runtime settings
     * @returns disable autofocus
     */
    get disableAutoFocus(): boolean;
    /**
     * Determine if the focus event should trigger
     * @returns should autofocus
     */
    get shouldAutoFocus(): boolean;
    /**
     * Gets the enable GPS property value from the render state's current layout model state's runtime settings
     * @returns enable GPS
     */
    get enableGPS(): boolean;
    /**
     * Gets the high accuracy GPS property value from the render state's current layout model state's runtime settings
     * @returns high gps accuracy flag
     */
    get highGPSAccuracy(): boolean;
    /**
     * Gets keyboard navigation from the render state's current layout model state's runtime settings
     * @returns keyboard navigation
     */
    get keyboardNavigation(): KeyboardNavigation;
    /**
     * Gets the SkipShowFieldsAtKeyboardNavigation property value from the render state's current layout model state's runtime settings
     * This flag indicates if show-fields should be skipped when navigating with a keyboard
     * @returns skip show fields at keyboard navigation flag
     */
    get skipShowFieldsAtKeyboardNavigation(): boolean;
    /**
     * Determines the navigation mode based on the keyboard navigation from the render state's current layout model state's runtime settings
     * @returns navigation mode
     */
    get navigationMode(): NavigationMode;
    /**
     * Gets the auto select input content property value from the render state's current layout model state's runtime settings
     * @returns auto select input content
     */
    get autoSelectInputContent(): boolean;
    /**
     * Returns the use CSS Grids property value from the render state's current layout model state's runtime settings
     * @returns use CSS Grids flag, defaults to true in 5.13
     */
    get useCssGrids(): boolean;
    /**
     * Gets the page object from the render state
     * @returns page
     */
    get page(): Nullable<IPage>;
    /**
     * Retrieves all fields from the render state's page object
     * @returns fields
     */
    get fields(): Nullable<IField[]>;
    /**
     * Retrieves and filters fields from the render state's page object
     * @param filter (optional) the filter to use. The default filter checks if the field's origin is "Route" and has at least 1 visible input control.
     * @returns a list containing fields that succeeded through the filter
     */
    getFilteredFields(filter?: (field: IField) => boolean): IField[];
    /**
     * Retrieves a field by name
     * @param fieldName the name of the field to retrieve
     * @returns The retrieved field or null
     */
    getFieldByName(fieldName: string): Optional<IField>;
    /**
     * Retrieves a field property by name
     * @param fieldName the name of the field for which to retrieve a field property
     * @param fieldPropertyName the name of the field property to retrieve
     * @returns The retrieved field property or null
     */
    getFieldPropertyByName(fieldName: string, fieldPropertyName: string): Optional<IFieldProperty>;
    /**
     * Retrieves all groups from the render state's page object
     * @returns groups
     */
    get groups(): Nullable<IGroup[]>;
    /**
     * Retrieves a group by its name
     * @param groupName the name of the group to retrieve
     * @returns The retrieved group or null
     */
    getGroupByName(groupName: string): Optional<IGroup>;
    /**
     * Retrieves a specific section by its name
     * @param sectionName the name of the section to retrieve
     * @returns The retrieved section or null
     */
    getSectionByName(sectionName: string): Optional<ISection>;
    /**
     * Sets the is visited flag of a specified field and its field properties to true
     * @param fieldName
     */
    flagFieldNameAsVisited(fieldName: string): void;
    /**
     * Sets the is visited flag of a specified field and its field properties to true
     * @param field
     */
    flagFieldAsVisited(field?: IField): void;
    /**
     * Sets the is visited property of all fields with at least 1 visible input control to true
     */
    flagPageAsVisited(): void;
    /**
     * Retrieves the name of the first field of a group or its subgroups (deep search)
     * @param groupName the name of the group containing the field
     * @returns The name of the first found field or null if no field was found
     */
    getFirstFieldNameFromGroup(groupName: string): Optional<string>;
    /**
     * Retrieves lookup information from a field by the field's name
     * @param fieldName the name of the field for which to retrieve lookup information
     * @returns The retrieved lookup information
     */
    getLookupInfoForField(fieldName: string): Optional<ILookupInformation>;
    /**
     * Retrieves the data source from a field by the field's name
     * @param fieldName the name of the field for which to retrieve the data source
     * @returns The retrieved data source
     */
    getDataSourceForField(fieldName: string): Optional<IDataSource>;
    /**
     * Check each answered field for errors. If any errors are found, they will be configured for the field and the field will be updated.
     */
    applyPageErrors(): void;
    /**
     * Determine if the current page has a range check error
     * @returns {boolean} true if the page contains at least one range check error, otherwise false
     */
    get pageHasRangeErrors(): boolean;
    /**
     * Function that retrieves involved fields from the first relevant error of a field.
     * @param fieldName the name of the field for which to retrieve involved fields
     * @param errorKindFilter
     * @returns an array of involved fields or null if none are found
     */
    getInvolvedFields(fieldName: string, errorKindFilter: number[]): Optional<IInvolvedField[]>;
    /**
     * Function that retrieves involved fields for a specified group
     * @param groupName the name of the group for which to retrieve involved fields
     * @param includeGroupErrors
     * @param errorKindFilter
     * @returns an array of involved fields or null if none are found
     */
    getGroupInvolvedFields(groupName: string, includeGroupErrors: boolean, errorKindFilter: number[]): Optional<IInvolvedField[]>;
    /**
     * Function that retrieves involved fields for the current page
     * @param includeGroupErrors
     * @param errorKindFilter
     * @returns an array of involved fields or null if none are found
     */
    getPageInvolvedFields(includeGroupErrors: boolean, errorKindFilter: number[]): Optional<IInvolvedField[]>;
    /**
     * Function that retrieves an error for a specified group
     * @param groupName the name of the group for which to retrieve an error
     * @param includeGroupErrors
     * @param errorKindFilter
     * @returns an error if one was found, otherwise null
     */
    getGroupError(groupName: string, includeGroupErrors: boolean, errorKindFilter: number[]): Optional<IError>;
    /**
     * Function that retrieves an error for the current page
     * @param includeGroupErrors
     * @param errorKindFilter
     * @returns an error if one was found, otherwise null
     */
    getPageError(includeGroupErrors: boolean, errorKindFilter: number[]): Optional<IError>;
    /**
     * Function that retrieves a route-item with an error for the current page
     * @param includeGroupErrors
     * @returns an route-item with an error if one was found, otherwise null
     */
    getPageErrorAsRouteItem(includeGroupErrors: boolean): Optional<IRouteItemReference>;
    /**
     * Gets the first relevant error from an array of errors
     * @param errors
     * @returns the first relevant error
     */
    getFirstRelevantError(errors: IError[]): Optional<IError>;
    /**
     * Gets the active field from the render state's page fields, using the active field name set in the render state's layout model state
     * @returns active field
     */
    get activeField(): Optional<IField>;
    /**
     * Gets the active field from the render state's page fields, using the active field name set in the render state's layout model state
     * @returns active field
     */
    get currentActiveField(): Optional<IFieldInfo>;
    /**
     * Property value that indicates if the current active field is critical.
     * @returns {boolean} true if the current active field is critical, otherwise false
     */
    get isCurrentActiveFieldCritical(): boolean;
    /**
     * Property value that indicates if the current active field is dirty.
     * @returns {boolean} true if the current active field is critical, otherwise false
     */
    get isCurrentActiveFieldDirty(): boolean;
    /**
     * Property value that indicates if the current custom page name has the receipt page name value.
     * @returns {boolean} true if the current custom page name is `ReceiptPage`, otherwise false
     */
    get isLastPage(): boolean;
    /**
     * Gets the record error collection from the render state's page object
     */
    get recordErrors(): Nullable<IError[]>;
    /**
     * Gets a field's index from a list of (filtered) fields, using a given field name or the currently active field name (default).
     * @param fields (optional) field list from which to retrieve an index, the getFilteredFields function result is used when the argument is undefined, null or an empty list.
     * @param fieldName (optional) field name for which to retrieve the index from the field list, the current active field name is used if no field name is provided.
     * @returns index of the field in the list or -1 if not found
     */
    getFieldIndexByName(fields?: IField[], fieldName?: string): number;
    /**
     * Gets the survey root from the render state
     * @returns survey root
     */
    get surveyRoot(): string;
    /**
     * Gets the instrument title set on the render state
     * @returns instrument title
     */
    get instrumentTitle(): string;
    /**
     * Gets the text provider object from the render state
     * @returns textProvider dictionary object
     */
    get textProvider(): any;
    /**
     * Retrieves a textbox property value from the text provider dictionary object by id
     * @param textboxId
     * @returns a text provider textbox
     */
    getTextBox(textboxId: string): ITextBox;
    /**
     * Sets the textbox property value on the text provider object
     * @param textboxId id of the textbox for which to set the text
     * @param text to set
     */
    setTextBox(textboxId: string, text: string): void;
    private updateRenderState;
    /**
     * Retrieves a group by it from the render state's page object
     * @param fieldName
     * @returns group
     */
    private getGroupByFieldName;
    /**
     * Retrieves all route items from the render state's page object
     * @returns route items
     */
    private get routeItems();
    /**
     * Retrieves all sections from the render state's page object
     * @returns sections
     */
    private get sections();
    /**
     * Retrieves a field property from a field by its field property name
     * @param field the field from which to retrieve a field property
     * @param fieldPropertyName the name of the field property to retrieve
     * @returns The retrieved field property or null
     */
    private getFieldPropertyFromField;
    /**
     * Gets the first relevant field error for a field specified by name
     * @param fieldName
     * @returns the first relevant field error
     */
    private getFirstRelevantFieldError;
    /**
     * Retrieves involved fields for a specific error, filtered by field name
     * @param error
     * @param fieldName
     * @returns Involved fields filtered by field name
     */
    private filteredInvolvedFields;
    /**
     * Gets the first relevant group error for a specified group
     * @param groupName Name of the group in which to search for the first relevant route item error
     * @param includeGroupErrors if true, also deep search for errors in group route items
     * @param returnRouteItemReference flag indicating if the return type should be Error or IRouteItemReference. The default (false) indicates error.
     * @returns the first relevant field error or field error reference for the given group depending on the return type
     */
    private getFirstRelevantGroupErrorOrReference;
    /**
     * Gets the first relevant route item error from an array of route item errors
     * @param routeItems The route item errors
     * @param includeGroupErrors if true, also deep search for errors in group route items
     * @param returnRouteItemReference (optional) flag indicating if the return type should be a route item or an error
     * @returns the first relevant field error or field error reference depending on the return type
     */
    private getFirstRelevantRouteItemErrorOrReference;
    /**
     * Event handler for changing the RouteState of the fields
     * when one or multiple controls visibility have changed
     * @param controls
     */
    private updateRouteStatus;
    /**
     * Recursive function for finding the first field within a control
     * @param control
     * @returns IField
     */
    private findFieldForInputControlRecursive;
    static ɵfac: i0.ɵɵFactoryDeclaration<RenderStateService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<RenderStateService>;
}
