import { HttpClient } from '@angular/common/http';
import { LoggerService } from './logger.service';
import { StorageService } from './storage.service';
import { SubscriptionService } from './subscription.service';
import { IRuntimeParameters } from '../../typedefinitions/models/IRuntimeParameters';
import * as i0 from "@angular/core";
/**
 * Runtime parameters service retrieves and manages runtime parameters
 */
export declare class RuntimeParametersService {
    private http;
    private storageService;
    private subscriptionService;
    private loggerService;
    /**
     * Important: needed to create assets in Webpack!
     */
    private readonly runtimeParametersJsonPath;
    /**
     * Gets the survey-defined runtime parameters
     * @returns runtime parameters
     */
    get runtimeParameters(): IRuntimeParameters;
    /**
     * Sets the survey-defined runtime parameters
     * @param runtimeParameters survey-defined runtime parameters
     */
    set runtimeParameters(runtimeParameters: IRuntimeParameters);
    /**
     * Runtime parameters service class constructor
     * @param http Provides methods to perform HTTP requests
     * @param storageService Provides access to the device's local and session storage
     * @param subscriptionService Provides a central hub for managing subscriptions
     * @param loggerService handles console interactions
     */
    constructor(http: HttpClient, storageService: StorageService, subscriptionService: SubscriptionService, loggerService: LoggerService);
    /**
     * Retrieves the runtime parameters either from storage (after login) or from the server json.
     * Sets the data service's runtime-parameters property.
     * Sets the api paths based on the runtime settings.
     * Attaches the measure time event
     * Extends the runtime parameters with post runtime parameters.
     * @returns  Returns a promise with the retrieved runtime parameters.
     */
    setRuntimeParameters: () => void;
    static ɵfac: i0.ɵɵFactoryDeclaration<RuntimeParametersService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<RuntimeParametersService>;
}
