import { Injector } from '@angular/core';
import { AuditTrailService } from './audit-trail/audit-trail.service';
import { ColorService } from './color.service';
import { ConverterFactoryService } from './converters/converter-factory.service';
import { CultureInfoService } from './culture-info.service';
import { CustomPropertyService } from './custom-property.service';
import { DataService } from './data.service';
import { DimensionGeneratorService } from './dimension-generator.service';
import { EventService } from './event.service';
import { FocusService } from './focus.service';
import { FontService } from './font.service';
import { HelperService } from './helper.service';
import { KeyCodesService } from './key-codes.service';
import { LookupService } from './lookup.service';
import { MediaService } from './media.service';
import { NavigationService } from './navigation/navigation.service';
import { PerformanceService } from './performance/performance.service';
import { RenderStateService } from './renderstate.service';
import { RichTextConverterService } from './rich-text-converter.service';
import { ShortcutService } from './shortcut.service';
import { SizeTreeService } from './sizetree/sizetree.service';
import { SkipLinkService } from './skiplink.service';
import { StylablePropertyService } from './stylable-property.service';
import { StyleGeneratorService } from './style-generator.service';
import { SubscriptionService } from './subscription.service';
import { TooltipService } from './tooltip.service';
import { UserAgentService } from './user-agent.service';
import * as i0 from "@angular/core";
/**
 * The service provider service is designed to provide easy access to several common services via one injectable service.
 */
export declare class ServiceProviderService {
    /**
     * auditTrailService The audit trail service provides functionality for tracking user behaviour.
     */
    auditTrailService: AuditTrailService;
    /**
     * colorService The color service provides functionality for converting a color object into a css style string.
     */
    colorService: ColorService;
    /**
     * converterFactoryService The converter factory service helps with selecting the correct converter service derivative for a specific data type.
     */
    converterFactoryService: ConverterFactoryService;
    /**
     * cultureInfoService The culture info service is used for storing and consulting culture settings.
     */
    cultureInfoService: CultureInfoService;
    /**
     * customPropertyService The custom property service is used to make working with custom properties easier.
     */
    customPropertyService: CustomPropertyService;
    /**
     * dataService a central hub for most server communications.
     */
    dataService: DataService;
    /**
     * dimensionGeneratorService Provides functionality for calculating component dimensions.
     */
    dimensionGeneratorService: DimensionGeneratorService;
    /**
     * eventService central hub in Blaise containing global application events to which other classes can subscribe.
     */
    eventService: EventService;
    /**
     * focusService handles the focussing, blurring and activation of fields.
     */
    focusService: FocusService;
    /**
     * fontService calculates font sizes for available fonts to determine text width and height.
     */
    fontService: FontService;
    /**
     * helperService provides general functions that are commonly used throughout the application.
     */
    helperService: HelperService;
    /**
     * keyCodesService used to evaluate what kind of key is pressed.
     */
    keyCodesService: KeyCodesService;
    /**
     * lookupService performs lookup requests for lookup controls.
     */
    lookupService: LookupService;
    /**
     * mediaService provides functionality for retrieving media urls and making them accessible.
     */
    mediaService: MediaService;
    /**
     * navigationService manages the application's navigation mode.
     */
    navigationService: NavigationService;
    /**
     * performanceService handles performance measuring.
     */
    performanceService: PerformanceService;
    /**
     * renderStateService provides functionality for managing the render state information as provided by the server.
     */
    renderStateService: RenderStateService;
    /**
     * richTextConverter converts a rich text object to rich and dynamic html string.
     */
    richTextConverter: RichTextConverterService;
    /**
     * shortcutService handles shortcut registrations and updates.
     */
    shortcutService: ShortcutService;
    /**
     * sizeTreeService calculates control sizes.
     */
    sizeTreeService: SizeTreeService;
    /**
     * skipLinkService manages skip links.
     */
    skipLinkService: SkipLinkService;
    /**
     * stylablePropertyService provides functionality for managing the stylable properties of controls.
     */
    stylablePropertyService: StylablePropertyService;
    /**
     * styleGeneratorService generates css style objects and strings for stylable properties and controls.
     */
    styleGeneratorService: StyleGeneratorService;
    /**
     * subscriptionService provides a central hub for managing subjects and subscriptions.
     */
    subscriptionService: SubscriptionService;
    /**
     * tooltipService provides functionality for showing, hiding and emitting a tooltip.
     */
    tooltipService: TooltipService;
    /**
     * userAgentService provides device/browser information.
     */
    userAgentService: UserAgentService;
    /**
     * injector Handles dependency injection.
     */
    injector: Injector;
    /**
     * Constructor implementing and exposing several common services.
     * @param auditTrailService The audit trail service provides functionality for tracking user behaviour.
     * @param colorService The color service provides functionality for converting a color object into a css style string.
     * @param converterFactoryService The converter factory service helps with selecting the correct converter service derivative for a specific data type.
     * @param cultureInfoService The culture info service is used for storing and consulting culture settings.
     * @param customPropertyService The custom property service is used to make working with custom properties easier.
     * @param dataService a central hub for most server communications.
     * @param dimensionGeneratorService Provides functionality for calculating component dimensions.
     * @param eventService central hub in Blaise containing global application events to which other classes can subscribe.
     * @param focusService handles the focussing, blurring and activation of fields.
     * @param fontService calculates font sizes for available fonts to determine text width and height.
     * @param helperService provides general functions that are commonly used throughout the application.
     * @param keyCodesService used to evaluate what kind of key is pressed.
     * @param lookupService performs lookup requests for lookup controls.
     * @param mediaService provides functionality for retrieving media urls and making them accessible.
     * @param navigationService manages the application's navigation mode.
     * @param performanceService handles performance measuring
     * @param renderStateService provides functionality for managing the render state information as provided by the server.
     * @param richTextConverter converts a rich text object to rich and dynamic html string.
     * @param shortcutService handles shortcut registrations and updates.
     * @param sizeTreeService calculates control sizes.
     * @param skipLinkService manages skip links.
     * @param stylablePropertyService provides functionality for managing the stylable properties of controls.
     * @param styleGeneratorService generates css style objects and strings for stylable properties and controls.
     * @param subscriptionService provides a central hub for managing subjects and subscriptions.
     * @param tooltipService provides functionality for showing, hiding and emitting a tooltip.
     * @param userAgentService provides device/browser information.
     * @param injector Handles dependency injection.
     */
    constructor(
    /**
     * auditTrailService The audit trail service provides functionality for tracking user behaviour.
     */
    auditTrailService: AuditTrailService, 
    /**
     * colorService The color service provides functionality for converting a color object into a css style string.
     */
    colorService: ColorService, 
    /**
     * converterFactoryService The converter factory service helps with selecting the correct converter service derivative for a specific data type.
     */
    converterFactoryService: ConverterFactoryService, 
    /**
     * cultureInfoService The culture info service is used for storing and consulting culture settings.
     */
    cultureInfoService: CultureInfoService, 
    /**
     * customPropertyService The custom property service is used to make working with custom properties easier.
     */
    customPropertyService: CustomPropertyService, 
    /**
     * dataService a central hub for most server communications.
     */
    dataService: DataService, 
    /**
     * dimensionGeneratorService Provides functionality for calculating component dimensions.
     */
    dimensionGeneratorService: DimensionGeneratorService, 
    /**
     * eventService central hub in Blaise containing global application events to which other classes can subscribe.
     */
    eventService: EventService, 
    /**
     * focusService handles the focussing, blurring and activation of fields.
     */
    focusService: FocusService, 
    /**
     * fontService calculates font sizes for available fonts to determine text width and height.
     */
    fontService: FontService, 
    /**
     * helperService provides general functions that are commonly used throughout the application.
     */
    helperService: HelperService, 
    /**
     * keyCodesService used to evaluate what kind of key is pressed.
     */
    keyCodesService: KeyCodesService, 
    /**
     * lookupService performs lookup requests for lookup controls.
     */
    lookupService: LookupService, 
    /**
     * mediaService provides functionality for retrieving media urls and making them accessible.
     */
    mediaService: MediaService, 
    /**
     * navigationService manages the application's navigation mode.
     */
    navigationService: NavigationService, 
    /**
     * performanceService handles performance measuring.
     */
    performanceService: PerformanceService, 
    /**
     * renderStateService provides functionality for managing the render state information as provided by the server.
     */
    renderStateService: RenderStateService, 
    /**
     * richTextConverter converts a rich text object to rich and dynamic html string.
     */
    richTextConverter: RichTextConverterService, 
    /**
     * shortcutService handles shortcut registrations and updates.
     */
    shortcutService: ShortcutService, 
    /**
     * sizeTreeService calculates control sizes.
     */
    sizeTreeService: SizeTreeService, 
    /**
     * skipLinkService manages skip links.
     */
    skipLinkService: SkipLinkService, 
    /**
     * stylablePropertyService provides functionality for managing the stylable properties of controls.
     */
    stylablePropertyService: StylablePropertyService, 
    /**
     * styleGeneratorService generates css style objects and strings for stylable properties and controls.
     */
    styleGeneratorService: StyleGeneratorService, 
    /**
     * subscriptionService provides a central hub for managing subjects and subscriptions.
     */
    subscriptionService: SubscriptionService, 
    /**
     * tooltipService provides functionality for showing, hiding and emitting a tooltip.
     */
    tooltipService: TooltipService, 
    /**
     * userAgentService provides device/browser information.
     */
    userAgentService: UserAgentService, 
    /**
     * injector Handles dependency injection.
     */
    injector: Injector);
    static ɵfac: i0.ɵɵFactoryDeclaration<ServiceProviderService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ServiceProviderService>;
}
