import { BaseControlSize } from './BaseControlSize';
import { CellControlSize } from './CellControlSize';
import { ICellContainer } from './ICellContainer';
import { IControlSize } from './IControlSize';
import { GridUnitType } from '../../../typedefinitions/enums/GridUnitType';
import { GridType } from '../../../typedefinitions/enums/GridType';
/**
 * Represents tabular control dimensions. This can be either the  GridComponent or TableComponent and their cells.
 */
export declare class GridControlSize extends BaseControlSize implements ICellContainer {
    private cells;
    gridLines: GridType;
    gridLineWidth: number;
    colWidths: number[];
    rowHeights: number[];
    /**
     * Grid control size class constructor
     * @param name
     */
    constructor(name: string);
    getChildren(): CellControlSize[];
    addChild(child: IControlSize): void;
    clearChildren(): void;
    /**
     * Calculate the grid size and propagate calculation to cells.
     * @param version
     */
    calculate(version: number): void;
    rowCount(): number;
    columnCount(): number;
    getColumnWidths(version: number): number[];
    getRowHeights(version: number): number[];
    /**
     * Get the amount of horizontal space that is taken by gridlines
     * @param version
     */ getGridLineWidth(version: number): number;
    /**
     * Get the amount of vertical space that is taken by gridlines
     * @param version
     */ getGridLineHeight(version: number): number;
    getColumnSiblings(rowIndex: number, excludeColumnIndex?: number): CellControlSize[];
    getRowSiblings(columnIndex: number, excludeRowIndex?: number): CellControlSize[];
    /**
     * * Calculates the total amount of stars or percentages in a column (determined by the rowUnitType)
     * @param rowIndex
     * @param columnUnitType
     */
    countColumnWidth(rowIndex: number, columnUnitType: GridUnitType): number;
    /**
     * Calculates the total amount of stars or percentages in a row (determined by the rowUnitType)
     * @param colIndex
     * @param rowUnitType
     */
    countRowHeight(colIndex: number, rowUnitType: GridUnitType): number;
    getCell(colIndex: number, rowIndex: number): Nullable<CellControlSize>;
    hasOverflow(): boolean;
    saveState(): void;
    /**
     * Determine if the dimensions have changed since the last tree calculation.
     */
    dimensionsChanged(): boolean;
    protected calculateStretchWidth(): number;
    protected calculateStretchHeight(): number;
    protected calculateAutoWidth(version: number): number;
    protected calculateAutoHeight(version: number): number;
    /**
     * Set the width version of a control recursively (parent to children)
     * @param cs
     * @param widthVersion
     */
    private setWidthVersionRecursive;
    /**
     * Set the height version of a control recursively (parent to children)
     * @param cs
     * @param heightVersion
     */
    private setHeightVersionRecursive;
    private calculateCellWidths;
    private calculateCellHeights;
}
