import { BaseControlSize } from './BaseControlSize';
import { IControlSize } from './IControlSize';
/**
 * Leaf control size calculation class is used for size calculations on always-childless, non-container controls.
 */
export declare class LeafControlSize extends BaseControlSize {
    /**
     * Nullable previous content width
     * @private
     */
    private prevContentWidth;
    /**
     * Nullable previous content height
     * @private
     */
    private prevContentHeight;
    /**
     * Nullable content pixel width
     */
    contentWidth: Nullable<number>;
    /**
     * Nullable content pixel height
     */
    contentHeight: Nullable<number>;
    /**
     * The leaf control size calculation class constructor.
     * @param {string} name Branch/Leaf name
     */
    constructor(name: string);
    /**
     * A leaf control size never has children to return, so this method always returns an empty [].
     */
    getChildren(): IControlSize[];
    addChild(): void;
    clearChildren(): void;
    widthReady(): boolean;
    heightReady(): boolean;
    /**
     * Save current width and height values for change detection purposes.
     */
    saveState(): void;
    /**
     * Determine if the dimensions have changed since the last tree calculation.
     */
    dimensionsChanged(): boolean;
    /**
     * Calculates the width when it is set to auto
     * @param version
     * @protected
     */ protected calculateAutoWidth(version: number): number;
    /**
     * Calculates the height when it is set to auto
     * @param version
     * @protected
     */ protected calculateAutoHeight(version: number): number;
}
