import { BaseControlSize } from './BaseControlSize';
import { IControlSize } from './IControlSize';
/**
 * The panel control size calculation class represents dimensions of a container control with zero or one child controls.
 */
export declare class PanelControlSize extends BaseControlSize {
    /**
     * Pixel width/height of the vertical/horizontal scrollbar
     */
    scrollbarSize: number;
    /**
     * The nullable child control size
     * @private
     */
    private child;
    /**
     * The pixel width value of the content or legend of the control
     */
    contentWidth: Nullable<number>;
    /**
     * The pixel width value of the content or legend of the control
     */
    contentHeight: Nullable<number>;
    /**
     * Flag indicating if the control has a legend text specified
     */ isGroupBox: boolean;
    /**
     * Flag indicating if the control's content's size is greater than the pixel size of the control itself.
     */
    get hasOverflowingChild(): boolean;
    /**
     * The panel control size calculation class constructor.
     * @param {string} name Branch/Leaf name
     * @param {number} scrollbarSize Pixel width/height of the vertical/horizontal scrollbar
     */
    constructor(name: string, 
    /**
     * Pixel width/height of the vertical/horizontal scrollbar
     */
    scrollbarSize: number);
    /**
     * Returns the child's control size in an array
     * @returns {Array<IControlSize>} a single child control size in an array or an empty array
     */
    getChildren(): IControlSize[];
    /**
     * Sets the child's control size
     * @param {IControlSize} childControl child control size
     */
    addChild(childControl: IControlSize): void;
    /**
     * Recursively clears the control sizes of the control's child and all its children
     */
    clearChildren(): void;
    /**
     * Calculates the pixel width and height of the control and its child tree
     * @param {number} version Control size calculation version number
     */
    calculate(version: number): void;
    /**
     * Verifies if the calculation of the control's width has finished.
     * @returns {boolean} true if ready
     */
    widthReady(): boolean;
    /**
     Verifies if the calculation of the control's height has finished.
     * @returns {boolean} true if ready
     */
    heightReady(): boolean;
    /**
     * Calculates the auto width in pixels for the control.
     * Auto width is dependent on the child width.
     * @param {number} version width calculation version number
     * @returns {number} calculated auto pixel width
     * @protected
     */
    protected calculateAutoWidth(version: number): number;
    /**
     * Calculates the auto height in pixels for the control.
     * Auto height is dependent on the child height.
     * @param {number} version height calculation version number
     * @returns {number} calculated auto pixel height
     * @protected
     */
    protected calculateAutoHeight(version: number): number;
}
