import { SubscriptionService } from './subscription.service';
import { IControlContainerControl } from '../../typedefinitions/models/controls/IControlContainerControl';
import { IDictionary } from '../../typedefinitions/models/IDictionary';
import { ISkipLink } from '../../typedefinitions/models/ISkipLink';
import * as i0 from "@angular/core";
/**
 * The skip link service manages skip links
 */
export declare class SkipLinkService {
    private subscriptionService;
    /**
     * Getter for the skip link dictionary
     */
    get skipLinks(): IDictionary<ISkipLink>;
    /**
     * Setter for the skip link dictionary
     */
    set skipLinks(skipLinks: IDictionary<ISkipLink>);
    /**
     * Skip link service class constructor
     * @param subscriptionService subscription service
     */
    constructor(subscriptionService: SubscriptionService);
    /**
     * Adds a new (unique) skip link to the skip link dictionary
     * @param skipLink
     */
    add(skipLink: ISkipLink): void;
    /**
     * Remove a specified skip link entry from the skip link dictionary
     * @param id skip link id
     */
    remove(id: string): void;
    /**
     * Clears the skip link dictionary
     */
    clear(): void;
    /**
     * Creates a skip link object
     * Creates a new skip link based on the information provided on the control and adds it to the list.
     * @param control control container control
     * @returns if a skip link was successfully created and added, otherwise false
     */
    create(control: IControlContainerControl): ISkipLink;
    /**
     * Checks if the control has te IsSkipLinkTarget property
     * @param control control container control
     * @param element html element
     * @returns if control has the IsSkipLinkTarget property
     */
    addAnchor(control: IControlContainerControl, element: HTMLElement): void;
    /**
     * Checks if provided skip link is an error
     * @param skipLink
     */
    isError(skipLink: ISkipLink): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<SkipLinkService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SkipLinkService>;
}
