import { IBaseControl } from '../../typedefinitions/models/controls/IBaseControl';
import * as i0 from "@angular/core";
/**
 * The stylable property service provides functionality for managing the stylable properties of controls.
 */
export declare class StylablePropertyService {
    /**
     * Indicates whether a given control contains a specified stylable property
     * @param {IBaseControl} control The control for which to check the stylable property
     * @param {string} property The name of the stylable property
     * @returns {boolean} true if the stylable property was found, otherwise false
     */
    hasStylableProperty(control: IBaseControl, property: string): boolean;
    /**
     * Returns the value for a specified stylable property from a given control
     * @param {IBaseControl} control The control from which to retrieve the stylable property value
     * @param {string} property The name of the stylable property for which to return a value
     * @returns {any} If found, the value for the provided stylable property, otherwise null
     */
    getValueForStylableProperty(control: IBaseControl, property: string): any;
    /**
     * Tries to return the value for a specified stylable property from a given control
     * @param {IBaseControl} control The control from which to try to retrieve the stylable property value
     * @param {string} property The name of the stylable property for which to try to return a value
     * @param {Function} out Callback function for transferring the result value
     * @returns {boolean} true, if the value was successfully retrieved, otherwise false
     */
    tryGetValueForStylableProperty(control: IBaseControl, property: string, out: (value: any) => void): boolean;
    /**
     * Sets the value for a specified stylable property on a given control
     * @param {IBaseControl} control The control on which to set the stylable property value
     * @param {string} property The name of the stylable property for which to set a value
     * @param {any} value The value to be set on the stylable property
     */
    setValueForStylableProperty(control: IBaseControl, property: string, value: any): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<StylablePropertyService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<StylablePropertyService>;
}
