import { EventService } from './event.service';
import { ITimerControl } from '../../typedefinitions/models/controls/ITimerControl';
import { ITimerElement } from '../../typedefinitions/models/richText/elements/ITimerElement';
import * as i0 from "@angular/core";
/**
 * A timer reference can be either a timer control or a rich text timer element
 */
type ITimerReference = ITimerControl | ITimerElement;
/**
 * The timer service allows for a set of actions to be periodically executed.
 */
export declare class TimerService {
    private eventService;
    /**
     * Object containing timer properties, the observable timer and its subscription
     */
    private timers;
    /**
     * Constructor. Subscribes to the render state subscriptions in order to destroy all timers on page changes.
     * @param eventService Allows subscribing to the new server payload event to detect page changes.
     */
    constructor(eventService: EventService);
    /**
     * Creates a new or replaces an existing timer. Immediately starts the timer if auto start is flagged on the timer control or rich text timer element.
     * @param {ITimerReference} reference the timer control or rich text timer element.
     * @returns {boolean} true if the timer was successfully created, otherwise false.
     */
    createTimer(reference: ITimerReference): boolean;
    /**
     * Stops and deletes all the timers.
     */
    destroyAllTimers(): void;
    /**
     * Delete a specified set of timers.
     * @param ids an array of identification keys for the targeted timers.
     */
    deleteTimers(ids: string[]): void;
    /**
     * Stops and removes a specified timer and its observables from the list.
     * @param id an identification key for the timer.
     */
    deleteTimer(id: string): void;
    /**
     * (Re)starts a specified timer by creating a new observable for it.
     * @param id an identification key for the timer.
     */
    startTimer(id: string): void;
    /**
     * Unsubscribes and removes the observable from the timer.
     * @param id an identification key for the timer.
     */
    stopTimer(id: string): void;
    /**
     * Gets a list of timer identification keys.
     * @returns Array<string> a list of identification keys for all timers.
     */
    private getTimerKeys;
    /**
     * Executes on tick actions.
     * @param id an identification key for the timer.
     * @param count callback count in order to block the initial callback.
     */
    private handleCallback;
    /**
     * Subscribe to the timer observable.
     * @param id an identification key for the timer.
     * @returns Optional<string> an identification key for the timer subscription.
     */
    private subscribeToTimer;
    static ɵfac: i0.ɵɵFactoryDeclaration<TimerService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<TimerService>;
}
export {};
