import { RenderStateService } from './renderstate.service';
import { IClient } from '../../typedefinitions/models/IClient';
import * as i0 from "@angular/core";
/**
 * The user agent service provides device/browser information
 */
export declare class UserAgentService {
    private document;
    private renderStateService;
    /**
     * Public read-only property containing client, browser and OS information
     */
    readonly client: IClient;
    /**
     * User agent service class constructor
     * @param document A reference class for the global document object
     * @param renderStateService The render state service provides functionality for managing the render state information.
     */
    constructor(document: Document, renderStateService: RenderStateService);
    /**
     * Client side settings to send along with the payload. This is required for audit trail processing. See bug MVC2_068.
     */
    getClient(): IClient;
    /**
     * Sets client size and pixel ratio information
     */
    updateClientSize(): void;
    /**
     * Check if the user agent indicates a mobile device
     * @returns {boolean} true if the user agent indicates that the device is a mobile, otherwise false
     */
    get isMobile(): boolean;
    /**
     * Check for an iOS device
     * @returns {boolean} true if the user agent indicates that the used device runs on iOS, otherwise false
     */
    get isIOS(): boolean;
    /**
     * Detect and return the browser class
     * @returns browser class name
     */
    getBrowserClass(): string;
    /**
     * Determines the user's gps location and sets it in the client information
     */
    setGeolocation(highGPSAccuracy: boolean): void;
    private handleLocation;
    private handleLocationError;
    /**
     * Retrieves the user agent string
     * @returns user agent string
     */
    private getUserAgent;
    private getOrientation;
    private getClientLanguage;
    private getReferrer;
    /**
     * Determines the browser type
     * @returns type of browser
     */
    private detectBrowser;
    /**
     * Detects if the device allows touch
     * @returns {boolean} true if the device is touch enabled, otherwise false
     */
    private detectTouchEnabled;
    /**
     * Determines and returns the browser's scrollbar size
     * @returns scroll bar size
     */
    private getScrollbarSize;
    static ɵfac: i0.ɵɵFactoryDeclaration<UserAgentService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<UserAgentService>;
}
