/**
 * Function kind string enum containing possible client-side functions
 */
export declare enum FunctionName {
    /**
     * Returns the absolute value of the argument.
     */
    Abs = "ABS",
    /**
     * Performs an addition to a value in a numerical expression.
     * Performs a concatenation between two string.
     */
    Addition = "+",
    /**
     * Combines the results of two Boolean expressions.
     */
    And = "AND",
    /**
     * Arranges a set.
     */
    Arrangement = "ARRANGEMENT",
    /**
     * Returns a CornerRadius value of a valid expression. A CornerRadius defines the rounding of borderlines.
     */
    CornerRadius = "CORNERRADIUS",
    /**
     * Converts numerical values to a date representation.
     */
    Date = "DATE",
    /**
     * Performs a division on a numerator by a denominator in a numerical expression.
     */
    Division = "/",
    /**
     * Performs a division to an integer value in numerical expressions.
     */
    IntegerDivision = "DIV",
    /**
     * Checks whether a string ends with a certain substring.
     */
    EndsWith = "ENDSWITH",
    /**
     * Compares two values and evaluates their equality.
     */
    Equality = "=",
    /**
     * Returns the fractional part of the argument.
     */
    Frac = "FRAC",
    /**
     * Compares two values and evaluates if the first is greater than the second.
     */
    GreaterThan = ">",
    /**
     * Compares two values and evaluates if the first is greater than or equal to the second.
     */
    GreaterThanOrEqual = ">=",
    /**
     * Returns a GridUnit value of a valid expression. A GridUnit holds a value that is interpreted to determine the width and height of columns and rows in a grid or table control.
     */
    GridUnit = "GRIDUNIT",
    /**
     * Checks whether a numerical or enumerated value is present in a set.
     */
    In = "IN",
    /**
     * Evaluate if a value is in range of a set of field ranges.
     * Used for expressions with the function name IN where the expression kind of the second argument is a `RangeCollection`
     */
    InRange = "INRANGE",
    /**
     * Compares two values and evaluates their inequality.
     */
    Inequality = "<>",
    /**
     * Returns the length of the string argument.
     */
    Length = "LEN",
    /**
     * Compares two values and evaluates if the first is greater than the second.
     */
    LessThan = "<",
    /**
     * Compares two values and evaluates if the first is less than or equal to the second.
     */
    LessThanOrEqual = "<=",
    /**
     * Converts all uppercase characters in a string to the corresponding lower-case characters.
     */
    Lowercase = "LOWERCASE",
    /**
     * Returns the greater of two values.
     */
    Max = "MAX",
    /**
     * Returns the smallest of two numerical values.
     */
    Min = "MIN",
    /**
     * Computes the remainder of an integer division.
     */
    Modulo = "MOD",
    /**
     * Performs a multiplication in a numerical expression.
     */
    Multiplication = "*",
    /**
     * Reverses the outcome of a Boolean expression.
     */
    Not = "NOT",
    /**
     * Compares the result of two logical expressions.
     */
    Or = "OR",
    /**
     * Returns the position of the first character of a substring in a string.
     */
    Position = "POSITION",
    /**
     * Rounds a real expression to the nearest integer value.
     */
    Round = "ROUND",
    /**
     * Checks whether a string starts with a certain substring.
     */
    StartsWith = "STARTSWITH",
    /**
     * Returns a substring from a string expression.
     */
    SubString = "SUBSTRING",
    /**
     * Performs a subtraction in a numerical expression.
     */
    Subtraction = "-",
    /**
     * Converts numerical values to a thickness representation.
     */
    Thickness = "THICKNESS",
    /**
     * Converts numerical values to a time representation.
     */
    Time = "TIME",
    /**
     * Returns an integer value of a valid expression.
     */
    ToInteger = "TOINTEGER",
    /**
     * Returns a string representation of a valid expression.
     */
    ToString = "TOSTRING",
    /**
     * Returns a real value of a valid expression.
     */
    ToReal = "TOREAL",
    /**
     * Converts a string to a rich text object in order to return it as an expression result.
     */
    ToRichText = "TORICHTEXT",
    /**
     * Truncates a real value to an integer value.
     */
    Trunc = "TRUNC",
    /**
     * Converts lower-case characters of a string to the corresponding uppercase characters.
     */
    Uppercase = "UPPERCASE"
}
