import { BehaviorSubject } from 'rxjs';
import { IFieldReference } from './controls/references/IFieldReference';
import { IFieldPropertyReference } from './controls/references/IFieldPropertyReference';
import { IFieldInfo } from './observables/IFieldInfo';
/**
 * The get field subscription function interface defines the get field subscription function overload options
 */
export interface IGetFieldInfoSubjectFunc {
    /**
     * Retrieves a field subscription or a field property subscription by reference
     * @param reference reference to a field or a field property subscription containing a field name property and optionally a field property name
     *  field subscription
     */
    (reference: IFieldReference | IFieldPropertyReference): BehaviorSubject<IFieldInfo>;
    /**
     * Retrieves only a field property subscription by a field name and a field property name
     * @param fieldName
     * @param fieldPropertyName
     */
    (fieldName: string, fieldPropertyName: string): BehaviorSubject<IFieldInfo>;
    /**
     * Retrieves a field subscription or a field property subscription by field name
     * @param fieldName
     */
    (fieldName: string): BehaviorSubject<IFieldInfo>;
    /**
     * Retrieves a field or field property subscription either by field reference or by field name and (optionally) field property name
     * @param fieldNameOrReference
     * @param fieldPropertyName (optional)
     */
    (fieldNameOrReference: string | IFieldReference | IFieldPropertyReference, fieldPropertyName?: string): BehaviorSubject<IFieldInfo>;
}
