import { IActionsEventHandler } from './IActionsEventHandler';
import { IColor } from './IColor';
import { Visibility } from '../enums/Visibility';
/**
 * The menu item interface defines an object for the menu item component.
 */ export interface IMenuItem {
    /**
     * Menu item id
     */
    ID: string;
    /**
     * Displayed menu item text
     */
    Text: string;
    /**
     * Keyboard shortcut
     */
    Shortcut: string;
    /**
     * Flag that when true indicates that the menu item is enabled
     */
    Enabled: boolean;
    /**
     * Visibility state of the menu item
     */
    Visibility: Visibility;
    /**
     * Menu item background color
     */
    BackgroundColor: IColor;
    /**
     * Sub-menu items
     */
    MenuItems: IMenuItem[];
    /**
     * Flag indicating whether the menu item serves as a separator item
     */
    Separator: boolean;
    /**
     * Menu item click event handler containing the actions to execute
     */
    OnClick: IActionsEventHandler;
}
