import { IGridUnit } from './IGridUnit';
import { CSSStyleObject } from './style/CSSStyleObject';
import { IBaseComponentViewModel } from './view/IBaseViewModel';
import { Visibility } from '../enums/Visibility';
/**
 * Contains the prepared tablelayout for rendering both the GridControl and the TableControl
 */
export interface ITableLayout {
    /**
     * Used for creating the table head, so only column definition is needed
     */
    Columns: IGridUnit[];
    /**
     * Contains the prepared rows for rendering
     */
    Rows: IRowViewModel[];
    TotalStarColumns: number;
    TotalStarRows: number;
    RowSizes: number[];
    ColSizes: number[];
}
/**
 * Contains the prepared row layout for rendering
 */
export interface IRowViewModel {
    /**
     * This property contains the columns for rendering
     */
    Columns: IColumnViewModel[];
    /**
     * the row height definition
     */
    RowDefinition: IGridUnit;
    /**
     * when a table height is set to stretch but doesn't contain a star row, fill the gap with a spacer
     */
    Spacer: boolean;
    /**
     * inline styling
     */
    Style?: any;
    /**
     * css classes
     */
    CssClasses?: string;
    /**
     * a table row control contains an id, so this is only used by the TableControl
     */
    ID?: string;
    /**
     * a table row control contains a visibility, so this is only used by the TableControl
     */
    Visibility?: Visibility;
}
/**
 * Contains the prepared column view for rendering
 */
export interface IColumnViewModel {
    /**
     * set to false when this column doesn't need to be drawn, e.g. col/rowspan
     */
    Draw: boolean;
    /**
     * inline styling
     */
    Style?: CSSStyleObject;
    /**
     * optional style to apply to container div in case the child inside the cell is larger than the cell.
     */
    CellStyle?: any;
    /**
     * css classes
     */
    CssClasses?: string;
    /**
     * the column height definition
     */
    ColDefinition: IGridUnit;
    /**
     * The rowspan
     */
    RowSpan?: number;
    /**
     * The column span
     */
    ColSpan?: number;
    /**
     * The child component
     */
    Child: Nullable<IBaseComponentViewModel>;
    /**
     * when a table width is set to stretch but doesn't contain a star column, fill the gap with a spacer
     */
    Spacer: boolean;
    /**
     * The horizontal alignment of the child component
     */
    HorizontalAlignment?: string;
    /**
     * The vertical alignment of the child component
     */
    VerticalAlignment?: string;
}
