import { IBaseComponentViewModel } from './view/IBaseViewModel';
import { IBackgroundStyle } from './style/IBackgroundStyle';
/**
 * Contains the prepared tablelayout for rendering both the GridControl and the TableControl
 */
export interface ITableLayoutCss {
    /**
     * Contains the prepared css grid row definitions
     */
    Columns: string[];
    /**
     * Contains the prepared css grid row definitions
     */
    Rows: string[];
    /**
     * Table cell view-model definition array
     */
    Cells: ITableCellViewModel[];
}
/**
 * Contains the prepared column view for rendering
 */
export interface ITableCellViewModel {
    /**
     * set to false when this column doesn't need to be drawn, e.g. col/rowspan
     */
    Draw: () => boolean;
    /**
     * Background definition
     */
    Background?: IBackgroundStyle;
    /**
     * The rowspan
     */
    RowIndex: number;
    /**
     * The colwspan
     */
    ColIndex: number;
    /**
     * The rowspan
     */
    RowSpan: number;
    /**
     * The colwspan
     */
    ColSpan: number;
    /**
     * The child component
     */
    Child?: IBaseComponentViewModel;
    /**
     * The horizontal alignment of the child component
     */
    HorizontalAlignment?: string;
    /**
     * The vertical alignment of the child component
     */
    VerticalAlignment?: string;
    /**
     * Border width property used for horizontal gridlines
     */
    BorderWidthTop?: string;
    /**
     * Border width property used for vertical gridlines
     */
    BorderWidthRight?: string;
    /**
     * Border color property used for gridlines
     */
    BorderColor?: string;
}
