import { IAction } from './IAction';
import { IExpression } from '../expressions/IExpression';
import { EventSource } from '../../enums/EventSource';
/**
 * The condition-field action interface serves as the base interface several field actions.
 */ export interface IConditionFieldAction extends IAction {
    /**
     * Nullable expression of which, if set, the result determines if the field action should be executed.
     * When the condition is not set, the field action should always be executed.
     */
    Condition?: IExpression;
}
/**
 * The next-field action interface defines the properties required to perform the next-field action.
 */ export interface INextFieldAction extends IConditionFieldAction {
    /**
     * Optional client-side property to indicate the source (`Keyboard` or `Mouse`) of the event that triggered the next field action.
     */
    eventSource?: EventSource;
}
/**
 * The first-field action interface defines the properties required to perform the first-field action.
 */ export interface IFirstFieldAction extends IConditionFieldAction {
}
/**
 * The last-field action interface defines the properties required to perform the last-field action.
 */ export interface ILastFieldAction extends IConditionFieldAction {
}
/**
 * The previous-field action interface defines the properties required to perform the previous-field action.
 */ export interface IPreviousFieldAction extends IConditionFieldAction {
}
