import { IAction } from './IAction';
import { IExpression } from '../expressions/IExpression';
/**
 * The conditional action interface defines the properties required to perform one of two sets of actions based on either a flag value or an expression result.
 */ export interface IConditionalAction extends IAction {
    /**
     * Flag indicating whether the actions from the then-branch property (when true) or the else-branch property (when false) should be executed.
     */
    Condition: boolean;
    /**
     * Expression of which the result determines if the actions from the then-branch property (when true) or the else-branch property (when false) should be executed.
     */
    ConditionAsExpression: IExpression;
    /**
     * Actions to execute on a truthy condition result
     */
    ThenBranch: IAction[];
    /**
     * Actions to execute on a falsy condition result
     */
    ElseBranch: IAction[];
}
