import { IAction } from './IAction';
/**
 * The control action interface defines the properties required to reference a control during an action.
 */ export interface IControlAction extends IAction {
    /**
     * Control root ID
     */
    RootID: string;
    /**
     * Control ID
     */
    ControlID: string;
}
/**
 * The start-timer control action interface defines the properties required to perform the start-timer action.
 */ export interface IStartTimerAction extends IControlAction {
}
/**
 * The stop-timer control action interface defines the properties required to perform the stop-timer action.
 */ export interface IStopTimerAction extends IControlAction {
}
/**
 * The set-focus control action interface defines the properties required to perform the set-focus action.
 */ export interface ISetFocusAction extends IControlAction {
}
/**
 * The play-audio control action interface defines the properties required to perform the play-audio action.
 */ export interface IPlayAudioAction extends IControlAction {
}
/**
 * The pause-audio control action interface defines the properties required to perform the pause-audio action.
 */ export interface IPauseAudioAction extends IControlAction {
}
/**
 * The play-/pause-audio control action interface defines the properties required to perform the toggle play-/pause-audio action.
 */ export interface IPlayPauseAudioAction extends IControlAction {
}
/**
 * The play-/stop-audio control action interface defines the properties required to perform the toggle play-/stop-audio action.
 */ export interface IPlayStopAudioAction extends IControlAction {
}
/**
 * The stop-audio control action interface defines the properties required to perform the stop-audio action.
 */ export interface IStopAudioAction extends IControlAction {
}
/**
 * The play-video control action interface defines the properties required to perform the play-video action.
 */ export interface IPlayVideoAction extends IControlAction {
}
/**
 * The pause-video control action interface defines the properties required to perform the pause-video action.
 */ export interface IPauseVideoAction extends IControlAction {
}
/**
 * The play-/pause-video control action interface defines the properties required to perform the toggle play-/pause-video action.
 */ export interface IPlayPauseVideoAction extends IControlAction {
}
/**
 * The play-/stop-video control action interface defines the properties required to perform the toggle play-/stop-video action.
 */ export interface IPlayStopVideoAction extends IControlAction {
}
/**
 * The stop-video control action interface defines the properties required to perform the stop-video action.
 */ export interface IStopVideoAction extends IControlAction {
}
/**
 * The clipboard control action interface serves as the base interface for all clipboard actions.
 */ export interface IClipboardAction extends IControlAction {
}
/**
 * The cut-to-clipboard control action interface defines the properties required to perform the cut-to-clipboard action.
 */ export interface ICutToClipboardAction extends IClipboardAction {
}
/**
 * The copy-to-clipboard control action interface defines the properties required to perform the copy-to-clipboard action.
 */ export interface ICopyToClipboardAction extends IClipboardAction {
}
/**
 * The paste-from-clipboard control action interface defines the properties required to perform the paste-from-clipboard action.
 */ export interface IPasteFromClipboardAction extends IClipboardAction {
}
