import { IActionsEventHandler } from '../IActionsEventHandler';
import { ICustomProperty } from '../ICustomProperty';
import { IPropertyStyle } from '../IPropertyStyle';
import { ITooltip } from './properties/tooltip/ITooltip';
import { ControlKind } from '../../enums/ControlKind';
import { Visibility } from '../../enums/Visibility';
/**
 * The base control interface defines the base data object for all components.
 */ export interface IBaseControl {
    /**
     * Control kind
     */
    Kind: ControlKind;
    /**
     * Parent table's row index
     */
    RowIndex: number;
    /**
     * Parent table row's column/cell index
     */
    ColumnIndex: number;
    /**
     * Parent table row span
     */
    RowSpan: number;
    /**
     * Parent table column span
     */
    ColSpan: number;
    /**
     * Control id
     */
    ID: string;
    /**
     * Visibility setting of the control (Visible, Hidden or Collapsed)
     */
    Visibility: Visibility;
    /**
     * Initial visibility setting of the control (Visible, Hidden or Collapsed), set by the application, never from the server
     */
    InitialVisibility?: Visibility;
    /**
     * Flag indicating whether the control is enabled and if the user is able to interact with it
     */
    Enabled: boolean;
    /**
     * Text for a screen reader to read to a user using accessibility tools
     */
    ScreenReaderText: string;
    /**
     * Reference to the control's label component
     */
    LabelledBy: string;
    /**
     * Accessibility role
     */
    AccessibilityRole: string;
    /**
     * Tooltip object (optional)
     */
    Tooltip?: ITooltip;
    /**
     * List of custom defined properties
     */
    CustomProperties: Nullable<ICustomProperty[]>;
    /**
     * Template target name
     */
    TemplateTargetName: string;
    /**
     * Indicates if the control is part of the part of the content area
     */
    PlaceholderKindName: string;
    /**
     * Control style name
     */
    ControlStyleName: string;
    /**
     * List of stylable property info objects
     */
    StylableProperties: IPropertyStyle[];
    /**
     * Flag indicating if the control's visibility value changes client-side
     */
    CanVisibilityChange: boolean;
    /**
     * Actions to execute on an element focus event
     */
    OnGotFocus?: IActionsEventHandler;
    /**
     * Actions to execute on an element blur event
     */
    OnLostFocus?: IActionsEventHandler;
    /**
     * On mouse enter actions event handler
     */
    OnMouseEnter?: IActionsEventHandler;
    /**
     * On mouse leave actions event handler
     */
    OnMouseLeave?: IActionsEventHandler;
    /**
     * On mouse down actions event handler
     */
    OnMouseDown?: IActionsEventHandler;
    /**
     * On mouse up actions event handler
     */
    OnMouseUp?: IActionsEventHandler;
}
