import { IActionsEventHandler } from '../IActionsEventHandler';
import { IColor } from '../IColor';
import { IHasFont } from './properties/IHasFont';
import { IHeadersSettings } from './properties/headers-settings/IHeaderSettings';
import { IInputControl } from './IInputControl';
import { IThickness } from '../IThickness';
import { GridType } from '../../enums/GridType';
/**
 * The data grid control interface defines the data object for the data grid input component.
 */ export interface IDataGridControl extends IInputControl {
    /**
     * Flag indicating if the first row of a result set should be automatically selected after (result-) page update
     */
    AutoSelect: boolean;
    /**
     * On record selected actions event handler
     */
    OnRecordSelected: IActionsEventHandler;
    /**
     * On selection confirmed actions event handler
     */
    OnConfirmSelection: IActionsEventHandler;
    /**
     * Flag indicating whether an initial search should be executed on component creation
     */
    SearchOnCreate: boolean;
    /**
     * Data source id
     */
    DataSourceID: string;
    /**
     * Maximum amount of results retrieved by the server on search
     */
    MaximumResultCount: number;
    /**
     * Determines the layout of the header of the data grid input component.
     */
    Headers: IGridHeaderSettings;
    /**
     * Row color settings (even, odd, selected and hover colors)
     */
    RowColors: IRowOptions;
    /**
     * Grid lines settings for type (None, Horizontal, Vertical or Both), width and color
     */
    GridLines: IGridLineOptions;
    /**
     * Comma-separated list that forms a subset of field names of a DataSource
     */
    FieldFilter: Unknown<string>;
    /**
     * A comma-seperated list of column sizes (amount of characters), similar to the html input's size attribute
     */
    ColumnWidths: Unknown<string>;
    /**
     * A comma-separated list of custom column names
     */
    ColumnNames: Unknown<string>;
}
/**
 * The header options interface determines the layout of the header of the data grid input component.
 */
export interface IGridHeaderSettings extends IHasFont, IHeadersSettings {
    /**
     * Header background style property
     */
    BackgroundColor: IColor;
    /**
     * Header grid lines settings for type (None, Horizontal, Vertical or Both), width and color
     */
    GridLines: IGridLineOptions;
    /**
     * Header padding pixel value
     */
    TextMargin: IThickness;
}
/**
 * The row options interface defines row color options for the data row of the data grid input component.
 */
export interface IRowOptions {
    /**
     * Grid's even row's background color value
     */
    EvenColor: IColor;
    /**
     * Grid's odd row's background color value
     */
    OddColor: IColor;
    /**
     * Grid's selected row's background color value
     */
    SelectedColor: IColor;
    /**
     * Grid's hovered row's background color value
     */
    HoverColor: IColor;
}
/**
 * The grid line options interface describes the layout of the grid lines of the data grid input component and component header.
 */
export interface IGridLineOptions {
    /**
     * Grid lines setting (None, Horizontal, Vertical or Both)
     */
    Kind: GridType;
    /**
     * Pixel width value of the grid lines
     */
    Width: number;
    /**
     * Grid line color value
     */
    Color: IColor;
}
