import { IInputControl } from './IInputControl';
import { IHasOptionSettings } from './properties/IHasOptionSettings';
import { IHasWatermark } from './properties/IHasWatermark';
import { IRichTextItem } from '../richText/IRichTextItem';
import { SelectionSource } from '../../enums/SelectionSource';
import { EmptyItemVisibility } from '../../enums/EmptyItemVisibility';
/**
 * The dropdown list control interface defines the data object for the dropdown list component.
 */ export interface IDropdownListControl extends IInputControl, IHasOptionSettings, IHasWatermark {
    /**
     * Dropdown list control's select element's rich text option items
     */
    RichTextItems: IRichTextItem[];
    /**
     * Flag indicating whether special answers (defined on the data-type) should be included in the option list
     */
    ExcludeSpecialAnswers: boolean;
    /**
     * Flag indicating whether an empty option should be included in the option list
     */
    IncludeEmptyItem: EmptyItemVisibility;
    /**
     * Determines the text that is shown for selected options. Either `Code`, `Name` or `Text`
     */
    SelectionSource: SelectionSource;
}
