import { IInputControl } from './IInputControl';
import { IActionsEventHandler } from '../IActionsEventHandler';
import { IMarker } from '../IMarker';
import { IShapeFile } from '../IShapeFile';
import { MapProvider } from '../../enums/MapProvider';
import { MapSelectionMode } from '../../enums/MapSelectionMode';
import { MapStyle } from '../../enums/MapStyle';
/**
 * The maps control interface defines the data object for the maps component.
 */ export interface IMapsControl extends IInputControl {
    /**
     * Specifies a maps' provider. A different map library is used for each particular provider.
     */
    Provider: MapProvider;
    /**
     * Specifies the selection mode. Default: None.
     */
    SelectionMode: MapSelectionMode;
    /**
     * Style of the map being rendered.
     */
    Style: MapStyle;
    /**
     * CONTESTED
     * The maximum number of locations that can be selected/created on the map. Applies only for SelectionMode = Multiple. Default: 1.
     * Similar to the Cardinality of the set control, this value should be placed on the ValueType.
     */
    MaxLocations: number;
    /**
     * The Geolocation that receives center/focus when the maps control is loaded on an empty field. This position will not be marked on the map. Default: 0,0 (somewhere in the Atlantic).
     */
    InitialLocation: string;
    /**
     * Determines whether locations can be added to the map by a user. Default: false
     */
    AllowAddLocations: boolean;
    /**
     * Markers that should be shown on the map.
     * Markers that are defined here can be either selected or unselected, but can never be removed from the map.
     */
    Markers: IMarker[];
    /**
     * Shape files serve as an additional maps layer. Shapefiles are only supported when using Bing or ArcGIS as maps provider.
     */
    ShapeFiles: IShapeFile[];
    /**
     * This property is not supported in browsers.
     */
    MapsPath: string;
    /**
     * This property is not supported in browsers.
     */
    MobilePackage: string;
    /**
     * The API key is a unique identifier used for authenticating of maps API requests at the selected Provider.
     */
    ApiKey: string;
    /**
     * Image that should be used if a geolocation is selected. The image should exist in the resource database. If the property is not set, the default selected marker of the provider is shown.
     */
    SelectedImage: string;
    /**
     * Image that should be used if a geolocation is not selected. The image should exist in the resource database. If the property is not set, the default unselected marker of the provider is shown.
     */
    UnselectedImage: string;
    /**
     * The initial zoom level of the maps view (1- 20). Default: 10
     */
    ZoomLevel: number;
    /**
     * The minimum zoom level of the maps view.
     */
    MinZoomLevel: number;
    /**
     * The maximum zoom level of the maps view.
     */
    MaxZoomLevel: number;
    /**
     * Fires when the zoom level of the map changes.
     */
    OnZoomLevelChanged: IActionsEventHandler;
}
