import { IInputControl } from './IInputControl';
import { IHasWatermark } from './properties/IHasWatermark';
import { Orientation } from '../../enums/Orientation';
import { TickPlacement } from '../../enums/TickPlacement';
import { IColor } from '../IColor';
/**
 * The number slider control interface defines the data object for the number slider component.
 */ export interface INumberSliderControl extends IInputControl, IHasWatermark {
    /**
     * Determines which and where number labels are drawn
     */
    LabelInterval: number;
    /**
     * Determines which and where tick markers are drawn
     */
    TicksPerInterval: number;
    /**
     * Indicates if the number slider is drawn in a horizontal or vertical direction
     */
    Orientation: Orientation;
    /**
     * Determines the position of tick marks with respect to the track of the slider: None, TopLeft, BottomRight or Both
     */
    TickPlacement: TickPlacement;
    /**
     * Depending on the orientation, this property determines the height or width of the slider handle (for a respectively horizontal and vertical oriented slider)
     */
    ThumbSize: number;
    /**
     * Color of the slider thumb element
     */
    ThumbColor: IColor;
    /**
     * Depending on the orientation, determines the height or width of the slider bar (for a respectively horizontal and vertical oriented slider)
     */
    TrackSize: number;
    /**
     * Color of the slider track
     */
    TrackColor: IColor;
    /**
     * Flag indicating if the number slider should display options in an ascending (false) or descending (true) order
     */
    ReverseOrder: boolean;
}
