import { IControlInfo } from '../IControlInfo';
import { IDataValue } from '../IDataValue';
import { IError } from '../IError';
import { IValueType } from '../value-types/IValueType';
import { IDictionary } from '../IDictionary';
import { IDataSource } from '../server/data-source/IDataSource';
import { ILookupInformation } from '../server/ILookupInformation';
import { RouteStatus } from '../../enums/RouteStatus';
export interface IFieldInfo {
    FieldName: string;
    FieldPropertyName?: string;
    ValueType: IValueType;
    DataValue: IDataValue;
    IsRequired: boolean;
    IsCritical: boolean;
    IsVisited: boolean;
    RouteStatus: RouteStatus;
    InputControls: IControlInfo[];
    /**
     * Contains error information for a field or field property.
     * BL513-412 FieldInfo is used for both fields and field properties.
     * The errors property should never be null or undefined for fields, but is always undefined for field properties.
     * There are however no code occurrences for the latter and
     * the property should never be reinitialised on fields as it is used by reference,
     * so we remove the optionality from this property.
     */
    Errors: IError[];
    SpecialAnswers?: string[];
    DataSource?: IDataSource;
    LookupInformation?: ILookupInformation;
    RoleTexts: IDictionary<string>;
    /**
     * The id of control that caused the new DataValueSubscription
     */
    EventSourceId: string;
    /**
     * Flag to determine if the ui should update
     * Added for: BL59-1106, BL510-727, BL511-70
     */
    UpdateUI?: boolean;
}
