import { IActionsEventHandler } from '../../IActionsEventHandler';
import { IBrush } from '../../IBrush';
import { IHasOutline } from '../../controls/properties/IHasOutline';
import { ElementKind } from '../../../enums/ElementKind';
import { Visibility } from '../../../enums/Visibility';
/**
 * Run element definition combines the TextMarkup's ActionsElement and RunElement into a single run element definition with outline properties
 */ export interface IRunElement extends IHasOutline {
    /**
     * Run element's element kind
     */
    Kind: ElementKind;
    /**
     * Run element's name
     */
    Name: string;
    /**
     * Reference to the run element's label component
     */
    LabelledBy: string;
    /**
     * Run element's Accessibility role
     */
    AccessibilityRole: string;
    /**
     * Actions element's identifier
     */
    ID: string;
    /**
     * Optional background brush style property
     */
    Background?: IBrush;
    /**
     * Flag indicating whether the run element is enabled and if the user is able to interact with it
     */
    Enabled: boolean;
    /**
     * Optional text for a screen reader to read to a user using accessibility tools
     */
    ScreenReaderText?: string;
    /**
     * Flag indicating if the focus should be marked on the run element
     */
    ShowKeyboardFocus: boolean;
    /**
     * The actions element's position in the page's tab order
     */
    TabIndex: number;
    /**
     * Optional tooltip text
     */
    TooltipText?: string;
    /**
     * Visibility setting of the run element (Visible, Hidden or Collapsed)
     */
    Visibility: Visibility;
    /**
     * Actions to execute on an element focus event
     */
    OnGotFocus?: IActionsEventHandler;
    /**
     * Actions to execute on an element blur event
     */
    OnLostFocus?: IActionsEventHandler;
    /**
     * On mouse enter actions event handler
     */
    OnMouseEnter?: IActionsEventHandler;
    /**
     * On mouse leave actions event handler
     */
    OnMouseLeave?: IActionsEventHandler;
    /**
     * On mouse down actions event handler
     */
    OnMouseDown?: IActionsEventHandler;
    /**
     * On mouse up actions event handler
     */
    OnMouseUp?: IActionsEventHandler;
}
