import { IDataSourceFieldDefinition } from './data-source/IDataSource';
import { IFieldData } from './IFieldData';
/**
 * Information required for a lookup.
 */ export interface ILookupInformation {
    /**
     * The keys and start values that can be used for the lookup
     */
    KeyAssignments?: IKeyAssigment[];
    /**
     * The name of the field returned by the lookup
     */
    ReturnField: string;
    /**
     * The data model filename of the used data model for the lookup
     */
    UsedDatamodelFileName: string;
    /**
     * The data filename of the external database
     */
    ExternalDataFileName: string;
    /**
     * A filtered list of shown field names
     */
    FieldFilter: string[];
    /**
     * Applied record filter
     */
    RecordFilter: string;
    /**
     * Flag indicating whether the user should be allowed to clear a record, or not.
     */
    AllowClearRecord: boolean;
    /**
     * Optional FieldDefinitions
     */
    FieldDefs?: IDataSourceFieldDefinition[];
}
/**
 * A key and start value that can be used for the lookup
 */
export interface IKeyAssigment {
    /**
     * Name of the key
     */
    KeyName: string;
    /**
     * The computed start field names and values
     */
    StartValueFields: IFieldData[];
}
