import { Observable, Subscription } from 'rxjs';
import { ITimerControl } from '../controls/ITimerControl';
import { ITimerElement } from '../richText/elements/ITimerElement';
/**
 * The timer reference type describes a reference to either a timer control or a timer text element
 */
type ITimerReference = ITimerControl | ITimerElement;
/**
 * The timer interface provides an object definition for storing the information needed by the timer services to manage timers and handle ticks.
 */
export interface ITimer {
    /**
     * A reference to either a timer control or a timer text element
     */
    reference: ITimerReference;
    /**
     * The timer observable that starts an interval after a specified delay
     */
    observable?: Observable<number>;
    /**
     * Represents the disposable resource for the execution of the Observable.
     */
    subscription?: Subscription;
}
export {};
