import { IColor } from '../models/IColor';
/**
 * The color service provides functionality for converting a color object into a css style string.
 */
export interface IColorService {
    /**
     * Helper function that checks whether a color is relevant (not transparent)
     * @param {IColor} colorObj rgba color object
     * @returns {boolean} true if any of the color object's properties are set to a value higher than 0, otherwise false
     */
    hasColor: (colorObj: IColor) => boolean;
    /**
     * Generates an RGB color string based on the given color object
     * @param {IColor} colorObj
     * @param {Optional<string>} property (optional) When provided this property is prefixed to the color string
     * @returns {string} RGB color string
     */
    generateRGBColorForProperty: (colorObj: IColor, property?: string) => string;
    /**
     * Generates an RGBA color string based on the given color object
     * @param {IColor} colorObj
     * @param {Optional<string>} property (optional) When provided this property is prefixed to the color string
     * @returns {string} RGBA color string
     */
    generateRGBAColorForProperty: (colorObj: IColor, property?: string) => string;
    /**
     * Generates an RGBA color string based on the given color object
     * @param {IColor} colorObj
     * @returns {string} RGBA color string
     */
    generateRGBAColor: (colorObj: IColor) => string;
}
