import { IMediaUrls } from '../models/server/IMediaUrls';
/**
 * The media service provides functionality for retrieving media urls and making them accessible.
 */
export interface IMediaService {
    /**
     * Media URLs property
     */
    mediaUrls: IMediaUrls;
    /**
     * Retrieves the url for a specific audio file
     * @param {string} fileName
     * @returns {Nullable<string>} url for a audio file
     */
    getMediaUrlForAudio: (fileName: string) => Nullable<string>;
    /**
     * Retrieves the url for a specific document file
     * @param {string} fileName
     * @returns {Nullable<string>} url for a audio file
     */
    getMediaUrlForDocument: (fileName: string) => Nullable<string>;
    /**
     * Retrieves the url for a specific image file
     * @param {string} fileName
     * @returns {Nullable<string>} url for an audio file
     */
    getMediaUrlForImage: (fileName: string) => Nullable<string>;
    /**
     * Retrieves the url for a specific video file
     * @param {string} fileName
     * @returns {Nullable<string>} url for a video file
     */
    getMediaUrlForVideo: (fileName: string) => Nullable<string>;
    /**
     * Retrieves the url for a media file by type and file name
     * @param {string} mediaType
     * @param {string} key
     * @returns {Nullable<string>} url for a media file or null
     */
    getMediaUrl: (mediaType: string, key: string) => Nullable<string>;
}
